@@ -1,23 +1,22 @@
 // This may look like C code, but it is really -*- C++ -*-
 //
-// Copyright Bob Friesenhahn, 1999, 2000, 2001
+// Copyright Bob Friesenhahn, 1999, 2000, 2001, 2002, 2003
 //
 // Geometry implementation
 //
 
-#define MAGICK_IMPLEMENTATION
+#define MAGICKCORE_IMPLEMENTATION  1
 
+#include "Magick++/Include.h"
 #include <string>
-#include <iostream>
-#include <iomanip>
-#include <strstream>
-
 #include <ctype.h> // for isdigit
 
 using namespace std;
 
 #include "Magick++/Geometry.h"
-#include "Magick++/Functions.h"
+#include "Magick++/Exception.h"
+
+#define AbsoluteValue(x)  ((x) < 0 ? -(x) : (x))
 
 int Magick::operator == ( const Magick::Geometry& left_,
 			  const Magick::Geometry& right_ )
@@ -88,7 +87,7 @@ Magick::Geometry::Geometry ( unsigned int width_,
 }
 
 // Assignment from C++ string
-Magick::Geometry::Geometry ( const std::string geometry_ )
+Magick::Geometry::Geometry ( const std::string &geometry_ )
   : _width( 0 ),
     _height( 0 ),
     _xOff( 0 ),
@@ -102,12 +101,11 @@ Magick::Geometry::Geometry ( const std::string geometry_ )
     _less( false )
 {
   *this = geometry_; // Use assignment operator
-
 }
 
 
 // Assignment from C character string
-Magick::Geometry::Geometry ( const char * geometry_ )
+Magick::Geometry::Geometry ( const char *geometry_ )
   : _width( 0 ),
     _height( 0 ),
     _xOff( 0 ),
@@ -124,7 +122,7 @@ Magick::Geometry::Geometry ( const char * geometry_ )
 }
 
 // Copy constructor
-Magick::Geometry::Geometry ( const Geometry & geometry_ )
+Magick::Geometry::Geometry ( const Geometry &geometry_ )
   :  _width( geometry_._width ),
      _height( geometry_._height ),
      _xOff( geometry_._xOff ),
@@ -160,7 +158,7 @@ Magick::Geometry::Geometry ( void )
   // Nothing to do
 }
 
-Magick::Geometry Magick::Geometry::operator = ( const Geometry& geometry_ )
+Magick::Geometry& Magick::Geometry::operator = ( const Geometry& geometry_ )
 {
   // If not being set to ourself
   if ( this != &geometry_ )
@@ -190,26 +188,33 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
   // If argument does not start with digit, presume that it is a
   // page-size specification that needs to be converted to an
   // equivalent geometry specification using PostscriptGeometry()
-  strcpy(geom,geometry_.c_str());
+  (void) CopyMagickString(geom,geometry_.c_str(),MaxTextExtent);
   if ( geom[0] != '-' &&
        geom[0] != '+' &&
        geom[0] != 'x' &&
        !isdigit(static_cast<int>(geom[0])))
     {
       char *pageptr = GetPageGeometry( geom );
-      if ( pageptr )
-	{
-	  strcpy(geom,pageptr);
-	  LiberateMemory( (void **) &pageptr );
-	}
+      if ( pageptr != 0 )
+        {
+          (void) CopyMagickString(geom,pageptr,MaxTextExtent);
+          pageptr=(char *) RelinquishMagickMemory( pageptr );
+        }
     }
 
   long x = 0;
   long y = 0;
   unsigned long width_val = 0;
   unsigned long height_val = 0;
-  int flags = GetGeometry ( geom,
-			    &x, &y, &width_val, &height_val );
+  int flags = GetGeometry (geom, &x, &y, &width_val, &height_val );
+
+  if (flags == NoValue)
+    {
+      // Total failure!
+      *this=Geometry();
+      isValid( false );
+      return *this;
+    }
 
   if ( ( flags & WidthValue ) != 0 )
     {
@@ -218,17 +223,20 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
     }
 
   if ( ( flags & HeightValue ) != 0 )
-    _height = height_val;
+    {
+      _height = height_val;
+      isValid( true );
+    }
 
   if ( ( flags & XValue ) != 0 )
     {
-      _xOff = ::abs(x);
+      _xOff = static_cast<unsigned int>(AbsoluteValue(x));
       isValid( true );
     }
 
   if ( ( flags & YValue ) != 0 )
     {
-      _yOff = ::abs(y);
+      _yOff = static_cast<unsigned int>(AbsoluteValue(y));
       isValid( true );
     }
 
@@ -264,65 +272,67 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
 // Return geometry string
 Magick::Geometry::operator std::string() const
 {
+  if (!isValid())
+    {
+      throwExceptionExplicit( OptionError, "Invalid geometry argument" );
+    }
+
+  string geometry;
   char buffer[32];
-  ostrstream geomStr( buffer, sizeof( buffer ) - 1 );
 
   if ( _width )
-    geomStr << _width;
+    {
+      FormatString( buffer, "%u", _width );
+      geometry += buffer;
+    }
 
-  if ( _width && _height )
-    geomStr << "x"
-	    << _height;
+  if ( _height )
+    {
+      FormatString( buffer, "%u",  _height);
+      geometry += 'x';
+      geometry +=  buffer;
+    }
 
   if ( _xOff || _yOff )
     {
       if ( _xNegative )
-	geomStr << "-";
+        geometry += '-';
       else
-	geomStr << "+";
-      geomStr << _xOff;
+        geometry += '+';
+
+      FormatString( buffer, "%u", _xOff);
+      geometry += buffer;
 
       if ( _yNegative )
-	geomStr << "-";
+        geometry += '-';
       else
-	geomStr << "+";
-      geomStr << _yOff;
+        geometry += '+';
+
+      FormatString( buffer, "%u", _yOff);
+      geometry += buffer;
     }
 
   if ( _percent )
-    geomStr << "%";
-
+    geometry += '%';
+  
   if ( _aspect )
-    geomStr << "!";
+    geometry += '!';
 
   if ( _greater )
-    geomStr << ">";
+    geometry += '>';
 
   if ( _less )
-    geomStr << "<";
+    geometry += '<';
 
-  geomStr << ends;
-
-  std::string geometry = buffer;
   return geometry;
 }
 
-// print object to a stream
-ostream& operator<<(ostream& stream_, const Magick::Geometry& geometry_)
-{
-  std::string geomStr( geometry_ );
-  stream_ << geomStr;
-  return stream_;
-}
-
 // Construct from RectangleInfo
-#undef abs
-#define abs(x) ((x) >= 0 ? (x) : -(x))
 Magick::Geometry::Geometry ( const MagickLib::RectangleInfo &rectangle_ )
-  : _width(static_cast<unsigned int>(abs(rectangle_.width))),
-    _height(static_cast<unsigned int>(abs(rectangle_.height))),
-    _xOff(static_cast<unsigned int>(abs(rectangle_.x))),
-    _yOff(static_cast<unsigned int>(abs(rectangle_.y))),
+  : _width(static_cast<unsigned int>(rectangle_.width)),
+    _height(static_cast<unsigned int>(rectangle_.height)),
+    _xOff(static_cast<unsigned int>(AbsoluteValue(rectangle_.x))),
+    _yOff(static_cast<unsigned int>(AbsoluteValue(rectangle_.y))),
     _xNegative(rectangle_.x < 0 ? true : false),
     _yNegative(rectangle_.y < 0 ? true : false),
     _isValid(true),
@@ -339,7 +349,7 @@ Magick::Geometry::operator MagickLib::RectangleInfo() const
   RectangleInfo rectangle;
   rectangle.width = _width;
   rectangle.height = _height;
-  _xNegative ? rectangle.x = -_xOff : rectangle.x = _xOff;
-  _yNegative ? rectangle.y = -_yOff : rectangle.y = _yOff;
+  _xNegative ? rectangle.x = static_cast<long>(0-_xOff) : rectangle.x = static_cast<long>(_xOff);
+  _yNegative ? rectangle.y = static_cast<long>(0-_yOff) : rectangle.y = static_cast<long>(_yOff);
   return rectangle;
 }
