@@ -144,6 +144,15 @@ Magick::Color Magick::Options::boxColor ( void ) const
   return Magick::Color( _drawInfo->undercolor );
 }
 
+void Magick::Options::colorspaceType ( Magick::ColorspaceType colorspace_ )
+{
+  _imageInfo->colorspace = colorspace_;
+}
+Magick::ColorspaceType Magick::Options::colorspaceType ( void ) const
+{
+  return static_cast<Magick::ColorspaceType>(_imageInfo->colorspace);
+}
+
 void Magick::Options::compressType ( CompressionType compressType_ )
 {
   _imageInfo->compression = compressType_;
@@ -232,12 +241,13 @@ std::string Magick::Options::fileName ( void ) const
 void Magick::Options::fillColor ( const Magick::Color &fillColor_ )
 {
   _drawInfo->fill = fillColor_;
+  if (fillColor_ == Magick::Color())
+    fillPattern((const MagickLib::Image*) NULL);
 }
 Magick::Color Magick::Options::fillColor ( void ) const
 {
   return _drawInfo->fill;
 }
-
 // Pattern image to use when filling objects
 void Magick::Options::fillPattern ( const MagickLib::Image *fillPattern_ )
 {
@@ -246,7 +256,6 @@ void Magick::Options::fillPattern ( const MagickLib::Image *fillPattern_ )
       DestroyImageList( _drawInfo->fill_pattern );
       _drawInfo->fill_pattern = 0;
     }
-
   if ( fillPattern_ )
     {
       ExceptionInfo exceptionInfo;
@@ -258,6 +267,7 @@ void Magick::Options::fillPattern ( const MagickLib::Image *fillPattern_ )
 		    static_cast<MagickBooleanType>(MagickTrue),
 		    &exceptionInfo );
       throwException( exceptionInfo );
+  DestroyExceptionInfo( &exceptionInfo );
     }
 }
 const MagickLib::Image* Magick::Options::fillPattern ( void  ) const
@@ -314,6 +324,7 @@ std::string Magick::Options::format ( void ) const
   GetExceptionInfo(&exception);
   if ( *_imageInfo->magick != '\0' )
     magick_info = GetMagickInfo( _imageInfo->magick , &exception);
+  DestroyExceptionInfo(&exception);
   
   if (( magick_info != 0 ) && 
       ( *magick_info->description != '\0' ))
@@ -342,6 +353,7 @@ void Magick::Options::magick ( const std::string &magick_ )
     throwExceptionExplicit( OptionWarning,
 			    "Unrecognized image format",
 			    magick_.c_str() );
+  DestroyExceptionInfo(&exception);
 }
 std::string Magick::Options::magick ( void ) const
 {
@@ -573,6 +585,7 @@ void Magick::Options::strokePattern ( const MagickLib::Image *strokePattern_ )
 		    MagickTrue,
 		    &exceptionInfo );
       throwException( exceptionInfo );
+  DestroyExceptionInfo( &exceptionInfo );
     }
 }
 const MagickLib::Image* Magick::Options::strokePattern ( void  ) const
