@@ -42,7 +42,6 @@
 */
 #include <setjmp.h>
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color-private.h"
@@ -60,6 +59,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/profile.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -166,7 +166,7 @@ typedef struct _BMPInfo
     important_colors;
 } BMPInfo;
 
-typedef struct _StreamInfo
+typedef struct _AVIStreamInfo
 {
   char
     data_type[5],
@@ -183,7 +183,7 @@ typedef struct _StreamInfo
     buffer_size,
     quality,
     sample_size;
-} StreamInfo;
+} AVIStreamInfo;
 
 /*
   MJPEG Information from Microsoft SDK
@@ -416,7 +416,7 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
   for (p=comment; i-- >= 0; p++)
     *p=(char) GetCharacter(jpeg_info);
   *p='\0';
-  (void) SetImageAttribute(image,"Comment",comment);
+  (void) SetImageProperty(image,"Comment",comment);
   comment=(char *) RelinquishMagickMemory(comment);
   return(MagickTrue);
 }
@@ -456,7 +456,7 @@ static boolean ReadICCProfile(j_decompress_ptr jpeg_info)
   length-=2;
   if (length <= 14)
     {
-      while (length-- >= 0)
+      while (length-- > 0)
         (void) GetCharacter(jpeg_info);
       return(MagickTrue);
     }
@@ -999,6 +999,9 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
   AVIInfo
     avi_info;
 
+  AVIStreamInfo
+    stream_info;
+
   BMPInfo
     bmp_info;
 
@@ -1042,9 +1045,6 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ssize_t
     count;
 
-  StreamInfo
-    stream_info;
-
   unsigned char
     *pixels;
 
@@ -1055,8 +1055,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     number_colors;
 
 #if defined(HasJPEG)
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   ErrorManager
     error_manager;
@@ -1182,23 +1182,21 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               image->y_resolution=(double) jpeg_info.Y_density;
               units=(unsigned long) jpeg_info.density_unit;
             }
-            attribute=GetImageAttribute(image,"EXIF:XResolution");
-            if ((attribute != (const ImageAttribute *) NULL) &&
-              (attribute->value != (char *) NULL))
+            value=GetImageProperty(image,"EXIF:XResolution");
+            if (value != (char *) NULL)
             {
-              (void) ParseGeometry(attribute->value,&geometry_info);
+              (void) ParseGeometry(value,&geometry_info);
               if (geometry_info.sigma != 0)
                 image->x_resolution=geometry_info.rho/geometry_info.sigma;
-              (void) SetImageAttribute(image,"EXIF:XResolution",(char *) NULL);
+              (void) SetImageProperty(image,"EXIF:XResolution",(char *) NULL);
             }
-            attribute=GetImageAttribute(image,"EXIF:YResolution");
-            if ((attribute != (const ImageAttribute *) NULL) &&
-              (attribute->value != (char *) NULL))
+            value=GetImageProperty(image,"EXIF:YResolution");
+            if (value != (char *) NULL)
             {
-              (void) ParseGeometry(attribute->value,&geometry_info);
+              (void) ParseGeometry(value,&geometry_info);
               if (geometry_info.sigma != 0)
                 image->y_resolution=geometry_info.rho/geometry_info.sigma;
-              (void) SetImageAttribute(image,"EXIF:YResolution",(char *) NULL);
+              (void) SetImageProperty(image,"EXIF:YResolution",(char *) NULL);
             }
             if (units == 1)
               image->units=PixelsPerInchResolution;
@@ -1592,7 +1590,7 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Consume Buffer.
             */
-            chunk_size = ((SourceManager *) jpeg_info.src)->source_length;
+            chunk_size = (unsigned long) ((SourceManager *) jpeg_info.src)->source_length;
             for ( ; chunk_size != 0; chunk_size--)
               (void) ReadBlobByte(image);
             /*
@@ -2105,8 +2103,8 @@ static Image *ReadAVIImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterAVIImage() adds attributes for the AVI image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterAVIImage() adds properties for the AVI image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
