@@ -82,7 +82,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -104,9 +103,7 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
     status;
 
   register char
-    *p,
-    *q,
-    *s;
+    *p;
 
   register long
     i;
@@ -117,9 +114,6 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   TypeMetric
     metrics;
 
-  unsigned long
-    width;
-
   /*
     Initialize Image structure.
   */
@@ -147,12 +141,6 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
   /*
     Format caption.
   */
-  draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
-  draw_info->text=AcquireString(caption);
-  gravity=GetImageOption(image_info,"gravity");
-  if (gravity != (char *) NULL)
-    draw_info->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
-      MagickFalse,gravity);
   length=strlen(caption)+1;
   for (p=caption; *p != '\0'; p++)
   {
@@ -164,50 +152,70 @@ static Image *ReadCAPTIONImage(const ImageInfo *image_info,
         *p='\n';
       }
   }
-  q=draw_info->text;
-  s=(char *) NULL;
-  for (p=caption; *p != '\0'; p++)
-  {
-    if (isspace((int) ((unsigned char) *p)) != 0)
-      s=p;
-    *q++=(*p);
-    *q='\0';
-    status=GetTypeMetrics(image,draw_info,&metrics);
-    if (status == MagickFalse)
-      ThrowReaderException(TypeError,"UnableToGetTypeMetrics");
-    width=(unsigned long) (metrics.width+metrics.max_advance+0.5);
-    if (*p != '\n')
-      if (width < image->columns)
-        continue;
-    if (s == (char *) NULL)
+  draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
+  draw_info->text=AcquireString(caption);
+  gravity=GetImageOption(image_info,"gravity");
+  if (gravity != (char *) NULL)
+    draw_info->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
+      MagickFalse,gravity);
+  if ((image->rows != 0) && (image_info->pointsize == 0.0))
+    {
+      char
+        *text;
+
+      /*
+        Scale text to fit bounding box.
+      */
+      for ( ; ; )
       {
-        s=p;
-        while ((isspace((int) ((unsigned char) *s)) == 0) && (*s != '\0'))
-          s++;
-    	}
-    if (*s != '\0')
-      {
-        *s='\n';
-        p=s+1;
-        s=(char *) NULL;
+        text=AcquireString(caption);
+        i=FormatMagickCaption(image,draw_info,text,&metrics);
+        (void) CloneString(&draw_info->text,text);
+        text=DestroyString(text);
+        (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
+          -metrics.bounds.x1,metrics.ascent);
+        if (draw_info->gravity == UndefinedGravity)
+          (void) CloneString(&draw_info->geometry,AcquireString(geometry));
+        status=GetMultilineTypeMetrics(image,draw_info,&metrics);
+        if (((unsigned long) (metrics.width+0.5) > image->columns) ||
+            ((unsigned long) (metrics.height+0.5) > image->rows))
+          break;
+        draw_info->pointsize*=2.0;
       }
-    q=draw_info->text;
-  }
-  i=0;
-  for (p=caption; *p != '\0'; p++)
-    if (*p == '\n')
-      i++;
+      draw_info->pointsize/=2.0;
+      for ( ; ; )
+      {
+        text=AcquireString(caption);
+        i=FormatMagickCaption(image,draw_info,text,&metrics);
+        (void) CloneString(&draw_info->text,text);
+        text=DestroyString(text);
+        (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
+          -metrics.bounds.x1,metrics.ascent);
+        if (draw_info->gravity == UndefinedGravity)
+          (void) CloneString(&draw_info->geometry,AcquireString(geometry));
+        status=GetMultilineTypeMetrics(image,draw_info,&metrics);
+        if (((unsigned long) (metrics.width+0.5) > image->columns) ||
+            ((unsigned long) (metrics.height+0.5) > image->rows))
+          break;
+        draw_info->pointsize++;
+      }
+      draw_info->pointsize--;
+    }
+  i=FormatMagickCaption(image,draw_info,caption,&metrics);
   if (image->rows == 0)
-    image->rows=(unsigned long) ((i+1)*(metrics.ascent-metrics.descent));
-  SetImageBackgroundColor(image);
+    image->rows=(unsigned long) ((i+1)*(metrics.ascent-metrics.descent)+0.5);
+  if (image->rows == 0)
+    image->rows=(unsigned long) ((i+1)*draw_info->pointsize+0.5);
+  (void) SetImageBackgroundColor(image);
   /*
     Draw caption.
   */
-  (void) CopyMagickString(draw_info->text,caption,length);
-  (void) FormatMagickString(geometry,MaxTextExtent,"+%g+%g",
-    metrics.max_advance/4.0,metrics.ascent);
+  (void) CloneString(&draw_info->text,caption);
+  status=GetMultilineTypeMetrics(image,draw_info,&metrics);
+  (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
+    -metrics.bounds.x1,metrics.ascent);
   if (draw_info->gravity == UndefinedGravity)
-    draw_info->geometry=AcquireString(geometry);
+    (void) CloneString(&draw_info->geometry,AcquireString(geometry));
   (void) AnnotateImage(image,draw_info);
   draw_info=DestroyDrawInfo(draw_info);
   caption=(char *) RelinquishMagickMemory(caption);
