@@ -16,7 +16,7 @@
 %                                April 2004                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -39,9 +39,9 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/constitute.h"
 #include "magick/exception.h"
@@ -52,7 +52,9 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/property.h"
 #include "magick/quantize.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -74,8 +76,8 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterCIPImage() adds attributes for the CIP IP phone image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterCIPImage() adds properties for the CIP IP phone image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -94,8 +96,8 @@ ModuleExport void RegisterCIPImage(void)
   entry=SetMagickInfo("CIP");
   entry->encoder=(EncoderHandler *) WriteCIPImage;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("Cisco IP phone image format");
-  entry->module=AcquireString("CIP");
+  entry->description=ConstantString("Cisco IP phone image format");
+  entry->module=ConstantString("CIP");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -154,8 +156,8 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   char
     buffer[MaxTextExtent];
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   long
     y;
@@ -181,15 +183,14 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
   (void) WriteBlobString(image,"<CiscoIPPhoneImage>\n");
-  attribute=GetImageAttribute(image,"Label");
-  if (attribute != (const ImageAttribute *) NULL)
-    (void) FormatMagickString(buffer,MaxTextExtent,"<Title>%s</Title>\n",
-      attribute->value);
+  value=GetImageProperty(image,"Label");
+  if (value != (const char *) NULL)
+    (void) FormatMagickString(buffer,MaxTextExtent,"<Title>%s</Title>\n",value);
   else
     {
       char
@@ -215,7 +216,8 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
   (void) FormatMagickString(buffer,MaxTextExtent,"<Depth>2</Depth>\n");
   (void) WriteBlobString(image,buffer);
   (void) WriteBlobString(image,"<Data>");
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
@@ -224,10 +226,10 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
     for (x=0; x < ((long) image->columns-3); x+=4)
     {
       byte=(unsigned char)
-        (((4*PixelIntensityToQuantum(p+3)/MaxRGB) & 0x03) << 6) |
-         (((4*PixelIntensityToQuantum(p+2)/MaxRGB) & 0x03) << 4) |
-         (((4*PixelIntensityToQuantum(p+1)/MaxRGB) & 0x03) << 2) |
-         (((4*PixelIntensityToQuantum(p+0)/MaxRGB) & 0x03) << 0);
+        (((4*PixelIntensityToQuantum(p+3)/QuantumRange) & 0x03) << 6) |
+         (((4*PixelIntensityToQuantum(p+2)/QuantumRange) & 0x03) << 4) |
+         (((4*PixelIntensityToQuantum(p+1)/QuantumRange) & 0x03) << 2) |
+         (((4*PixelIntensityToQuantum(p+0)/QuantumRange) & 0x03) << 0);
       (void) FormatMagickString(buffer,MaxTextExtent,"%02x",byte);
       (void) WriteBlobString(image,buffer);
       p+=4;
@@ -236,10 +238,10 @@ static MagickBooleanType WriteCIPImage(const ImageInfo *image_info,Image *image)
       {
         i=(long) image->columns % 4;
         byte=(unsigned char)
-          ((((4*PixelIntensityToQuantum(p+Min(i,3))/MaxRGB) & 0x03) << 6) |
-           (((4*PixelIntensityToQuantum(p+Min(i,2))/MaxRGB) & 0x03) << 4) |
-           (((4*PixelIntensityToQuantum(p+Min(i,1))/MaxRGB) & 0x03) << 2) |
-           (((4*PixelIntensityToQuantum(p+Min(i,0))/MaxRGB) & 0x03) << 0));
+          ((((4*PixelIntensityToQuantum(p+Min(i,3))/QuantumRange) & 0x03) << 6) |
+           (((4*PixelIntensityToQuantum(p+Min(i,2))/QuantumRange) & 0x03) << 4) |
+           (((4*PixelIntensityToQuantum(p+Min(i,1))/QuantumRange) & 0x03) << 2) |
+           (((4*PixelIntensityToQuantum(p+Min(i,0))/QuantumRange) & 0x03) << 0));
         (void) FormatMagickString(buffer,MaxTextExtent,"%02x",~byte);
         (void) WriteBlobString(image,buffer);
       }
