@@ -141,9 +141,9 @@ ModuleExport void UnregisterCLIPImage(void)
 %
 %    o image:  The image.
 %
-%
 */
-static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,Image *image)
+static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,
+  Image *image)
 {
   Image
     *clip_image;
@@ -157,8 +157,7 @@ static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,Image *image
   if (clip_image == (Image *) NULL)
     return(MagickFalse);
   (void) SetImageType(clip_image,TrueColorType);
-  (void) FormatMagickString(clip_image->filename,MaxTextExtent,
-    "MIFF:%s",image->filename);
+  (void) CopyMagickString(clip_image->filename,image->filename,MaxTextExtent);
   status=WriteImage(image_info,clip_image);
   clip_image=DestroyImage(clip_image);
   return(status);
