@@ -59,8 +59,10 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/utility.h"
 
 typedef struct
 {
@@ -256,7 +258,7 @@ static int GetCutColors(Image *image)
   for (y=0; y < (long) image->rows; y++)
   {
     q=GetImagePixels(image,0,y,image->columns,1);
-    for (x=(long) image->columns-1; x >= 0; x--)
+    for (x=0; x < (long) image->columns; x++)
     {
       if (intensity < q->red)
         intensity=q->red;
@@ -269,7 +271,7 @@ static int GetCutColors(Image *image)
     return(2);
   if (intensity < ScaleCharToQuantum(16))
     return(16);
-  return(intensity);
+  return((int) intensity);
 }
 
 /*
@@ -323,7 +325,8 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -397,14 +400,16 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
     }
 
-  (void) strcpy(clone_info->filename+i,".PAL");
-  if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL)
+  (void) CopyMagickString(clone_info->filename+i,".PAL",(size_t)
+    (MaxTextExtent-i));
+  if((clone_info->file=MagickOpenStream(clone_info->filename,"rb"))==NULL)
     {
-      (void) strcpy(clone_info->filename+i,".pal");
-      if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL)
+      (void) CopyMagickString(clone_info->filename+i,".pal",(size_t)
+        (MaxTextExtent-i));
+      if((clone_info->file=MagickOpenStream(clone_info->filename,"rb"))==NULL)
         {
           clone_info->filename[i]='\0';
-          if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL)
+          if((clone_info->file=MagickOpenStream(clone_info->filename,"rb"))==NULL)
             {
               clone_info=DestroyImageInfo(clone_info);
               clone_info=NULL;
@@ -444,9 +449,9 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image->colors=PalHeader.MaxIndex+1;
       if (AllocateImageColormap(image,image->colors) == MagickFalse) goto NoMemory;
 
-      if(PalHeader.MaxRed==0) PalHeader.MaxRed=MaxRGB;  /*avoid division by 0*/
-      if(PalHeader.MaxGreen==0) PalHeader.MaxGreen=MaxRGB;
-      if(PalHeader.MaxBlue==0) PalHeader.MaxBlue=MaxRGB;
+      if(PalHeader.MaxRed==0) PalHeader.MaxRed=QuantumRange;  /*avoid division by 0*/
+      if(PalHeader.MaxGreen==0) PalHeader.MaxGreen=QuantumRange;
+      if(PalHeader.MaxBlue==0) PalHeader.MaxBlue=QuantumRange;
 
       for(i=0;i<=(int) PalHeader.MaxIndex;i++)
         {      /*this may be wrong- I don't know why is palette such strange*/
@@ -457,22 +462,22 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
               (void) SeekBlob(palette,j,SEEK_SET);
             }
           image->colormap[i].red=ReadBlobLSBShort(palette);
-          if(MaxRGB!=(Quantum) PalHeader.MaxRed)
+          if(QuantumRange!=(Quantum) PalHeader.MaxRed)
             {
               image->colormap[i].red=(Quantum)
-                (((double)image->colormap[i].red*MaxRGB+(PalHeader.MaxRed>>1))/PalHeader.MaxRed+0.5);
+                (((double)image->colormap[i].red*QuantumRange+(PalHeader.MaxRed>>1))/PalHeader.MaxRed+0.5);
             }
           image->colormap[i].green=ReadBlobLSBShort(palette);
-          if(MaxRGB!=(Quantum) PalHeader.MaxGreen)
+          if(QuantumRange!=(Quantum) PalHeader.MaxGreen)
             {
               image->colormap[i].green=(Quantum)
-                (((double)image->colormap[i].green*MaxRGB+(PalHeader.MaxGreen>>1))/PalHeader.MaxGreen+0.5);
+                (((double)image->colormap[i].green*QuantumRange+(PalHeader.MaxGreen>>1))/PalHeader.MaxGreen+0.5);
             }
           image->colormap[i].blue=ReadBlobLSBShort(palette);
-          if(MaxRGB!=(Quantum) PalHeader.MaxBlue)
+          if(QuantumRange!=(Quantum) PalHeader.MaxBlue)
             {
               image->colormap[i].blue=(Quantum)
-                (((double)image->colormap[i].blue*MaxRGB+(PalHeader.MaxBlue>>1))/PalHeader.MaxBlue+0.5);
+                (((double)image->colormap[i].blue*QuantumRange+(PalHeader.MaxBlue>>1))/PalHeader.MaxBlue+0.5);
             }
 
         }
@@ -493,9 +498,9 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
       for (i=0; i < (long)image->colors; i++)
         {
-          image->colormap[i].red=ScaleCharToQuantum(i);
-          image->colormap[i].green=ScaleCharToQuantum(i);
-          image->colormap[i].blue=ScaleCharToQuantum(i);
+          image->colormap[i].red=ScaleCharToQuantum((unsigned char) i);
+          image->colormap[i].green=ScaleCharToQuantum((unsigned char) i);
+          image->colormap[i].blue=ScaleCharToQuantum((unsigned char) i);
         }
     }
 
@@ -560,13 +565,13 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 {
                   register Quantum
                     sample;
-                  sample=ScaleCharToQuantum(i);
+                  sample=ScaleCharToQuantum((unsigned char) i);
                   if(image->colormap[i].red!=sample) goto Finish;
                   if(image->colormap[i].green!=sample) goto Finish;
                   if(image->colormap[i].blue!=sample) goto Finish;
                 }
 
-              image->colormap[1].red=image->colormap[1].green=image->colormap[1].blue=MaxRGB;
+              image->colormap[1].red=image->colormap[1].green=image->colormap[1].blue=QuantumRange;
               for (i=0; i < (long)image->rows; i++)
                 {
                   q=SetImagePixels(image,0,i,image->columns,1);
@@ -574,7 +579,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     {
                       if(q->red==ScaleCharToQuantum(1))
                         {
-                          q->red=q->green=q->blue=MaxRGB;
+                          q->red=q->green=q->blue=QuantumRange;
                         }
                       q++;
                     }
@@ -629,8 +634,8 @@ ModuleExport void RegisterCUTImage(void)
   entry=SetMagickInfo("CUT");
   entry->decoder=(DecoderHandler *) ReadCUTImage;
   entry->seekable_stream=MagickTrue;
-  entry->description=AcquireString("DR Halo");
-  entry->module=AcquireString("CUT");
+  entry->description=ConstantString("DR Halo");
+  entry->module=ConstantString("CUT");
   (void) RegisterMagickInfo(entry);
 }
 
