@@ -186,7 +186,7 @@ static MagickBooleanType DecodeImage(Image *image,
       break;
     if (count != 0)
       {
-        count=Min((unsigned long) count,(size_t) (q-p));
+        count=(int) Min((unsigned long) count,(size_t) (q-p));
         /*
           Encoded mode.
         */
@@ -239,7 +239,7 @@ static MagickBooleanType DecodeImage(Image *image,
             /*
               Absolute mode.
             */
-            count=Min((unsigned long) count,(size_t) (q-p));
+            count=(int) Min((unsigned long) count,(size_t) (q-p));
             if (compression == BI_RLE8)
               for (i=0; i < count; i++)
                 *p++=(unsigned char) ReadBlobByte(image);
@@ -534,8 +534,8 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       dib_info.blue_mask=ReadBlobLSBLong(image);
     }
   image->matte=dib_info.bits_per_pixel == 32 ? MagickTrue : MagickFalse;
-  image->columns=dib_info.width;
-  image->rows=AbsoluteValue(dib_info.height);
+  image->columns=(unsigned long) dib_info.width;
+  image->rows=(unsigned long) AbsoluteValue(dib_info.height);
   image->depth=8;
   if ((dib_info.number_colors != 0) || (dib_info.bits_per_pixel < 16))
     {
@@ -623,8 +623,8 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Initialize image structure.
   */
   image->units=PixelsPerCentimeterResolution;
-  image->x_resolution=dib_info.x_pixels/100.0;
-  image->y_resolution=dib_info.y_pixels/100.0;
+  image->x_resolution=(double) dib_info.x_pixels/100.0;
+  image->y_resolution=(double) dib_info.y_pixels/100.0;
   /*
     Convert DIB raster image to pixel packets.
   */
@@ -646,7 +646,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           for (bit=0; bit < 8; bit++)
           {
-            index=((*p) & (0x80 >> bit) ? 0x01 : 0x00);
+            index=(IndexPacket) ((*p) & (0x80 >> bit) ? 0x01 : 0x00);
             indexes[x+bit]=index;
             *q++=image->colormap[index];
           }
@@ -656,7 +656,7 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             for (bit=0; bit < (long) (image->columns % 8); bit++)
             {
-              index=((*p) & (0x80 >> bit) ? 0x01 : 0x00);
+              index=(IndexPacket) ((*p) & (0x80 >> bit) ? 0x01 : 0x00);
               indexes[x+bit]=index;
               *q++=image->colormap[index];
             }
@@ -666,9 +666,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(image->rows-y-1,image->rows) != MagickFalse))
+              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
             {
-              status=image->progress_monitor(LoadImageTag,image->rows-y-1,
+              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
                 image->rows,image->client_data);
               if (status == MagickFalse)
                 break;
@@ -709,9 +709,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(image->rows-y-1,image->rows) != MagickFalse))
+              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
             {
-              status=image->progress_monitor(LoadImageTag,image->rows-y-1,
+              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
                 image->rows,image->client_data);
               if (status == MagickFalse)
                 break;
@@ -746,9 +746,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(image->rows-y-1,image->rows) != MagickFalse))
+              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
             {
-              status=image->progress_monitor(LoadImageTag,image->rows-y-1,
+              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
                 image->rows,image->client_data);
               if (status == MagickFalse)
                 break;
@@ -779,15 +779,21 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           word|=(*p++ << 8);
           if (dib_info.red_mask == 0)
             {
-              q->red=ScaleCharToQuantum(ScaleColor5to8((word >> 10) & 0x1f));
-              q->green=ScaleCharToQuantum(ScaleColor5to8((word >> 5) & 0x1f));
-              q->blue=ScaleCharToQuantum(ScaleColor5to8(word & 0x1f));
+              q->red=ScaleCharToQuantum(ScaleColor5to8((unsigned char)
+                ((word >> 10) & 0x1f)));
+              q->green=ScaleCharToQuantum(ScaleColor5to8((unsigned char)
+                ((word >> 5) & 0x1f)));
+              q->blue=ScaleCharToQuantum(ScaleColor5to8((unsigned char)
+                (word & 0x1f)));
             }
           else
             {
-              q->red=ScaleCharToQuantum(ScaleColor5to8((word >> 11) & 0x1f));
-              q->green=ScaleCharToQuantum(ScaleColor6to8((word >> 5) & 0x3f));
-              q->blue=ScaleCharToQuantum(ScaleColor5to8(word & 0x1f));
+              q->red=ScaleCharToQuantum(ScaleColor5to8((unsigned char)
+                ((word >> 11) & 0x1f)));
+              q->green=ScaleCharToQuantum(ScaleColor6to8((unsigned char)
+                ((word >> 5) & 0x3f)));
+              q->blue=ScaleCharToQuantum(ScaleColor5to8((unsigned char)
+                (word & 0x1f)));
             }
           q++;
         }
@@ -795,9 +801,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(image->rows-y-1,image->rows) != MagickFalse))
+              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
             {
-              status=image->progress_monitor(LoadImageTag,image->rows-y-1,
+              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
                 image->rows,image->client_data);
               if (status == MagickFalse)
                 break;
@@ -830,9 +836,9 @@ static Image *ReadDIBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-              (QuantumTick(image->rows-y-1,image->rows) != MagickFalse))
+              (QuantumTick(1L*image->rows-y-1,image->rows) != MagickFalse))
             {
-              status=image->progress_monitor(LoadImageTag,image->rows-y-1,
+              status=image->progress_monitor(LoadImageTag,1L*image->rows-y-1,
                 image->rows,image->client_data);
               if (status == MagickFalse)
                 break;
@@ -1012,7 +1018,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         Full color DIB raster.
       */
       dib_info.number_colors=0;
-      dib_info.bits_per_pixel=image->matte ? 32 : 24;
+      dib_info.bits_per_pixel=(unsigned short) (image->matte ? 32 : 24);
     }
   else
     {
@@ -1020,7 +1026,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         Colormapped DIB raster.
       */
       dib_info.bits_per_pixel=8;
-			if (image_info->depth > 8)
+      if (image_info->depth > 8)
         dib_info.bits_per_pixel=16;
       if (IsMonochromeImage(image,&image->exception) != MagickFalse)
         dib_info.bits_per_pixel=1;
@@ -1032,7 +1038,8 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
   dib_info.width=(long) image->columns;
   dib_info.height=(long) image->rows;
   dib_info.planes=1;
-  dib_info.compression=dib_info.bits_per_pixel == 16 ? BI_BITFIELDS : BI_RGB;
+  dib_info.compression=(unsigned long) (dib_info.bits_per_pixel == 16 ?
+    BI_BITFIELDS : BI_RGB);
   dib_info.image_size=bytes_per_line*image->rows;
   dib_info.x_pixels=75*39;
   dib_info.y_pixels=75*39;
@@ -1125,7 +1132,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         indexes=GetIndexes(image);
         q=pixels+(image->rows-y-1)*bytes_per_line;
         for (x=0; x < (long) image->columns; x++)
-          *q++=indexes[x];
+          *q++=(unsigned char) indexes[x];
         for ( ; x < (long) bytes_per_line; x++)
           *q++=0x00;
         if (image->previous == (Image *) NULL)
@@ -1155,15 +1162,15 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
         q=pixels+(image->rows-y-1)*bytes_per_line;
         for (x=0; x < (long) image->columns; x++)
         {
-          word=(ScaleColor8to5((unsigned long) ScaleQuantumToChar(
-            p->red)) << 11) | (ScaleColor8to6((unsigned long)
+          word=(unsigned short) ((ScaleColor8to5((unsigned char)
+            ScaleQuantumToChar(p->red)) << 11) | (ScaleColor8to6((unsigned char)
             ScaleQuantumToChar(p->green)) << 5) | (ScaleColor8to5(
-            (unsigned long) ScaleQuantumToChar(p->blue) << 0));
+            (unsigned char) ScaleQuantumToChar((unsigned char) p->blue) << 0)));
           *q++=(unsigned char)(word & 0xff);
           *q++=(unsigned char)(word >> 8);
           p++;
         }
-        for (x=2*image->columns; x < (long) bytes_per_line; x++)
+        for (x=2L*image->columns; x < (long) bytes_per_line; x++)
           *q++=0x00;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -1199,7 +1206,7 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
           p++;
         }
         if (dib_info.bits_per_pixel == 24)
-          for (x=3*image->columns; x < (long) bytes_per_line; x++)
+          for (x=3L*image->columns; x < (long) bytes_per_line; x++)
             *q++=0x00;
         if (image->previous == (Image *) NULL)
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -1230,7 +1237,8 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
             pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        dib_info.image_size=EncodeImage(image,bytes_per_line,pixels,dib_data);
+        dib_info.image_size=(unsigned long) EncodeImage(image,bytes_per_line,
+          pixels,dib_data);
         pixels=(unsigned char *) RelinquishMagickMemory(pixels);
         pixels=dib_data;
         dib_info.compression = BI_RLE8;
@@ -1239,9 +1247,9 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
     Write DIB header.
   */
   (void) WriteBlobLSBLong(image,dib_info.size);
-  (void) WriteBlobLSBLong(image,dib_info.width);
-  (void) WriteBlobLSBLong(image,dib_info.height);
-  (void) WriteBlobLSBShort(image,dib_info.planes);
+  (void) WriteBlobLSBLong(image,(unsigned long) dib_info.width);
+  (void) WriteBlobLSBLong(image,(unsigned short) dib_info.height);
+  (void) WriteBlobLSBShort(image,(unsigned short) dib_info.planes);
   (void) WriteBlobLSBShort(image,dib_info.bits_per_pixel);
   (void) WriteBlobLSBLong(image,dib_info.compression);
   (void) WriteBlobLSBLong(image,dib_info.image_size);
@@ -1271,14 +1279,15 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image)
             *q++=ScaleQuantumToChar(image->colormap[i].red);
             *q++=(Quantum) 0x0;
           }
-          for ( ; i < (1L << dib_info.bits_per_pixel); i++)
+          for ( ; i < (long) (1L << dib_info.bits_per_pixel); i++)
           {
             *q++=(Quantum) 0x0;
             *q++=(Quantum) 0x0;
             *q++=(Quantum) 0x0;
             *q++=(Quantum) 0x0;
           }
-          (void) WriteBlob(image,4*(1 << dib_info.bits_per_pixel),dib_colormap);
+          (void) WriteBlob(image,(size_t) (4*(1 << dib_info.bits_per_pixel)),
+            dib_colormap);
           dib_colormap=(unsigned char *) RelinquishMagickMemory(dib_colormap);
         }
       else
