@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,17 +52,21 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/option.h"
 #include "magick/resource_.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
 #include "magick/xwindow-private.h"
-#if defined(HasDOT)
+#if defined(HasGVC)
 #undef HAVE_CONFIG_H
-#include <dotneato.h>
+#include <gvc.h>
+static GVC_t
+  *graphic_context;
 #endif
 
-#if defined(HasDOT)
+#if defined(HasGVC)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -74,9 +78,9 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ReadDOTImage() reads a Adobe Postscript image file and returns it.  It
-%  allocates the memory necessary for the new Image structure and returns a
-%  pointer to the new image.
+%  ReadDOTImage() reads a Graphviz image file and returns it.  It allocates
+%  the memory necessary for the new Image structure and returns a pointer to
+%  the new image.
 %
 %  The format of the ReadDOTImage method is:
 %
@@ -92,16 +96,14 @@
 */
 static Image *ReadDOTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  Agraph_t
-    *graph,
-    *previous_graph;
-
   char
-    **argv,
     command[MaxTextExtent];
 
-  GVC_t
-    *gvc;
+  const char
+    *option;
+
+  graph_t
+    *graph;
 
   Image
     *image;
@@ -109,64 +111,38 @@ static Image *ReadDOTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ImageInfo
     *read_info;
 
-  int
-    argc;
-
   MagickBooleanType
     status;
 
-  register long
-    i;
-
-  static char
-    *dot_info[] =
-    {
-      "dot",
-      "1.12",
-      "Sun Apr 11 18:49:30 UTC 2004"
-    };
-
   /*
     Open image file.
   */
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     return((Image *) NULL);
-  CloseBlob(image);
-  image=DestroyImage(image);
-  graph=(Agraph_t *) NULL;
-  previous_graph=(Agraph_t *) NULL;
   read_info=CloneImageInfo(image_info);
   (void) CopyMagickString(read_info->magick,"PS",MaxTextExtent);
   (void) AcquireUniqueFilename(read_info->filename);
   (void) FormatMagickString(command,MaxTextExtent,"-Tps2 -o%s %s",
     read_info->filename,image_info->filename);
-  argv=StringToArgv(command,&argc);
-  gvc=gvNEWcontext(dot_info,"dot");
-  dotneato_initialize(gvc,argc,argv);
-  while ((graph=next_input_graph()) != (Agraph_t *) NULL)
-  {
-    if (previous_graph != (Agraph_t *) NULL)
-      {
-        dot_cleanup(previous_graph);
-        agclose(previous_graph);
-      }
-    previous_graph=graph;
-    gvBindContext(gvc,graph);
-    dot_layout(graph);
-    dotneato_write(gvc);
-  }
-  dotneato_eof(gvc);
-  for (i=0; i < argc; i++)
-    argv[i]=(char *) RelinquishMagickMemory(argv[i]);
-  argv=(char **) RelinquishMagickMemory(argv);
+  graph=agread(GetBlobFileHandle(image));
+  if (graph == (graph_t *) NULL)
+    return ((Image *) NULL);
+  option=GetImageOption(image_info,"dot:layout-engine");
+  if (option == (const char *) NULL)
+    gvLayout(graphic_context,graph,"dot");
+  else
+    gvLayout(graphic_context,graph,(char *) option);
+  gvRenderFilename(graphic_context,graph,"ps2",read_info->filename);
+  gvFreeLayout(graphic_context,graph);
   /*
     Read Postscript graph.
   */
@@ -208,13 +184,16 @@ ModuleExport void RegisterDOTImage(void)
     *entry;
 
   entry=SetMagickInfo("DOT");
-#if defined(HasDOT)
+#if defined(HasGVC)
   entry->decoder=(DecoderHandler *) ReadDOTImage;
 #endif
   entry->blob_support=MagickFalse;
-  entry->description=AcquireString("Graphviz");
-  entry->module=AcquireString("DOT");
+  entry->description=ConstantString("Graphviz");
+  entry->module=ConstantString("DOT");
   (void) RegisterMagickInfo(entry);
+#if defined(HasGVC)
+  graphic_context=gvContext();
+#endif
 }
 
 /*
@@ -239,4 +218,7 @@ ModuleExport void RegisterDOTImage(void)
 ModuleExport void UnregisterDOTImage(void)
 {
   (void) UnregisterMagickInfo("DOT");
+#if defined(HasGVC)
+  gvFreeContext(graphic_context);
+#endif
 }
