@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,6 +51,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -222,8 +223,9 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Rasterize the file into the pixmap.
   */
   status=XDPSImageFileIntoDrawable((DPSContext) NULL,screen,pixmap,
-    GetBlobFileHandle(image),bits_per_pixel.height,visual_info->depth,&page,
-    -page.x,-page.y,pixels_per_point,MagickTrue,MagickFalse,MagickTrue,&sans);
+    GetBlobFileHandle(image),(int) bits_per_pixel.height,visual_info->depth,
+    &page,-page.x,-page.y,pixels_per_point,MagickTrue,MagickFalse,MagickTrue,
+    &sans);
   if (status != dps_status_success)
     {
       image=DestroyImage(image);
@@ -257,11 +259,10 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (XFontStruct *) NULL,&resource_info,(XWindowInfo *) NULL);
       return((Image *) NULL);
     }
-  if ((visual_info->storage_class != DirectColor) &&
-      (visual_info->storage_class != TrueColor))
+  if ((visual_info->klass != DirectColor) && (visual_info->klass != TrueColor))
     for (i=0; i < visual_info->colormap_size; i++)
     {
-      colors[i].pixel=i;
+      colors[i].pixel=(unsigned long) i;
       colors[i].pad=0;
     }
   else
@@ -303,11 +304,10 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Convert X image to MIFF format.
   */
-  if ((visual_info->storage_class != TrueColor) &&
-      (visual_info->storage_class != DirectColor))
+  if ((visual_info->klass != TrueColor) && (visual_info->klass != DirectColor))
     image->storage_class=PseudoClass;
-  image->columns=dps_image->width;
-  image->rows=dps_image->height;
+  image->columns=(unsigned long) dps_image->width;
+  image->rows=(unsigned long) dps_image->height;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
@@ -358,7 +358,7 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         Convert X image to DirectClass packets.
       */
       if ((visual_info->colormap_size > 0) &&
-          (visual_info->storage_class == DirectColor))
+          (visual_info->klass == DirectColor))
         for (y=0; y < (long) image->rows; y++)
         {
           q=SetImagePixels(image,0,y,image->columns,1);
@@ -396,11 +396,14 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             pixel=XGetPixel(dps_image,x,y);
             color=(pixel >> red_shift) & red_mask;
-            q->red=ScaleShortToQuantum((color*65535L)/red_mask);
+            color=(color*65535L)/red_mask;
+            q->red=ScaleShortToQuantum((unsigned short) color);
             color=(pixel >> green_shift) & green_mask;
-            q->green=ScaleShortToQuantum((color*65535L)/green_mask);
+            color=(color*65535L)/green_mask;
+            q->green=ScaleShortToQuantum((unsigned short) color);
             color=(pixel >> blue_shift) & blue_mask;
-            q->blue=ScaleShortToQuantum((color*65535L)/blue_mask);
+            color=(color*65535L)/blue_mask;
+            q->blue=ScaleShortToQuantum((unsigned short) color);
             q++;
           }
           if (SyncImagePixels(image) == MagickFalse)
@@ -421,7 +424,7 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /*
         Create colormap.
       */
-      if (AllocateImageColormap(image,visual_info->colormap_size) == MagickFalse)
+      if (AllocateImageColormap(image,(unsigned long) visual_info->colormap_size) == MagickFalse)
         {
           image=DestroyImage(image);
           colors=(XColor *) RelinquishMagickMemory(colors);
@@ -475,7 +478,7 @@ static Image *ReadDPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((status != dps_status_failure) && (status != dps_status_no_extension))
     {
       status=XDPSImageFileIntoDrawable((DPSContext) NULL,screen,pixmap,
-        GetBlobFileHandle(image),bits_per_pixel.height,1,&page,-page.x,
+        GetBlobFileHandle(image),(int) bits_per_pixel.height,1,&page,-page.x,
         -page.y,pixels_per_point,MagickTrue,MagickTrue,MagickTrue,&sans);
       if (status == dps_status_success)
         {
@@ -554,8 +557,8 @@ ModuleExport void RegisterDPSImage(void)
   entry->decoder=(DecoderHandler *) ReadDPSImage;
 #endif
   entry->blob_support=MagickFalse;
-  entry->description=AcquireString("Display Postscript Interpreter");
-  entry->module=AcquireString("DPS");
+  entry->description=ConstantString("Display Postscript Interpreter");
+  entry->module=ConstantString("DPS");
   (void) RegisterMagickInfo(entry);
 }
 
