@@ -60,6 +60,7 @@
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -339,7 +340,7 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
 
   image=AllocateImage(image_info);
   hemf=ReadEnhMetaFile(image_info->filename,&width,&height);
-  if (hemf == 0)
+  if (hemf == (HENHMETAFILE) NULL)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   if ((image->columns == 0) || (image->rows == 0))
     {
@@ -347,8 +348,8 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
         y_resolution,
         x_resolution;
 
-       y_resolution=DefaultResolution;
-       x_resolution=DefaultResolution;
+      y_resolution=DefaultResolution;
+      x_resolution=DefaultResolution;
       if (image->y_resolution > 0)
         {
           y_resolution=image->y_resolution;
@@ -361,10 +362,10 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
           if (image->units == PixelsPerCentimeterResolution)
             x_resolution*=CENTIMETERS_INCH;
         }
-      image->rows=(unsigned long)
-        ((height*CENTIMETERS_INCH)/1000*y_resolution+0.5);
-      image->columns=(unsigned long)
-        ((width*CENTIMETERS_INCH)/1000*x_resolution+0.5);
+      image->rows=(unsigned long) ((height*CENTIMETERS_INCH)/1000*
+        y_resolution+0.5);
+      image->columns=(unsigned long) ((width*CENTIMETERS_INCH)/1000*
+        x_resolution+0.5);
     }
   if (image_info->size != (char *) NULL)
     {
@@ -398,11 +399,10 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
           flags=ParseMetaGeometry(geometry,&sans,&sans,&image->columns,
             &image->rows);
           if (image->x_resolution != 0.0)
-            image->columns=(unsigned long)
-              ((image->columns*image->x_resolution)+0.5);
+            image->columns=(unsigned long) ((image->columns*
+              image->x_resolution)+0.5);
           if (image->y_resolution != 0.0)
-            image->rows=(unsigned long)
-              ((image->rows*image->y_resolution)+0.5);
+            image->rows=(unsigned long) ((image->rows*image->y_resolution)+0.5);
         }
       else
         {
@@ -410,17 +410,20 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
           flags=ParseMetaGeometry(geometry,&sans,&sans,&image->columns,
             &image->rows);
           if (image->x_resolution != 0.0)
-            image->columns=(unsigned long)
-              (((image->columns*image->x_resolution)/DefaultResolution)+0.5);
+            image->columns=(unsigned long) (((image->columns*
+              image->x_resolution)/DefaultResolution)+0.5);
           if (image->y_resolution != 0.0)
-            image->rows=(unsigned long)
-              (((image->rows*image->y_resolution)/DefaultResolution)+0.5);
+            image->rows=(unsigned long) (((image->rows*image->y_resolution)/
+              DefaultResolution)+0.5);
         }
       geometry=(char *) RelinquishMagickMemory(geometry);
     }
   hDC=GetDC(NULL);
-  if (hDC == 0)
-    ThrowReaderException(ResourceLimitError,"UnableToCreateADC");
+  if (hDC == (HDC) NULL)
+    {
+      DeleteEnhMetaFile(hemf);
+      ThrowReaderException(ResourceLimitError,"UnableToCreateADC");
+    }
   /*
     Initialize the bitmap header info.
   */
@@ -431,20 +434,25 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
   DIBinfo.bmiHeader.biPlanes=1;
   DIBinfo.bmiHeader.biBitCount=32;
   DIBinfo.bmiHeader.biCompression=BI_RGB;
-  hBitmap=
-    CreateDIBSection(hDC,&DIBinfo,DIB_RGB_COLORS,(void **) &ppBits,NULL,0);
+  hBitmap=CreateDIBSection(hDC,&DIBinfo,DIB_RGB_COLORS,(void **) &ppBits,
+    NULL,0);
   ReleaseDC(NULL,hDC);
-  if (hBitmap == 0)
-    ThrowReaderException(ResourceLimitError,"UnableToCreateBitmap");
-  hDC=CreateCompatibleDC(NULL);
-  if (hDC == 0)
+  if (hBitmap == (HBITMAP) NULL)
     {
+      DeleteEnhMetaFile(hemf);
+      ThrowReaderException(ResourceLimitError,"UnableToCreateBitmap");
+    }
+  hDC=CreateCompatibleDC(NULL);
+  if (hDC == (HDC) NULL)
+    {
+      DeleteEnhMetaFile(hemf);
       DeleteObject(hBitmap);
       ThrowReaderException(ResourceLimitError,"UnableToCreateADC");
     }
   hOldBitmap=(HBITMAP) SelectObject(hDC,hBitmap);
-  if (hOldBitmap == 0)
+  if (hOldBitmap == (HBITMAP) NULL)
     {
+      DeleteEnhMetaFile(hemf);
       DeleteDC(hDC);
       DeleteObject(hBitmap);
       ThrowReaderException(ResourceLimitError,"UnableToCreateBitmap");
@@ -489,8 +497,7 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
     if (SyncImagePixels(image) == MagickFalse)
       break;
   }
-  if (hemf)
-    DeleteEnhMetaFile(hemf);
+  DeleteEnhMetaFile(hemf);
   SelectObject(hDC,hOldBitmap);
   DeleteDC(hDC);
   DeleteObject(hBitmap);
