@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -57,6 +57,7 @@
 #include "magick/monitor.h"
 #include "magick/quantize.h"
 #include "magick/resource_.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/transform.h"
@@ -176,7 +177,8 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -264,8 +266,9 @@ ModuleExport void RegisterEPTImage(void)
   entry->magick=(MagickHandler *) IsEPT;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
-  entry->description=AcquireString("Encapsulated PostScript with TIFF preview");
-  entry->module=AcquireString("EPT");
+  entry->description=ConstantString(
+    "Encapsulated PostScript with TIFF preview");
+  entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPT2");
   entry->decoder=(DecoderHandler *) ReadEPTImage;
@@ -273,18 +276,18 @@ ModuleExport void RegisterEPTImage(void)
   entry->magick=(MagickHandler *) IsEPT;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
-  entry->description=
-    AcquireString("Encapsulated PostScript Level II with TIFF preview");
-  entry->module=AcquireString("EPT");
+  entry->description=ConstantString(
+    "Encapsulated PostScript Level II with TIFF preview");
+  entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPT3");
   entry->decoder=(DecoderHandler *) ReadEPTImage;
   entry->encoder=(EncoderHandler *) WriteEPTImage;
   entry->magick=(MagickHandler *) IsEPT;
   entry->blob_support=MagickFalse;
-  entry->description=
-    AcquireString("Encapsulated PostScript Level III with TIFF preview");
-  entry->module=AcquireString("EPT");
+  entry->description=ConstantString(
+    "Encapsulated PostScript Level III with TIFF preview");
+  entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -360,16 +363,16 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
   write_image=CloneImage(image,0,0,MagickTrue,&image->exception);
   if (write_image == (Image *) NULL)
     return(MagickFalse);
-  write_info=CloneImageInfo(image_info);
   DestroyBlob(write_image);
   write_image->blob=CloneBlobInfo((BlobInfo *) NULL);
+  write_info=CloneImageInfo(image_info);
   (void) CopyMagickString(write_info->magick,"EPS",MaxTextExtent);
   if (LocaleCompare(image_info->magick,"EPT2") == 0)
     (void) CopyMagickString(write_info->magick,"EPS2",MaxTextExtent);
@@ -379,15 +382,19 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   ept_info.magick=0xc6d3d0c5ul;
   ept_info.postscript=(unsigned char *) ImageToBlob(write_info,write_image,
     &ept_info.postscript_length,&image->exception);
+  write_image=DestroyImage(write_image);
+  write_info=DestroyImageInfo(write_info);
   if (ept_info.postscript == (void *) NULL)
-    {
-      write_image=DestroyImage(write_image);
-      write_info=DestroyImageInfo(write_info);
-      return(MagickFalse);
-    }
+    return(MagickFalse);
+  write_image=CloneImage(image,0,0,MagickTrue,&image->exception);
+  if (write_image == (Image *) NULL)
+    return(MagickFalse);
   DestroyBlob(write_image);
   write_image->blob=CloneBlobInfo((BlobInfo *) NULL);
+  write_info=CloneImageInfo(image_info);
   (void) CopyMagickString(write_info->magick,"TIFF",MaxTextExtent);
+  (void) FormatMagickString(write_info->filename,MaxTextExtent,"tiff:%.1024s",
+    write_info->filename); 
   (void) TransformImage(&write_image,(char *) NULL,"512x512>");
   if ((write_image->storage_class == DirectClass) ||
       (write_image->colors > 256))
@@ -410,8 +417,8 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   write_info=DestroyImageInfo(write_info);
   if (ept_info.tiff == (void *) NULL)
     {
-      ept_info.postscript=(unsigned char *)
-        RelinquishMagickMemory(ept_info.postscript);
+      ept_info.postscript=(unsigned char *) RelinquishMagickMemory(
+        ept_info.postscript);
       return(MagickFalse);
     }
   /*
@@ -419,19 +426,19 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   */
   (void) WriteBlobLSBLong(image,ept_info.magick);
   (void) WriteBlobLSBLong(image,30);
-  (void) WriteBlobLSBLong(image,ept_info.postscript_length);
+  (void) WriteBlobLSBLong(image,(unsigned long) ept_info.postscript_length);
   (void) WriteBlobLSBLong(image,0);
   (void) WriteBlobLSBLong(image,0);
-  (void) WriteBlobLSBLong(image,ept_info.postscript_length+30);
-  (void) WriteBlobLSBLong(image,ept_info.tiff_length);
+  (void) WriteBlobLSBLong(image,(unsigned long) ept_info.postscript_length+30);
+  (void) WriteBlobLSBLong(image,(unsigned long) ept_info.tiff_length);
   (void) WriteBlobLSBShort(image,0xffff);
   (void) WriteBlob(image,ept_info.postscript_length,ept_info.postscript);
   (void) WriteBlob(image,ept_info.tiff_length,ept_info.tiff);
   /*
     Relinquish resources.
   */
-  ept_info.postscript=(unsigned char *)
-    RelinquishMagickMemory(ept_info.postscript);
+  ept_info.postscript=(unsigned char *) RelinquishMagickMemory(
+    ept_info.postscript);
   ept_info.tiff=(unsigned char *) RelinquishMagickMemory(ept_info.tiff);
   CloseBlob(image);
   return(MagickTrue);
