@@ -40,7 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color-private.h"
@@ -54,11 +54,12 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/pixel.h"
+#include "magick/quantum.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
+#include "magick/version.h"
 
 /*
   Forward declarations.
@@ -145,7 +146,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       columns,
       rows,
       number_axes,
-      number_scenes;
+      number_planes;
 
     double
       min_data,
@@ -162,7 +163,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     exponential[2048],
     pixel,
     scale,
-    scaled_pixel;
+    scale_pixel;
 
   FITSInfo
     fits_info;
@@ -242,7 +243,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
   fits_info.columns=1;
   fits_info.rows=1;
   fits_info.rows=1;
-  fits_info.number_scenes=1;
+  fits_info.number_planes=1;
   fits_info.number_axes=0;
   fits_info.min_data=0.0;
   fits_info.max_data=0.0;
@@ -311,7 +312,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
         if (LocaleCompare(keyword,"NAXIS2") == 0)
           fits_info.rows=atoi(value);
         if (LocaleCompare(keyword,"NAXIS3") == 0)
-          fits_info.number_scenes=atoi(value);
+          fits_info.number_planes=atoi(value);
         if (LocaleCompare(keyword,"DATAMAX") == 0)
           fits_info.max_data=atof(value);
         if (LocaleCompare(keyword,"DATAMIN") == 0)
@@ -320,7 +321,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           fits_info.zero=atof(value);
         if (LocaleCompare(keyword,"BSCALE") == 0)
           fits_info.scale=atof(value);
-        (void) SetImageAttribute(image,keyword,value);
+        (void) SetImageProperty(image,keyword,value);
       }
     while (((TellBlob(image) % 80) != 0) && (c != EOF))
       c=ReadBlobByte(image);
@@ -351,7 +352,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
       for (i=1074; i >= 0; i--)
         exponential[i]=exponential[i+1]/2.0;
     }
-  for (scene=0; scene < (long) fits_info.number_scenes; scene++)
+  for (scene=0; scene < (long) fits_info.number_planes; scene++)
   {
     /*
       Create linear colormap.
@@ -376,8 +377,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if ((packet_size*number_pixels) !=
         (MagickSizeType) ((size_t) (packet_size*number_pixels)))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    fits_pixels=(unsigned char *)
-      AcquireMagickMemory(packet_size*image->columns*image->rows);
+    fits_pixels=(unsigned char *) AcquireMagickMemory(packet_size*
+      image->columns*image->rows*sizeof(*fits_pixels));
     if (fits_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -386,9 +387,11 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     count=ReadBlob(image,packet_size*image->columns*image->rows,fits_pixels);
     if (count != (ssize_t) (packet_size*image->columns*image->rows))
       ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
-    if ((fits_info.bits_per_pixel > 0) &&
-        (fits_info.min_data == 0.0) && (fits_info.max_data == 0.0))
-      fits_info.max_data=(1UL << fits_info.bits_per_pixel)-1;
+    if ((fits_info.min_data != 0.0) || (fits_info.max_data != 0.0))
+      {
+        if ((fits_info.bits_per_pixel != 0) && (fits_info.max_data == 0.0))
+          fits_info.max_data=(1UL << fits_info.bits_per_pixel)-1;
+      }
     else
       {
         /*
@@ -403,40 +406,45 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           quantum=(quantum << 8) | (*p++);
         }
         pixel=(double) quantum;
+        if (fits_info.bits_per_pixel == 16)
+          {
+            if ((long_quantum[0] & 0x80) == 0)
+              pixel=(long_quantum[0] << 8) | long_quantum[1];
+            else
+              pixel=((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
+          }
         if (fits_info.bits_per_pixel == -32)
           {
             j=((long) long_quantum[1] << 16) | ((long) long_quantum[2] << 8) |
                (long) long_quantum[3];
             k=(int) *long_quantum;
-            exponent=((k & 127) << 1) | (j >> 23);
+            exponent=((k & 0x7f) << 1) | (j >> 23);
             *(float *) long_quantum=
               exponential[exponent]*(float) (j | 0x800000);
             if ((exponent | j) == 0)
               *(float *) long_quantum=0.0;
-            if (k & 128)
+            if (k & 0x7f)
               *(float *) long_quantum=(-(*(float *) long_quantum));
             pixel=(double) (*((float *) long_quantum));
           }
         if (fits_info.bits_per_pixel == -64)
           {
-            j=((long) long_quantum[1] << 24) |
-              ((long) long_quantum[2] << 16) |
-              ((long) long_quantum[3] << 8) |
-               (long) long_quantum[4];
+            j=((long) long_quantum[1] << 24) | ((long) long_quantum[2] << 16) |
+              ((long) long_quantum[3] << 8) | (long) long_quantum[4];
             k=(int) *long_quantum;
             l=((int) long_quantum[5] << 16) | ((int) long_quantum[6] << 8) |
                (int) long_quantum[7];
-            exponent=((k & 127) << 4) | (j >> 28);
+            exponent=((k & 0x7f) << 4) | (j >> 28);
             *(double *) long_quantum=exponential[exponent]*(16777216.0*
               (double) ((j & 0x0FFFFFFF) | 0x10000000)+(double) l);
             if ((exponent | j | l) == 0)
               *(double *) long_quantum=0.0;
-            if (k & 128)
-              *(double *)long_quantum=(-(*(double *) long_quantum));
+            if (k & 0x80)
+              *(double *) long_quantum=(-(*(double *) long_quantum));
             pixel=(double) (*((double *) long_quantum));
           }
-        fits_info.min_data=pixel*fits_info.scale-fits_info.zero;
-        fits_info.max_data=pixel*fits_info.scale-fits_info.zero;
+        fits_info.min_data=pixel*fits_info.scale+fits_info.zero;
+        fits_info.max_data=pixel*fits_info.scale+fits_info.zero;
         for (i=1; i < (long) number_pixels; i++)
         {
           long_quantum[0]=(*p);
@@ -447,47 +455,50 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
             quantum=(quantum << 8) | (*p++);
           }
           pixel=(double) quantum;
+          if (fits_info.bits_per_pixel == 16)
+            {
+              if ((long_quantum[0] & 0x80) == 0)
+                pixel=(long_quantum[0] << 8) | long_quantum[1];
+              else
+                pixel=((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
+            }
           if (fits_info.bits_per_pixel == -32)
             {
               j=((long) long_quantum[1] << 16) | ((long) long_quantum[2] << 8) |
                  (long) long_quantum[3];
               k=(int) *long_quantum;
-              exponent=((k & 127) << 1) | (j >> 23);
-              *(float *) long_quantum=
-                exponential[exponent]*(float) (j | 0x800000);
+              exponent=((k & 0x7f) << 1) | (j >> 23);
+              *(float *) long_quantum=exponential[exponent]*(float)
+                (j | 0x800000);
               if ((exponent | j) == 0)
                 *(float *) long_quantum=0.0;
-              if (k & 128)
+              if (k & 0x80)
                 *(float *) long_quantum=(-(*(float *) long_quantum));
               pixel=(double) (*((float *) long_quantum));
             }
           if (fits_info.bits_per_pixel == -64)
             {
               j=((long) long_quantum[1] << 24) |
-                ((long) long_quantum[2] << 16) |
-                ((long) long_quantum[3] << 8) |
+                ((long) long_quantum[2] << 16) | ((long) long_quantum[3] << 8) |
                  (long) long_quantum[4];
               k=(int) *long_quantum;
               l=((int) long_quantum[5] << 16) | ((int) long_quantum[6] << 8) |
                  (int) long_quantum[7];
-              exponent=((k & 127) << 4) | (j >> 28);
+              exponent=((k & 0x7f) << 4) | (j >> 28);
               *(double *) long_quantum=exponential[exponent]*(16777216.0*
                 (double) ((j & 0x0FFFFFFF) | 0x10000000)+(double) l);
               if ((exponent | j | l) == 0)
                 *(double *) long_quantum=0.0;
-              if (k & 128)
+              if (k & 0x80)
                 *(double *)long_quantum=(-(*(double *) long_quantum));
               pixel=(double) (*((double *) long_quantum));
             }
-          scaled_pixel=pixel*fits_info.scale-fits_info.zero;
-          if (scaled_pixel < fits_info.min_data)
-            fits_info.min_data=scaled_pixel;
-          if (scaled_pixel > fits_info.max_data)
-            fits_info.max_data=scaled_pixel;
+          scale_pixel=pixel*fits_info.scale+fits_info.zero;
+          if (scale_pixel < fits_info.min_data)
+            fits_info.min_data=scale_pixel;
+          if (scale_pixel > fits_info.max_data)
+            fits_info.max_data=scale_pixel;
         }
-        if (fits_info.bits_per_pixel == 16)
-          if (pixel > 32767)
-            pixel-=65536L;
       }
     /*
       Convert FITS pixels to pixel packets.
@@ -495,8 +506,8 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     scale=1.0;
     if ((fits_info.bits_per_pixel < 0) || ((fits_info.max_data-
         fits_info.min_data) > (double) ((1UL << image->depth)-1)))
-      scale=(double) ((1UL << image->depth)-1)/
-        (fits_info.max_data-fits_info.min_data);
+      scale=(double) ((1UL << image->depth)-1)/(fits_info.max_data-
+        fits_info.min_data);
     p=fits_pixels;
     for (y=(long) image->rows-1; y >= 0; y--)
     {
@@ -514,47 +525,49 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
           quantum=(quantum << 8) | (*p++);
         }
         pixel=(double) quantum;
+        if (fits_info.bits_per_pixel == 16)
+          {
+            if ((long_quantum[0] & 0x80) == 0)
+              pixel=(long_quantum[0] << 8) | long_quantum[1];
+            else
+              pixel=((long_quantum[0] << 8) | long_quantum[1] | ~0xFFFF);
+          }
         if (fits_info.bits_per_pixel == -32)
           {
             j=((long) long_quantum[1] << 16) | ((long) long_quantum[2] << 8) |
                (long) long_quantum[3];
             k=(int) *long_quantum;
-            exponent=((k & 127) << 1) | (j >> 23);
-            *(float *) long_quantum=
-              exponential[exponent]*(float) (j | 0x800000);
+            exponent=((k & 0x7f) << 1) | (j >> 23);
+            *(float *) long_quantum=exponential[exponent]*(float)
+              (j | 0x800000);
             if ((exponent | j) == 0)
               *(float *) long_quantum=0.0;
-            if (k & 128)
+            if (k & 0x80)
               *(float *) long_quantum=(-(*(float *) long_quantum));
             pixel=(double) (*((float *) long_quantum));
           }
         if (fits_info.bits_per_pixel == -64)
           {
-            j=((long) long_quantum[1] << 24) |
-              ((long) long_quantum[2] << 16) |
-              ((long) long_quantum[3] << 8) |
-               (long) long_quantum[4];
+            j=((long) long_quantum[1] << 24) | ((long) long_quantum[2] << 16) |
+              ((long) long_quantum[3] << 8) | (long) long_quantum[4];
             k=(long) *long_quantum;
             l=((long) long_quantum[5] << 16) | ((long) long_quantum[6] << 8) |
                (long) long_quantum[7];
-            exponent=(long) ((((unsigned long) k & 127) << 4) |
+            exponent=(long) ((((unsigned long) k & 0x7f) << 4) |
               ((unsigned long) j >> 28));
             *(double *) long_quantum=exponential[exponent]*(16777216.0*
               (double) ((j & 0x0FFFFFFF) | 0x10000000)+(double) l);
             if ((exponent | j | l) == 0)
               *(double *) long_quantum=0.0;
-            if ((k & 128) != 0)
-              *(double *)long_quantum=(-(*(double *) long_quantum));
+            if ((k & 0x80) != 0)
+              *(double *) long_quantum=(-(*(double *) long_quantum));
             pixel=(double) (*((double *) long_quantum));
           }
-        scaled_pixel=scale*
-          (pixel*fits_info.scale-fits_info.min_data-fits_info.zero);
-        if (fits_info.bits_per_pixel == 16)
-          if (scaled_pixel > 32767)
-            scaled_pixel-=65536L;
-        index=(IndexPacket) ((scaled_pixel < 0.0) ? 0 :
-          ((unsigned long) scaled_pixel > ((1UL << image->depth)-1)) ?
-          ((1UL << image->depth)-1) : (unsigned long) (scaled_pixel+0.5));
+        scale_pixel=scale*(pixel*fits_info.scale-fits_info.min_data+
+          fits_info.zero);
+        index=(IndexPacket) ((scale_pixel < 0.0) ? 0 : ((unsigned long)
+          scale_pixel > ((1UL << image->depth)-1)) ? ((1UL << image->depth)-1) :
+          (unsigned long) (scale_pixel+0.5));
         index=ConstrainColormapIndex(image,index);
         indexes[x]=index;
         *q++=image->colormap[index];
@@ -583,7 +596,7 @@ static Image *ReadFITSImage(const ImageInfo *image_info,
     if (image_info->number_scenes != 0)
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    if (scene < (long) (fits_info.number_scenes-1))
+    if (scene < (long) (fits_info.number_planes-1))
       {
         /*
           Allocate next image structure.
@@ -644,6 +657,14 @@ ModuleExport void RegisterFITSImage(void)
   entry->description=ConstantString("Flexible Image Transport System");
   entry->module=ConstantString("FITS");
   (void) RegisterMagickInfo(entry);
+  entry=SetMagickInfo("FTS");
+  entry->decoder=(DecoderHandler *) ReadFITSImage;
+  entry->encoder=(EncoderHandler *) WriteFITSImage;
+  entry->magick=(MagickHandler *) IsFITS;
+  entry->adjoin=MagickFalse;
+  entry->description=ConstantString("Flexible Image Transport System");
+  entry->module=ConstantString("FTS");
+  (void) RegisterMagickInfo(entry);
 }
 
 /*
@@ -668,6 +689,7 @@ ModuleExport void RegisterFITSImage(void)
 ModuleExport void UnregisterFITSImage(void)
 {
   (void) UnregisterMagickInfo("FITS");
+  (void) UnregisterMagickInfo("FTS");
 }
 
 /*
@@ -695,21 +717,26 @@ ModuleExport void UnregisterFITSImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   Image *image)
 {
   char
-    buffer[MaxTextExtent],
+    header[MaxTextExtent],
     *fits_info;
 
+  IndexPacket
+    *indexes;
+
   long
     y;
 
   MagickBooleanType
     status;
 
+  MagickRealType
+    pixel;
+
   MagickSizeType
     length;
 
@@ -717,14 +744,21 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
     *p;
 
   register long
-    i;
+    i,
+    x;
 
   size_t
     packet_size;
 
+  ssize_t
+    offset;
+
   unsigned char
     *pixels;
 
+  unsigned long
+    number_planes;
+
   /*
     Open output image file.
   */
@@ -744,7 +778,7 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   */
   image->endian=MSBEndian;
   image->depth=GetImageQuantumDepth(image,MagickTrue);
-  packet_size=(size_t) (image->depth > 8 ? 2 : 1);
+  packet_size=(size_t) image->depth/8;
   fits_info=(char *) AcquireMagickMemory(2880*sizeof(*fits_info));
   pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
   if ((fits_info == (char *) NULL) || (pixels == (unsigned char *) NULL))
@@ -752,51 +786,119 @@ static MagickBooleanType WriteFITSImage(const ImageInfo *image_info,
   /*
     Initialize image header.
   */
+  offset=0;
   for (i=0; i < 2880; i++)
     fits_info[i]=' ';
-  (void) CopyMagickString(buffer,"SIMPLE  =                    T",
-    MaxTextExtent);
-  (void) CopyMagickString(fits_info+0,buffer,2880);
-  (void) FormatMagickString(buffer,MaxTextExtent,"BITPIX  =           %10lu",
+  (void) FormatMagickString(header,MaxTextExtent,
+    "SIMPLE  =                    T");
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"BITPIX  =           %10lu",
     image->depth);
-  (void) CopyMagickString(fits_info+80,buffer,2880);
-  (void) CopyMagickString(buffer,"NAXIS   =                    2",
-    MaxTextExtent);
-  (void) CopyMagickString(fits_info+160,buffer,2880);
-  (void) FormatMagickString(buffer,MaxTextExtent,"NAXIS1  =           %10lu",
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  number_planes=1;
+  if (IsGrayImage(image,&image->exception) == MagickFalse)
+    {
+      number_planes=3;
+      if (image->colorspace == CMYKColorspace)
+        number_planes++;
+      if (image->matte != MagickFalse)
+        number_planes++;
+    }
+  (void) FormatMagickString(header,MaxTextExtent,"NAXIS   =           %10lu",
+    number_planes >= 3 ? number_planes : 2);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"NAXIS1  =           %10lu",
     image->columns);
-  (void) CopyMagickString(fits_info+240,buffer,2880);
-  (void) FormatMagickString(buffer,MaxTextExtent,"NAXIS2  =           %10lu",
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"NAXIS2  =           %10lu",
     image->rows);
-  (void) CopyMagickString(fits_info+320,buffer,2880);
-  (void) FormatMagickString(buffer,MaxTextExtent,"DATAMIN =           %10u",0);
-  (void) CopyMagickString(fits_info+400,buffer,2880);
-  (void) FormatMagickString(buffer,MaxTextExtent,"DATAMAX =           %10u",
-    (1 << image->depth)-1);
-  (void) CopyMagickString(fits_info+480,buffer,2880);
-  (void) FormatMagickString(buffer,MaxTextExtent,"BZERO   =           %10u",
-    image->depth > 8 ? 32768 : 0);
-  (void) CopyMagickString(fits_info+560,buffer,2880);
-  (void) CopyMagickString(buffer,"HISTORY Created by ImageMagick.",
-    MaxTextExtent);
-  (void) CopyMagickString(fits_info+640,buffer,2880);
-  (void) CopyMagickString(buffer,"END",MaxTextExtent);
-  (void) CopyMagickString(fits_info+720,buffer,2880);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  if (number_planes > 2)
+    {
+      (void) FormatMagickString(header,MaxTextExtent,"NAXIS3  =           %10lu",
+        number_planes);
+      (void) strncpy(fits_info+offset,header,strlen(header));
+      offset+=80;
+    }
+  (void) FormatMagickString(header,MaxTextExtent,"BSCALE  =         %E",1.0);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"BZERO   =         %E",
+    image->depth > 8 ? 1.0*(1UL << (image->depth-1UL)) : 0.0);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"DATAMAX =         %E",
+    image->depth == 32 ? 4294967295.0 : 1.0*(1UL << image->depth)-1.0);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"DATAMIN =         %E",0.0);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) FormatMagickString(header,MaxTextExtent,"HISTORY %s",
+    GetMagickVersion((unsigned long *) NULL));
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
+  (void) strncpy(header,"END",MaxTextExtent);
+  (void) strncpy(fits_info+offset,header,strlen(header));
+  offset+=80;
   (void) WriteBlob(image,2880,(unsigned char *) fits_info);
   /*
     Convert image to fits scale PseudoColor class.
   */
-  for (y=(long) image->rows-1; y >= 0; y--)
+  for (i=0; i < (long) number_planes; i++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
-    if (p == (const PixelPacket *) NULL)
-      break;
-    (void) ImportQuantumPixels(image,GrayQuantum,0,pixels);
-    (void) WriteBlob(image,packet_size*image->columns,pixels);
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(image->rows-y-1,image->rows) != MagickFalse))
+    for (y=(long) image->rows-1; y >= 0; y--)
+    {
+      p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+      if (p == (const PixelPacket *) NULL)
+        break;
+      indexes=GetIndexes(image);
+      for (x=0; x < (long) image->columns; x++)
       {
-        status=image->progress_monitor(SaveImageTag,image->rows-y-1,image->rows,
+        switch (i)
+        {
+          default:
+          case 0:
+          {
+            pixel=(MagickRealType) p->red;
+            if (number_planes == 1)
+              pixel=(MagickRealType) PixelIntensity(p);
+            break;
+          }
+          case 1: pixel=(MagickRealType) p->green; break;
+          case 2: pixel=(MagickRealType) p->blue; break;
+          case 3:
+          {
+            if (image->colorspace == CMYKColorspace)
+              pixel=(MagickRealType) indexes[x];
+          }
+          case 4: pixel=(MagickRealType) p->opacity; break;
+        }
+        if (image->depth > 8)
+          pixel+=1.0*(1UL << (image->depth-1UL));
+        if (image->depth > 16)
+          {
+            (void) WriteBlobByte(image,((unsigned long)
+              (pixel+0.5) >> 24) & 0xff);
+            (void) WriteBlobByte(image,((unsigned long)
+              (pixel+0.5) >> 16) & 0xff);
+          }
+        if (image->depth > 8)
+          (void) WriteBlobByte(image,((unsigned long)
+            (pixel+0.5) >> 8) & 0xff);
+        (void) WriteBlobByte(image,(unsigned long) (pixel+0.5) & 0xff);
+        p++;
+      }
+    }
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(i,number_planes) != MagickFalse))
+      {
+        status=image->progress_monitor(SaveImageTag,i,number_planes,
           image->client_data);
         if (status == MagickFalse)
           break;
