@@ -40,7 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -297,8 +297,8 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Note image label.
         */
-        label=(char *)
-          AcquireMagickMemory(summary_info.title.length+MaxTextExtent);
+        label=(char *) AcquireMagickMemory(summary_info.title.length+
+          MaxTextExtent);
         if (label == (char *) NULL)
           {
             FPX_ClearSystem();
@@ -306,7 +306,7 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
         (void) CopyMagickString(label,(char *) summary_info.title.ptr,
           summary_info.title.length+1);
-        (void) SetImageAttribute(image,"label",label);
+        (void) SetImageProperty(image,"label",label);
         label=(char *) RelinquishMagickMemory(label);
       }
   if (summary_info.comments_valid)
@@ -319,8 +319,8 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Note image comment.
         */
-        comments=(char *)
-          AcquireMagickMemory(summary_info.comments.length+MaxTextExtent);
+        comments=(char *) AcquireMagickMemory(summary_info.comments.length+
+          MaxTextExtent);
         if (comments == (char *) NULL)
           {
             FPX_ClearSystem();
@@ -328,7 +328,7 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
         (void) CopyMagickString(comments,(char *) summary_info.comments.ptr,
           summary_info.comments.length+1);
-        (void) SetImageAttribute(image,"Comment",comments);
+        (void) SetImageProperty(image,"Comment",comments);
         comments=(char *) RelinquishMagickMemory(comments);
       }
   /*
@@ -781,7 +781,7 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
       }
     };
 
-  const ImageAttribute
+  const char
     *comment,
     *label;
 
@@ -806,6 +806,9 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   MagickBooleanType
     status;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -907,30 +910,30 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   summary_info.thumbnail_valid=MagickFalse;
   summary_info.appname_valid=MagickFalse;
   summary_info.security_valid=MagickFalse;
-  label=GetImageAttribute(image,"Label");
-  if (label != (ImageAttribute *) NULL)
+  label=GetImageProperty(image,"Label");
+  if (label != (const char *) NULL)
     {
       /*
         Note image label.
       */
       summary_info.title_valid=MagickTrue;
-      summary_info.title.length=strlen(label->value);
+      summary_info.title.length=strlen(label);
       summary_info.title.ptr=(unsigned char *)
-        AcquireMagickMemory(strlen(label->value)+MaxTextExtent);
+        AcquireMagickMemory(strlen(label)+MaxTextExtent);
       if (summary_info.title.ptr == (unsigned char *) NULL)
         ThrowWriterException(DelegateError,"UnableToSetImageTitle");
-      (void) CopyMagickString((char *) summary_info.title.ptr,label->value,
+      (void) CopyMagickString((char *) summary_info.title.ptr,label,
         MaxTextExtent);
     }
-  comment=GetImageAttribute(image,"Comment");
-  if (comment != (ImageAttribute *) NULL)
+  comment=GetImageProperty(image,"Comment");
+  if (comment != (const char *) NULL)
     {
       /*
         Note image comment.
       */
       summary_info.comments_valid=MagickTrue;
-      summary_info.comments.ptr=(unsigned char *) AcquireString(comment->value);
-      summary_info.comments.length=strlen(comment->value);
+      summary_info.comments.ptr=(unsigned char *) AcquireString(comment);
+      summary_info.comments.length=strlen(comment);
     }
   fpx_status=FPX_SetSummaryInformation(flashpix,&summary_info);
   if (fpx_status != FPX_OK)
@@ -968,18 +971,19 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   /*
     Write image scanlines.
   */
+  GetQuantumInfo(image_info,&quantum_info);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     if (fpx_info.numberOfComponents == 1)
-      (void) ImportQuantumPixels(image,GrayQuantum,0,pixels);
+      (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,pixels);
     else
       if (image->matte == MagickFalse)
-        (void) ImportQuantumPixels(image,RGBQuantum,0,pixels);
+        (void) ImportQuantumPixels(image,&quantum_info,RGBQuantum,pixels);
       else
-        (void) ImportQuantumPixels(image,RGBAQuantum,0,pixels);
+        (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,pixels);
     fpx_status=FPX_WriteImageLine(flashpix,&fpx_info);
     if (fpx_status != FPX_OK)
       break;
