@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -55,6 +54,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/option.h"
+#include "magick/property.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
@@ -129,7 +129,7 @@ static MagickBooleanType
 static ssize_t
   ReadBlobBlock(Image *,unsigned char *);
 
-static unsigned long
+static long
   PopLZWStack(LZWStack *);
 
 static void
@@ -210,7 +210,7 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
   for (i=0; i <= (long) lzw_info->maximum_data_value; i++)
   {
     lzw_info->table[0][i]=0;
-    lzw_info->table[1][i]=i;
+    lzw_info->table[1][i]=(unsigned long) i;
   }
   ResetLZWInfo(lzw_info);
   lzw_info->code_info.buffer[0]='\0';
@@ -239,12 +239,12 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
 
 static int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
 {
+  int
+    code;
+
   register long
     i;
 
-  unsigned long
-    code;
-
   if (((lzw_info->code_info.bit+bits) > (8*lzw_info->code_info.count)) &&
       (lzw_info->code_info.eof == MagickFalse))
     {
@@ -276,12 +276,12 @@ static int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
   return(code);
 }
 
-static unsigned long PopLZWStack(LZWStack *stack_info)
+static long PopLZWStack(LZWStack *stack_info)
 {
   if (stack_info->index <= stack_info->codes)
     return(-1);
   stack_info->index--;
-  return(*stack_info->index);
+  return((long) *stack_info->index);
 }
 
 static void PushLZWStack(LZWStack *stack_info,const unsigned long value)
@@ -310,10 +310,11 @@ static int ReadBlobLZWByte(LZWInfo *lzw_info)
       lzw_info->genesis=MagickFalse;
       do
       {
-        lzw_info->first_code=GetNextLZWCode(lzw_info,lzw_info->bits);
+        lzw_info->first_code=(unsigned long) GetNextLZWCode(lzw_info,
+          lzw_info->bits);
         lzw_info->last_code=lzw_info->first_code;
       } while (lzw_info->first_code == lzw_info->clear_code);
-      return(lzw_info->first_code);
+      return((int) lzw_info->first_code);
     }
   code=GetNextLZWCode(lzw_info,lzw_info->bits);
   if (code < 0)
@@ -326,7 +327,7 @@ static int ReadBlobLZWByte(LZWInfo *lzw_info)
   if ((unsigned long) code == lzw_info->end_code)
     return(-1);
   if ((unsigned long) code < lzw_info->slot)
-    value=code;
+    value=(unsigned long) code;
   else
     {
       PushLZWStack(lzw_info->stack,lzw_info->first_code);
@@ -357,7 +358,7 @@ static int ReadBlobLZWByte(LZWInfo *lzw_info)
           lzw_info->maximum_code=1UL << lzw_info->bits;
         }
     }
-  lzw_info->last_code=code;
+  lzw_info->last_code=(unsigned long) code;
   return(PopLZWStack(lzw_info->stack));
 }
 
@@ -429,7 +430,7 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
       c=ReadBlobLZWByte(lzw_info);
       if (c < 0)
         break;
-      index=ConstrainColormapIndex(image,c);
+      index=ConstrainColormapIndex(image,(unsigned long) c);
       q->red=image->colormap[index].red;
       q->green=image->colormap[index].green;
       q->blue=image->colormap[index].blue;
@@ -1059,7 +1060,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               header[count]='\0';
               (void) ConcatenateString(&comments,(const char *) header);
             }
-            (void) SetImageAttribute(image,"Comment",comments);
+            (void) SetImageProperty(image,"Comment",comments);
             comments=(char *) RelinquishMagickMemory(comments);
             break;
           }
@@ -1248,8 +1249,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterGIFImage() adds attributes for the GIF image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterGIFImage() adds properties for the GIF image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -1332,7 +1333,6 @@ ModuleExport void UnregisterGIFImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
 {
@@ -1561,12 +1561,12 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
           0));
         (void) WriteBlobByte(image,(unsigned char) 0x00);
         if ((LocaleCompare(write_info->magick,"GIF87") != 0) &&
-            (GetImageAttribute(image,"Comment") != (ImageAttribute *) NULL))
+            (GetImageProperty(image,"Comment") != (const char *) NULL))
           {
-            const ImageAttribute
-              *attribute;
+            const char
+              *value;
 
-            register char
+            register const char
               *p;
 
             size_t
@@ -1577,8 +1577,8 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             */
             (void) WriteBlobByte(image,(unsigned char) 0x21);
             (void) WriteBlobByte(image,(unsigned char) 0xfe);
-            attribute=GetImageAttribute(image,"Comment");
-            p=attribute->value;
+            value=GetImageProperty(image,"Comment");
+            p=value;
             while (strlen(p) != 0)
             {
               count=Min(strlen(p),255);
