@@ -187,7 +187,7 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
 
       status=jbg_dec_in(&jbig_info,p,length,&count);
       p+=count;
-      length-=count;
+      length-=(long) count;
     }
   } while ((status == JBG_EAGAIN) || (status == JBG_EOK));
   /*
