@@ -647,7 +647,7 @@ ModuleExport void RegisterJP2Image(void)
   entry->magick=(MagickHandler *) IsJP2;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
   entry->decoder=(DecoderHandler *) ReadJP2Image;
   entry->encoder=(EncoderHandler *) WriteJP2Image;
@@ -659,7 +659,7 @@ ModuleExport void RegisterJP2Image(void)
   entry->magick=(MagickHandler *) IsJPC;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
   entry->decoder=(DecoderHandler *) ReadJP2Image;
   entry->encoder=(EncoderHandler *) WriteJP2Image;
@@ -671,7 +671,7 @@ ModuleExport void RegisterJP2Image(void)
   entry->magick=(MagickHandler *) IsJPC;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
   entry->decoder=(DecoderHandler *) ReadJP2Image;
   entry->encoder=(EncoderHandler *) WriteJP2Image;
@@ -683,7 +683,7 @@ ModuleExport void RegisterJP2Image(void)
   entry->magick=(MagickHandler *) IsJPC;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJP2)
   entry->decoder=(DecoderHandler *) ReadJP2Image;
 #endif
