@@ -44,7 +44,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -63,9 +62,10 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/profile.h"
+#include "magick/property.h"
+#include "magick/quantum.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
-#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -322,7 +322,7 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
   for (p=comment; i-- >= 0; p++)
     *p=(char) GetCharacter(jpeg_info);
   *p='\0';
-  (void) SetImageAttribute(image,"Comment",comment);
+  (void) SetImageProperty(image,"Comment",comment);
   comment=(char *) RelinquishMagickMemory(comment);
   return(MagickTrue);
 }
@@ -961,7 +961,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   }
   (void) FormatMagickString(value,MaxTextExtent,"%ld",(long)
     jpeg_info.out_color_space);
-  (void) SetImageAttribute(image,"JPEG-Colorspace",value);
+  (void) SetImageProperty(image,"JPEG-Colorspace",value);
   /*
     Set image sampling factors.
   */
@@ -1018,7 +1018,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
       break;
     }
   }
-  (void) SetImageAttribute(image,"JPEG-Sampling-factors",sampling_factors);
+  (void) SetImageProperty(image,"JPEG-Sampling-factors",sampling_factors);
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
     "Sampling Factors: %s",sampling_factors);
   if (image_info->ping != MagickFalse)
@@ -1179,8 +1179,8 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterJPEGImage() adds attributes for the JPEG image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterJPEGImage() adds properties for the JPEG image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -1197,7 +1197,7 @@ ModuleExport void RegisterJPEGImage(void)
     *entry;
 
   entry=SetMagickInfo("JPEG");
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJPEG)
   entry->decoder=(DecoderHandler *) ReadJPEGImage;
   entry->encoder=(EncoderHandler *) WriteJPEGImage;
@@ -1218,7 +1218,7 @@ ModuleExport void RegisterJPEGImage(void)
   entry->module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("JPG");
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJPEG)
   entry->decoder=(DecoderHandler *) ReadJPEGImage;
   entry->encoder=(EncoderHandler *) WriteJPEGImage;
@@ -1229,7 +1229,7 @@ ModuleExport void RegisterJPEGImage(void)
   entry->module=ConstantString("JPEG");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PJPEG");
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
 #if defined(HasJPEG)
   entry->decoder=(DecoderHandler *) ReadJPEGImage;
   entry->encoder=(EncoderHandler *) WriteJPEGImage;
@@ -1407,8 +1407,8 @@ static void WriteProfile(j_compress_ptr jpeg_info,Image *image)
             (void) CopyMagickMemory(custom_profile->datum,
               "Photoshop 3.0\08BIM\04\04\0\0\0\0",24);
             custom_profile->datum[13]=0x00;
-            custom_profile->datum[24]=profile->length >> 8;
-            custom_profile->datum[25]=profile->length & 0xff;
+            custom_profile->datum[24]=(unsigned char) (profile->length >> 8);
+            custom_profile->datum[25]=(unsigned char) (profile->length & 0xff);
             tag_length=26;
           }
         for (i=0; i < (long) profile->length; i+=65500L)
@@ -1497,11 +1497,9 @@ static char **SamplingFactorToList(const char *text)
 static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   Image *image)
 {
-  char
-    *sampling_factors;
-
-  const ImageAttribute
-    *attribute;
+  const char
+    *sampling_factors,
+    *value;
 
   ErrorManager
     error_manager;
@@ -1732,19 +1730,18 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
         }
 #endif
     }
-  sampling_factors=(char *) NULL;
-  attribute=GetImageAttribute(image,"JPEG-Sampling-factors");
-  if ((attribute != (const ImageAttribute *) NULL) &&
-      (attribute->value != (char *) NULL))
+  sampling_factors=(const char *) NULL;
+  value=GetImageProperty(image,"JPEG-Sampling-factors");
+  if (value != (char *) NULL)
     {
-      sampling_factors=attribute->value;
+      sampling_factors=value;
       if (image->debug != MagickFalse)
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),
           "  Input sampling-factors=%s",sampling_factors);
     }
   if (image_info->sampling_factor != (char *) NULL)
     sampling_factors=image_info->sampling_factor;
-  if (sampling_factors == (char *) NULL)
+  if (sampling_factors == (const char *) NULL)
     {
       if (image->quality >= 90)
         for (i=0; i < MAX_COMPONENTS; i++)
@@ -1791,6 +1788,12 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
         jpeg_info.comp_info[i].v_samp_factor=1;
       }
     }
+  if (jpeg_info.input_components == 1)
+    for (i=0; i < MAX_COMPONENTS; i++)
+    {
+      jpeg_info.comp_info[i].h_samp_factor=1;
+      jpeg_info.comp_info[i].v_samp_factor=1;
+    }
   jpeg_start_compress(&jpeg_info,MagickTrue);
   if (image->debug != MagickFalse)
     {
@@ -1911,12 +1914,11 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   /*
     Write JPEG profiles.
   */
-  attribute=GetImageAttribute(image,"Comment");
-  if ((attribute != (const ImageAttribute *) NULL) &&
-      (attribute->value != (char *) NULL))
-    for (i=0; i < (long) strlen(attribute->value); i+=65533L)
-      jpeg_write_marker(&jpeg_info,JPEG_COM,(unsigned char *) attribute->value+
-        i,(unsigned int) Min((long) strlen(attribute->value+i),65533L));
+  value=GetImageProperty(image,"Comment");
+  if (value != (char *) NULL)
+    for (i=0; i < (long) strlen(value); i+=65533L)
+      jpeg_write_marker(&jpeg_info,JPEG_COM,(unsigned char *) value+i,
+        (unsigned int) Min((long) strlen(value+i),65533L));
   if (image->profiles != (void *) NULL)
     WriteProfile(&jpeg_info,image);
   /*
