@@ -51,6 +51,7 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -120,8 +121,9 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
+  image=AllocateImage(image_info);
   if (*image_info->filename != '@')
-    label=AcquireString(image_info->filename);
+    label=InterpretImageProperties(image_info,image,image_info->filename);
   else
     {
       label=FileToString(image_info->filename+1,~0,exception);
@@ -141,7 +143,6 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         *p='\n';
       }
   }
-  image=AllocateImage(image_info);
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
   draw_info->text=label;
   if ((image->columns != 0) || (image->rows != 0))
@@ -150,9 +151,9 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
         Fit label to canvas size.
       */
       status=GetMultilineTypeMetrics(image,draw_info,&metrics);
-      for ( ; status != MagickFalse; draw_info->pointsize*=2)
+      for ( ; status != MagickFalse; draw_info->pointsize*=2.0)
       {
-        width=(unsigned long) (metrics.width+metrics.max_advance+0.5);
+        width=(unsigned long) (metrics.width+0.5);
         height=(unsigned long) (metrics.height+0.5);
         if (((image->columns != 0) && (width >= image->columns)) ||
             ((image->rows != 0) && (height >= image->rows)))
@@ -161,7 +162,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       }
       for ( ; status != MagickFalse; draw_info->pointsize--)
       {
-        width=(unsigned long) (metrics.width+metrics.max_advance+0.5);
+        width=(unsigned long) (metrics.width+0.5);
         height=(unsigned long) (metrics.height+0.5);
         if ((image->columns != 0) && (width <= image->columns) &&
            ((image->rows == 0) || (height <= image->rows)))
@@ -182,19 +183,20 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
       return((Image *) NULL);
     }
   if (image->columns == 0)
-    image->columns=(unsigned long) (metrics.width+metrics.max_advance+0.5);
+    image->columns=(unsigned long) (metrics.width+0.5);
+  if (image->columns == 0)
+    image->columns=(unsigned long) (draw_info->pointsize+0.5);
   if (draw_info->gravity == UndefinedGravity)
     {
-      (void) FormatMagickString(geometry,MaxTextExtent,"+%g+%g",
-        metrics.max_advance/4,metrics.ascent);
-      if (image->rows == 0)
-        (void) FormatMagickString(geometry,MaxTextExtent,"+%g+%g",
-          image->columns/2.0-metrics.width/2.0,metrics.ascent);
+      (void) FormatMagickString(geometry,MaxTextExtent,"%+g%+g",
+        -metrics.bounds.x1,metrics.ascent);
       draw_info->geometry=AcquireString(geometry);
     }
   if (image->rows == 0)
     image->rows=(unsigned long) metrics.height;
-  SetImageBackgroundColor(image);
+  if (image->rows == 0)
+    image->rows=(unsigned long) (draw_info->pointsize+0.5);
+  (void) SetImageBackgroundColor(image);
   (void) AnnotateImage(image,draw_info);
   draw_info=DestroyDrawInfo(draw_info);
   return(GetFirstImageInList(image));
@@ -211,8 +213,8 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterLABELImage() adds attributes for the LABEL image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterLABELImage() adds properties for the LABEL image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
