@@ -277,9 +277,9 @@ static void InsertComplexFloatRow(Image *image,double *p,int y,double MinVal,
   {
     if (*p > 0)
       {
-        f=(*p/MaxVal)*(MaxRGB-q->red);
-        if ((f+q->red) > MaxRGB)
-          q->red=MaxRGB;
+        f=(*p/MaxVal)*(QuantumRange-q->red);
+        if ((f+q->red) > QuantumRange)
+          q->red=QuantumRange;
         else
           q->red+=(int) f;
         if ((int) f/2.0 > q->green)
@@ -289,9 +289,9 @@ static void InsertComplexFloatRow(Image *image,double *p,int y,double MinVal,
       }
     if (*p < 0)
       {
-        f=(*p/MaxVal)*(MaxRGB-q->blue);
-        if ((f+q->blue) > MaxRGB)
-          q->blue=MaxRGB;
+        f=(*p/MaxVal)*(QuantumRange-q->blue);
+        if ((f+q->blue) > QuantumRange)
+          q->blue=QuantumRange;
         else
           q->blue+=(int) f;
         if ((int) f/2.0 > q->green)
@@ -322,7 +322,7 @@ static void InsertFloatRow(Image *image,double *p,int y,double MinVal,
     return;
   for (x=0; x < (long) image->columns; x++)
   {
-    f=(MagickRealType) MaxRGB*(*p-MinVal)/(MaxVal-MinVal);
+    f=(MagickRealType) QuantumRange*(*p-MinVal)/(MaxVal-MinVal);
     q->red=RoundToQuantum(f);
     q->green=q->red;
     q->blue=q->red;
@@ -867,7 +867,7 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobByte(image,0x00);
   length=3*image->rows*image->columns;
   pad=((unsigned char) (length-1) & 0x7) ^ 0x7;
-  WriteBlobLSBLong(image,length+56L+pad);
+  WriteBlobLSBLong(image,(unsigned long) (length+56L+pad));
   WriteBlobLSBLong(image,0x06);
   WriteBlobLSBLong(image,0x08);
   WriteBlobLSBLong(image,0x06);
@@ -882,7 +882,7 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   WriteBlobLSBShort(image,1);
   WriteBlobLSBLong(image,'M');
   WriteBlobLSBLong(image,0x02);
-  WriteBlobLSBLong(image,length);
+  WriteBlobLSBLong(image,(unsigned long) length);
   for (y=0; y < (long) image->columns; y++)
   {
     p=AcquireImagePixels(image,y-1,0,1,image->rows-1,&image->exception);    
