@@ -213,7 +213,7 @@ static int convertHTMLcodes(char *s, int len)
             break;
         }
         if (o < 6)
-          (void) CopyMagickString(s+1,s+1+o,strlen(s+1+o)+1);
+          (void) strcpy(s+1,s+1+o);
         *s = val;
         return o;
       }
@@ -222,14 +222,14 @@ static int convertHTMLcodes(char *s, int len)
     {
       int
         i,
-        codes = sizeof(html_codes) / sizeof(html_code);
+        codes = (int) (sizeof(html_codes) / sizeof(html_code));
 
       for (i=0; i < codes; i++)
       {
         if (html_codes[i].len <= len)
-          if (stringnicmp(s, html_codes[i].code, html_codes[i].len) == 0)
+          if (stringnicmp(s,html_codes[i].code,(size_t) html_codes[i].len) == 0)
             {
-              (void) CopyMagickString(s+1,s+html_codes[i].len,strlen(s+html_codes[i].len)+1);
+              (void) strcpy(s+1,s+html_codes[i].len);
               *s = html_codes[i].val;
               return html_codes[i].len-1;
             }
@@ -262,7 +262,7 @@ static char *super_fgets(char **b, int *blen, Image *file)
 
         tlen=q-p;
         len<<=1;
-        p=(unsigned char *) ResizeMagickMemory(p,(len+2));
+        p=(unsigned char *) ResizeMagickMemory(p,(size_t) (len+2));
         *b=(char *) p;
         if (p == (unsigned char *) NULL)
           break;
@@ -325,18 +325,18 @@ static long parse8BIM(Image *ifile, Image *ofile)
 
   dataset = 0;
   recnum = 0;
-  line = (char *) AcquireMagickMemory(inputlen);
+  line = (char *) AcquireMagickMemory((size_t) inputlen);
   name = token = (char *)NULL;
   savedpos = 0;
   token_info=AcquireTokenInfo();
-  while(super_fgets(&line,&inputlen,ifile)!=NULL)
+  while (super_fgets(&line,&inputlen,ifile)!=NULL)
   {
     state=0;
     next=0;
 
-    token = (char *) AcquireMagickMemory(inputlen);
-    newstr = (char *) AcquireMagickMemory(inputlen);
-    while (Tokenizer(token_info, 0, token, inputlen, line, (char *) "",
+    token = (char *) AcquireMagickMemory((size_t) inputlen);
+    newstr = (char *) AcquireMagickMemory((size_t) inputlen);
+    while (Tokenizer(token_info, 0, token, (size_t) inputlen, line, (char *) "",
       (char *) "=", (char *) "\"", 0, &brkused,&next,&quoted)==0)
     {
       if (state == 0)
@@ -351,8 +351,9 @@ static long parse8BIM(Image *ifile, Image *ofile)
 
           state=0;
           next=0;
-          while(Tokenizer(token_info, 0, newstr, inputlen, token, (char *) "",
-            (char *) "#", (char *) "", 0, &brkused, &next, &quoted)==0)
+          while (Tokenizer(token_info, 0, newstr, (size_t) inputlen, token,
+            (char *) "", (char *) "#", (char *) "", 0, &brkused, &next,
+            &quoted)==0)
           {
             switch (state)
             {
@@ -363,12 +364,12 @@ static long parse8BIM(Image *ifile, Image *ofile)
                   dataset = (unsigned char) atoi(newstr);
                 break;
               case 1:
-                recnum = atoi(newstr);
+                recnum = (unsigned int) atoi(newstr);
                 break;
               case 2:
                 name=(char *) AcquireMagickMemory(strlen(newstr)+MaxTextExtent);
                 if (name)
-                  (void) CopyMagickString(name,newstr,strlen(newstr)+MaxTextExtent);
+                  (void) strcpy(name,newstr);
                 break;
             }
             state++;
@@ -380,7 +381,7 @@ static long parse8BIM(Image *ifile, Image *ofile)
             int
               next;
 
-            unsigned long
+            long
               len;
 
             char
@@ -388,16 +389,17 @@ static long parse8BIM(Image *ifile, Image *ofile)
               quoted;
 
             next=0;
-            len = strlen(token);
-            while (Tokenizer(token_info,0, newstr, inputlen, token, (char *) "",
-              (char *) "&", (char *) "", 0, &brkused, &next, &quoted)==0)
+            len = (long) strlen(token);
+            while (Tokenizer(token_info,0, newstr, (size_t) inputlen, token,
+              (char *) "", (char *) "&", (char *) "", 0, &brkused, &next,
+              &quoted)==0)
             {
               if (brkused && next > 0)
                 {
                   char
                     *s = &token[next-1];
 
-                  len -= convertHTMLcodes(s, strlen(s));
+                  len -= (long) convertHTMLcodes(s,(int) strlen(s));
                 }
             }
 
@@ -413,44 +415,44 @@ static long parse8BIM(Image *ifile, Image *ofile)
                   {
                     long diff = outputlen - savedolen;
                     currentpos = TellBlob(ofile);
-                    SeekBlob(ofile,savedpos,SEEK_SET);
-                    WriteBlobMSBLong(ofile,diff);
-                    SeekBlob(ofile,currentpos,SEEK_SET);
+                    (void) SeekBlob(ofile,savedpos,SEEK_SET);
+                    (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
+                    (void) SeekBlob(ofile,currentpos,SEEK_SET);
                     savedolen = 0L;
                   }
                 if (outputlen & 1)
                   {
-                    WriteBlobByte(ofile,0x00);
+                    (void) WriteBlobByte(ofile,0x00);
                     outputlen++;
                   }
-                WriteBlobString(ofile,"8BIM");
-                WriteBlobMSBShort(ofile,(unsigned short) recnum);
+                (void) WriteBlobString(ofile,"8BIM");
+                (void) WriteBlobMSBShort(ofile,(unsigned short) recnum);
                 outputlen += 6;
                 if (name)
-                  nlen = strlen(name);
-                WriteBlobByte(ofile,nlen);
+                  nlen = (unsigned char) strlen(name);
+                (void) WriteBlobByte(ofile,nlen);
                 outputlen++;
                 for (i=0; i<nlen; i++)
-                  WriteBlobByte(ofile,name[i]);
+                  (void) WriteBlobByte(ofile,(unsigned char) name[i]);
                 outputlen += nlen;
                 if ((nlen & 0x01) == 0)
                   {
-                    WriteBlobByte(ofile,0x00);
+                    (void) WriteBlobByte(ofile,0x00);
                     outputlen++;
                   }
                 if (recnum != IPTC_ID)
                   {
-                    WriteBlobMSBLong(ofile, len);
+                    (void) WriteBlobMSBLong(ofile, (unsigned long) len);
                     outputlen += 4;
 
                     next=0;
                     outputlen += len;
                     while (len--)
-                      WriteBlobByte(ofile,token[next++]);
+                      (void) WriteBlobByte(ofile,(unsigned char) token[next++]);
 
                     if (outputlen & 1)
                       {
-                        WriteBlobByte(ofile,0x00);
+                        (void) WriteBlobByte(ofile,0x00);
                         outputlen++;
                       }
                   }
@@ -458,7 +460,7 @@ static long parse8BIM(Image *ifile, Image *ofile)
                   {
                     /* patch in a fake length for now and fix it later */
                     savedpos = TellBlob(ofile);
-                    WriteBlobMSBLong(ofile,0xFFFFFFFFUL);
+                    (void) WriteBlobMSBLong(ofile,0xFFFFFFFFUL);
                     outputlen += 4;
                     savedolen = outputlen;
                   }
@@ -467,15 +469,15 @@ static long parse8BIM(Image *ifile, Image *ofile)
               {
                 if (len <= 0x7FFF)
                   {
-                    WriteBlobByte(ofile,0x1c);
-                    WriteBlobByte(ofile,dataset);
-                    WriteBlobByte(ofile,(unsigned char) (recnum & 0xff));
-                    WriteBlobMSBShort(ofile,len);
+                    (void) WriteBlobByte(ofile,0x1c);
+                    (void) WriteBlobByte(ofile,(unsigned char) dataset);
+                    (void) WriteBlobByte(ofile,(unsigned char) (recnum & 0xff));
+                    (void) WriteBlobMSBShort(ofile,(unsigned short) len);
                     outputlen += 5;
                     next=0;
                     outputlen += len;
                     while (len--)
-                      WriteBlobByte(ofile,token[next++]);
+                      (void) WriteBlobByte(ofile,(unsigned char) token[next++]);
                   }
               }
           }
@@ -492,9 +494,9 @@ static long parse8BIM(Image *ifile, Image *ofile)
       long diff = outputlen - savedolen;
 
       currentpos = TellBlob(ofile);
-      SeekBlob(ofile,savedpos,SEEK_SET);
-      WriteBlobMSBLong(ofile,diff);
-      SeekBlob(ofile,currentpos,SEEK_SET);
+      (void) SeekBlob(ofile,savedpos,SEEK_SET);
+      (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
+      (void) SeekBlob(ofile,currentpos,SEEK_SET);
       savedolen = 0L;
     }
   return outputlen;
@@ -514,8 +516,8 @@ static char *super_fgets_w(char **b, int *blen, Image *file)
   p=(unsigned char *) (*b);
   for (q=p; ; q++)
   {
-    c=ReadBlobLSBShort(file);
-    if (c == ((unsigned short) ~0) || c == '\n')
+    c=(int) ReadBlobLSBShort(file);
+    if ((c == -1) || (c == '\n'))
       break;
    if (EOFBlob(file))
       break;
@@ -526,7 +528,7 @@ static char *super_fgets_w(char **b, int *blen, Image *file)
 
         tlen=q-p;
         len<<=1;
-        p=(unsigned char *) ResizeMagickMemory(p,(len+2));
+        p=(unsigned char *) ResizeMagickMemory(p,(size_t) (len+2));
         *b=(char *) p;
         if (p == (unsigned char *) NULL)
           break;
@@ -585,18 +587,18 @@ static long parse8BIMW(Image *ifile, Image *ofile)
 
   dataset = 0;
   recnum = 0;
-  line = (char *) AcquireMagickMemory(inputlen);
+  line = (char *) AcquireMagickMemory((size_t) inputlen);
   name = token = (char *)NULL;
   savedpos = 0;
   token_info=AcquireTokenInfo();
-  while(super_fgets_w(&line,&inputlen,ifile)!=NULL)
+  while (super_fgets_w(&line,&inputlen,ifile) != NULL)
   {
     state=0;
     next=0;
 
-    token = (char *) AcquireMagickMemory(inputlen);
-    newstr = (char *) AcquireMagickMemory(inputlen);
-    while (Tokenizer(token_info, 0, token, inputlen, line,
+    token=(char *) AcquireMagickMemory((size_t) inputlen);
+    newstr=(char *) AcquireMagickMemory((size_t) inputlen);
+    while (Tokenizer(token_info, 0, token, (size_t) inputlen, line,
           (char *) "", (char *) "=",
       (char *) "\"", 0, &brkused,&next,&quoted)==0)
     {
@@ -612,8 +614,9 @@ static long parse8BIMW(Image *ifile, Image *ofile)
 
           state=0;
           next=0;
-          while(Tokenizer(token_info, 0, newstr, inputlen, token, (char *) "",
-            (char *) "#", (char *) "", 0, &brkused, &next, &quoted)==0)
+          while (Tokenizer(token_info, 0, newstr, (size_t) inputlen, token,
+            (char *) "", (char *) "#", (char *) "", 0, &brkused, &next,
+            &quoted)==0)
           {
             switch (state)
             {
@@ -624,7 +627,7 @@ static long parse8BIMW(Image *ifile, Image *ofile)
                   dataset = (unsigned char) atoi(newstr);
                 break;
               case 1:
-                recnum = atoi(newstr);
+                recnum=(unsigned int) atoi(newstr);
                 break;
               case 2:
                 name=(char *) AcquireMagickMemory(strlen(newstr)+MaxTextExtent);
@@ -641,7 +644,7 @@ static long parse8BIMW(Image *ifile, Image *ofile)
             int
               next;
 
-            unsigned long
+            long
               len;
 
             char
@@ -649,16 +652,17 @@ static long parse8BIMW(Image *ifile, Image *ofile)
               quoted;
 
             next=0;
-            len = strlen(token);
-            while (Tokenizer(token_info,0, newstr, inputlen, token, (char *) "",
-              (char *) "&", (char *) "", 0, &brkused, &next, &quoted)==0)
+            len = (long) strlen(token);
+            while (Tokenizer(token_info,0, newstr, (size_t) inputlen, token,
+              (char *) "", (char *) "&", (char *) "", 0, &brkused, &next,
+              &quoted)==0)
             {
               if (brkused && next > 0)
                 {
                   char
                     *s = &token[next-1];
 
-                  len -= convertHTMLcodes(s, strlen(s));
+                  len -= (long) convertHTMLcodes(s,(int) strlen(s));
                 }
             }
 
@@ -674,44 +678,44 @@ static long parse8BIMW(Image *ifile, Image *ofile)
                   {
                     long diff = outputlen - savedolen;
                     currentpos = TellBlob(ofile);
-                    SeekBlob(ofile,savedpos,SEEK_SET);
-                    WriteBlobMSBLong(ofile,diff);
-                    SeekBlob(ofile,currentpos,SEEK_SET);
+                    (void) SeekBlob(ofile,savedpos,SEEK_SET);
+                    (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
+                    (void) SeekBlob(ofile,currentpos,SEEK_SET);
                     savedolen = 0L;
                   }
                 if (outputlen & 1)
                   {
-                    WriteBlobByte(ofile,0x00);
+                    (void) WriteBlobByte(ofile,0x00);
                     outputlen++;
                   }
-                WriteBlobString(ofile,"8BIM");
-                WriteBlobMSBShort(ofile,(unsigned short) recnum);
+                (void) WriteBlobString(ofile,"8BIM");
+                (void) WriteBlobMSBShort(ofile,(unsigned short) recnum);
                 outputlen += 6;
                 if (name)
-                  nlen = strlen(name);
-                WriteBlobByte(ofile,nlen);
+                  nlen = (unsigned char) strlen(name);
+                (void) WriteBlobByte(ofile,(unsigned char) nlen);
                 outputlen++;
                 for (i=0; i<nlen; i++)
-                  WriteBlobByte(ofile,name[i]);
+                  (void) WriteBlobByte(ofile,(unsigned char) name[i]);
                 outputlen += nlen;
                 if ((nlen & 0x01) == 0)
                   {
-                    WriteBlobByte(ofile,0x00);
+                    (void) WriteBlobByte(ofile,0x00);
                     outputlen++;
                   }
                 if (recnum != IPTC_ID)
                   {
-                    WriteBlobMSBLong(ofile, len);
+                    (void) WriteBlobMSBLong(ofile,(unsigned long) len);
                     outputlen += 4;
 
                     next=0;
                     outputlen += len;
                     while (len--)
-                      WriteBlobByte(ofile,token[next++]);
+                      (void) WriteBlobByte(ofile,(unsigned char) token[next++]);
 
                     if (outputlen & 1)
                       {
-                        WriteBlobByte(ofile,0x00);
+                        (void) WriteBlobByte(ofile,0x00);
                         outputlen++;
                       }
                   }
@@ -719,7 +723,7 @@ static long parse8BIMW(Image *ifile, Image *ofile)
                   {
                     /* patch in a fake length for now and fix it later */
                     savedpos = TellBlob(ofile);
-                    WriteBlobMSBLong(ofile,0xFFFFFFFFUL);
+                    (void) WriteBlobMSBLong(ofile,0xFFFFFFFFUL);
                     outputlen += 4;
                     savedolen = outputlen;
                   }
@@ -728,15 +732,15 @@ static long parse8BIMW(Image *ifile, Image *ofile)
               {
                 if (len <= 0x7FFF)
                   {
-                    WriteBlobByte(ofile,0x1c);
-                    WriteBlobByte(ofile,dataset);
-                    WriteBlobByte(ofile,(unsigned char) (recnum & 0xff));
-                    WriteBlobMSBShort(ofile,(unsigned short) len);
+                    (void) WriteBlobByte(ofile,0x1c);
+                    (void) WriteBlobByte(ofile,dataset);
+                    (void) WriteBlobByte(ofile,(unsigned char) (recnum & 0xff));
+                    (void) WriteBlobMSBShort(ofile,(unsigned short) len);
                     outputlen += 5;
                     next=0;
                     outputlen += len;
                     while (len--)
-                      WriteBlobByte(ofile,token[next++]);
+                      (void) WriteBlobByte(ofile,(unsigned char) token[next++]);
                   }
               }
           }
@@ -753,9 +757,9 @@ static long parse8BIMW(Image *ifile, Image *ofile)
       long diff = outputlen - savedolen;
 
       currentpos = TellBlob(ofile);
-      SeekBlob(ofile,savedpos,SEEK_SET);
-      WriteBlobMSBLong(ofile,diff);
-      SeekBlob(ofile,currentpos,SEEK_SET);
+      (void) SeekBlob(ofile,savedpos,SEEK_SET);
+      (void) WriteBlobMSBLong(ofile,(unsigned long) diff);
+      (void) SeekBlob(ofile,currentpos,SEEK_SET);
       savedolen = 0L;
     }
   return outputlen;
@@ -802,7 +806,7 @@ static int jpeg_transfer_1(Image *ifile, Image *ofile)
   c = ReadBlobByte(ifile);
   if (c == EOF)
     return EOF;
-  WriteBlobByte(ofile,(unsigned char) c);
+  (void) WriteBlobByte(ofile,(unsigned char) c);
   return c;
 }
 
@@ -877,7 +881,7 @@ static int jpeg_nextmarker(Image *ifile, Image *ofile)
       return M_EOI; /* we hit EOF */
     else
       if (c != 0xff)
-        WriteBlobByte(ofile,(unsigned char) c);
+        (void) WriteBlobByte(ofile,(unsigned char) c);
   } while (c != 0xff);
 
   /* get marker byte, swallowing possible padding */
@@ -937,7 +941,7 @@ static int jpeg_embed(Image *ifile, Image *ofile, Image *iptc)
 
   while (done == MagickFalse)
   {
-    marker = jpeg_nextmarker(ifile, ofile);
+    marker=(unsigned int) jpeg_nextmarker(ifile, ofile);
     if (marker == M_EOI)
       { /* EOF */
         break;
@@ -946,8 +950,8 @@ static int jpeg_embed(Image *ifile, Image *ofile, Image *iptc)
       {
         if (marker != M_APP13)
           {
-            WriteBlobByte(ofile,0xff);
-            WriteBlobByte(ofile,(unsigned char) marker);
+            (void) WriteBlobByte(ofile,0xff);
+            (void) WriteBlobByte(ofile,(unsigned char) marker);
           }
       }
 
@@ -964,17 +968,17 @@ static int jpeg_embed(Image *ifile, Image *ofile, Image *iptc)
 
         if (iptc != (Image *)NULL)
           {
-            len=GetBlobSize(iptc);
+            len=(unsigned int) GetBlobSize(iptc);
             if (len & 1)
               len++; /* make the length even */
-            psheader[ 2 ] = (len+16)>>8;
-            psheader[ 3 ] = (len+16)&0xff;
+            psheader[2]=(char) ((len+16)>>8);
+            psheader[3]=(char) ((len+16)&0xff);
             for (inx = 0; inx < 18; inx++)
-              WriteBlobByte(ofile,psheader[inx]);
+              (void) WriteBlobByte(ofile,(unsigned char) psheader[inx]);
             jpeg_read_remaining(iptc, ofile);
-            len=GetBlobSize(iptc);
+            len=(unsigned int) GetBlobSize(iptc);
             if (len & 1)
-              WriteBlobByte(ofile,0);
+              (void) WriteBlobByte(ofile,0);
           }
         break;
 
@@ -1001,8 +1005,8 @@ static void jpeg_strip(Image *ifile, Image *ofile)
   marker = jpeg_skip_till_marker(ifile, M_SOI);
   if (marker == M_SOI)
   {
-    WriteBlobByte(ofile,0xff);
-    WriteBlobByte(ofile,M_SOI);
+    (void) WriteBlobByte(ofile,0xff);
+    (void) WriteBlobByte(ofile,M_SOI);
     jpeg_read_remaining(ifile, ofile);
   }
 }
@@ -1072,7 +1076,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
     }
   image->columns=1;
   image->rows=1;
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   length=1;
   if (LocaleNCompare(image_info->magick,"8BIM",4) == 0)
     {
@@ -1091,15 +1095,15 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
       AttachBlob(buff->blob,blob,length);
       if (LocaleCompare(image_info->magick,"8BIMTEXT") == 0)
         {
-          length=parse8BIM(image, buff);
+          length=(size_t) parse8BIM(image, buff);
           if (length & 1)
-            WriteBlobByte(buff,0x0);
+            (void) WriteBlobByte(buff,0x0);
         }
       else if (LocaleCompare(image_info->magick,"8BIMWTEXT") == 0)
         {
-          length=parse8BIMW(image, buff);
+          length=(size_t) parse8BIMW(image, buff);
           if (length & 1)
-            WriteBlobByte(buff,0x0);
+            (void) WriteBlobByte(buff,0x0);
         }
       else
         {
@@ -1108,7 +1112,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
             c=ReadBlobByte(image);
             if (c == EOF)
               break;
-            WriteBlobByte(buff,(unsigned char) c);
+            (void) WriteBlobByte(buff,(unsigned char) c);
           }
         }
       profile=AcquireStringInfo((size_t) GetBlobSize(buff));
@@ -1145,16 +1149,14 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
           int
             result;
 
-          profile=(StringInfo *) image_info->client_data;
-          if ((profile == (StringInfo *) NULL) ||
-              (profile->datum == (unsigned char *) NULL) ||
-              (profile->length == 0))
+          if (image_info->profile == (void *) NULL)
             {
               blob=DetachBlob(buff->blob);
               blob=(char *) RelinquishMagickMemory(blob);
               buff=DestroyImage(buff);
               ThrowReaderException(CoderError,"NoIPTCProfileAvailable");
             }
+          profile=CloneStringInfo((StringInfo *) image_info->profile);
           iptc=AllocateImage((ImageInfo *) NULL);
           if (iptc == (Image *) NULL)
             {
@@ -1185,7 +1187,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
             c=ReadBlobByte(image);
             if (c == EOF)
               break;
-            WriteBlobByte(buff,c);
+            (void) WriteBlobByte(buff,c);
           }
 #else
           long
@@ -1194,11 +1196,9 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
           unsigned char
             *buffer;
 
-          size_t
-            length;
-
           ssize_t
-            count;
+            count,
+            length;
 
           buffer=(unsigned char *) AcquireMagickMemory(MagickMaxBufferSize*
             sizeof(*buffer));
@@ -1210,7 +1210,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
                 count=0;
                 for (i=0; i < (long) length; i+=count)
                 {
-                  count=WriteBlob(buff,length-i,buffer+i);
+                  count=WriteBlob(buff,(size_t) (length-i),buffer+i);
                   if (count <= 0)
                     break;
                 }
@@ -1249,7 +1249,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
         c=ReadBlobByte(image);
         if (c == EOF)
           break;
-        WriteBlobByte(buff,(unsigned char) c);
+        (void) WriteBlobByte(buff,(unsigned char) c);
       }
       profile=AcquireStringInfo((size_t) GetBlobSize(buff));
       SetStringInfoDatum(profile,GetBlobStreamData(buff));
@@ -1272,13 +1272,13 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
         }
       AttachBlob(buff->blob,blob,length);
       /* write out the header - length field patched below */
-      WriteBlob(buff,11,(unsigned char *) "8BIM\04\04\0\0\0\0\01");
-      WriteBlobByte(buff,0xe0);
+      (void) WriteBlob(buff,11,(unsigned char *) "8BIM\04\04\0\0\0\0\01");
+      (void) WriteBlobByte(buff,0xe0);
       if (LocaleCompare(image_info->magick,"IPTCTEXT") == 0)
         {
-          length=parse8BIM(image, buff);
+          length=(size_t) parse8BIM(image,buff);
           if (length & 1)
-            WriteBlobByte(buff,0x00);
+            (void) WriteBlobByte(buff,0x00);
         }
       else if (LocaleCompare(image_info->magick,"IPTCWTEXT") == 0)
         {
@@ -1290,7 +1290,7 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
             c=ReadBlobByte(image);
             if (c == EOF)
               break;
-            WriteBlobByte(buff,(unsigned char) c);
+            (void) WriteBlobByte(buff,(unsigned char) c);
           }
         }
       profile=AcquireStringInfo((size_t) GetBlobSize(buff));
@@ -1298,8 +1298,8 @@ static Image *ReadMETAImage(const ImageInfo *image_info,
         subtract off the length of the 8BIM stuff.
       */
       length=profile->length-12;
-      profile->datum[10]=length >> 8;
-      profile->datum[11]=length & 0xff;
+      profile->datum[10]=(unsigned char) (length >> 8);
+      profile->datum[11]=(unsigned char) (length & 0xff);
       SetStringInfoDatum(profile,GetBlobStreamData(buff));
       (void) SetImageProfile(image,"iptc",profile);
       profile=DestroyStringInfo(profile);
@@ -1621,12 +1621,13 @@ iptc_find:
             break;
           info_length++;
         }
-        tag_length=(((long) buffer[0]) << 24) | (((long) buffer[1]) << 16) |
-          (((long) buffer[2]) << 8) | (((long) buffer[3])); 
+        tag_length=(((unsigned long) buffer[0]) << 24) |
+          (((unsigned long) buffer[1]) << 16) |
+          (((unsigned long) buffer[2]) << 8) | (((unsigned long) buffer[3])); 
       }
     else
       {
-        tag_length=(c << 8);
+        tag_length=(unsigned long) (c << 8);
         c=(*p++);
         length--;
         if (length == 0)
@@ -1650,42 +1651,42 @@ static void formatString(Image *ofile, const char *s, int len)
   char
     temp[MaxTextExtent];
 
-  WriteBlobByte(ofile,'"');
+  (void) WriteBlobByte(ofile,'"');
   for (; len > 0; len--, s++) {
     int c = (*s) & 255;
     switch (c) {
     case '&':
-      WriteBlobString(ofile,"&amp;");
+      (void) WriteBlobString(ofile,"&amp;");
       break;
 #ifdef HANDLE_GT_LT
     case '<':
-      WriteBlobString(ofile,"&lt;");
+      (void) WriteBlobString(ofile,"&lt;");
       break;
     case '>':
-      WriteBlobString(ofile,"&gt;");
+      (void) WriteBlobString(ofile,"&gt;");
       break;
 #endif
     case '"':
-      WriteBlobString(ofile,"&quot;");
+      (void) WriteBlobString(ofile,"&quot;");
       break;
     default:
       if (isprint(c))
-        WriteBlobByte(ofile,*s);
+        (void) WriteBlobByte(ofile,(unsigned char) *s);
       else
         {
           (void) FormatMagickString(temp,MaxTextExtent,"&#%d;", c & 255);
-          WriteBlobString(ofile,temp);
+          (void) WriteBlobString(ofile,temp);
         }
       break;
     }
   }
 #if defined(__WINDOWS__)
-  WriteBlobString(ofile,"\"\r\n");
+  (void) WriteBlobString(ofile,"\"\r\n");
 #else
 #if defined(macintosh)
-  WriteBlobString(ofile,"\"\r");
+  (void) WriteBlobString(ofile,"\"\r");
 #else
-  WriteBlobString(ofile,"\"\n");
+  (void) WriteBlobString(ofile,"\"\n");
 #endif
 #endif
 }
@@ -1778,7 +1779,7 @@ static int formatIPTC(Image *ifile, Image *ofile)
 
   int
     i,
-    tagcount = sizeof(tags) / sizeof(tag_spec);
+    tagcount = (int) (sizeof(tags) / sizeof(tag_spec));
 
   int
     c;
@@ -1809,7 +1810,7 @@ static int formatIPTC(Image *ifile, Image *ofile)
     /* try to match this record to one of the ones in our named table */
     for (i=0; i< tagcount; i++)
     {
-      if (tags[i].id == recnum)
+      if (tags[i].id == (short) recnum)
           break;
     }
     if (i < tagcount)
@@ -1855,7 +1856,7 @@ static int formatIPTC(Image *ifile, Image *ofile)
     else
       (void) FormatMagickString(temp,MaxTextExtent,"%d#%d=",
         (unsigned int) dataset,(unsigned int) recnum);
-    WriteBlobString(ofile,temp);
+    (void) WriteBlobString(ofile,temp);
     formatString( ofile, (char *)str, taglen );
     str=(unsigned char *) RelinquishMagickMemory(str);
 
@@ -1863,7 +1864,7 @@ static int formatIPTC(Image *ifile, Image *ofile)
 
     c=ReadBlobByte(ifile);
   }
-  return tagsfound;
+  return((int) tagsfound);
 }
 
 static int readWordFromBuffer(char **s, long *len)
@@ -1908,7 +1909,7 @@ static int formatIPTCfromBuffer(Image *ofile, char *s, long len)
 
   int
     i,
-    tagcount = sizeof(tags) / sizeof(tag_spec);
+    tagcount = (int) (sizeof(tags) / sizeof(tag_spec));
 
   int
     c;
@@ -1939,10 +1940,8 @@ static int formatIPTCfromBuffer(Image *ofile, char *s, long len)
     recnum = (unsigned char) c;
     /* try to match this record to one of the ones in our named table */
     for (i=0; i< tagcount; i++)
-    {
-      if (tags[i].id == recnum)
-          break;
-    }
+      if (tags[i].id == (short) recnum)
+        break;
     if (i < tagcount)
       readable = (unsigned char *) tags[i].name;
     else
@@ -2144,7 +2143,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
   if (LocaleCompare(image_info->magick,"8BIM") == 0)
     {
       /*
-        Write 8BIM image.
+        (void) Write 8BIM image.
       */
       profile=GetImageProfile(image,"8bim");
       if (profile == (StringInfo *) NULL)
@@ -2172,7 +2171,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
       info=profile->datum;
       length=profile->length;
-      length=GetIPTCStream(&info,length);
+      length=(unsigned long) GetIPTCStream(&info,(unsigned long) length);
       if (length == 0)
         ThrowWriterException(CoderError,"NoIPTCProfileAvailable");
       (void) WriteBlob(image,length,info);
@@ -2219,7 +2218,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
         ThrowWriterException(CoderError,"No8BIMDataIsAvailable");
       info=profile->datum;
       length=profile->length;
-      length=GetIPTCStream(&info,length);
+      length=(unsigned long) GetIPTCStream(&info,(unsigned long) length);
       if (length == 0)
         ThrowWriterException(CoderError,"NoIPTCProfileAvailable");
       status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
@@ -2242,7 +2241,7 @@ static MagickBooleanType WriteMETAImage(const ImageInfo *image_info,
       (LocaleCompare(image_info->magick,"XMP") == 0))
     {
       /*
-        Write APP1 image.
+        (void) Write APP1 image.
       */
       profile=GetImageProfile(image,image_info->magick);
       if (profile == (StringInfo *) NULL)
