@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -60,6 +59,7 @@
 #include "magick/option.h"
 #include "magick/pixel.h"
 #include "magick/profile.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -124,8 +124,8 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsMIFF() returns MagickTrue if the image format type, identified by the magick
-%  string, is MIFF.
+%  IsMIFF() returns MagickTrue if the image format type, identified by the
+%  magick string, is MIFF.
 %
 %  The format of the IsMIFF method is:
 %
@@ -413,6 +413,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   PixelPacket
     pixel;
 
+  QuantumInfo
+    quantum_info;
+
   QuantumType
     quantum_type;
 
@@ -527,7 +530,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           if (comment == (char *) NULL)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           *p='\0';
-          (void) SetImageAttribute(image,"Comment",comment);
+          (void) SetImageProperty(image,"Comment",comment);
           comment=(char *) RelinquishMagickMemory(comment);
           c=ReadBlobByte(image);
         }
@@ -613,7 +616,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                       exception);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'c':
@@ -647,7 +650,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->columns=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'd':
@@ -669,7 +672,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                       MagickDisposeOptions,MagickFalse,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'e':
@@ -681,7 +684,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                       MagickEndianOptions,MagickFalse,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'g':
@@ -702,7 +705,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                         image->chromaticity.green_primary.x;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'i':
@@ -718,7 +721,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->iterations=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'm':
@@ -741,7 +744,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     (void) CloneString(&image->montage,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'o':
@@ -753,7 +756,13 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                       MagickBooleanOptions,MagickFalse,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                if (LocaleCompare(keyword,"orientation") == 0)
+                  {
+                    image->orientation=(OrientationType) ParseMagickOption(
+                      MagickOrientationOptions,MagickFalse,options);
+                    break;
+                  }
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'p':
@@ -783,7 +792,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     profile=DestroyStringInfo(profile);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'q':
@@ -794,7 +803,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->quality=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'r':
@@ -812,8 +821,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                   }
                 if (LocaleCompare(keyword,"rendering-intent") == 0)
                   {
-                    image->rendering_intent=(RenderingIntent)
-                      ParseMagickOption(MagickIntentOptions,MagickFalse,options);
+                    image->rendering_intent=(RenderingIntent) ParseMagickOption(
+                      MagickIntentOptions,MagickFalse,options);
                     break;
                   }
                 if (LocaleCompare(keyword,"resolution") == 0)
@@ -830,7 +839,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->rows=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 's':
@@ -841,7 +850,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->scene=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 't':
@@ -852,7 +861,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->ticks_per_second=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'u':
@@ -864,7 +873,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                       MagickResolutionOptions,MagickFalse,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'v':
@@ -875,7 +884,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     version=atof(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'w':
@@ -891,12 +900,12 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                         image->chromaticity.white_point.x;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               default:
               {
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
             }
@@ -1066,16 +1075,18 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     if (image->compression == RLECompression)
       packet_size++;
     length=packet_size*image->columns;
-    pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
+    pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
     length=(size_t) Max(BZipMaxExtent(packet_size*image->columns),
       ZipMaxExtent(packet_size*image->columns));
-    compress_pixels=(unsigned char *) AcquireMagickMemory(length);
+    compress_pixels=(unsigned char *) AcquireMagickMemory(length*
+      sizeof(*compress_pixels));
     if ((pixels == (unsigned char *) NULL) ||
         (compress_pixels == (unsigned char *) NULL))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     /*
       Read image pixels.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     quantum_type=RGBQuantum;
     if (image->storage_class == PseudoClass)
       quantum_type=image->matte != MagickFalse ? IndexAlphaQuantum :
@@ -1134,7 +1145,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               if (code >= 0)
                 status=MagickTrue;
             }
-          status=ExportQuantumPixels(image,quantum_type,0,pixels);
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           break;
         }
 #endif
@@ -1177,7 +1188,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               if (code >= 0)
                 status=MagickTrue;
             }
-          status=ExportQuantumPixels(image,quantum_type,0,pixels);
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           break;
         }
 #endif
@@ -1207,7 +1218,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         default:
         {
           p=ReadBlobStream(image,packet_size*image->columns,pixels,&count);
-          status=ExportQuantumPixels(image,quantum_type,0,p);
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
           break;
         }
       }
@@ -1273,8 +1284,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterMIFFImage() adds attributes for the MIFF image format to the list of
-%  supported formats.  The attributes include the image format tag, a method to
+%  RegisterMIFFImage() adds properties for the MIFF image format to the list of
+%  supported formats.  The properties include the image format tag, a method to
 %  read and/or write the format, whether the format supports the saving of more
 %  than one frame to the same file or blob, whether the format supports native
 %  in-memory I/O, and a brief description of the format.
@@ -1517,8 +1528,9 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   CompressionType
     compression;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *property,
+    *value;
 
   IndexPacket
     index;
@@ -1538,6 +1550,9 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
   PixelPacket
     pixel;
 
+  QuantumInfo
+    quantum_info;
+
   QuantumType
     quantum_type;
 
@@ -1596,10 +1611,10 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
 #if defined(HasZLIB)
       case LZWCompression:
       case ZipCompression: compression=ZipCompression; break;
-#endif  
+#endif
 #if defined(HasBZLIB)
       case BZipCompression: compression=BZipCompression; break;
-#endif  
+#endif
       case RLECompression: compression=RLECompression; break;
       default:
         break;
@@ -1614,13 +1629,14 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (compression == RLECompression)
       packet_size+=image->depth/8;
     length=packet_size*image->columns;
-    pixels=(unsigned char *) AcquireMagickMemory(length);
+    pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
     length=(size_t) Max(BZipMaxExtent(packet_size*image->columns),
       ZipMaxExtent(packet_size*image->columns));
     if ((compression == BZipCompression) || (compression == ZipCompression))
       if (length != (size_t) ((unsigned int) length))
         compression=NoCompression;
-    compress_pixels=(unsigned char *) AcquireMagickMemory(length);
+    compress_pixels=(unsigned char *) AcquireMagickMemory(length*
+      sizeof(*compress_pixels));
     if ((pixels == (unsigned char *) NULL) ||
         (compress_pixels == (unsigned char *) NULL))
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1753,6 +1769,13 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           image->chromaticity.white_point.x,image->chromaticity.white_point.y);
         (void) WriteBlobString(image,buffer);
       }
+    if (image->orientation != UndefinedOrientation)
+      {
+        (void) FormatMagickString(buffer,MaxTextExtent,
+          "orientation=%s\n",MagickOptionToMnemonic(MagickOrientationOptions,
+          image->orientation));
+        (void) WriteBlobString(image,buffer);
+      }
     if (image->profiles != (void *) NULL)
       {
         const char
@@ -1784,26 +1807,29 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
-    ResetImageAttributeIterator(image);
-	  attribute=GetNextImageAttribute(image);
-    while (attribute != (const ImageAttribute *) NULL)
+    ResetImagePropertyIterator(image);
+    property=GetNextImageProperty(image);
+    while (property != (const char *) NULL)
     {
-      if (*attribute->key != '[')
+      if (*property != '[')
         {
-          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",attribute->key);
+          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
           (void) WriteBlobString(image,buffer);
-          for (i=0; i < (long) strlen(attribute->value); i++)
-            if (isspace((int) ((unsigned char) attribute->value[i])) != 0)
-              break;
-          if (i <= (long) strlen(attribute->value))
-            (void) WriteBlobByte(image,'{');
-          (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-            attribute->value);
-          if (i <= (long) strlen(attribute->value))
-            (void) WriteBlobByte(image,'}');
+          value=GetImageProperty(image,property);
+          if (value != (const char *) NULL)
+             {
+               for (i=0; i < (long) strlen(value); i++)
+                 if (isspace((int) ((unsigned char) value[i])) != 0)
+                   break;
+               if (i <= (long) strlen(value))
+                 (void) WriteBlobByte(image,'{');
+               (void) WriteBlob(image,strlen(value),(unsigned char *) value);
+               if (i <= (long) strlen(value))
+                 (void) WriteBlobByte(image,'}');
+             }
           (void) WriteBlobByte(image,'\n');
         }
-  	  attribute=GetNextImageAttribute(image);
+      property=GetNextImageProperty(image);
     }
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
@@ -1876,6 +1902,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               PopLongPixel(q,pixel);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
               PopLongPixel(q,pixel);
+              break;
             }
             case 16:
             {
@@ -1906,6 +1933,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     /*
       Write image pixels to file.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     quantum_type=RGBQuantum;
     if (image->storage_class == PseudoClass)
       quantum_type=image->matte != MagickFalse ? IndexAlphaQuantum :
@@ -1941,7 +1969,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             }
           zip_info.next_in=pixels;
           zip_info.avail_in=(uInt) (packet_size*image->columns);
-          (void) ImportQuantumPixels(image,quantum_type,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           do
           {
             zip_info.next_out=compress_pixels;
@@ -1994,7 +2022,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             }
           bzip_info.next_in=(char *) pixels;
           bzip_info.avail_in=(unsigned int) (packet_size*image->columns);
-          (void) ImportQuantumPixels(image,quantum_type,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           do
           {
             bzip_info.next_out=(char *) compress_pixels;
@@ -2043,7 +2071,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           for (x=0; x < (long) image->columns; x++)
           {
             if ((length < 255) && (x < (long) (image->columns-1)) &&
-                (ColorMatch(p,&pixel) != MagickFalse) &&
+                (IsColorEqual(p,&pixel) != MagickFalse) &&
                 ((image->matte == MagickFalse) ||
                  (p->opacity == pixel.opacity)) &&
                 ((indexes == (IndexPacket *) NULL) || (index == indexes[x])))
@@ -2065,7 +2093,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         }
         default:
         {
-          (void) ImportQuantumPixels(image,quantum_type,0,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           (void) WriteBlob(image,packet_size*image->columns,pixels);
           break;
         }
