@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -51,6 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -162,7 +164,10 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
     {
       if (bit == 0)
         byte=(unsigned long) ReadBlobByte(image);
-      indexes[x]=(IndexPacket) (((byte & 0x01) != 0) ? 0x01 : 0x00);
+      if (image_info->endian == LSBEndian)
+        indexes[x]=(IndexPacket) (((byte & 0x01) != 0) ? 0x00 : 0x01);
+      else
+        indexes[x]=(IndexPacket) (((byte & 0x01) != 0) ? 0x01 : 0x00);
       bit++;
       if (bit == 8)
         bit=0;
@@ -179,7 +184,7 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
           break;
       }
   }
-  SyncImage(image);
+  (void) SyncImage(image);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
@@ -221,9 +226,9 @@ ModuleExport void RegisterMONOImage(void)
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->adjoin=MagickFalse;
-  entry->description=
-    AcquireString("Bi-level bitmap in least-significant-byte first order");
-  entry->module=AcquireString("MONO");
+  entry->description=ConstantString(
+    "Bi-level bitmap in least-significant-byte first order");
+  entry->module=ConstantString("MONO");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -313,16 +318,20 @@ static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Convert image to a bi-level image.
   */
+  (void) SetImageType(image,PaletteType);
   (void) SetImageType(image,BilevelType);
-  polarity=(IndexPacket)
-    (PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2));
+  polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+    (QuantumRange/2) ? 1 : 0);
   if (image->colors == 2)
     polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-      PixelIntensityToQuantum(&image->colormap[1]));
+      PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
+  if (image->endian == LSBEndian)
+    polarity=polarity == 0 ? 1 : 0;
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
