@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,7 +41,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/cache.h"
@@ -60,6 +59,8 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/profile.h"
+#include "magick/property.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
@@ -86,7 +87,7 @@
 }
 #define PushCharPixel(pixel,p) \
 { \
-  pixel=(unsigned long) (*(p)); \
+  pixel=(unsigned char) (*(p)); \
   (p)++; \
 }
 #define PushLongPixel(pixel,p) \
@@ -97,7 +98,7 @@
 }
 #define PushShortPixel(pixel,p) \
 { \
-  pixel=(unsigned long) ((*(p) << 8) | *((p)+1)); \
+  pixel=(unsigned short) ((*(p) << 8) | *((p)+1)); \
   (p)+=2; \
 }
 
@@ -226,7 +227,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -245,6 +247,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       return((Image *) NULL);
     }
   *id='\0';
+  (void) ResetMagickMemory(keyword,0,sizeof(keyword));
   offset=0;
   do
   {
@@ -292,7 +295,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (comment == (char *) NULL)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           *p='\0';
-          (void) SetImageAttribute(image,"Comment",comment);
+          (void) SetImageProperty(image,"Comment",comment);
           comment=(char *) RelinquishMagickMemory(comment);
           c=ReadBlobByte(image);
         }
@@ -309,7 +312,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 break;
               if (c == (int) '=')
                 break;
-              if ((size_t) (p-keyword) < (MaxTextExtent-1))
+              if ((size_t) (p-keyword) < (MaxTextExtent/2))
                 *p++=(char) c;
               c=ReadBlobByte(image);
             } while (c != EOF);
@@ -378,7 +381,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                       exception);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'c':
@@ -412,7 +415,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     image->columns=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'd':
@@ -434,7 +437,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                       MagickDisposeOptions,MagickFalse,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'e':
@@ -451,7 +454,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     image->error.mean_error_per_pixel=atof(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'g':
@@ -472,7 +475,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                         image->chromaticity.green_primary.x;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'i':
@@ -488,7 +491,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     image->iterations=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'm':
@@ -521,7 +524,25 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     (void) CloneString(&image->montage,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
+                break;
+              }
+              case 'o':
+              case 'O':
+              {
+                if (LocaleCompare(keyword,"opaque") == 0)
+                  {
+                    image->matte=(MagickBooleanType) ParseMagickOption(
+                      MagickBooleanOptions,MagickFalse,options);
+                    break;
+                  }
+                if (LocaleCompare(keyword,"orientation") == 0)
+                  {
+                    image->orientation=(OrientationType) ParseMagickOption(
+                      MagickOrientationOptions,MagickFalse,options);
+                    break;
+                  }
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'p':
@@ -548,19 +569,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     profile=DestroyStringInfo(profile);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
-                break;
-              }
-              case 'o':
-              case 'O':
-              {
-                if (LocaleCompare(keyword,"opaque") == 0)
-                  {
-                    image->matte=(MagickBooleanType) ParseMagickOption(
-                      MagickBooleanOptions,MagickFalse,options);
-                    break;
-                  }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'q':
@@ -576,7 +585,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     quantum_depth=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'r':
@@ -610,7 +619,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     image->rows=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 's':
@@ -621,7 +630,18 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     image->scene=(unsigned long) atol(options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
+                break;
+              }
+              case 't':
+              case 'T':
+              {
+                if (LocaleCompare(keyword,"ticks-per-second") == 0)
+                  {
+                    image->ticks_per_second=(unsigned long) atol(options);
+                    break;
+                  }
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'u':
@@ -633,7 +653,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                       MagickResolutionOptions,MagickFalse,options);
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               case 'w':
@@ -649,12 +669,12 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                         image->chromaticity.white_point.x;
                     break;
                   }
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
               default:
               {
-                (void) SetImageAttribute(image,keyword,options);
+                (void) SetImageProperty(image,keyword,options);
                 break;
               }
             }
@@ -711,6 +731,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
         const char
           *name;
 
+        const StringInfo
+          *profile;
+
         /*
           Read image profiles.
         */
@@ -741,9 +764,6 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
             unsigned char
               *colormap;
 
-            unsigned long
-              pixel;
-
             /*
               Read image colormap from file.
             */
@@ -764,6 +784,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   "ImageDepthNotSupported");
               case 8:
               {
+                unsigned char
+                  pixel;
+
                 for (i=0; i < (long) image->colors; i++)
                 {
                   PushCharPixel(pixel,p);
@@ -777,6 +800,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
               case 16:
               {
+                unsigned short
+                  pixel;
+
                 for (i=0; i < (long) image->colors; i++)
                 {
                   PushShortPixel(pixel,p);
@@ -790,6 +816,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
               case 32:
               {
+                unsigned long
+                  pixel;
+
                 for (i=0; i < (long) image->colors; i++)
                 {
                   PushLongPixel(pixel,p);
@@ -833,7 +862,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Allocate next image structure.
         */
         AllocateNextImage(image_info,image);
-        if (image->next == (Image *) NULL)
+        if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
             return((Image *) NULL);
@@ -863,8 +892,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterMPCImage() adds attributes for the Cache image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterMPCImage() adds properties for the Cache image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -881,15 +910,15 @@ ModuleExport void RegisterMPCImage(void)
     *entry;
 
   entry=SetMagickInfo("CACHE");
-  entry->description=AcquireString("Magick Persistent Cache image format");
-  entry->module=AcquireString("CACHE");
+  entry->description=ConstantString("Magick Persistent Cache image format");
+  entry->module=ConstantString("CACHE");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPC");
   entry->decoder=(DecoderHandler *) ReadMPCImage;
   entry->encoder=(EncoderHandler *) WriteMPCImage;
   entry->magick=(MagickHandler *) IsMPC;
-  entry->description=AcquireString("Magick Persistent Cache image format");
-  entry->module=AcquireString("MPC");
+  entry->description=ConstantString("Magick Persistent Cache image format");
+  entry->module=ConstantString("MPC");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -949,8 +978,9 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
     buffer[MaxTextExtent],
     cache_filename[MaxTextExtent];
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *property,
+    *value;
 
   MagickBooleanType
     status;
@@ -973,7 +1003,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
@@ -1048,15 +1078,18 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
             image->page.x,image->page.y);
           (void) WriteBlobString(image,buffer);
         }
-    if ((image->next != (Image *) NULL) || (image->previous != (Image *) NULL))
+    if ((GetNextImageInList(image) != (Image *) NULL) ||
+        (GetPreviousImageInList(image) != (Image *) NULL))
       {
         if (image->scene == 0)
           (void) FormatMagickString(buffer,MaxTextExtent,
-            "iterations=%lu  delay=%lu\n",image->iterations,image->delay);
+            "iterations=%lu  delay=%lu  ticks-per-second=%lu\n",
+            image->iterations,image->delay,image->ticks_per_second);
         else
           (void) FormatMagickString(buffer,MaxTextExtent,
-            "scene=%lu  iterations=%lu  delay=%lu\n",image->scene,
-            image->iterations,image->delay);
+            "scene=%lu  iterations=%lu  delay=%lu  ticks-per-second=%lu\n",
+            image->scene,image->iterations,image->delay,
+            image->ticks_per_second);
         (void) WriteBlobString(image,buffer);
       }
     else
@@ -1079,6 +1112,12 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
               image->delay);
             (void) WriteBlobString(image,buffer);
           }
+        if (image->ticks_per_second != UndefinedTicksPerSecond)
+          {
+            (void) FormatMagickString(buffer,MaxTextExtent,
+              "ticks-per-second=%lu\n",image->ticks_per_second);
+            (void) WriteBlobString(image,buffer);
+          }
       }
     if (image->dispose != UndefinedDispose)
       {
@@ -1086,12 +1125,6 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           MagickOptionToMnemonic(MagickDisposeOptions,image->dispose));
         (void) WriteBlobString(image,buffer);
       }
-    if (image->compose != UndefinedCompositeOp)
-      {
-        (void) FormatMagickString(buffer,MaxTextExtent,"compose=%s\n",
-          MagickOptionToMnemonic(MagickCompositeOptions,image->compose));
-        (void) WriteBlobString(image,buffer);
-      }
     if (image->rendering_intent != UndefinedIntent)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,
@@ -1122,6 +1155,13 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           image->chromaticity.white_point.x,image->chromaticity.white_point.y);
         (void) WriteBlobString(image,buffer);
       }
+    if (image->orientation != UndefinedOrientation)
+      {
+        (void) FormatMagickString(buffer,MaxTextExtent,
+          "orientation=%s\n",MagickOptionToMnemonic(MagickOrientationOptions,
+          image->orientation));
+        (void) WriteBlobString(image,buffer);
+      }
     if (image->profiles != (void *) NULL)
       {
         const char
@@ -1153,26 +1193,29 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
-    ResetImageAttributeIterator(image);
-	  attribute=GetNextImageAttribute(image);
-		while (attribute != (const ImageAttribute *) NULL)
+    ResetImagePropertyIterator(image);
+    property=GetNextImageProperty(image);
+    while (property != (const char *) NULL)
     {
-      if (*attribute->key != '[')
+      if (*property != '[')
         {
-          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",attribute->key);
+          (void) FormatMagickString(buffer,MaxTextExtent,"%s=",property);
           (void) WriteBlobString(image,buffer);
-          for (i=0; i < (long) strlen(attribute->value); i++)
-            if (isspace((int) ((unsigned char) attribute->value[i])) != 0)
-              break;
-          if (i <= (long) strlen(attribute->value))
-            (void) WriteBlobByte(image,'{');
-          (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-            attribute->value);
-          if (i <= (long) strlen(attribute->value))
-            (void) WriteBlobByte(image,'}');
+          value=GetImageProperty(image,property);
+          if (value != (const char *) NULL)
+            {
+              for (i=0; i < (long) strlen(value); i++)
+                if (isspace((int) ((unsigned char) value[i])) != 0)
+                  break;
+              if (i <= (long) strlen(value))
+                (void) WriteBlobByte(image,'{');
+              (void) WriteBlob(image,strlen(value),(unsigned char *) value);
+              if (i <= (long) strlen(value))
+                (void) WriteBlobByte(image,'}');
+            }
           (void) WriteBlobByte(image,'\n');
         }
-  	  attribute=GetNextImageAttribute(image);
+      property=GetNextImageProperty(image);
     }
     (void) WriteBlobString(image,"\f\n:\032");
     if (image->montage != (char *) NULL)
@@ -1278,7 +1321,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
       &image->exception);
     if (status == MagickFalse)
       ThrowWriterException(CacheError,"UnableToPersistPixelCache");
-    if (image->next == (Image *) NULL)
+    if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
     if (image->progress_monitor != (MagickProgressMonitor) NULL)
