@@ -48,6 +48,7 @@
 #include "magick/geometry.h"
 #include "magick/image.h"
 #include "magick/image-private.h"
+#include "magick/layer.h"
 #include "magick/list.h"
 #include "magick/log.h"
 #include "magick/magick.h"
@@ -364,7 +365,7 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
   /*
     Write parameter file (see mpeg2encode documentation for details).
   */
-  file=fopen(basename,"w");
+  file=MagickOpenStream(basename,"w");
   if (file == (FILE *) NULL)
     return(MagickFalse);
   (void) fprintf(file,"MPEG\n");  /* comment */
@@ -379,7 +380,7 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
       */
       (void) FormatMagickString(filename,MaxTextExtent,"%s.iqm",basename);
       (void) fprintf(file,"%s\n",filename);
-      parameter_file=fopen(filename,"w");
+      parameter_file=MagickOpenStream(filename,"w");
       if (parameter_file == (FILE *) NULL)
         return(MagickFalse);
       if (image->quality >= 75)
@@ -415,7 +416,7 @@ static MagickBooleanType WriteMPEGParameterFiles(const ImageInfo *image_info,
       */
       (void) FormatMagickString(filename,MaxTextExtent,"%s.niq",basename);
       (void) fprintf(file,"%s\n",filename);
-      parameter_file=fopen(filename,"w");
+      parameter_file=MagickOpenStream(filename,"w");
       if (parameter_file == (FILE *) NULL)
         return(MagickFalse);
       q=Min(Max(66.0-(2*image->quality)/3.0,1.0),255);
