@@ -17,7 +17,7 @@
 %                                 April 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/draw.h"
@@ -51,6 +50,8 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/property.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -137,9 +138,6 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
-  size_t
-    length;
-
   unsigned char
     *primitive;
 
@@ -149,7 +147,8 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -188,22 +187,21 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
-  draw_info->affine.sx=
-    image->x_resolution == 0.0 ? 1.0 : image->x_resolution/DefaultResolution;
-  draw_info->affine.sy=
-    image->y_resolution == 0.0 ? 1.0 : image->y_resolution/DefaultResolution;
+  draw_info->affine.sx=image->x_resolution == 0.0 ? 1.0 : image->x_resolution/
+    DefaultResolution;
+  draw_info->affine.sy=image->y_resolution == 0.0 ? 1.0 : image->y_resolution/
+    DefaultResolution;
   image->columns=(unsigned long) (draw_info->affine.sx*image->columns);
   image->rows=(unsigned long) (draw_info->affine.sy*image->rows);
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   /*
     Render drawing.
   */
-  draw_info->fill=image_info->pen;
   primitive=GetBlobStreamData(image);
   if (primitive != (unsigned char) NULL)
     draw_info->primitive=AcquireString((char *) primitive);
   else
-    draw_info->primitive=(char *) FileToBlob(image->filename,&length,exception);
+    draw_info->primitive=FileToString(image->filename,~0,exception);
   if (draw_info->primitive == (char *) NULL)
     return((Image *) NULL);
   (void) DrawImage(image,draw_info);
@@ -223,8 +221,8 @@ static Image *ReadMVGImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterMVGImage() adds attributes for the MVG image format
-%  to the list of supported formats.  The attributes include the image format
+%  RegisterMVGImage() adds properties for the MVG image format
+%  to the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -246,8 +244,8 @@ ModuleExport void RegisterMVGImage(void)
   entry->magick=(MagickHandler *) IsMVG;
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->description=AcquireString("Magick Vector Graphics");
-  entry->module=AcquireString("MVG");
+  entry->description=ConstantString("Magick Vector Graphics");
+  entry->module=ConstantString("MVG");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -302,8 +300,8 @@ ModuleExport void UnregisterMVGImage(void)
 */
 static MagickBooleanType WriteMVGImage(const ImageInfo *image_info,Image *image)
 {
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   MagickBooleanType
     status;
@@ -316,15 +314,15 @@ static MagickBooleanType WriteMVGImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
-  attribute=GetImageAttribute(image,"[MVG]");
-  if (attribute == (ImageAttribute *) NULL)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  value=GetImageProperty(image,"[MVG]");
+  if (value == (const char *) NULL)
     ThrowWriterException(OptionError,"NoImageVectorGraphics");
   status=OpenBlob(image_info,image,WriteBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-    attribute->value);
+  (void) WriteBlob(image,strlen(value),(unsigned char *)
+    value);
   CloseBlob(image);
   return(MagickTrue);
 }
