@@ -130,7 +130,7 @@ static Image *ReadNULLImage(const ImageInfo *image_info,
     image->rows=1;
   image->matte=MagickTrue;
   GetMagickPixelPacket(image,&background);
-  background.opacity=TransparentOpacity;
+  background.opacity=(MagickRealType) TransparentOpacity;
   if (image->colorspace == CMYKColorspace)
     RGBtoCMYK(&background);
   for (y=0; y < (long) image->rows; y++)
