@@ -17,7 +17,7 @@
 %                               January 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -41,6 +41,7 @@
 #include "magick/studio.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
+#include "magick/color-private.h"
 #include "magick/colorspace.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
@@ -50,6 +51,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -122,7 +124,8 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -135,20 +138,20 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Initialize image structure.
   */
-  info=ReadBlobByte(image);
+  info=(unsigned char) ReadBlobByte(image);
   if (GetBit(info,4) == 0)
     {
-      image->columns=ReadBlobByte(image);
-      image->rows=ReadBlobByte(image);
+      image->columns=(unsigned long) ReadBlobByte(image);
+      image->rows=(unsigned long) ReadBlobByte(image);
     }
   else
     {
-      image->columns=ReadBlobMSBShort(image);
-      image->rows=ReadBlobMSBShort(image);
+      image->columns=(unsigned long) ReadBlobMSBShort(image);
+      image->rows=(unsigned long) ReadBlobMSBShort(image);
     }
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  depth=ReadBlobByte(image);
+  depth=(unsigned char) ReadBlobByte(image);
   if (depth != 1)
     ThrowReaderException(CoderError,"OnlyLevelZerofilesSupported");
   if (AllocateImageColormap(image,2) == MagickFalse)
@@ -177,7 +180,7 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (byte == EOF)
             ThrowReaderException(CorruptImageError,"CorruptImage");
         }
-      indexes[x]=(byte & (0x01 << (7-bit))) ? 0x00 : 0x01;
+      indexes[x]=(IndexPacket) ((byte & (0x01 << (7-bit))) ? 0x00 : 0x01);
       bit++;
       if (bit == 8)
         bit=0;
@@ -193,7 +196,7 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
       }
   }
-  SyncImage(image);
+  (void) SyncImage(image);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
@@ -233,8 +236,8 @@ ModuleExport void RegisterOTBImage(void)
   entry->decoder=(DecoderHandler *) ReadOTBImage;
   entry->encoder=(EncoderHandler *) WriteOTBImage;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("On-the-air bitmap");
-  entry->module=AcquireString("OTB");
+  entry->description=ConstantString("On-the-air bitmap");
+  entry->module=ConstantString("OTB");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -293,6 +296,9 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
 #define SetBit(a,i,set) \
   a=(unsigned char) ((set) ? (a) | (1L << (i)) : (a) & ~(1L << (i)))
 
+  IndexPacket
+    polarity;
+
   long
     y;
 
@@ -311,8 +317,7 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
   unsigned char
     bit,
     byte,
-    info,
-    polarity;
+    info;
 
   /*
     Open output image file.
@@ -322,32 +327,35 @@ static MagickBooleanType WriteOTBImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Convert image to a bi-level image.
   */
-  SetImageType(image,BilevelType);
-  polarity=PixelIntensityToQuantum(&image->colormap[0]) < (MaxRGB/2);
+  (void) SetImageType(image,PaletteType);
+  (void) SetImageType(image,BilevelType);
+  polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+    (QuantumRange/2) ? 1 : 0);
   if (image->colors == 2)
-    polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-      PixelIntensityToQuantum(&image->colormap[1]);
+    polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+      PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
   info=0;
   if ((image->columns >= 256) || (image->rows >= 256))
     SetBit(info,4,1);
   (void) WriteBlobByte(image,info);
   if ((image->columns >= 256) || (image->rows >= 256))
     {
-      (void) WriteBlobMSBShort(image,image->columns);
-      (void) WriteBlobMSBShort(image,image->rows);
+      (void) WriteBlobMSBShort(image,(unsigned short) image->columns);
+      (void) WriteBlobMSBShort(image,(unsigned short) image->rows);
     }
   else
     {
-      (void) WriteBlobByte(image,(long) image->columns);
-      (void) WriteBlobByte(image,(long) image->rows);
+      (void) WriteBlobByte(image,(unsigned char) image->columns);
+      (void) WriteBlobByte(image,(unsigned char) image->rows);
     }
   (void) WriteBlobByte(image,1);  /* depth */
   for (y=0; y < (long) image->rows; y++)
