@@ -42,7 +42,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -56,6 +55,7 @@
 #include "magick/memory_.h"
 #include "magick/paint.h"
 #include "magick/pixel-private.h"
+#include "magick/property.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
@@ -295,7 +295,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
-      DestroyImageList(image);
+      (void) DestroyImageList(image);
       return((Image *) NULL);
     }
   totalOffset=0;
@@ -310,13 +310,13 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
       ThrowReaderException(CorruptImageError,"NegativeOrZeroImageSize");
     bytes_per_row=ReadBlobMSBShort(image);
     flags=ReadBlobMSBShort(image);
-    bits_per_pixel=ReadBlobByte(image);
+    bits_per_pixel=(unsigned long) ReadBlobByte(image);
     if (bits_per_pixel > 16)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-    version=ReadBlobByte(image);
-    nextDepthOffset=ReadBlobMSBShort(image);
-    transparentIndex=ReadBlobByte(image);
-    compressionType=ReadBlobByte(image);
+    version=(unsigned long) ReadBlobByte(image);
+    nextDepthOffset=(unsigned long) ReadBlobMSBShort(image);
+    transparentIndex=(unsigned long) ReadBlobByte(image);
+    compressionType=(unsigned long) ReadBlobByte(image);
     pad=ReadBlobMSBShort(image);
     /*
       Initialize image colormap.
@@ -327,20 +327,20 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
     GetMagickPixelPacket(image,&transpix);
     if (bits_per_pixel == 16)  /* Direct Color */
       {
-        redbits=ReadBlobByte(image);  /* # of bits of red */
-        greenbits=ReadBlobByte(image);  /* # of bits of green */
-        bluebits=ReadBlobByte(image);  /* # of bits of blue */
+        redbits=(unsigned long) ReadBlobByte(image);  /* # of bits of red */
+        greenbits=(unsigned long) ReadBlobByte(image);  /* # of bits of green */
+        bluebits=(unsigned long) ReadBlobByte(image);  /* # of bits of blue */
         ReadBlobByte(image);  /* reserved by Palm */
         ReadBlobByte(image);  /* reserved by Palm */
-        transpix.red=QuantumRange*ReadBlobByte(image)/31;
-        transpix.green=QuantumRange*ReadBlobByte(image)/63;
-        transpix.blue=QuantumRange*ReadBlobByte(image)/31;
+        transpix.red=(MagickRealType) (QuantumRange*ReadBlobByte(image)/31);
+        transpix.green=(MagickRealType) (QuantumRange*ReadBlobByte(image)/63);
+        transpix.blue=(MagickRealType) (QuantumRange*ReadBlobByte(image)/31);
       }
     if (bits_per_pixel == 8)
       {
         if (flags & PALM_HAS_COLORMAP_FLAG)
           {
-            count=ReadBlobMSBShort(image);
+            count=(ssize_t) ReadBlobMSBShort(image);
             for (i=0; i < (long) count; i++)
             {
               ReadBlobByte(image);
@@ -398,9 +398,9 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
               image->compression=RLECompression;
               for (i=0; i < (long) bytes_per_row; )
               {
-                count=ReadBlobByte(image);
-                byte=ReadBlobByte(image);
-                (void) ResetMagickMemory(one_row+i,(int) byte,count);
+                count=(ssize_t) Min(ReadBlobByte(image),(long) bytes_per_row-i);
+                byte=(unsigned long) ReadBlobByte(image);
+                (void) ResetMagickMemory(one_row+i,(int) byte,(size_t) count);
                 i+=count;
               }
           }
@@ -411,12 +411,12 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
               image->compression=FaxCompression;
               for (i=0; i < (long) bytes_per_row; i+=8)
               {
-                count=ReadBlobByte(image);
+                count=(ssize_t) ReadBlobByte(image);
                 byte=Min(bytes_per_row-i,8);
                 for (bit=0; bit < byte; bit++)
                 {
                   if ((y == 0) || (count & (1 << (7 - bit))))
-                    one_row[i+bit]=ReadBlobByte(image);
+                    one_row[i+bit]=(unsigned char) ReadBlobByte(image);
                   else
                     one_row[i+bit]=lastrow[i+bit];
                 }
@@ -431,13 +431,15 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
       indexes=GetIndexes(image);
       if (bits_per_pixel == 16)
         {
+          if (image->columns > (2*bytes_per_row))
+            ThrowReaderException(CorruptImageError,"CorruptImage");
           for (x=0; x < (long) image->columns; x++)
           {
             color16=(*ptr++ << 8);
             color16|=(*ptr++);
-            q->red=(QuantumRange*((color16 >> 11) & 0x1f))/0x1f;
-            q->green=(QuantumRange*((color16 >> 5) & 0x3f))/0x3f;
-            q->blue=(QuantumRange*((color16 >> 0) & 0x1f))/0x1f;
+            q->red=(Quantum) ((QuantumRange*((color16 >> 11) & 0x1f))/0x1f);
+            q->green=(Quantum) ((QuantumRange*((color16 >> 5) & 0x3f))/0x3f);
+            q->blue=(Quantum) ((QuantumRange*((color16 >> 0) & 0x1f))/0x1f);
             q->opacity=OpaqueOpacity;
             q++;
           }
@@ -447,6 +449,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
           bit=8-bits_per_pixel;
           for (x=0; x < (long) image->columns; x++)
           {
+            if ((size_t) (ptr-one_row) >= bytes_per_row)
+              ThrowReaderException(CorruptImageError,"CorruptImage");
             index=(IndexPacket) (mask-(((*ptr) & (mask << bit)) >> bit));
             indexes[x]=index;
             *q++=image->colormap[index];
@@ -467,7 +471,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         if (bits_per_pixel != 16)
           SetMagickPixelPacket(image->colormap+(mask-transparentIndex),
             (const IndexPacket *) NULL,&transpix);
-        PaintTransparentImage(image,&transpix,TransparentOpacity);
+        (void) PaintTransparentImage(image,&transpix,TransparentOpacity);
       }
     one_row=(unsigned char *) RelinquishMagickMemory(one_row);
     if (compressionType == PALM_COMPRESSION_SCANLINE)
@@ -500,7 +504,7 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
         AllocateNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
-            DestroyImageList(image);
+            (void) DestroyImageList(image);
             return((Image *) NULL);
           }
         image=SyncNextImageInList(image);
@@ -529,8 +533,8 @@ static Image *ReadPALMImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPALMImage() adds attributes for the PALM image format to the list of
-%  supported formats.  The attributes include the image format tag, a method to
+%  RegisterPALMImage() adds properties for the PALM image format to the list of
+%  supported formats.  The properties include the image format tag, a method to
 %  read and/or write the format, whether the format supports the saving of more
 %  than one frame to the same file or blob, whether the format supports native
 %  in-memory I/O, and a brief description of the format.
@@ -575,7 +579,7 @@ ModuleExport void RegisterPALMImage(void)
 */
 ModuleExport void UnregisterPALMImage(void)
 {
-  UnregisterMagickInfo("PALM");
+  (void) UnregisterMagickInfo("PALM");
 }
 
 /*
@@ -608,8 +612,8 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
   int
     y;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   Image
     *map;
@@ -685,19 +689,19 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
   transpix.opacity=0;
   do
   {
-    attribute=GetImageAttribute(image, "Comment");
-    if (attribute != (ImageAttribute *)NULL)
-      if (LocaleCompare("COLORMAP",attribute->value) == 0)
+    value=GetImageProperty(image, "Comment");
+    if (value != (const char *) NULL)
+      if (LocaleCompare("COLORMAP",value) == 0)
         flags|=PALM_HAS_COLORMAP_FLAG;
     count = GetNumberColors(image, NULL, &exception);
     for (bits_per_pixel=1;  (1UL << bits_per_pixel) < count;  bits_per_pixel*=2);
     if (image_info->depth > 100)
       bits_per_pixel=image_info->depth-100;
     if (bits_per_pixel < 16)
-      SetImageColorspace(image,image->colorspace);
+      (void) SetImageColorspace(image,image->colorspace);
     if (bits_per_pixel < 8)
       {
-        SetImageColorspace(image,GRAYColorspace);
+        (void) SetImageColorspace(image,GRAYColorspace);
         (void) SortColormapByIntensity(image);
       }
     if (bits_per_pixel > 8)
@@ -730,11 +734,11 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
     offset=16;
     if (bits_per_pixel == 16)
       {
-        WriteBlobByte(image,5);  /* # of bits of red */
-        WriteBlobByte(image,6);  /* # of bits of green */
-        WriteBlobByte(image,5);  /* # of bits of blue */
-        WriteBlobByte(image,0);  /* reserved by Palm */
-        WriteBlobMSBLong(image,0);  /* no transparent color, YET */
+        (void) WriteBlobByte(image,5);  /* # of bits of red */
+        (void) WriteBlobByte(image,6);  /* # of bits of green */
+        (void) WriteBlobByte(image,5);  /* # of bits of blue */
+        (void) WriteBlobByte(image,0);  /* reserved by Palm */
+        (void) WriteBlobMSBLong(image,0);  /* no transparent color, YET */
         offset+=8;
       }
     if (bits_per_pixel == 8)
@@ -745,15 +749,15 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
             quantize_info.dither=IsPaletteImage(image,&image->exception);
             quantize_info.number_colors=image->colors;
             (void) QuantizeImage(&quantize_info,image);
-            WriteBlobMSBShort(image,(unsigned short) image->colors);
+            (void) WriteBlobMSBShort(image,(unsigned short) image->colors);
             for (count = 0; count < image->colors; count++)
             {
-              WriteBlobByte(image,count);
-              WriteBlobByte(image,ScaleQuantumToChar(
+              (void) WriteBlobByte(image,(unsigned char) count);
+              (void) WriteBlobByte(image,ScaleQuantumToChar(
                 image->colormap[count].red));
-              WriteBlobByte(image,
+              (void) WriteBlobByte(image,
                 ScaleQuantumToChar(image->colormap[count].green));
-              WriteBlobByte(image,
+              (void) WriteBlobByte(image,
                 ScaleQuantumToChar(image->colormap[count].blue));
             }
             offset+=2+count*4;
@@ -761,20 +765,20 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
       else  /* Map colors to Palm standard colormap */
         {
           map=ConstituteImage(256,1,"RGB",CharPixel,&PalmPalette,&exception);
-          SetImageColorspace(map,map->colorspace);
-          MapImage(image,map,image_info->dither);
+          (void) SetImageColorspace(map,map->colorspace);
+          (void) MapImage(image,map,image_info->dither);
           for (y=0; y < (long) image->rows; y++)
           {
             p=GetImagePixels(image,0,y,image->columns,1);
             indexes=GetIndexes(image);
             for (x=0; x < (long) image->columns; x++)
-              indexes[x]=FindColor(&image->colormap[indexes[x]]);
+              indexes[x]=(IndexPacket) FindColor(&image->colormap[indexes[x]]);
           }
-          DestroyImage(map);
+          (void) DestroyImage(map);
         }
       }
     if (flags & PALM_IS_COMPRESSED_FLAG)
-      WriteBlobMSBShort(image,0);  /* fill in size later */
+      (void) WriteBlobMSBShort(image,0);  /* fill in size later */
     lastrow=(unsigned char *) NULL;
     if (image->compression == FaxCompression)
       lastrow=(unsigned char *) AcquireMagickMemory(bytes_per_row);
@@ -794,8 +798,9 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
         {
           for (x=0; x < (int) image->columns; x++)
           {
-            color16=(((31*p->red)/QuantumRange) << 11) | (((63*p->green)/QuantumRange) << 5) |
-              ((31*p->blue)/QuantumRange);
+            color16=(unsigned short) ((((31*p->red)/QuantumRange) << 11) |
+              (((63*p->green)/QuantumRange) << 5) |
+              ((31*p->blue)/QuantumRange));
             if (p->opacity == TransparentOpacity)
               {
                 transpix.red=p->red;
@@ -804,8 +809,8 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
                 transpix.opacity=p->opacity;
                 flags|=PALM_HAS_TRANSPARENCY_FLAG;
               }
-            *ptr++=(color16 >> 8) & 0xff;
-            *ptr++=color16 & 0xff;
+            *ptr++=(unsigned char) ((color16 >> 8) & 0xff);
+            *ptr++=(unsigned char) (color16 & 0xff);
             p++;
           }
         }
@@ -857,12 +862,12 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
             for (x = 0;  x < (long) bytes_per_row;  x += 8)
             {
               tptr = tmpbuf;
-              for (bit = 0, byte = 0; bit < Min(8, bytes_per_row - x); bit++)
+              for (bit=0, byte=0; bit < (unsigned char) Min(8,bytes_per_row-x); bit++)
               {
                 if ((y == 0) || (lastrow[x + bit] != one_row[x + bit]))
                   {
                   byte |= (1 << (7 - bit));
-                  *tptr++ = one_row[x + bit];
+                  *tptr++ = (char) one_row[x + bit];
                 }
               }
               (void) WriteBlobByte(image, byte);
@@ -875,22 +880,22 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
       }
     if (flags & PALM_HAS_TRANSPARENCY_FLAG)
       {
-        SeekBlob(image,currentOffset+6,SEEK_SET);
+        (void) SeekBlob(image,currentOffset+6,SEEK_SET);
         (void) WriteBlobMSBShort(image,flags);
-        SeekBlob(image,currentOffset+12,SEEK_SET);
+        (void) SeekBlob(image,currentOffset+12,SEEK_SET);
         (void) WriteBlobByte(image,(unsigned char) transparentIndex);  /* trans index */
       }
     if (bits_per_pixel == 16)
       {
-        SeekBlob(image,currentOffset+20,SEEK_SET);
-        WriteBlobByte(image,0);  /* reserved by Palm */
-        WriteBlobByte(image,(unsigned char) ((31*transpix.red)/QuantumRange));
-        WriteBlobByte(image,(unsigned char) ((63*transpix.green)/QuantumRange));
-        WriteBlobByte(image,(unsigned char) ((31*transpix.blue)/QuantumRange));
+        (void) SeekBlob(image,currentOffset+20,SEEK_SET);
+        (void) WriteBlobByte(image,0);  /* reserved by Palm */
+        (void) WriteBlobByte(image,(unsigned char) ((31*transpix.red)/QuantumRange));
+        (void) WriteBlobByte(image,(unsigned char) ((63*transpix.green)/QuantumRange));
+        (void) WriteBlobByte(image,(unsigned char) ((31*transpix.blue)/QuantumRange));
       }
     if (flags & PALM_IS_COMPRESSED_FLAG)  /* fill in size now */
       {
-        SeekBlob(image,currentOffset+offset,SEEK_SET);
+        (void) SeekBlob(image,currentOffset+offset,SEEK_SET);
         (void) WriteBlobMSBShort(image,(unsigned short) (GetBlobSize(image)-currentOffset-offset));
       }
     if (one_row != (unsigned char *) NULL) 
@@ -905,11 +910,11 @@ static MagickBooleanType WritePALMImage(const ImageInfo *image_info,Image *image
       (void) WriteBlobByte(image,0);
     } 
     /* write nextDepthOffset and return to end of image */
-    SeekBlob(image,currentOffset+10,SEEK_SET);
+    (void) SeekBlob(image,currentOffset+10,SEEK_SET);
     nextDepthOffset=(unsigned long) ((GetBlobSize(image)-currentOffset)/4);
     (void) WriteBlobMSBShort(image,(unsigned short) nextDepthOffset);
     currentOffset=(MagickOffsetType) GetBlobSize(image);
-    SeekBlob(image,currentOffset,SEEK_SET);
+    (void) SeekBlob(image,currentOffset,SEEK_SET);
     image=SyncNextImageInList(image);
   } while (image_info->adjoin != MagickFalse);
   CloseBlob(image);
