@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color-private.h"
@@ -54,7 +53,8 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/pixel.h"
+#include "magick/property.h"
+#include "magick/quantum.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -170,14 +170,14 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *pixels,
     pixel=ReadBlobByte(image);
     if (pixel <= 0x80)
       {
-        count=pixel+1;
-        for (i=0; i < count; i++)
-          *p++=ReadBlobByte(image);
+        count=(ssize_t) (pixel+1);
+        for (i=0; i < (long) count; i++)
+          *p++=(unsigned char) ReadBlobByte(image);
         continue;
       }
-    count=pixel+1-0x80;
+    count=(ssize_t) (pixel+1-0x80);
     pixel=ReadBlobByte(image);
-    for (i=0; i < count; i++)
+    for (i=0; i < (long) count; i++)
       *p++=(unsigned char) pixel;
   }
   return(MagickTrue);
@@ -283,7 +283,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register unsigned char
     *p;
 
-  size_t
+  ssize_t
     count;
 
   unsigned char
@@ -314,8 +314,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Determine if this is a PDB image file.
   */
   count=ReadBlob(image,32,(unsigned char *) pdb_info.name);
-  pdb_info.attributes=ReadBlobMSBShort(image);
-  pdb_info.version=ReadBlobMSBShort(image);
+  pdb_info.attributes=(short) ReadBlobMSBShort(image);
+  pdb_info.version=(short) ReadBlobMSBShort(image);
   pdb_info.create_time=ReadBlobMSBLong(image);
   pdb_info.modify_time=ReadBlobMSBLong(image);
   pdb_info.archive_time=ReadBlobMSBLong(image);
@@ -329,7 +329,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   pdb_info.seed=ReadBlobMSBLong(image);
   pdb_info.next_record=ReadBlobMSBLong(image);
-  pdb_info.number_records=ReadBlobMSBShort(image);
+  pdb_info.number_records=(short) ReadBlobMSBShort(image);
   if (pdb_info.next_record != 0)
     ThrowReaderException(CoderError,"MultipleRecordListNotSupported");
   /*
@@ -368,21 +368,21 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   pdb_image.type=ReadBlobByte(image);
   pdb_image.reserved_1=ReadBlobMSBLong(image);
   pdb_image.note=ReadBlobMSBLong(image);
-  pdb_image.x_last=ReadBlobMSBShort(image);
-  pdb_image.y_last=ReadBlobMSBShort(image);
+  pdb_image.x_last=(short) ReadBlobMSBShort(image);
+  pdb_image.y_last=(short) ReadBlobMSBShort(image);
   pdb_image.reserved_2=ReadBlobMSBLong(image);
-  pdb_image.x_anchor=ReadBlobMSBShort(image);
-  pdb_image.y_anchor=ReadBlobMSBShort(image);
-  pdb_image.width=ReadBlobMSBShort(image);
-  pdb_image.height=ReadBlobMSBShort(image);
+  pdb_image.x_anchor=(short) ReadBlobMSBShort(image);
+  pdb_image.y_anchor=(short) ReadBlobMSBShort(image);
+  pdb_image.width=(short) ReadBlobMSBShort(image);
+  pdb_image.height=(short) ReadBlobMSBShort(image);
   /*
     Initialize image structure.
   */
-  image->columns=pdb_image.width;
-  image->rows=pdb_image.height;
+  image->columns=(unsigned long) pdb_image.width;
+  image->rows=(unsigned long) pdb_image.height;
   image->depth=8;
   image->storage_class=PseudoClass;
-  bits_per_pixel=pdb_image.type == 0 ? 2 : pdb_image.type == 2 ? 4 : 1;
+  bits_per_pixel=pdb_image.type == 0 ? 2UL : pdb_image.type == 2 ? 4UL : 1UL;
   if (AllocateImageColormap(image,1 << bits_per_pixel) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
@@ -399,7 +399,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     case 0:
     {
       image->compression=NoCompression;
-      count=ReadBlob(image,packets,pixels);
+      count=(ssize_t) ReadBlob(image,packets,pixels);
       break;
     }
     case 1:
@@ -433,7 +433,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           for (bit=0; bit < 8; bit++)
           {
-            index=(*p & (0x80 >> bit) ? 0x00 : 0x01);
+            index=(IndexPacket) (*p & (0x80 >> bit) ? 0x00 : 0x01);
             indexes[x+bit]=index;
             *q++=image->colormap[index];
           }
@@ -465,16 +465,16 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x+=4)
         {
-          index=ConstrainColormapIndex(image,3-((*p >> 6) & 0x03));
+          index=ConstrainColormapIndex(image,3UL-((*p >> 6) & 0x03));
           indexes[x]=index;
           *q++=image->colormap[index];
-          index=ConstrainColormapIndex(image,3-((*p >> 4) & 0x03));
+          index=ConstrainColormapIndex(image,3UL-((*p >> 4) & 0x03));
           indexes[x+1]=index;
           *q++=image->colormap[index];
-          index=ConstrainColormapIndex(image,3-((*p >> 2) & 0x03));
+          index=ConstrainColormapIndex(image,3UL-((*p >> 2) & 0x03));
           indexes[x+2]=index;
           *q++=image->colormap[index];
-          index=ConstrainColormapIndex(image,3-((*p) & 0x03));
+          index=ConstrainColormapIndex(image,3UL-((*p) & 0x03));
           indexes[x+3]=index;
           *q++=image->colormap[index];
           p++;
@@ -505,10 +505,10 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x+=2)
         {
-          index=ConstrainColormapIndex(image,15-((*p >> 4) & 0x0f));
+          index=ConstrainColormapIndex(image,15UL-((*p >> 4) & 0x0f));
           indexes[x]=index;
           *q++=image->colormap[index];
-          index=ConstrainColormapIndex(image,15-((*p) & 0x0f));
+          index=ConstrainColormapIndex(image,15UL-((*p) & 0x0f));
           indexes[x+1]=index;
           *q++=image->colormap[index];
           p++;
@@ -572,7 +572,7 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       *p='\0';
       if (comment == (char *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-      (void) SetImageAttribute(image,"Comment",comment);
+      (void) SetImageProperty(image,"Comment",comment);
       comment=(char *) RelinquishMagickMemory(comment);
     }
   CloseBlob(image);
@@ -590,8 +590,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPDBImage() adds attributes for the PDB image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterPDBImage() adds properties for the PDB image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -670,12 +670,12 @@ static unsigned char *EncodeRLE(unsigned char *destination,
   unsigned char *source,unsigned long literal,unsigned long repeat)
 {
   if (literal > 0)
-    *destination++=literal-1;
+    *destination++=(unsigned char) (literal-1);
   (void) CopyMagickMemory(destination,source,literal);
   destination+=literal;
   if (repeat > 0)
     {
-      *destination++=0x80 | (repeat-1);
+      *destination++=(unsigned char) (0x80 | (repeat-1));
       *destination++=source[literal];
     }
   return(destination);
@@ -683,6 +683,9 @@ static unsigned char *EncodeRLE(unsigned char *destination,
 
 static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
 {
+  const char
+    *comment;
+
   int
     bits;
 
@@ -698,6 +701,9 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   PDBInfo
     pdb_info;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -721,9 +727,6 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     packets,
     repeat;
 
-  const ImageAttribute
-    *comment;
-
   /*
     Open output image file.
   */
@@ -757,11 +760,11 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   (void) CopyMagickMemory(pdb_info.id,"View",4);
   pdb_info.seed=0;
   pdb_info.next_record=0;
-  comment=GetImageAttribute(image,"Comment");
-  pdb_info.number_records=(comment == (ImageAttribute *) NULL ? 1 : 2);
+  comment=GetImageProperty(image,"Comment");
+  pdb_info.number_records=(comment == (const char *) NULL ? 1 : 2);
   (void) WriteBlob(image,32,(unsigned char *) pdb_info.name);
-  (void) WriteBlobMSBShort(image,pdb_info.attributes);
-  (void) WriteBlobMSBShort(image,pdb_info.version);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_info.attributes);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_info.version);
   (void) WriteBlobMSBLong(image,pdb_info.create_time);
   (void) WriteBlobMSBLong(image,pdb_info.modify_time);
   (void) WriteBlobMSBLong(image,pdb_info.archive_time);
@@ -770,9 +773,9 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   (void) WriteBlobMSBLong(image,pdb_info.sort_info);
   (void) WriteBlob(image,4,(unsigned char *) pdb_info.type);
   (void) WriteBlob(image,4,(unsigned char *) pdb_info.id);
-  (void) WriteBlobMSBLong(image,pdb_info.seed);
-  (void) WriteBlobMSBLong(image,pdb_info.next_record);
-  (void) WriteBlobMSBShort(image,pdb_info.number_records);
+  (void) WriteBlobMSBLong(image,(unsigned long) pdb_info.seed);
+  (void) WriteBlobMSBLong(image,(unsigned long) pdb_info.next_record);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_info.number_records);
   (void) CopyMagickString(pdb_image.name,pdb_info.name,32);
   pdb_image.version=1;  /* RLE Compressed */
   switch (bits_per_pixel)
@@ -808,6 +811,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
   /*
     Convert to GRAY raster scanline.
   */
+  GetQuantumInfo(image_info,&quantum_info);
   bits=8/(long) bits_per_pixel-1;  /* start at most significant bits */
   literal=0;
   repeat=0;
@@ -818,7 +822,7 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    (void) ImportQuantumPixels(image,GrayQuantum,0,scanline);
+    (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,scanline);
     for (x=0; x < pdb_image.width; x++)
     {
       if (x < (long) image->columns)
@@ -892,7 +896,8 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
       /*
         Write the comment record header.
       */
-      (void) WriteBlobMSBLong(image,TellBlob(image)+8+58+q-runlength);
+      (void) WriteBlobMSBLong(image,(unsigned long) (TellBlob(image)+8+58+q-
+        runlength));
       (void) WriteBlobByte(image,0x40);
       (void) WriteBlobByte(image,0x6f);
       (void) WriteBlobByte(image,0x80);
@@ -902,21 +907,21 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     Write the Image data.
   */
   (void) WriteBlob(image,32,(unsigned char *) pdb_image.name);
-  (void) WriteBlobByte(image,pdb_image.version);
-  (void) WriteBlobByte(image,pdb_image.type);
+  (void) WriteBlobByte(image,(unsigned char) pdb_image.version);
+  (void) WriteBlobByte(image,(unsigned char) pdb_image.type);
   (void) WriteBlobMSBLong(image,pdb_image.reserved_1);
   (void) WriteBlobMSBLong(image,pdb_image.note);
-  (void) WriteBlobMSBShort(image,pdb_image.x_last);
-  (void) WriteBlobMSBShort(image,pdb_image.y_last);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_image.x_last);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_image.y_last);
   (void) WriteBlobMSBLong(image,pdb_image.reserved_2);
-  (void) WriteBlobMSBShort(image,pdb_image.x_anchor);
-  (void) WriteBlobMSBShort(image,pdb_image.y_anchor);
-  (void) WriteBlobMSBShort(image,pdb_image.width);
-  (void) WriteBlobMSBShort(image,pdb_image.height);
-  (void) WriteBlob(image,q-runlength,runlength);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_image.x_anchor);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_image.y_anchor);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_image.width);
+  (void) WriteBlobMSBShort(image,(unsigned short) pdb_image.height);
+  (void) WriteBlob(image,(size_t) (q-runlength),runlength);
   runlength=(unsigned char *) RelinquishMagickMemory(runlength);
   if (pdb_info.number_records > 1)
-    WriteBlobString(image,comment->value);
+    (void) WriteBlobString(image,comment);
   CloseBlob(image);
   return(MagickTrue);
 }
