@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -60,6 +59,8 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/option.h"
+#include "magick/profile.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/resource_.h"
 #include "magick/resize.h"
@@ -151,12 +152,12 @@ static MagickBooleanType InvokePostscriptDelegate(
     }
   status=(gs_func->new_instance)(&interpreter,(void *) NULL);
   if (status < 0)
-    return(MagickFalse);
+    return(SystemCommand(verbose,command) == 0 ? MagickFalse : MagickTrue);
   argv=StringToArgv(command,&argc);
   status=(gs_func->init_with_args)(interpreter,argc-1,argv+1);
   if (status == 0)
-    status=(gs_func->run_string)
-      (interpreter,"systemdict /start get exec\n",0,&code);
+    status=(gs_func->run_string)(interpreter,"systemdict /start get exec\n",0,
+      &code);
   (gs_func->exit)(interpreter);
   (gs_func->delete_instance)(interpreter);
 #if defined(__WINDOWS__)
@@ -246,7 +247,9 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define DeviceCMYK  "DeviceCMYK"
 #define MediaBox  "MediaBox"
 #define RenderPostscriptText  "  Rendering Postscript...  "
+#define SpotColor  "Separation"
 #define TrimBox  "TrimBox"
+#define PDFVersion  "PDF-"
 
   char
     command[MaxTextExtent],
@@ -265,7 +268,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   Image
     *image,
-    *next_image;
+    *next_image,
+    *pdf_image;
 
   ImageInfo
     *read_info;
@@ -289,17 +293,19 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register char
     *p;
 
-  register long
+  register int
     c;
 
   SegmentInfo
-    bounds;
+    bounds,
+    hires_bounds;
 
   ssize_t
     count;
 
   unsigned long
-    scene;
+    scene,
+    spotcolor;
 
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
@@ -360,8 +366,10 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (option != (const char *) NULL)
     trimbox=IsMagickTrue(option);
   count=0;
+  spotcolor=0;
   (void) ResetMagickMemory(&bounding_box,0,sizeof(bounding_box));
   (void) ResetMagickMemory(&bounds,0,sizeof(bounds));
+  (void) ResetMagickMemory(&hires_bounds,0,sizeof(hires_bounds));
   (void) ResetMagickMemory(&page,0,sizeof(page));
   (void) ResetMagickMemory(command,0,sizeof(command));
   p=command;
@@ -373,7 +381,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       Note PDF elements.
     */
     *p++=(char) c;
-    if ((c != (int) '/') && (c != '\n') &&
+    if ((c != (int) '/') && (c != (int) '%') && (c != '\n') &&
         ((size_t) (p-command) < (MaxTextExtent/2)))
       continue;
     *p='\0';
@@ -383,9 +391,37 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     */
     if (LocaleNCompare(DeviceCMYK,command,strlen(DeviceCMYK)) == 0)
       cmyk=MagickTrue;
-    if ((bounds.x1 != 0.0) || (bounds.y1 != 0.0) || (bounds.x2 != 0.0) ||
-        (bounds.y2 != 0.0))
-      continue;
+    if (LocaleNCompare(SpotColor,command,strlen(SpotColor)) == 0)
+      {
+        char
+          name[MaxTextExtent],
+          property[MaxTextExtent],
+          *value;
+
+        register long
+          i;
+
+        /*
+          Note spot names.
+        */
+        (void) FormatMagickString(property,MaxTextExtent,"pdf:SpotColor-%lu",
+          spotcolor++);
+        i=0;
+        for (c=ReadBlobByte(image); c != EOF; c=ReadBlobByte(image))
+        {
+          if ((isspace(c) != 0) || (c == '/') || ((i+1) == MaxTextExtent))
+            break;
+          name[i++]=(char) c;
+        }
+        name[i]='\0';
+        value=AcquireString(name);
+        (void) SubstituteString(&value,"#20"," ");
+        (void) SetImageProperty(image,property,value);
+        value=(char *) RelinquishMagickMemory(value);
+        continue;
+      }
+    if (LocaleNCompare(PDFVersion,command,strlen(PDFVersion)) == 0)
+      (void) SetImageProperty(image,"pdf:Version",command);
     count=0;
     if ((cropbox != MagickFalse) &&
         (LocaleNCompare(CropBox,command,strlen(CropBox)) == 0))
@@ -424,11 +460,18 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     if (count != 4)
       continue;
-    /*
-      Set PDF render geometry.
-    */
-    page.width=(unsigned long) (bounds.x2-bounds.x1+0.5);
-    page.height=(unsigned long) (bounds.y2-bounds.y1+0.5);
+    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
+      {
+        /*
+          Set PDF render geometry.
+        */
+        (void) FormatMagickString(geometry,MaxTextExtent,"%gx%g%+g%+g",
+          bounds.x2-bounds.x1,bounds.y2-bounds.y1,bounds.x1,bounds.y1);
+        (void) SetImageProperty(image,"pdf:HiResBoundingBox",geometry);
+        page.width=(unsigned long) (bounds.x2-bounds.x1+0.5);
+        page.height=(unsigned long) (bounds.y2-bounds.y1+0.5);
+        hires_bounds=bounds;
+      }
   }
   CloseBlob(image);
   if (image_info->colorspace == RGBColorspace)
@@ -453,13 +496,10 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
   if (image_info->page != (char *) NULL)
     (void) ParseAbsoluteGeometry(image_info->page,&page);
-  page.width=(unsigned long)
-    (page.width*image->x_resolution/delta.x+0.5);
-  page.height=(unsigned long)
-    (page.height*image->y_resolution/delta.y+0.5);
-  image=DestroyImage(image);
-  (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu",
-    page.width,page.height);
+  page.width=(unsigned long) (page.width*image->x_resolution/delta.x+0.5);
+  page.height=(unsigned long) (page.height*image->y_resolution/delta.y+0.5);
+  (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu",page.width,
+    page.height);
   if ((image_info->ping != MagickFalse) ||
       (image_info->monochrome != MagickFalse))
     delegate_info=GetDelegateInfo("ps:mono",(char *) NULL,exception);
@@ -471,6 +511,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (delegate_info == (const DelegateInfo *) NULL)
     {
       (void) RelinquishUniqueFileResource(postscript_filename);
+      image=DestroyImage(image);
       return((Image *) NULL);
     }
   *options='\0';
@@ -504,36 +545,39 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     read_info->antialias != MagickFalse ? 4 : 1,geometry,density,options,
     read_info->filename,postscript_filename,input_filename);
   status=InvokePostscriptDelegate(read_info->verbose,command);
-  image=ReadImage(read_info,exception);
+  pdf_image=ReadImage(read_info,exception);
   (void) RelinquishUniqueFileResource(postscript_filename);
   (void) RelinquishUniqueFileResource(read_info->filename);
   (void) RelinquishUniqueFileResource(input_filename);
   read_info=DestroyImageInfo(read_info);
-  if (image == (Image *) NULL)
+  if (pdf_image == (Image *) NULL)
     ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
-  if (LocaleCompare(image->magick,"BMP") == 0)
+  if (LocaleCompare(pdf_image->magick,"BMP") == 0)
     {
       Image
         *cmyk_image;
 
-      cmyk_image=ConsolidateCMYKImages(image,&image->exception);
+      cmyk_image=ConsolidateCMYKImages(pdf_image,exception);
       if (cmyk_image != (Image *) NULL)
         {
-          image=DestroyImageList(image);
-          image=cmyk_image;
+          pdf_image=DestroyImageList(pdf_image);
+          pdf_image=cmyk_image;
         }
     }
   scene=0;
   do
   {
-    (void) CopyMagickString(image->filename,filename,MaxTextExtent);
-    image->page=page;
-    image->scene=scene++;
-    next_image=SyncNextImageInList(image);
+    (void) CopyMagickString(pdf_image->filename,filename,MaxTextExtent);
+    pdf_image->page=page;
+    pdf_image->scene=scene++;
+    (void) CloneImageProfiles(pdf_image,image);
+    (void) CloneImageProperties(pdf_image,image);
+    next_image=SyncNextImageInList(pdf_image);
     if (next_image != (Image *) NULL)
-      image=next_image;
+      pdf_image=next_image;
   } while (next_image != (Image *) NULL);
-  return(GetFirstImageInList(image));
+  image=DestroyImage(image);
+  return(GetFirstImageInList(pdf_image));
 }
 
 /*
@@ -547,8 +591,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPDFImage() adds attributes for the PDF image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterPDFImage() adds properties for the PDF image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -570,7 +614,7 @@ ModuleExport void RegisterPDFImage(void)
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString("Encapsulated Portable Document Format");
   entry->module=ConstantString("PDF");
   (void) RegisterMagickInfo(entry);
@@ -580,7 +624,7 @@ ModuleExport void RegisterPDFImage(void)
   entry->magick=(MagickHandler *) IsPDF;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString("Portable Document Format");
   entry->module=ConstantString("PDF");
   (void) RegisterMagickInfo(entry);
@@ -681,8 +725,11 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
   CompressionType
     compression;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
+
+  double
+    pointsize;
 
   GeometryInfo
     geometry_info;
@@ -784,7 +831,8 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     else
       if (next->matte != MagickFalse)
         version=Max(version,1.4);
-  (void) FormatMagickString(buffer,MaxTextExtent,"%%PDF-%.1f \n",version);
+  (void) FormatMagickString(buffer,MaxTextExtent,"%%PDF-%.1f \n",(double)
+    version);
   (void) WriteBlobString(image,buffer);
   xref[object++]=TellBlob(image);
   info_id=object;
@@ -908,7 +956,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     if (compression == JPEG2000Compression)
       {
         if (image_info->colorspace == UndefinedColorspace)
-  	      (void) SetImageColorspace(image,RGBColorspace);
+          (void) SetImageColorspace(image,RGBColorspace);
       }
     /*
       Scale relative to dots-per-inch.
@@ -964,11 +1012,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         geometry.x=(-page_info.x);
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
+    pointsize=12.0;
+    if (image_info->pointsize != 0.0)
+      pointsize=image_info->pointsize;
     text_size=0;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      text_size=(unsigned long)
-        (MultilineCensus(attribute->value)*image_info->pointsize+12);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     /*
       Write Page object.
     */
@@ -1020,20 +1070,19 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
     offset=TellBlob(image);
     (void) WriteBlobString(image,"q\n");
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      labels=StringToList(attribute->value);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      labels=StringToList(value);
     if (labels != (char **) NULL)
       {
         for (i=0; labels[i] != (char *) NULL; i++)
         {
           (void) WriteBlobString(image,"BT\n");
           (void) FormatMagickString(buffer,MaxTextExtent,"/F%lu %g Tf\n",
-            image->scene,image_info->pointsize);
+            image->scene,pointsize);
           (void) WriteBlobString(image,buffer);
           (void) FormatMagickString(buffer,MaxTextExtent,"%ld %ld Td\n",
-            geometry.x,(long) (geometry.y+geometry.height+i*
-            image_info->pointsize+12));
+            geometry.x,(long) (geometry.y+geometry.height+i*pointsize+12));
           (void) WriteBlobString(image,buffer);
           (void) FormatMagickString(buffer,MaxTextExtent,"(%s) Tj\n",
             labels[i]);
@@ -1208,14 +1257,14 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
           }
           case JPEGCompression:
           {
-            status=JPEGEncodeImage(image_info,image);
+            status=InjectImageBlob(image_info,image,"jpeg");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,image->exception.reason);
             break;
           }
           case JPEG2000Compression:
           {
-            status=JP2EncodeImage(image_info,image);
+            status=InjectImageBlob(image_info,image,"jp2");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,image->exception.reason);
             break;
@@ -1313,14 +1362,14 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         {
           case JPEGCompression:
           {
-            status=JPEGEncodeImage(image_info,image);
+            status=InjectImageBlob(image_info,image,"jpeg");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,image->exception.reason);
             break;
           }
           case JPEG2000Compression:
           {
-            status=JP2EncodeImage(image_info,image);
+            status=InjectImageBlob(image_info,image,"jp2");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,image->exception.reason);
             break;
@@ -1655,14 +1704,14 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
           }
           case JPEGCompression:
           {
-            status=JPEGEncodeImage(image_info,tile_image);
+            status=InjectImageBlob(image_info,tile_image,"jpeg");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,tile_image->exception.reason);
             break;
           }
           case JPEG2000Compression:
           {
-            status=JP2EncodeImage(image_info,tile_image);
+            status=InjectImageBlob(image_info,tile_image,"jp2");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,tile_image->exception.reason);
             break;
@@ -1746,14 +1795,14 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         {
           case JPEGCompression:
           {
-            status=JPEGEncodeImage(image_info,tile_image);
+            status=InjectImageBlob(image_info,tile_image,"jpeg");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,tile_image->exception.reason);
             break;
           }
           case JPEG2000Compression:
           {
-            status=JP2EncodeImage(image_info,tile_image);
+            status=InjectImageBlob(image_info,tile_image,"jp2");
             if (status == MagickFalse)
               ThrowWriterException(CoderError,tile_image->exception.reason);
             break;
@@ -1925,16 +1974,16 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       (unsigned long) offset);
     (void) WriteBlobString(image,buffer);
     (void) WriteBlobString(image,"endobj\n");
-    /*
-      Write Colormap object.
-    */
     xref[object++]=TellBlob(image);
-    (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
-    (void) WriteBlobString(image,buffer);
-    (void) WriteBlobString(image,"<<\n");
     if ((image->storage_class != DirectClass) && (image->colors <= 256) &&
         (compression != FaxCompression) && (compression != Group4Compression))
       {
+        /*
+          Write Colormap object.
+        */
+        (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
+        (void) WriteBlobString(image,buffer);
+        (void) WriteBlobString(image,"<<\n");
         if (compression == NoCompression)
           (void) WriteBlobString(image,"/Filter [ /ASCII85Decode ]\n");
         (void) FormatMagickString(buffer,MaxTextExtent,"/Length %lu 0 R\n",
@@ -1963,10 +2012,10 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         }
         if (compression == NoCompression)
           Ascii85Flush(image);
+       offset=TellBlob(image)-offset;
+       (void) WriteBlobString(image,"\nendstream\n");
+       (void) WriteBlobString(image,"endobj\n");
       }
-    offset=TellBlob(image)-offset;
-    (void) WriteBlobString(image,"\nendstream\n");
-    (void) WriteBlobString(image,"endobj\n");
     /*
       Write Length object.
     */
