@@ -61,21 +61,24 @@
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/transform.h"
+#include "magick/utility.h"
 
 /*
   ImageMagick Macintosh PICT Methods.
 */
 #define ReadPixmap(pixmap) \
 { \
-  pixmap.version=ReadBlobMSBShort(image); \
-  pixmap.pack_type=ReadBlobMSBShort(image); \
+  pixmap.version=(short) ReadBlobMSBShort(image); \
+  pixmap.pack_type=(short) ReadBlobMSBShort(image); \
   pixmap.pack_size=ReadBlobMSBLong(image); \
-  pixmap.horizontal_resolution=ReadBlobMSBLong(image); \
-  pixmap.vertical_resolution=ReadBlobMSBLong(image); \
-  pixmap.pixel_type=ReadBlobMSBShort(image); \
-  pixmap.bits_per_pixel=ReadBlobMSBShort(image); \
-  pixmap.component_count=ReadBlobMSBShort(image); \
-  pixmap.component_size=ReadBlobMSBShort(image); \
+  pixmap.horizontal_resolution=1UL*ReadBlobMSBShort(image); \
+  (void) ReadBlobMSBShort(image); \
+  pixmap.vertical_resolution=1UL*ReadBlobMSBShort(image); \
+  (void) ReadBlobMSBShort(image); \
+  pixmap.pixel_type=(short) ReadBlobMSBShort(image); \
+  pixmap.bits_per_pixel=(short) ReadBlobMSBShort(image); \
+  pixmap.component_count=(short) ReadBlobMSBShort(image); \
+  pixmap.component_size=(short) ReadBlobMSBShort(image); \
   pixmap.plane_bytes=ReadBlobMSBLong(image); \
   pixmap.table=ReadBlobMSBLong(image); \
   pixmap.reserved=ReadBlobMSBLong(image); \
@@ -83,10 +86,10 @@
 
 #define ReadRectangle(rectangle) \
 { \
-  rectangle.top=ReadBlobMSBShort(image); \
-  rectangle.left=ReadBlobMSBShort(image); \
-  rectangle.bottom=ReadBlobMSBShort(image); \
-  rectangle.right=ReadBlobMSBShort(image); \
+  rectangle.top=(short) ReadBlobMSBShort(image); \
+  rectangle.left=(short) ReadBlobMSBShort(image); \
+  rectangle.bottom=(short) ReadBlobMSBShort(image); \
+  rectangle.right=(short) ReadBlobMSBShort(image); \
 }
 
 typedef struct _PICTCode
@@ -340,7 +343,7 @@ static MagickBooleanType
 */
 
 static unsigned char *ExpandBuffer(unsigned char *pixels,
-  unsigned long *bytes_per_line,const unsigned int bits_per_pixel)
+  MagickSizeType *bytes_per_line,const unsigned int bits_per_pixel)
 {
   register long
     i;
@@ -414,6 +417,9 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
     j,
     y;
 
+  MagickSizeType
+    number_pixels;
+
   register long
     i;
 
@@ -436,7 +442,6 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
 
   unsigned long
     bytes_per_pixel,
-    number_pixels,
     scanline_length,
     width;
 
@@ -480,9 +485,9 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
       {
         q=pixels+y*width;
         number_pixels=bytes_per_line;
-        count=ReadBlob(blob,number_pixels,scanline);
+        count=ReadBlob(blob,(size_t) number_pixels,scanline);
         p=ExpandBuffer(scanline,&number_pixels,bits_per_pixel);
-        (void) CopyMagickMemory(q,p,number_pixels);
+        (void) CopyMagickMemory(q,p,(size_t) number_pixels);
       }
       scanline=(unsigned char *) RelinquishMagickMemory(scanline);
       return(pixels);
@@ -496,7 +501,7 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
     if (bytes_per_line > 200)
       scanline_length=ReadBlobMSBShort(blob);
     else
-      scanline_length=ReadBlobByte(blob);
+      scanline_length=1UL*ReadBlobByte(blob);
     if (scanline_length >= row_bytes)
       {
         (void) ThrowMagickException(&image->exception,GetMagickModule(),
@@ -507,21 +512,21 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
     for (j=0; j < (long) scanline_length; )
       if ((scanline[j] & 0x80) == 0)
         {
-          length=(scanline[j] & 0xff)+1;
+          length=(size_t) ((scanline[j] & 0xff)+1);
           number_pixels=length*bytes_per_pixel;
           p=ExpandBuffer(scanline+j+1,&number_pixels,bits_per_pixel);
-          (void) CopyMagickMemory(q,p,number_pixels);
+          (void) CopyMagickMemory(q,p,(size_t) number_pixels);
           q+=number_pixels;
-          j+=length*bytes_per_pixel+1;
+          j+=(long) (length*bytes_per_pixel+1);
         }
       else
         {
-          length=((scanline[j] ^ 0xff) & 0xff)+2;
+          length=(size_t) (((scanline[j] ^ 0xff) & 0xff)+2);
           number_pixels=bytes_per_pixel;
           p=ExpandBuffer(scanline+j+1,&number_pixels,bits_per_pixel);
           for (i=0; i < (long) length; i++)
           {
-            (void) CopyMagickMemory(q,p,number_pixels);
+            (void) CopyMagickMemory(q,p,(size_t) number_pixels);
             q+=number_pixels;
           }
           j+=bytes_per_pixel+1;
@@ -669,11 +674,11 @@ static size_t EncodeImage(Image *image,const unsigned char *scanline,
       }
     }
   if (count > 0)
-    *q++=count-1;
+    *q++=(unsigned char) (count-1);
   /*
     Write the number of and the packed length.
   */
-  length=(q-pixels);
+  length=(size_t) (q-pixels);
   if (bytes_per_line > 200)
     {
       (void) WriteBlobMSBShort(image,(unsigned short) length);
@@ -854,8 +859,11 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
     Create black canvas.
   */
   flags=0;
-  image->columns=frame.right-frame.left;
-  image->rows=frame.bottom-frame.top;
+  image->columns=1UL*(frame.right-frame.left);
+  image->rows=1UL*(frame.bottom-frame.top);
+  image->x_resolution=DefaultResolution;
+  image->y_resolution=DefaultResolution;
+  image->units=UndefinedResolution;
   /*
     Interpret PICT opcodes.
   */
@@ -868,7 +876,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
     if ((version == 1) || ((TellBlob(image) % 2) != 0))
       code=ReadBlobByte(image);
     if (version == 2)
-      code=ReadBlobMSBShort(image);
+      code=(int) ReadBlobMSBShort(image);
     if (code > 0xa1)
       {
         if (image->debug != MagickFalse)
@@ -896,9 +904,9 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             ReadRectangle(frame);
             if (((frame.left & 0x8000) != 0) || ((frame.top & 0x8000) != 0))
               break;
-            image->columns=frame.right-frame.left;
-            image->rows=frame.bottom-frame.top;
-            SetImageBackgroundColor(image);
+            image->columns=1UL*(frame.right-frame.left);
+            image->rows=1UL*(frame.bottom-frame.top);
+            (void) SetImageBackgroundColor(image);
             break;
           }
           case 0x12:
@@ -915,7 +923,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             /*
               Skip pattern definition.
             */
-            pattern=ReadBlobMSBShort(image);
+            pattern=1L*ReadBlobMSBShort(image);
             for (i=0; i < 8; i++)
               (void) ReadBlobByte(image);
             if (pattern == 2)
@@ -929,14 +937,17 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             length=ReadBlobMSBShort(image);
             ReadRectangle(frame);
             ReadPixmap(pixmap);
-            image->depth=pixmap.component_size;
+            image->depth=1UL*pixmap.component_size;
+            image->x_resolution=1.0*pixmap.horizontal_resolution;
+            image->y_resolution=1.0*pixmap.vertical_resolution;
+            image->units=PixelsPerInchResolution;
             (void) ReadBlobMSBLong(image);
-            flags=ReadBlobMSBShort(image);
+            flags=1L*ReadBlobMSBShort(image);
             length=ReadBlobMSBShort(image);
             for (i=0; i <= (long) length; i++)
               (void) ReadBlobMSBLong(image);
-            width=frame.bottom-frame.top;
-            height=frame.right-frame.left;
+            width=1UL*(frame.bottom-frame.top);
+            height=1UL*(frame.right-frame.left);
             if (pixmap.bits_per_pixel <= 8)
               length&=0x7fff;
             if (pixmap.bits_per_pixel == 16)
@@ -951,10 +962,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             else
               for (j=0; j < (int) height; j++)
                 if (length > 200)
-                  for (j=0; j < ReadBlobMSBShort(image); j++)
+                  for (j=0; j < (long) ReadBlobMSBShort(image); j++)
                     (void) ReadBlobByte(image);
                 else
-                  for (j=0; j < ReadBlobByte(image); j++)
+                  for (j=0; j < (long) ReadBlobByte(image); j++)
                     (void) ReadBlobByte(image);
             break;
           }
@@ -1019,7 +1030,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             */
             bytes_per_line=0;
             if ((code != 0x9a) && (code != 0x9b))
-              bytes_per_line=ReadBlobMSBShort(image);
+              bytes_per_line=1L*ReadBlobMSBShort(image);
             else
               {
                 (void) ReadBlobMSBShort(image);
@@ -1030,8 +1041,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             /*
               Initialize tile image.
             */
-            tile_image=CloneImage(image,frame.right-frame.left,
-              frame.bottom-frame.top,MagickTrue,exception);
+            tile_image=CloneImage(image,1UL*(frame.right-frame.left),
+              1UL*(frame.bottom-frame.top),MagickTrue,exception);
             if (tile_image == (Image *) NULL)
               return((Image *) NULL);
             DestroyBlob(tile_image);
@@ -1040,9 +1051,12 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 ((bytes_per_line & 0x8000) != 0))
               {
                 ReadPixmap(pixmap);
-                tile_image->depth=pixmap.component_size;
+                tile_image->depth=1UL*pixmap.component_size;
                 tile_image->matte=pixmap.component_count == 4 ?
                   MagickTrue : MagickFalse;
+                tile_image->x_resolution=(double) pixmap.horizontal_resolution;
+                tile_image->y_resolution=(double) pixmap.vertical_resolution;
+                tile_image->units=PixelsPerInchResolution;
                 if (tile_image->matte != MagickFalse)
                   image->matte=tile_image->matte;
               }
@@ -1055,8 +1069,8 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                 if ((bytes_per_line & 0x8000) != 0)
                   {
                     (void) ReadBlobMSBLong(image);
-                    flags=ReadBlobMSBShort(image);
-                    tile_image->colors=ReadBlobMSBShort(image)+1;
+                    flags=1L*ReadBlobMSBShort(image);
+                    tile_image->colors=1UL*ReadBlobMSBShort(image)+1;
                   }
                 status=AllocateImageColormap(tile_image,tile_image->colors);
                 if (status == MagickFalse)
@@ -1071,7 +1085,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     {
                       j=ReadBlobMSBShort(image) % tile_image->colors;
                       if ((flags & 0x8000) != 0)
-                        j=i;
+                        j=(size_t) i;
                       tile_image->colormap[j].red=(Quantum)
                         ScaleShortToQuantum(ReadBlobMSBShort(image));
                       tile_image->colormap[j].green=(Quantum)
@@ -1107,10 +1121,11 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               }
             if ((code != 0x9a) && (code != 0x9b) &&
                 (bytes_per_line & 0x8000) == 0)
-              pixels=DecodeImage(image_info,image,tile_image,bytes_per_line,1);
+              pixels=DecodeImage(image_info,image,tile_image,1UL*
+                bytes_per_line,1);
             else
-              pixels=DecodeImage(image_info,image,tile_image,bytes_per_line,
-                pixmap.bits_per_pixel);
+              pixels=DecodeImage(image_info,image,tile_image,1UL*bytes_per_line,
+                1U*pixmap.bits_per_pixel);
             if (pixels == (unsigned char *) NULL)
               {
                 tile_image=DestroyImage(tile_image);
@@ -1309,7 +1324,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         file=(FILE *) NULL;
         unique_file=AcquireUniqueFileResource(read_info->filename);
         if (unique_file != -1)
-          file=fopen(read_info->filename,"wb");
+          file=MagickOpenStream(read_info->filename,"wb");
         if ((unique_file == -1) || (file == (FILE *) NULL))
           {
             (void) CopyMagickString(image->filename,read_info->filename,
@@ -1341,7 +1356,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
           Max(image->rows,tile_image->rows));
         (void) TransformImage(&image,(char *) NULL,geometry);
         if (image_info->colorspace == UndefinedColorspace)
-          SetImageColorspace(image,tile_image->colorspace);
+          (void) SetImageColorspace(image,tile_image->colorspace);
         (void) CompositeImage(image,CopyCompositeOp,tile_image,frame.left,
           frame.right);
         image->compression=tile_image->compression;
@@ -1366,7 +1381,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         /*
           Skip reserved.
         */
-        length=(code >> 7) & 0xff;
+        length=(size_t) ((code >> 7) & 0xff);
         for (i=0; i < (long) length; i++)
           (void) ReadBlobByte(image);
         continue;
@@ -1585,8 +1600,10 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   pixmap.table=0;
   pixmap.reserved=0;
   transfer_mode=0;
-  x_resolution=image->x_resolution ? image->x_resolution : DefaultResolution;
-  y_resolution=image->y_resolution ? image->y_resolution : DefaultResolution;
+  x_resolution=image->x_resolution != 0.0 ? image->x_resolution :
+    DefaultResolution;
+  y_resolution=image->y_resolution != 0.0 ? image->y_resolution :
+    DefaultResolution;
   storage_class=image->storage_class;
   if (image->compression == JPEGCompression)
     storage_class=DirectClass;
@@ -1606,24 +1623,25 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   if ((storage_class == DirectClass) || (image->matte != MagickFalse))
     bytes_per_line*=image->matte ? 4 : 3;
   buffer=(unsigned char *) AcquireMagickMemory(PictInfoSize);
-  packed_scanline=(unsigned char *) AcquireMagickMemory(row_bytes+MaxCount);
+  packed_scanline=(unsigned char *) AcquireMagickMemory((size_t)
+   (row_bytes+MaxCount));
   scanline=(unsigned char *) AcquireMagickMemory(row_bytes);
   if ((buffer == (unsigned char *) NULL) ||
       (packed_scanline == (unsigned char *) NULL) ||
       (scanline == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(scanline,0,row_bytes);
-  (void) ResetMagickMemory(packed_scanline,0,row_bytes+MaxCount);
+  (void) ResetMagickMemory(packed_scanline,0,(size_t) (row_bytes+MaxCount));
   /*
     Write header, header size, size bounding box, version, and reserved.
   */
   (void) ResetMagickMemory(buffer,0,PictInfoSize);
   (void) WriteBlob(image,PictInfoSize,buffer);
   (void) WriteBlobMSBShort(image,0);
-  (void) WriteBlobMSBShort(image,size_rectangle.top);
-  (void) WriteBlobMSBShort(image,size_rectangle.left);
-  (void) WriteBlobMSBShort(image,size_rectangle.bottom);
-  (void) WriteBlobMSBShort(image,size_rectangle.right);
+  (void) WriteBlobMSBShort(image,(unsigned short) size_rectangle.top);
+  (void) WriteBlobMSBShort(image,(unsigned short) size_rectangle.left);
+  (void) WriteBlobMSBShort(image,(unsigned short) size_rectangle.bottom);
+  (void) WriteBlobMSBShort(image,(unsigned short) size_rectangle.right);
   (void) WriteBlobMSBShort(image,PictVersion);
   (void) WriteBlobMSBShort(image,0x02ff);  /* version #2 */
   (void) WriteBlobMSBShort(image,PictInfoOp);
@@ -1635,10 +1653,10 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   (void) WriteBlobMSBShort(image,0x0000);
   (void) WriteBlobMSBShort(image,(unsigned short) y_resolution);
   (void) WriteBlobMSBShort(image,0x0000);
-  (void) WriteBlobMSBShort(image,frame_rectangle.top);
-  (void) WriteBlobMSBShort(image,frame_rectangle.left);
-  (void) WriteBlobMSBShort(image,frame_rectangle.bottom);
-  (void) WriteBlobMSBShort(image,frame_rectangle.right);
+  (void) WriteBlobMSBShort(image,(unsigned short) frame_rectangle.top);
+  (void) WriteBlobMSBShort(image,(unsigned short) frame_rectangle.left);
+  (void) WriteBlobMSBShort(image,(unsigned short) frame_rectangle.bottom);
+  (void) WriteBlobMSBShort(image,(unsigned short) frame_rectangle.right);
   (void) WriteBlobMSBLong(image,0x00000000L);
   profile=GetImageProfile(image,"iptc");
   if (profile != (StringInfo *) NULL)
@@ -1667,10 +1685,10 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   */
   (void) WriteBlobMSBShort(image,PictCropRegionOp);
   (void) WriteBlobMSBShort(image,0xa);
-  (void) WriteBlobMSBShort(image,crop_rectangle.top);
-  (void) WriteBlobMSBShort(image,crop_rectangle.left);
-  (void) WriteBlobMSBShort(image,crop_rectangle.bottom);
-  (void) WriteBlobMSBShort(image,crop_rectangle.right);
+  (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.top);
+  (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.left);
+  (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.bottom);
+  (void) WriteBlobMSBShort(image,(unsigned short) crop_rectangle.right);
   if (image->compression == JPEGCompression)
     {
       Image
@@ -1703,7 +1721,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
         return(MagickFalse);
       jpeg_image=DestroyImage(jpeg_image);
       (void) WriteBlobMSBShort(image,PictJPEGOp);
-      (void) WriteBlobMSBLong(image,length+154);
+      (void) WriteBlobMSBLong(image,(unsigned long) length+154);
       (void) WriteBlobMSBShort(image,0x0000);
       (void) WriteBlobMSBLong(image,0x00010000UL);
       (void) WriteBlobMSBLong(image,0x00000000UL);
@@ -1764,28 +1782,28 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
       (void) WriteBlobMSBShort(image,PictPixmapOp);
       (void) WriteBlobMSBLong(image,(unsigned long) base_address);
     }
-  (void) WriteBlobMSBShort(image,row_bytes | 0x8000);
-  (void) WriteBlobMSBShort(image,bounds.top);
-  (void) WriteBlobMSBShort(image,bounds.left);
-  (void) WriteBlobMSBShort(image,bounds.bottom);
-  (void) WriteBlobMSBShort(image,bounds.right);
+  (void) WriteBlobMSBShort(image,(unsigned short) (row_bytes | 0x8000));
+  (void) WriteBlobMSBShort(image,(unsigned short) bounds.top);
+  (void) WriteBlobMSBShort(image,(unsigned short) bounds.left);
+  (void) WriteBlobMSBShort(image,(unsigned short) bounds.bottom);
+  (void) WriteBlobMSBShort(image,(unsigned short) bounds.right);
   /*
     Write pack type, pack size, resolution, pixel type, and pixel size.
   */
-  (void) WriteBlobMSBShort(image,pixmap.version);
-  (void) WriteBlobMSBShort(image,pixmap.pack_type);
+  (void) WriteBlobMSBShort(image,(unsigned short) pixmap.version);
+  (void) WriteBlobMSBShort(image,(unsigned short) pixmap.pack_type);
   (void) WriteBlobMSBLong(image,pixmap.pack_size);
-  (void) WriteBlobMSBShort(image,(unsigned short) x_resolution);
+  (void) WriteBlobMSBShort(image,(unsigned short) (x_resolution+0.5));
   (void) WriteBlobMSBShort(image,0x0000);
-  (void) WriteBlobMSBShort(image,(unsigned short) y_resolution);
+  (void) WriteBlobMSBShort(image,(unsigned short) (y_resolution+0.5));
   (void) WriteBlobMSBShort(image,0x0000);
-  (void) WriteBlobMSBShort(image,pixmap.pixel_type);
-  (void) WriteBlobMSBShort(image,pixmap.bits_per_pixel);
+  (void) WriteBlobMSBShort(image,(unsigned short) pixmap.pixel_type);
+  (void) WriteBlobMSBShort(image,(unsigned short) pixmap.bits_per_pixel);
   /*
     Write component count, size, plane bytes, table size, and reserved.
   */
-  (void) WriteBlobMSBShort(image,pixmap.component_count);
-  (void) WriteBlobMSBShort(image,pixmap.component_size);
+  (void) WriteBlobMSBShort(image,(unsigned short) pixmap.component_count);
+  (void) WriteBlobMSBShort(image,(unsigned short) pixmap.component_size);
   (void) WriteBlobMSBLong(image,(unsigned long) pixmap.plane_bytes);
   (void) WriteBlobMSBLong(image,(unsigned long) pixmap.table);
   (void) WriteBlobMSBLong(image,(unsigned long) pixmap.reserved);
@@ -1811,15 +1829,15 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   /*
     Write source and destination rectangle.
   */
-  (void) WriteBlobMSBShort(image,source_rectangle.top);
-  (void) WriteBlobMSBShort(image,source_rectangle.left);
-  (void) WriteBlobMSBShort(image,source_rectangle.bottom);
-  (void) WriteBlobMSBShort(image,source_rectangle.right);
-  (void) WriteBlobMSBShort(image,destination_rectangle.top);
-  (void) WriteBlobMSBShort(image,destination_rectangle.left);
-  (void) WriteBlobMSBShort(image,destination_rectangle.bottom);
-  (void) WriteBlobMSBShort(image,destination_rectangle.right);
-  (void) WriteBlobMSBShort(image,transfer_mode);
+  (void) WriteBlobMSBShort(image,(unsigned short) source_rectangle.top);
+  (void) WriteBlobMSBShort(image,(unsigned short) source_rectangle.left);
+  (void) WriteBlobMSBShort(image,(unsigned short) source_rectangle.bottom);
+  (void) WriteBlobMSBShort(image,(unsigned short) source_rectangle.right);
+  (void) WriteBlobMSBShort(image,(unsigned short) destination_rectangle.top);
+  (void) WriteBlobMSBShort(image,(unsigned short) destination_rectangle.left);
+  (void) WriteBlobMSBShort(image,(unsigned short) destination_rectangle.bottom);
+  (void) WriteBlobMSBShort(image,(unsigned short) destination_rectangle.right);
+  (void) WriteBlobMSBShort(image,(unsigned short) transfer_mode);
   /*
     Write picture data.
   */
@@ -1832,8 +1850,9 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
         break;
       indexes=GetIndexes(image);
       for (x=0; x < (long) image->columns; x++)
-        scanline[x]=indexes[x];
-      count+=EncodeImage(image,scanline,row_bytes & 0x7FFF,packed_scanline);
+        scanline[x]=(unsigned char) indexes[x];
+      count+=EncodeImage(image,scanline,(unsigned long) (row_bytes & 0x7FFF),
+        packed_scanline);
       if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
           (QuantumTick(y,image->rows) != MagickFalse))
         {
@@ -1848,7 +1867,8 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
       {
         (void) ResetMagickMemory(scanline,0,row_bytes);
         for (y=0; y < (long) image->rows; y++)
-          count+=EncodeImage(image,scanline,row_bytes & 0x7FFF,packed_scanline);
+          count+=EncodeImage(image,scanline,(unsigned long)
+            (row_bytes & 0x7FFF),packed_scanline);
       }
     else
       {
