@@ -82,10 +82,9 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
-static void inline PlasmaPixel(Image *image,double x,double y)
+static inline void PlasmaPixel(Image *image,double x,double y)
 {
   register PixelPacket
     *q;
@@ -145,7 +144,7 @@ static Image *ReadPlasmaImage(const ImageInfo *image_info,
   image=ReadImage(read_info,exception);
   read_info=DestroyImageInfo(read_info);
   if (image == (Image *) NULL)
-    return(GetFirstImageInList(image));
+    return((Image *) NULL);
   image->storage_class=DirectClass;
   for (y=0; y < (long) image->rows; y++)
   {
@@ -196,6 +195,7 @@ static Image *ReadPlasmaImage(const ImageInfo *image_info,
           break;
       }
   }
+  (void) SetImageOpacity(image,OpaqueOpacity);
   return(GetFirstImageInList(image));
 }
 
