@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -54,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -188,7 +188,7 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
   } while (isdigit(c) == MagickFalse);
   if (comment != (char *) NULL)
     {
-      (void) SetImageAttribute(image,"Comment",comment);
+      (void) SetImageProperty(image,"Comment",comment);
       comment=(char *) RelinquishMagickMemory(comment);
     }
   if (base == 2)
@@ -393,6 +393,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
     if ((image->columns == 0) || (image->rows == 0))
       ThrowReaderException(CorruptImageError,"NegativeOrZeroImageSize");
+    if (max_value >= 65536)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     for (image->depth=1; (1UL << image->depth) < max_value; image->depth++);
     scale=(Quantum *) NULL;
     if (image->storage_class == PseudoClass)
@@ -403,8 +405,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Compute pixel scaling table.
         */
-        scale=(Quantum *)
-          AcquireMagickMemory((size_t) (max_value+1)*sizeof(*scale));
+        scale=(Quantum *) AcquireMagickMemory((size_t) (max_value+1)*
+          sizeof(*scale));
         if (scale == (Quantum *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (i=0; i <= (long) max_value; i++)
@@ -936,8 +938,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPNMImage() adds attributes for the PNM image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterPNMImage() adds properties for the PNM image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -1058,8 +1060,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
   char
     buffer[MaxTextExtent];
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   IndexPacket
     index;
@@ -1143,17 +1145,17 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       format-=3;
     (void) FormatMagickString(buffer,MaxTextExtent,"P%d\n",format);
     (void) WriteBlobString(image,buffer);
-    attribute=GetImageAttribute(image,"Comment");
-    if (attribute != (const ImageAttribute *) NULL)
+    value=GetImageProperty(image,"Comment");
+    if (value != (const char *) NULL)
       {
-        register char
+        register const char
           *p;
 
         /*
           Write comments to file.
         */
         (void) WriteBlobByte(image,'#');
-        for (p=attribute->value; *p != '\0'; p++)
+        for (p=value; *p != '\0'; p++)
         {
           (void) WriteBlobByte(image,(unsigned char) *p);
           if ((*p == '\r') && (*(p+1) != '\0'))
