@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -60,6 +59,7 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/resource_.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -144,12 +144,12 @@ static MagickBooleanType InvokePostscriptDelegate(
     }
   status=(gs_func->new_instance)(&interpreter,(void *) NULL);
   if (status < 0)
-    return(MagickFalse);
+    return(SystemCommand(verbose,command) == 0 ? MagickFalse : MagickTrue);
   argv=StringToArgv(command,&argc);
   status=(gs_func->init_with_args)(interpreter,argc-1,argv+1);
   if (status == 0)
-    status=(gs_func->run_string)
-      (interpreter,"systemdict /start get exec\n",0,&code);
+    status=(gs_func->run_string)(interpreter,"systemdict /start get exec\n",0,
+      &code);
   (gs_func->exit)(interpreter);
   (gs_func->delete_instance)(interpreter);
 #if defined(__WINDOWS__)
@@ -233,7 +233,6 @@ static MagickBooleanType IsPS(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static inline int ProfileInteger(Image *image,short int *hex_digits)
@@ -267,7 +266,10 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
 #define BoundingBox  "BoundingBox:"
 #define BeginDocument  "BeginDocument:"
+#define CMYKCustomColor  "CMYKCustomColor:"
 #define DocumentMedia  "DocumentMedia:"
+#define DocumentCustomColors  "DocumentCustomColors:"
+#define DocumentProcessColors  "DocumentProcessColors:"
 #define EndDocument  "EndDocument:"
 #define HiResBoundingBox  "HiResBoundingBox:"
 #define ImageData  "ImageData:"
@@ -278,6 +280,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 #define PhotoshopProfile  "BeginPhotoshop:"
 #define PostscriptLevel  "!PS-"
 #define RenderPostscriptText  "  Rendering Postscript...  "
+#define SpotColor  "+ "
 #define XMLProfile  "begin_xml_packet:"
 
   char
@@ -288,8 +291,6 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     input_filename[MaxTextExtent],
     options[MaxTextExtent],
     postscript_filename[MaxTextExtent],
-    *q,
-    token[MaxTextExtent],
     translate_geometry[MaxTextExtent];
 
   const DelegateInfo
@@ -300,7 +301,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   Image
     *image,
-    *next_image;
+    *next_image,
+    *postscript_image;
 
   ImageInfo
     *read_info;
@@ -330,7 +332,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     i;
 
   SegmentInfo
-    bounds;
+    bounds,
+    hires_bounds;
 
   short int
     hex_digits[256];
@@ -339,8 +342,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   StringInfo
-    *iptc_profile,
-    *xml_profile;
+    *profile;
 
   unsigned long
     columns,
@@ -348,7 +350,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     length,
     pages,
     rows,
-    scene;
+    scene,
+    spotcolor;
 
   /*
     Open image file.
@@ -419,12 +422,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Determine page geometry from the Postscript bounding box.
   */
   (void) ResetMagickMemory(&bounds,0,sizeof(bounds));
+  (void) ResetMagickMemory(&hires_bounds,0,sizeof(hires_bounds));
   (void) ResetMagickMemory(&page,0,sizeof(page));
   (void) ResetMagickMemory(command,0,sizeof(command));
   columns=0;
   rows=0;
-  iptc_profile=(StringInfo *) NULL;
-  xml_profile=(StringInfo *) NULL;
+  spotcolor=0;
   language_level=1;
   skip=MagickFalse;
   cmyk=image_info->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
@@ -453,8 +456,11 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (skip != MagickFalse)
       continue;
     if (LocaleNCompare(PostscriptLevel,command,strlen(PostscriptLevel)) == 0)
-      if (GlobExpression(command,"*EPSF-*") != MagickFalse)
-        pages=1;
+      {
+        (void) SetImageProperty(image,"ps:Level",command+4);
+        if (GlobExpression(command,"*EPSF-*") != MagickFalse)
+          pages=1;
+      }
     if (LocaleNCompare(LanguageLevel,command,strlen(LanguageLevel)) == 0)
       (void) sscanf(command,LanguageLevel " %lu",&language_level);
     if (LocaleNCompare(Pages,command,strlen(Pages)) == 0)
@@ -469,10 +475,12 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         count=(ssize_t) sscanf(command,PhotoshopProfile " %lu",&length);
         if (count != 1)
           continue;
-        iptc_profile=AcquireStringInfo(length);
+        profile=AcquireStringInfo(length);
         for (i=0; i < (long) length; i++)
-          iptc_profile->datum[i]=(unsigned char)
-            ProfileInteger(image,hex_digits);
+          profile->datum[i]=(unsigned char) ProfileInteger(image,hex_digits);
+        (void) SetImageProfile(image,"IPTC",profile);
+        profile=DestroyStringInfo(profile);
+        continue;
       }
     if (LocaleNCompare(XMLProfile,command,strlen(XMLProfile)) == 0)
       {
@@ -482,25 +490,49 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         count=(ssize_t) sscanf(command,XMLProfile " %lu",&length);
         if (count != 1)
           continue;
-        xml_profile=AcquireStringInfo(length);
+        profile=AcquireStringInfo(length);
         for (i=0; i < (long) length; i++)
-          xml_profile->datum[i]=(unsigned char)
-            ProfileInteger(image,hex_digits);
+          profile->datum[i]=(unsigned char) ReadBlobByte(image);
+        (void) SetImageProfile(image,"XML",profile);
+        profile=DestroyStringInfo(profile);
+        continue;
       }
     /*
       Is this a CMYK document?
     */
-    for (q=p; *q != '\0'; )
-    {
-      GetMagickToken(q,&q,token);
-      if (LocaleCompare(token,"cmyk") == 0)
-        cmyk=MagickTrue;
-      if (LocaleCompare(token,"cyan") == 0)
-        cmyk=MagickTrue;
-    }
-    if ((bounds.x1 != 0.0) || (bounds.y1 != 0.0) || (bounds.x2 != 0.0) ||
-        (bounds.y2 != 0.0))
-      continue;
+    length=strlen(DocumentProcessColors);
+    if (LocaleNCompare(DocumentProcessColors,command,length) == 0)
+      cmyk=MagickTrue;
+    if (LocaleNCompare(CMYKCustomColor,command,strlen(CMYKCustomColor)) == 0)
+      cmyk=MagickTrue;
+    length=strlen(DocumentCustomColors);
+    if ((LocaleNCompare(DocumentCustomColors,command,length) == 0) ||
+        (LocaleNCompare(CMYKCustomColor,command,strlen(CMYKCustomColor)) == 0) ||
+        (LocaleNCompare(SpotColor,command,strlen(SpotColor)) == 0))
+      {
+        char
+          property[MaxTextExtent],
+          *value;
+
+        register char
+          *p;
+
+        /*
+          Note spot names.
+        */
+        (void) FormatMagickString(property,MaxTextExtent,"ps:SpotColor-%lu",
+          spotcolor++);
+        for (p=command; *p != '\0'; p++)
+          if (isspace((int) (unsigned char) *p) != 0)
+            break;
+        value=AcquireString(p);
+        (void) SubstituteString(&value,"(","");
+        (void) SubstituteString(&value,")","");
+        (void) StripString(value);
+        (void) SetImageProperty(image,property,value);
+        value=(char *) RelinquishMagickMemory(value);
+        continue;
+      }
     /*
       Note region defined by bounding box.
     */
@@ -522,11 +554,18 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         &bounds.y2)+2;
     if (count != 4)
       continue;
-    /*
-      Set Postscript render geometry.
-    */
-    page.width=(unsigned long) (bounds.x2-bounds.x1+0.5);
-    page.height=(unsigned long) (bounds.y2-bounds.y1+0.5);
+    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
+      {
+        /*
+          Set Postscript render geometry.
+        */
+        (void) FormatMagickString(geometry,MaxTextExtent,"%gx%g%+g%+g",
+          bounds.x2-bounds.x1,bounds.y2-bounds.y1,bounds.x1,bounds.y1);
+        (void) SetImageProperty(image,"ps:HiResBoundingBox",geometry);
+        page.width=(unsigned long) (bounds.x2-bounds.x1+0.5);
+        page.height=(unsigned long) (bounds.y2-bounds.y1+0.5);
+        hires_bounds=bounds;
+      }
   }
   CloseBlob(image);
   if (image_info->colorspace == RGBColorspace)
@@ -544,10 +583,10 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
   (void) CopyMagickString(command,"/setpagedevice {pop} bind 1 index where {"
     "dup wcheck {3 1 roll put} {pop def} ifelse} {def} ifelse\n",MaxTextExtent);
-  (void) write(file,command,strlen(command));
+  (void) write(file,command,(unsigned int) strlen(command));
   (void) FormatMagickString(translate_geometry,MaxTextExtent,
     "%g %g translate\n",-bounds.x1,-bounds.y1);
-  (void) write(file,translate_geometry,strlen(translate_geometry));
+  (void) write(file,translate_geometry,(unsigned int) strlen(translate_geometry));
   file=close(file)-1;
   /*
     Render Postscript with the Ghostscript delegate.
@@ -556,11 +595,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
   if (image_info->page != (char *) NULL)
     (void) ParseAbsoluteGeometry(image_info->page,&page);
-  page.width=(unsigned long)
-    (page.width*image->y_resolution/delta.x+0.5);
-  page.height=(unsigned long)
-    (page.height*image->y_resolution/delta.y+0.5);
-  image=DestroyImageList(image);
+  page.width=(unsigned long) (page.width*image->y_resolution/delta.x+0.5);
+  page.height=(unsigned long) (page.height*image->y_resolution/delta.y+0.5);
   (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu",
     page.width,page.height);
   if (image_info->monochrome != MagickFalse)
@@ -576,6 +612,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (delegate_info == (const DelegateInfo *) NULL)
     {
       (void) RelinquishUniqueFileResource(postscript_filename);
+      image=DestroyImageList(image);
       return((Image *) NULL);
     }
   *options='\0';
@@ -602,67 +639,67 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     read_info->antialias != MagickFalse ? 4 : 1,geometry,density,options,
     read_info->filename,postscript_filename,input_filename);
   status=InvokePostscriptDelegate(read_info->verbose,command);
-  image=ReadImage(read_info,exception);
-  if (image == (Image *) NULL)
+  postscript_image=ReadImage(read_info,exception);
+  if (postscript_image == (Image *) NULL)
     {
       (void) ConcatenateMagickString(command," -c showpage",MaxTextExtent);
       status=InvokePostscriptDelegate(read_info->verbose,command);
       *read_info->magick='\0';
-      image=ReadImage(read_info,exception);
+      postscript_image=ReadImage(read_info,exception);
     }
   (void) RelinquishUniqueFileResource(postscript_filename);
   (void) RelinquishUniqueFileResource(read_info->filename);
   (void) RelinquishUniqueFileResource(input_filename);
-  if (image == (Image *) NULL)
+  if (postscript_image == (Image *) NULL)
     {
       /*
         Ghostscript has failed-- try the Display Postscript Extension.
       */
+      image=DestroyImageList(image);
       (void) FormatMagickString(read_info->filename,MaxTextExtent,"dps:%s",
         filename);
-      image=ReadImage(read_info,exception);
-      if (image != (Image *) NULL)
-        return(GetFirstImageInList(image));
+      postscript_image=ReadImage(read_info,exception);
+      read_info=DestroyImageInfo(read_info);
+      if (postscript_image != (Image *) NULL)
+        return(GetFirstImageInList(postscript_image));
       ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
     }
   read_info=DestroyImageInfo(read_info);
-  if (image == (Image *) NULL)
-    ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
-  if (LocaleCompare(image->magick,"BMP") == 0)
+  if (postscript_image == (Image *) NULL)
+    {
+      image=DestroyImageList(image);
+      ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
+    }
+  if (LocaleCompare(postscript_image->magick,"BMP") == 0)
     {
       Image
         *cmyk_image;
 
-      cmyk_image=ConsolidateCMYKImages(image,&image->exception);
+      cmyk_image=ConsolidateCMYKImages(postscript_image,exception);
       if (cmyk_image != (Image *) NULL)
         {
-          image=DestroyImageList(image);
-          image=cmyk_image;
+          postscript_image=DestroyImageList(postscript_image);
+          postscript_image=cmyk_image;
         }
     }
   scene=0;
   do
   {
-    (void) CopyMagickString(image->filename,filename,MaxTextExtent);
+    (void) CopyMagickString(postscript_image->filename,filename,MaxTextExtent);
     if (columns != 0)
-      image->magick_columns=columns;
+      postscript_image->magick_columns=columns;
     if (rows != 0)
-      image->magick_rows=rows;
-    if (iptc_profile != (StringInfo *) NULL)
-      (void) SetImageProfile(image,"iptc",iptc_profile);
-    if (xml_profile != (StringInfo *) NULL)
-      (void) SetImageProfile(image,"xml",xml_profile);
-    image->page=page;
-    image->scene=scene++;
-    next_image=SyncNextImageInList(image);
+      postscript_image->magick_rows=rows;
+    postscript_image->page=page;
+    postscript_image->scene=scene++;
+    (void) CloneImageProfiles(postscript_image,image);
+    (void) CloneImageProperties(postscript_image,image);
+    next_image=SyncNextImageInList(postscript_image);
     if (next_image != (Image *) NULL)
-      image=next_image;
+      postscript_image=next_image;
   } while (next_image != (Image *) NULL);
-  if (iptc_profile != (StringInfo *) NULL)
-    iptc_profile=DestroyStringInfo(iptc_profile);
-  if (xml_profile != (StringInfo *) NULL)
-    xml_profile=DestroyStringInfo(xml_profile);
-  return(GetFirstImageInList(image));
+  image=DestroyImageList(image);
+  return(GetFirstImageInList(postscript_image));
 }
 
 /*
@@ -676,8 +713,8 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPSImage() adds attributes for the PS image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterPSImage() adds properties for the PS image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -700,7 +737,7 @@ ModuleExport void RegisterPSImage(void)
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString(
    "Encapsulated PostScript Interchange format");
   entry->module=ConstantString("PS");
@@ -712,7 +749,7 @@ ModuleExport void RegisterPSImage(void)
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString("Encapsulated PostScript");
   entry->module=ConstantString("PS");
   (void) RegisterMagickInfo(entry);
@@ -733,7 +770,7 @@ ModuleExport void RegisterPSImage(void)
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString(
     "Encapsulated PostScript Interchange format");
   entry->module=ConstantString("PS");
@@ -745,7 +782,7 @@ ModuleExport void RegisterPSImage(void)
   entry->module=ConstantString("PS");
   entry->blob_support=MagickFalse;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=EncoderThreadSupport;
   entry->description=ConstantString("PostScript");
   (void) RegisterMagickInfo(entry);
 }
@@ -1085,14 +1122,21 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     page_geometry[MaxTextExtent];
 
   const char
-    **q;
+    **q,
+    *value;
 
-  const ImageAttribute
-    *attribute;
+  const StringInfo
+    *profile;
+
+  double
+    pointsize;
 
   GeometryInfo
     geometry_info;
 
+  ImageType
+    type;
+
   IndexPacket
     index,
     polarity;
@@ -1224,11 +1268,13 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
         geometry.x=(-page_info.x);
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
+    pointsize=12.0;
+    if (image_info->pointsize != 0.0)
+      pointsize=image_info->pointsize;
     text_size=0;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      text_size=(unsigned long)
-        (MultilineCensus(attribute->value)*image_info->pointsize+12);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     count=0;
     if (page == 1)
       {
@@ -1272,8 +1318,40 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               bounds.x2,bounds.y2);
           }
         (void) WriteBlobString(image,buffer);
-        attribute=GetImageAttribute(image,"Label");
-        if (attribute != (const ImageAttribute *) NULL)
+        profile=GetImageProfile(image,"iptc");
+        if (profile != (StringInfo *) NULL)
+          {
+            /*
+              Embed Photoshop profile.
+            */
+            (void) FormatMagickString(buffer,MaxTextExtent,
+              "%%BeginPhotoshop: %lu",(unsigned long) profile->length);
+            (void) WriteBlobString(image,buffer);
+            for (i=0; i < (long) profile->length; i++)
+            {
+              if ((i % 32) == 0)
+                (void) WriteBlobString(image,"\n% ");
+              (void) FormatMagickString(buffer,MaxTextExtent,"%02X",
+                (unsigned int) (profile->datum[i] & 0xff));
+              (void) WriteBlobString(image,buffer);
+            }
+            (void) WriteBlobString(image,"\n%EndPhotoshop\n");
+          }
+        profile=GetImageProfile(image,"xml");
+        if (profile != (StringInfo *) NULL)
+          {
+            /*
+              Embed XML profile.
+            */
+            (void) FormatMagickString(buffer,MaxTextExtent,
+              "%%begin_xml_packet: %lu\n",(unsigned long) profile->length);
+            (void) WriteBlobString(image,buffer);
+            for (i=0; i < (long) profile->length; i++)
+              (void) WriteBlobByte(image,profile->datum[i]);
+            (void) WriteBlobString(image,"\n%end_xml_packet\n");
+          }
+        value=GetImageProperty(image,"Label");
+        if (value != (const char *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Times-Roman\n");
         (void) WriteBlobString(image,"%%DocumentData: Clean7Bit\n");
@@ -1316,8 +1394,9 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Dump image as bitmap.
             */
-            (void) SetImageType(preview_image,PaletteType);
-            (void) SetImageType(preview_image,BilevelType);
+            type=GetImageType(preview_image,&preview_image->exception);
+            if (type != BilevelType)
+              (void) SetImageType(preview_image,BilevelType);
             polarity=(IndexPacket) (PixelIntensityToQuantum(
               &preview_image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
             if (preview_image->colors == 2)
@@ -1385,15 +1464,14 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
           (void) FormatMagickString(buffer,MaxTextExtent,"%s\n",*q);
           (void) WriteBlobString(image,buffer);
         }
-        attribute=GetImageAttribute(image,"Label");
-        if (attribute != (const ImageAttribute *) NULL)
-          for (j=(long) MultilineCensus(attribute->value)-1; j >= 0; j--)
+        value=GetImageProperty(image,"Label");
+        if (value != (const char *) NULL)
+          for (j=(long) MultilineCensus(value)-1; j >= 0; j--)
           {
             (void) WriteBlobString(image,"  /label 512 string def\n");
             (void) WriteBlobString(image,"  currentfile label readline pop\n");
             (void) FormatMagickString(buffer,MaxTextExtent,
-              "  0 y %g add moveto label show pop\n",j*image_info->pointsize+
-              12);
+              "  0 y %g add moveto label show pop\n",j*pointsize+12);
             (void) WriteBlobString(image,buffer);
           }
         for (q=PostscriptEpilog; *q; q++)
@@ -1421,8 +1499,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       bounds.x2=(double) geometry.x+geometry.width-1;
     if ((double) (geometry.y+(geometry.height+text_size)-1) > bounds.y2)
       bounds.y2=(double) geometry.y+(geometry.height+text_size)-1;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
       (void) WriteBlobString(image,"%%%%PageResources: font Times-Roman\n");
     if (LocaleCompare(image_info->magick,"PS") != 0)
       (void) WriteBlobString(image,"userdict begin\n");
@@ -1431,12 +1509,12 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       Output image data.
     */
     (void) FormatMagickString(buffer,MaxTextExtent,"%ld %ld\n%g %g\n%f\n",
-      geometry.x,geometry.y,scale.x,scale.y,image_info->pointsize);
+      geometry.x,geometry.y,scale.x,scale.y,pointsize);
     (void) WriteBlobString(image,buffer);
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      labels=StringToList(attribute->value);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      labels=StringToList(value);
     if (labels != (char **) NULL)
       {
         for (i=0; labels[i] != (char *) NULL; i++)
@@ -1453,14 +1531,15 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     i=0;
     index=0;
     x=0;
+    type=GetImageType(image,&image->exception);
     if ((image_info->type != TrueColorType) &&
-        (IsGrayImage(image,&image->exception) != MagickFalse))
+        ((type == BilevelType) || (type == GrayscaleType) ||
+         (type == GrayscaleMatteType)))
       {
         (void) FormatMagickString(buffer,MaxTextExtent,"%lu %lu\n1\n1\n1\n%d\n",
-          image->columns,image->rows,
-          IsMonochromeImage(image,&image->exception) != MagickFalse ? 1 : 8);
+          image->columns,image->rows,type == BilevelType ? 1 : 8);
         (void) WriteBlobString(image,buffer);
-        if (IsMonochromeImage(image,&image->exception) == MagickFalse)
+        if (type != BilevelType)
           {
             /*
               Dump image as grayscale.
@@ -1504,8 +1583,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             /*
               Dump image as bitmap.
             */
-            (void) SetImageType(image,PaletteType);
-            (void) SetImageType(image,BilevelType);
+            if (image->storage_class != PseudoClass)
+              (void) SetImageType(image,BilevelType);
             polarity=(IndexPacket) (PixelIntensityToQuantum(
               &image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
             if (image->colors == 2)
@@ -1579,8 +1658,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
             Dump DirectClass image.
           */
           (void) FormatMagickString(buffer,MaxTextExtent,"%lu %lu\n0\n%d\n",
-            image->columns,image->rows,(int)
-            (image->compression == RLECompression));
+            image->columns,image->rows,
+            image->compression == RLECompression ? 1 : 0);
           (void) WriteBlobString(image,buffer);
           switch (image->compression)
           {
@@ -1600,8 +1679,9 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                 {
                   if ((p->red == pixel.red) && (p->green == pixel.green) &&
-                      (p->blue == pixel.blue) && (p->opacity == pixel.opacity) &&
-                      (length < 255) && (x < (long) (image->columns-1)))
+                      (p->blue == pixel.blue) &&
+                      (p->opacity == pixel.opacity) && (length < 255) &&
+                      (x < (long) (image->columns-1)))
                     length++;
                   else
                     {
@@ -1686,8 +1766,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
           */
           (void) FormatMagickString(buffer,MaxTextExtent,"%lu %lu\n%d\n%d\n0\n",
             image->columns,image->rows,
-            (int) (image->storage_class == PseudoClass),
-            (int) (image->compression == RLECompression));
+            image->storage_class == PseudoClass ? 1 : 0,
+            image->compression == RLECompression ? 1 : 0);
           (void) WriteBlobString(image,buffer);
           /*
             Dump number of colors and colormap.
