@@ -41,7 +41,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -59,8 +58,9 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/option.h"
-#include "magick/resource_.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
+#include "magick/resource_.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/token.h"
@@ -105,8 +105,8 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPS3Image() adds attributes for the PS3 image format to the list of
-%  supported formats.  The attributes include the image format tag, a method to
+%  RegisterPS3Image() adds properties for the PS3 image format to the list of
+%  supported formats.  The properties include the image format tag, a method to
 %  read and/or write the format, whether the format supports the saving of more
 %  than one frame to the same file or blob, whether the format supports native
 %  in-memory I/O, and a brief description of the format.
@@ -395,14 +395,11 @@ static MagickBooleanType SerializeImageIndexes(const ImageInfo *image_info,
 }
 
 static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
-  Image *image)
+  Image *image,const CompressionType compression)
 {
   char
     buffer[MaxTextExtent];
 
-  CompressionType
-    compression;
-
   Image
     *mask_image;
 
@@ -430,7 +427,6 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(image->matte != MagickFalse);
   status=MagickTrue;
-  compression=image->compression;
   /*
     Note BeginData DSC comment for update later.
   */
@@ -450,6 +446,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
       (void) FormatMagickString(buffer,MaxTextExtent,
         "currentfile %lu %lu "PS3_NoCompression" ByteStreamDecodeFilter\n",
         image->columns,image->rows);
+      break;
     }
     case FaxCompression:
     case Group4Compression:
@@ -500,6 +497,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
       mask_image=DestroyImage(mask_image);
       return(MagickFalse);
     }
+  (void) SetImageType(mask_image,PaletteType);
   (void) SetImageType(mask_image,BilevelType);
   mask_image->matte=MagickFalse;
   pixels=(unsigned char *) NULL;
@@ -522,7 +520,8 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
     case Group4Compression:
     default:
     {
-      if (LocaleCompare(CCITTParam,"0") == 0)
+      if ((compression == FaxCompression) ||
+          (LocaleCompare(CCITTParam,"0") == 0))
         status=HuffmanEncodeImage(image_info,mask_image);
       else
         status=Huffman2DEncodeImage(image_info,mask_image);
@@ -530,7 +529,7 @@ static MagickBooleanType WritePS3MaskImage(const ImageInfo *image_info,
     }
     case JPEGCompression:
     {
-      status=JPEGEncodeImage(image_info,mask_image);
+      status=InjectImageBlob(image_info,mask_image,"jpeg");
       break;
     }
     case LZWCompression:
@@ -714,13 +713,11 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       "/DisplayImage",
       "{",
       "  /buffer 512 string def",
-      "",
       "  % Translation.",
       "  currentfile buffer readline pop",
       "  token pop /x exch def",
       "  token pop /y exch def pop",
       "  x y translate",
-      "",
       "  % Image size and font size.",
       "  currentfile buffer readline pop",
       "  token pop /x exch def",
@@ -735,7 +732,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       "  % Clipping path.",
       "  currentfile buffer readline pop",
       "  token pop /clipped exch def pop",
-      "  % EPS.",
+      "  % Showpage.",
       "  currentfile buffer readline pop",
       "  token pop /sp exch def pop",
       "  % Image pixel size.",
@@ -778,15 +775,16 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     **labels,
     page_geometry[MaxTextExtent];
 
-  const char
-    *option,
-    **q;
-
   CompressionType
     compression;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *option,
+    **q,
+    *value;
+
+  double
+    pointsize;
 
   GeometryInfo
     geometry_info;
@@ -850,6 +848,14 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
   compression=image->compression;
   switch (compression)
   {
+    case FaxCompression:
+    case Group4Compression:
+    { 
+      if ((IsMonochromeImage(image,&image->exception) == MagickFalse) ||
+          (image->matte != MagickFalse))
+        compression=RLECompression;
+      break;
+    }
 #if !defined(HasJPEG)
     case JPEGCompression:
     {
@@ -917,6 +923,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         if ((image->gravity != UndefinedGravity) &&
             (LocaleCompare(image_info->magick,"PS") == 0))
           (void) CopyMagickString(page_geometry,PSPageGeometry,MaxTextExtent);
+    (void) ConcatenateMagickString(page_geometry,">",MaxTextExtent);
     (void) ParseMetaGeometry(page_geometry,&geometry.x,&geometry.y,
       &geometry.width,&geometry.height);
     scale.x=(double) (geometry.width*delta.x)/resolution.x;
@@ -930,11 +937,13 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         geometry.x=(-page_info.x);
         geometry.y=(long) (media_info.height+page_info.y-image->rows);
       }
+    pointsize=12.0;
+    if (image_info->pointsize != 0.0)
+      pointsize=image_info->pointsize;
     text_size=0;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      text_size=(unsigned long)
-        (MultilineCensus(attribute->value)*image_info->pointsize+12);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      text_size=(unsigned long) (MultilineCensus(value)*pointsize+12);
     page++;
     if (page == 1)
       {
@@ -991,8 +1000,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           Font resources
         */
-        attribute=GetImageAttribute(image,"Label");
-        if (attribute != (const ImageAttribute *) NULL)
+        value=GetImageProperty(image,"Label");
+        if (value != (const char *) NULL)
           (void) WriteBlobString(image,
             "%%DocumentNeededResources: font Helvetica\n");
         (void) WriteBlobString(image,"%%LanguageLevel: 3\n");
@@ -1025,20 +1034,20 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         /*
           One label line for each line in label string.
         */
-        attribute=GetImageAttribute(image,"Label");
-        if (attribute != (const ImageAttribute *) NULL)
-        {
-          (void) WriteBlobString(image,"\n  % Labels.\n  /Helvetica findfont "
-            "pointsize scalefont setfont\n");
-          for (i=(long) MultilineCensus(attribute->value)-1; i >= 0; i--)
+        value=GetImageProperty(image,"Label");
+        if (value != (const char *) NULL)
           {
-            (void) WriteBlobString(image,
-              "  currentfile buffer readline pop token pop\n");
-            (void) FormatMagickString(buffer,MaxTextExtent,
-              "  0 y %g add moveto show pop\n",i*image_info->pointsize+12);
-            (void) WriteBlobString(image,buffer);
+              (void) WriteBlobString(image,"\n  %% Labels.\n  /Helvetica "
+              " findfont pointsize scalefont setfont\n");
+            for (i=(long) MultilineCensus(value)-1; i >= 0; i--)
+            {
+              (void) WriteBlobString(image,
+                "  currentfile buffer readline pop token pop\n");
+              (void) FormatMagickString(buffer,MaxTextExtent,
+                "  0 y %g add moveto show pop\n",i*pointsize+12);
+              (void) WriteBlobString(image,buffer);
+            }
           }
-        }
         /*
           The static postscript procedures epilog.
         */
@@ -1081,24 +1090,24 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
     /*
       Page font resource if there's a label.
     */
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
       (void) WriteBlobString(image,"%%PageResources: font Helvetica\n");
     /*
       PS clipping path from Photoshop clipping path.
     */
     if ((image->clip_mask == (Image *) NULL) ||
         (LocaleNCompare("8BIM:",image->clip_mask->magick_filename,5) != 0))
-      (void)WriteBlobString(image,"/ClipImage {} def\n");
+      (void) WriteBlobString(image,"/ClipImage {} def\n");
     else
       {
-        const ImageAttribute
-          *attribute;
+        const char
+          *value;
 
-        attribute=GetImageAttribute(image,image->clip_mask->magick_filename);
-        if (attribute == (const ImageAttribute *) NULL)
+        value=GetImageProperty(image,image->clip_mask->magick_filename);
+        if (value == (const char *) NULL)
           return(MagickFalse);
-        (void) WriteBlobString(image,attribute->value);
+        (void) WriteBlobString(image,value);
         (void) WriteBlobByte(image,'\n');
       }
     /*
@@ -1110,7 +1119,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       Image mask.
     */
     if ((image->matte != MagickFalse) &&
-        (WritePS3MaskImage(image_info,image) == MagickFalse))
+        (WritePS3MaskImage(image_info,image,compression) == MagickFalse))
       {
         CloseBlob(image);
         return(MagickFalse);
@@ -1129,15 +1138,15 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       Translate, scale, and font point size.
     */
     (void) FormatMagickString(buffer,MaxTextExtent,"%ld %ld\n%g %g\n%f\n",
-      geometry.x,geometry.y,scale.x,scale.y,image_info->pointsize);
+      geometry.x,geometry.y,scale.x,scale.y,pointsize);
     (void) WriteBlobString(image,buffer);
     /*
       Output labels.
     */
     labels=(char **) NULL;
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      labels=StringToList(attribute->value);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      labels=StringToList(value);
     if (labels != (char **) NULL)
       {
         for (i=0; labels[i] != (char *) NULL; i++)
@@ -1168,13 +1177,11 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
         (void) WriteBlobString(image,"true\n");
       else
         (void) WriteBlobString(image,"false\n");
-    if ((compression == FaxCompression) || (compression == Group4Compression))
-      (void) SetImageType(image,BilevelType);
     /*
       Showpage for non-EPS.
     */
-    (void) WriteBlobString(image,
-      LocaleCompare(image_info->magick,"PS3") == 0 ?  "true\n" : "false\n");
+    (void) WriteBlobString(image, LocaleCompare(image_info->magick,"PS3") == 0 ?
+      "true\n" : "false\n");
     /*
       Image columns, rows, and color space.
     */
@@ -1191,8 +1198,8 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
       Render with imagemask operator?
     */
     option=GetImageOption(image_info,"ps3:imagemask");
-    (void) WriteBlobString(image,(option != (const char *) NULL) &&
-      (IsMonochromeImage(image,&image->exception) != MagickFalse) ?
+    (void) WriteBlobString(image,((option != (const char *) NULL) &&
+      (IsMonochromeImage(image,&image->exception) != MagickFalse)) ?
       "true\n" : "false\n");
     /*
       Output pixel data.
@@ -1260,7 +1267,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
           Image data.
         */
         if (compression == JPEGCompression)
-          status=JPEGEncodeImage(image_info,image);
+          status=InjectImageBlob(image_info,image,"jpeg");
         else
           if ((compression == FaxCompression) ||
               (compression == Group4Compression))
@@ -1283,8 +1290,11 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
               case NoCompression:
               default:
               {
+                Ascii85Initialize(image);
                 for (i=0; i < (long) length; i++)
-                  (void) WriteBlobByte(image,pixels[i]);
+                  Ascii85Encode(image,pixels[i]);
+                Ascii85Flush(image);
+                status=MagickTrue;
                 break;
               }
               case LZWCompression:
@@ -1347,7 +1357,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
             Image data.
           */
           if (compression == JPEGCompression)
-            status=JPEGEncodeImage(image_info,image);
+            status=InjectImageBlob(image_info,image,"jpeg");
           else
             {
               /*
@@ -1480,7 +1490,7 @@ static MagickBooleanType WritePS3Image(const ImageInfo *image_info,Image *image)
               }
               case JPEGCompression:
               {
-                status=JPEGEncodeImage(image_info,image);
+                status=InjectImageBlob(image_info,image,"jpeg");
                 break;
               }
               case RLECompression:
