@@ -41,7 +41,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/colorspace.h"
@@ -55,8 +54,8 @@
 #include "magick/log.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/quantum.h"
 #include "magick/profile.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -92,7 +91,6 @@ static MagickBooleanType
 %    o channel:  Specifies which channel: red, green, blue, or index to
 %      decode the pixel values into.
 %
-%
 */
 static MagickBooleanType DecodeImage(Image *image,const long channel)
 {
@@ -115,9 +113,8 @@ static MagickBooleanType DecodeImage(Image *image,const long channel)
   ssize_t
     count;
 
-  x=0;
-  number_pixels=(MagickSizeType) image->columns*image->rows;
-  while (number_pixels > 0)
+  number_pixels=(MagickOffsetType) image->columns*image->rows;
+  for (x=0; number_pixels > 0; )
   {
     count=(ssize_t) ReadBlobByte(image);
     if (count >= 128)
@@ -467,12 +464,13 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
     id,
     sans;
 
+  if (length < 16)
+    return(MagickFalse);
   profile=AcquireStringInfo(length);
   SetStringInfoDatum(profile,blocks);
   (void) SetImageProfile(image,"iptc",profile);
   profile=DestroyStringInfo(profile);
-  p=blocks;
-  while (p < (blocks+length))
+  for (p=blocks; (p >= blocks) && (p < (blocks+length-16)); )
   {
     if (LocaleNCompare((char *) p,"8BIM",4) != 0)
       break;
@@ -684,7 +682,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->depth=psd_info.depth;
   image->columns=psd_info.columns;
   image->rows=psd_info.rows;
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   image->matte=psd_info.channels >= 4 ? MagickTrue : MagickFalse;
   if (psd_info.mode == LabMode)
     image->colorspace=LABColorspace;
@@ -731,7 +729,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
           /*
             Read PSD raster colormap.
           */
-          if (AllocateImageColormap(image,length/3) == MagickFalse)
+          if (AllocateImageColormap(image,(1UL*length)/3UL) == MagickFalse)
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           for (i=0; i < (long) image->colors; i++)
             image->colormap[i].red=ScaleCharToQuantum((unsigned char)
@@ -1034,7 +1032,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (image->debug != MagickFalse)
               (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                 "    setting up new layer image");
-            SetImageBackgroundColor(layer_info[i].image);
+            (void) SetImageBackgroundColor(layer_info[i].image);
             layer_info[i].image->compose=
               PSDBlendModeToCompositeOperator(layer_info[i].blendkey);
             if (layer_info[i].visible == MagickFalse)
@@ -1047,14 +1045,16 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Set up some hidden attributes for folks that need them.
             */
-            FormatMagickString(s,MaxTextExtent,"%ld", layer_info[i].page.x );
-            (void) SetImageAttribute(layer_info[i].image,"[layer-xpos]",s);
-            FormatMagickString(s,MaxTextExtent,"%ld", layer_info[i].page.y );
-            (void) SetImageAttribute(layer_info[i].image,"[layer-ypos]",s);
-            FormatMagickString(s,MaxTextExtent,"%lu",(unsigned long)
+            (void) FormatMagickString(s,MaxTextExtent,"%ld",
+              layer_info[i].page.x );
+            (void) SetImageProperty(layer_info[i].image,"[layer-xpos]",s);
+            (void) FormatMagickString(s,MaxTextExtent,"%ld",
+              layer_info[i].page.y);
+            (void) SetImageProperty(layer_info[i].image,"[layer-ypos]",s);
+            (void) FormatMagickString(s,MaxTextExtent,"%lu",(unsigned long)
               layer_info[i].opacity );
-            (void) SetImageAttribute(layer_info[i].image,"[layer-opacity]",s);
-            (void) SetImageAttribute(layer_info[i].image,"label",(char *)
+            (void) SetImageProperty(layer_info[i].image,"[layer-opacity]",s);
+            (void) SetImageProperty(layer_info[i].image,"label",(char *)
               layer_info[i].name);
           }
         if (image->debug != MagickFalse)
@@ -1284,7 +1284,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
             }
           layer_offset-=TellBlob(image);
-          SeekBlob(image,layer_offset,SEEK_CUR);
+          (void) SeekBlob(image,layer_offset,SEEK_CUR);
         }
     }
   /*
@@ -1410,8 +1410,8 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterPSDImage() adds attributes for the PSD image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterPSDImage() adds properties for the PSD image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -1534,7 +1534,7 @@ static void WriteImageChannels(const ImageInfo *image_info,Image *image,
   else
     {
       if (tmp_image->colorspace == CMYKColorspace)
-        NegateImage(image,MagickFalse);
+        (void) NegateImage(image,MagickFalse);
       if (tmp_image->matte)
         WriteOneChannel(image_info,image,tmp_image,pixels,AlphaQuantum);
       WriteOneChannel(image_info,image,tmp_image,pixels,RedQuantum);
@@ -1543,7 +1543,7 @@ static void WriteImageChannels(const ImageInfo *image_info,Image *image,
       if (tmp_image->colorspace == CMYKColorspace)
         {
           WriteOneChannel(image_info,image,tmp_image,pixels,BlackQuantum);
-          NegateImage(image,MagickFalse);
+          (void) NegateImage(image,MagickFalse);
         }
     }
 }
@@ -1633,12 +1633,12 @@ static void WritePascalString (Image* inImage, const char *inString, int inPad)
 
 static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
 {
+  const char
+    *theAttr;
+
   const StringInfo
     *profile;
 
-  ImageAttribute
-    *theAttr;
-
   MagickBooleanType
     force_white_background = image->matte,
     invert_layer_count = MagickFalse,
@@ -1751,7 +1751,7 @@ static MagickBooleanType WritePSDImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobMSBLong(image,0);
   else
     {
-      (void) WriteBlobMSBLong( image, profile->length );
+      (void) WriteBlobMSBLong(image,(unsigned long) profile->length);
       (void) WriteBlob( image, profile->length, profile->datum );
     }
 
@@ -1770,8 +1770,8 @@ compute_layer_info:
     else
       num_channels = (tmp_image->matte != MagickFalse ? 5UL : 4UL);
 
-  channelLength=(tmp_image->columns * tmp_image->rows * packet_size + 2);
-  layer_info_size += (4*4 + 2 + num_channels * 6 + 4 + 4 + 4 * 1 + 4 + 12 + num_channels * channelLength);
+  channelLength=(unsigned long) (tmp_image->columns * tmp_image->rows * packet_size + 2);
+  layer_info_size += (unsigned long) (4*4 + 2 + num_channels * 6 + 4 + 4 + 4 * 1 + 4 + 12 + num_channels * channelLength);
 
   layer_count++;
   tmp_image = GetNextImageInList(tmp_image);
@@ -1809,7 +1809,7 @@ compute_layer_info:
       (void) WriteBlobMSBLong(image,tmp_image->columns);
 
       packet_size=tmp_image->depth > 8 ? 2UL : 1UL;
-      channel_size=((packet_size*tmp_image->rows*tmp_image->columns)+2);
+      channel_size=(unsigned long) ((packet_size*tmp_image->rows*tmp_image->columns)+2);
       if (tmp_image->storage_class == PseudoClass) {
        (void) WriteBlobMSBShort(image,(unsigned short)
          (tmp_image->matte ? 2 : 1));
@@ -1864,9 +1864,9 @@ compute_layer_info:
       (void) WriteBlobMSBLong(image, 0);
       (void) WriteBlobMSBLong(image, 0);
 
-      theAttr=(ImageAttribute *) GetImageAttribute(tmp_image,"label");
+      theAttr=(const char *) GetImageProperty(tmp_image,"label");
       if (theAttr) {
-        WritePascalString( image, theAttr->value, 4 );
+        WritePascalString( image, theAttr, 4 );
         /*
         sprintf((char *) &(layer_name[1]), "%4s", theAttr->value );
         (void) WriteBlobByte(image, 3);
