@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,6 +52,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resource_.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -159,7 +160,8 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   pwp_image=AllocateImage(image_info);
@@ -203,7 +205,7 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         return((Image *) NULL);
       }
     (void) fwrite("SFW94A",1,6,file);
-    filesize=65535L*magick[2]+256L*magick[1]+magick[0];
+    filesize=65535UL*magick[2]+256L*magick[1]+magick[0];
     for (i=0; i < (long) filesize; i++)
     {
       c=ReadBlobByte(pwp_image);
@@ -222,7 +224,7 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Link image into image list.
         */
-        for (p=image; p->next != (Image *) NULL; p=p->next);
+        for (p=image; p->next != (Image *) NULL; p=GetNextImageInList(p));
         next_image->previous=p;
         next_image->scene=p->scene+1;
         p->next=next_image;
@@ -243,8 +245,15 @@ static Image *ReadPWPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   CloseBlob(pwp_image);
   pwp_image=DestroyImage(pwp_image);
   if (EOFBlob(image) != MagickFalse)
-    (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageError,
-      "UnexpectedEndOfFile","`%s': %s",image->filename,strerror(errno));
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      (void) ThrowMagickException(exception,GetMagickModule(),CorruptImageError,
+        "UnexpectedEndOfFile","`%s': %s",image->filename,message);
+      message=(char *) RelinquishMagickMemory(message);
+    }
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
@@ -280,8 +289,8 @@ ModuleExport void RegisterPWPImage(void)
   entry=SetMagickInfo("PWP");
   entry->decoder=(DecoderHandler *) ReadPWPImage;
   entry->magick=(MagickHandler *) IsPWP;
-  entry->description=AcquireString("Seattle Film Works");
-  entry->module=AcquireString("PWP");
+  entry->description=ConstantString("Seattle Film Works");
+  entry->module=ConstantString("PWP");
   (void) RegisterMagickInfo(entry);
 }
 
