@@ -52,7 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/pixel.h"
+#include "magick/quantum.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -106,6 +106,9 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickOffsetType
     offset;
 
+  QuantumInfo
+    quantum_info;
+
   register long
     i;
 
@@ -184,6 +187,7 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Convert raster image to pixel packets.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
@@ -214,12 +218,15 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (q == (PixelPacket *) NULL)
             break;
           if (image->matte == MagickFalse)
-            (void) ExportQuantumPixels(image,RGBQuantum,0,pixels+offset);
+            (void) ExportQuantumPixels(image,&quantum_info,RGBQuantum,
+              pixels+offset);
           else
             if (LocaleCompare(image_info->magick,"RGBA") == 0)
-              (void) ExportQuantumPixels(image,RGBAQuantum,0,pixels+offset);
+              (void) ExportQuantumPixels(image,&quantum_info,RGBAQuantum,
+                pixels+offset);
             else
-              (void) ExportQuantumPixels(image,RGBOQuantum,0,pixels+offset);
+              (void) ExportQuantumPixels(image,&quantum_info,RGBOQuantum,
+                pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -265,15 +272,18 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,RedQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,RedQuantum,
+            pixels+offset);
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           if (count != (ssize_t) (packet_size*image->extract_info.width))
             break;
-          (void) ExportQuantumPixels(image,GreenQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,GreenQuantum,
+            pixels+offset);
           count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           if (count != (ssize_t) (packet_size*image->extract_info.width))
             break;
-          (void) ExportQuantumPixels(image,BlueQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,BlueQuantum,
+            pixels+offset);
           if (image->matte != MagickFalse)
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
@@ -281,10 +291,10 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               if (count != (ssize_t) (packet_size*image->extract_info.width))
                 break;
               if (LocaleCompare(image_info->magick,"RGBA") == 0)
-                (void) ExportQuantumPixels(image,AlphaQuantum,0,
+                (void) ExportQuantumPixels(image,&quantum_info,AlphaQuantum,
                   pixels+offset);
               else
-                (void) ExportQuantumPixels(image,OpacityQuantum,0,
+                (void) ExportQuantumPixels(image,&quantum_info,OpacityQuantum,
                   pixels+offset);
             }
           if (SyncImagePixels(image) == MagickFalse)
@@ -348,7 +358,8 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,RedQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,RedQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -394,7 +405,8 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,GreenQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,GreenQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -440,7 +452,8 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,BlueQuantum,0,pixels+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,BlueQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -494,10 +507,10 @@ static Image *ReadRGBImage(const ImageInfo *image_info,ExceptionInfo *exception)
               if (q == (PixelPacket *) NULL)
                 break;
               if (LocaleCompare(image_info->magick,"RGBA") == 0)
-                (void) ExportQuantumPixels(image,AlphaQuantum,0,
+                (void) ExportQuantumPixels(image,&quantum_info,AlphaQuantum,
                   pixels+offset);
               else
-                (void) ExportQuantumPixels(image,OpacityQuantum,0,
+                (void) ExportQuantumPixels(image,&quantum_info,OpacityQuantum,
                   pixels+offset);
               if (SyncImagePixels(image) == MagickFalse)
                 break;
@@ -684,6 +697,9 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
   MagickOffsetType
     scene;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -710,8 +726,8 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
   if ((LocaleCompare(image_info->magick,"RGBA") == 0) ||
       (LocaleCompare(image_info->magick,"RGBO") == 0))
     packet_size+=depth/8;
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->columns*sizeof(*pixels));
+  pixels=(unsigned char *) AcquireMagickMemory(packet_size*
+    image->columns*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->interlace != PartitionInterlace)
@@ -729,11 +745,12 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
     /*
       Convert MIFF to RGB raster pixels.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     if (LocaleCompare(image_info->magick,"RGBA") == 0)
       if (image->matte == MagickFalse)
-        SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageOpacity(image,OpaqueOpacity);
     switch (image_info->interlace)
     {
       case NoInterlace:
@@ -749,15 +766,17 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
             break;
           if (LocaleCompare(image_info->magick,"RGBA") != 0)
             {
-              (void) ImportQuantumPixels(image,RGBQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,RGBQuantum,pixels);
               (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           else
             {
               if (LocaleCompare(image_info->magick,"RGBA") == 0)
-                (void) ImportQuantumPixels(image,RGBAQuantum,0,pixels);
+                (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,
+                  pixels);
               else
-                (void) ImportQuantumPixels(image,RGBOQuantum,0,pixels);
+                (void) ImportQuantumPixels(image,&quantum_info,RGBOQuantum,
+                  pixels);
               (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           if (image->previous == (Image *) NULL)
@@ -777,24 +796,27 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
         /*
           Line interlacing:  RRR...GGG...BBB...RRR...GGG...BBB...
         */
+        packet_size=depth/8;
         for (y=0; y < (long) image->rows; y++)
         {
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,RedQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,GreenQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,BlueQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,RedQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,GreenQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,BlueQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
           if (LocaleCompare(image_info->magick,"RGBA") == 0)
             {
               if (LocaleCompare(image_info->magick,"RGBA") == 0)
-                (void) ImportQuantumPixels(image,AlphaQuantum,0,pixels);
+                (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                  pixels);
               else
-                (void) ImportQuantumPixels(image,OpacityQuantum,0,pixels);
-              (void) WriteBlob(image,(size_t) image->columns,pixels);
+                (void) ImportQuantumPixels(image,&quantum_info,OpacityQuantum,
+                  pixels);
+              (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
               (QuantumTick(y,image->rows) != MagickFalse))
@@ -813,6 +835,7 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
         /*
           Plane interlacing:  RRRRRR...GGGGGG...BBBBBB...
         */
+        packet_size=depth/8;
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("R",image->filename);
@@ -826,8 +849,8 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,RedQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,RedQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
         }
         if (image_info->interlace == PartitionInterlace)
           {
@@ -850,8 +873,8 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,GreenQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,GreenQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
         }
         if (image_info->interlace == PartitionInterlace)
           {
@@ -874,8 +897,8 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,BlueQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,BlueQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
         }
         if (LocaleCompare(image_info->magick,"RGBA") == 0)
           {
@@ -902,10 +925,12 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
               if (p == (const PixelPacket *) NULL)
                 break;
               if (LocaleCompare(image_info->magick,"RGBA") == 0)
-                (void) ImportQuantumPixels(image,AlphaQuantum,0,pixels);
+                (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                  pixels);
               else
-                (void) ImportQuantumPixels(image,OpacityQuantum,0,pixels);
-              (void) WriteBlob(image,(size_t) image->columns,pixels);
+                (void) ImportQuantumPixels(image,&quantum_info,OpacityQuantum,
+                  pixels);
+              (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           }
         if (image_info->interlace == PartitionInterlace)
