@@ -193,10 +193,10 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read paramter block.
   */
-  units=ReadBlobByte(image);
+  units=1UL*ReadBlobByte(image);
   if (units == 0)
     image->units=PixelsPerCentimeterResolution;
-  separations=ReadBlobByte(image);
+  separations=1UL*ReadBlobByte(image);
   separations_mask=ReadBlobMSBShort(image);
   count=ReadBlob(image,14,buffer);
   buffer[14]='\0';
@@ -205,15 +205,15 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   width=atof((char *) buffer);
   count=ReadBlob(image,12,buffer);
   buffer[12]='\0';
-  image->rows=atol((char *) buffer);
+  image->rows=1UL*atol((char *) buffer);
   count=ReadBlob(image,12,buffer);
-  image->columns=atol((char *) buffer);
+  image->columns=1UL*atol((char *) buffer);
   count=ReadBlob(image,200,buffer);
   count=ReadBlob(image,768,buffer);
   if (separations_mask == 0x0f)
     image->colorspace=CMYKColorspace;
-  image->x_resolution=image->columns/width;
-  image->y_resolution=image->rows/height;
+  image->x_resolution=1.0*image->columns/width;
+  image->y_resolution=1.0*image->rows/height;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
