@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -54,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -186,7 +186,7 @@ static MagickBooleanType SGIDecode(const size_t bytes_per_pixel,
         count=(ssize_t) (pixel & 0x7f);
         if (count == 0)
           break;
-        if (count > number_pixels)
+        if (count > (ssize_t) number_pixels)
           return(MagickFalse);
         number_pixels-=count;
         if ((pixel & 0x80) != 0)
@@ -222,7 +222,7 @@ static MagickBooleanType SGIDecode(const size_t bytes_per_pixel,
     count=(ssize_t) (pixel & 0x7f);
     if (count == 0)
       break;
-    if (count > number_pixels)
+    if (count > (ssize_t) number_pixels)
       return(MagickFalse);
     number_pixels-=count;
     if ((pixel & 0x80) != 0)
@@ -340,7 +340,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
       iris_info.name);
     iris_info.name[sizeof(iris_info.name)-1]='\0';
     if (*iris_info.name != '\0')
-      (void) SetImageAttribute(image,"label",iris_info.name);
+      (void) SetImageProperty(image,"label",iris_info.name);
     iris_info.pixel_format=ReadBlobMSBLong(image);
     if (iris_info.pixel_format != 0)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -349,7 +349,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->rows=iris_info.rows;
     image->depth=Min(iris_info.depth,QuantumDepth);
     if (iris_info.pixel_format == 0)
-      image->depth=Min(8*iris_info.bytes_per_pixel,QuantumDepth);
+      image->depth=1UL*Min(8*iris_info.bytes_per_pixel,QuantumDepth);
     if (iris_info.depth < 3)
       {
         image->storage_class=PseudoClass;
@@ -379,7 +379,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Read standard image format.
         */
         scanline=(unsigned char *) AcquireMagickMemory(bytes_per_pixel*
-          iris_info.columns);
+          iris_info.columns*sizeof(*scanline));
         if (scanline == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (z=0; z < (long) iris_info.depth; z++)
@@ -455,7 +455,7 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
               data_order=1;
             offset=offsets[y+z*iris_info.rows];
           }
-        offset=TellBlob(image);
+        offset=(ssize_t) TellBlob(image);
         if (data_order == 1)
           {
             for (z=0; z < (long) iris_info.depth; z++)
@@ -473,9 +473,9 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (EOFBlob(image) != MagickFalse)
                   break;
                 offset+=runlength[y+z*iris_info.rows];
-                status=SGIDecode(bytes_per_pixel,runlength[y+z*iris_info.rows]/
-                  bytes_per_pixel,packets,iris_info.columns,
-                  p+bytes_per_pixel*z);
+                status=SGIDecode(bytes_per_pixel,1L*
+                  runlength[y+z*iris_info.rows]/bytes_per_pixel,packets,
+                  1L*iris_info.columns,p+bytes_per_pixel*z);
                 if (status == MagickFalse)
                   ThrowReaderException(CorruptImageError,"ImproperImageHeader");
                 p+=(iris_info.columns*4*bytes_per_pixel);
@@ -503,9 +503,9 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (EOFBlob(image) != MagickFalse)
                   break;
                 offset+=runlength[y+z*iris_info.rows];
-                status=SGIDecode(bytes_per_pixel,runlength[y+z*iris_info.rows]/
-                  bytes_per_pixel,packets,iris_info.columns,
-                  p+bytes_per_pixel*z);
+                status=SGIDecode(bytes_per_pixel,1L*
+                  runlength[y+z*iris_info.rows]/bytes_per_pixel,packets,
+                  1L*iris_info.columns,p+bytes_per_pixel*z);
                 if (status == MagickFalse)
                   ThrowReaderException(CorruptImageError,"ImproperImageHeader");
               }
@@ -715,8 +715,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterSGIImage() adds attributes for the SGI image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterSGIImage() adds properties for the SGI image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -789,7 +789,6 @@ ModuleExport void UnregisterSGIImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 
 static size_t SGIEncode(unsigned char *pixels,size_t length,
@@ -847,8 +846,8 @@ static size_t SGIEncode(unsigned char *pixels,size_t length,
 
 static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
 {
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   long
     y,
@@ -904,11 +903,13 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       (void) SetImageColorspace(image,RGBColorspace);
     (void) ResetMagickMemory(&iris_info,0,sizeof(iris_info));
     iris_info.magic=0x01DA;
+    if (image->depth > 8)
+      image->compression=NoCompression;
     if (image->compression == NoCompression)
       iris_info.storage=(unsigned char) 0x00;
     else
       iris_info.storage=(unsigned char) 0x01;
-    iris_info.bytes_per_pixel=(unsigned char) 1;  /* one byte per pixel */
+    iris_info.bytes_per_pixel=(unsigned char) (image->depth > 8 ? 2 : 1);
     iris_info.dimension=3;
     iris_info.columns=(unsigned short) image->columns;
     iris_info.rows=(unsigned short) image->rows;
@@ -926,7 +927,8 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
           iris_info.depth=3;
       }
     iris_info.minimum_value=0;
-    iris_info.maximum_value=(unsigned long) ScaleQuantumToChar(QuantumRange);
+    iris_info.maximum_value=(unsigned long) (image->depth <= 8 ?
+      ScaleQuantumToChar(QuantumRange) : ScaleQuantumToShort(QuantumRange));
     /*
       Write SGI header.
     */
@@ -940,10 +942,9 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobMSBLong(image,iris_info.minimum_value);
     (void) WriteBlobMSBLong(image,iris_info.maximum_value);
     (void) WriteBlobMSBLong(image,iris_info.sans);
-    attribute=GetImageAttribute(image,"label");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) CopyMagickString(iris_info.name,attribute->value,
-        sizeof(iris_info.name));
+    value=GetImageProperty(image,"label");
+    if (value != (const char *) NULL)
+      (void) CopyMagickString(iris_info.name,value,sizeof(iris_info.name));
     (void) WriteBlob(image,sizeof(iris_info.name),(unsigned char *)
       iris_info.name);
     (void) WriteBlobMSBLong(image,iris_info.pixel_format);
@@ -952,10 +953,11 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       Allocate SGI pixels.
     */
     number_pixels=(MagickSizeType) image->columns*image->rows;
-    if ((4*number_pixels) != ((MagickSizeType) (size_t) (4*number_pixels)))
+    if ((4*iris_info.bytes_per_pixel*number_pixels) !=
+        ((MagickSizeType) (size_t) (4*iris_info.bytes_per_pixel*number_pixels)))
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    iris_pixels=(unsigned char *) AcquireMagickMemory(4*(size_t) image->columns*
-      image->rows);
+    iris_pixels=(unsigned char *) AcquireMagickMemory((size_t)
+      (4*iris_info.bytes_per_pixel*number_pixels*sizeof(*iris_pixels)));
     if (iris_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -966,15 +968,34 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
       p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
       if (p == (const PixelPacket *) NULL)
         break;
-      q=iris_pixels+((iris_info.rows-1)-y)*(iris_info.columns*4);
-      for (x=0; x < (long) image->columns; x++)
-      {
-        *q++=ScaleQuantumToChar(p->red);
-        *q++=ScaleQuantumToChar(p->green);
-        *q++=ScaleQuantumToChar(p->blue);
-        *q++=ScaleQuantumToChar((Quantum) (QuantumRange-p->opacity));
-        p++;
-      }
+      if (image->depth <= 8)
+        for (x=0; x < (long) image->columns; x++)
+        {
+          register unsigned char
+            *q;
+
+          q=(unsigned char *) iris_pixels;
+          q+=((iris_info.rows-1)-y)*(4*iris_info.columns)+4*x;
+          *q++=ScaleQuantumToChar(p->red);
+          *q++=ScaleQuantumToChar(p->green);
+          *q++=ScaleQuantumToChar(p->blue);
+          *q++=ScaleQuantumToChar((Quantum) (QuantumRange-p->opacity));
+          p++;
+        }
+      else
+        for (x=0; x < (long) image->columns; x++)
+        {
+          register unsigned short
+            *q;
+
+          q=(unsigned short *) iris_pixels;
+          q+=((iris_info.rows-1)-y)*(4*iris_info.columns)+4*x;
+          *q++=ScaleQuantumToShort(p->red);
+          *q++=ScaleQuantumToShort(p->green);
+          *q++=ScaleQuantumToShort(p->blue);
+          *q++=ScaleQuantumToShort((Quantum) (QuantumRange-p->opacity));
+          p++;
+        }
       if (image->previous == (Image *) NULL)
         if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
             (QuantumTick(y,image->rows) != MagickFalse))
@@ -985,34 +1006,42 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
               break;
           }
     }
-    if (image->compression == NoCompression)
+    switch (image->compression)
+    {
+      case NoCompression:
       {
-        unsigned char
-          *scanline;
-
         /*
           Write uncompressed SGI pixels.
         */
-        scanline=(unsigned char *)
-          AcquireMagickMemory((size_t) iris_info.columns);
-        if (scanline == (unsigned char *) NULL)
-          ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         for (z=0; z < (long) iris_info.depth; z++)
         {
-          q=iris_pixels+z;
           for (y=0; y < (long) iris_info.rows; y++)
           {
-            for (x=0; x < (long) iris_info.columns; x++)
-            {
-              scanline[x]=(*q);
-              q+=4;
-            }
-            (void) WriteBlob(image,(size_t) iris_info.columns,scanline);
+            if (image->depth <= 8)
+              for (x=0; x < (long) iris_info.columns; x++)
+              {
+                register unsigned char
+                  *q;
+
+                q=(unsigned char *) iris_pixels;
+                q+=y*(4*iris_info.columns)+4*x+z;
+                (void) WriteBlobByte(image,*q);
+              }
+            else
+              for (x=0; x < (long) iris_info.columns; x++)
+              {
+                register unsigned short
+                  *q;
+
+                q=(unsigned short *) iris_pixels;
+                q+=y*(4*iris_info.columns)+4*x+z;
+                (void) WriteBlobMSBShort(image,*q);
+              }
           }
         }
-        scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+        break;
       }
-    else
+      default:
       {
         ssize_t
           offset,
@@ -1028,10 +1057,10 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
         /*
           Convert SGI uncompressed pixels.
         */
-        offsets=(ssize_t *) AcquireMagickMemory(iris_info.rows*
-          iris_info.depth*sizeof(*offsets));
-        packets=(unsigned char *)
-          AcquireMagickMemory(4*(2*(size_t) iris_info.columns+10)*image->rows);
+        offsets=(ssize_t *) AcquireMagickMemory(iris_info.rows*iris_info.depth*
+          sizeof(*offsets));
+        packets=(unsigned char *) AcquireMagickMemory(4*(2*(size_t)
+          iris_info.columns+10)*image->rows*sizeof(*packets));
         runlength=(unsigned long *) AcquireMagickMemory(iris_info.rows*
           iris_info.depth*sizeof(*runlength));
         if ((offsets == (ssize_t *) NULL) ||
@@ -1050,7 +1079,7 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
             number_packets+=length;
             offsets[y+z*iris_info.rows]=offset;
             runlength[y+z*iris_info.rows]=(unsigned long) length;
-            offset+=length;
+            offset+=(ssize_t) length;
           }
           q+=(iris_info.columns*4);
         }
@@ -1068,7 +1097,9 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
         runlength=(unsigned long *) RelinquishMagickMemory(runlength);
         packets=(unsigned char *) RelinquishMagickMemory(packets);
         offsets=(ssize_t *) RelinquishMagickMemory(offsets);
+        break;
       }
+    }
     iris_pixels=(unsigned char *) RelinquishMagickMemory(iris_pixels);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
