@@ -154,7 +154,7 @@ static MagickBooleanType DecodeImage(const unsigned char *compressed_pixels,
   p=compressed_pixels;
   q=pixels;
   l=q+maxpixels;
-  while ((size_t) (p-compressed_pixels) < length && q < l)
+  while (((size_t) (p-compressed_pixels) < length) && (q < l))
   {
     byte=(*p++);
     if (byte != 128U)
@@ -167,7 +167,7 @@ static MagickBooleanType DecodeImage(const unsigned char *compressed_pixels,
         count=(ssize_t) (*p++);
         if (count > 0)
           byte=(*p++);
-        while (count >= 0 && q < l)
+        while ((count >= 0) && (q < l))
         {
           *q++=byte;
           count--;
@@ -379,10 +379,10 @@ static Image *ReadSUNImage(const ImageInfo *image_info,ExceptionInfo *exception)
         CloseBlob(image);
         return(GetFirstImageInList(image));
       }
-    if ((sun_info.length * sizeof(*sun_data)) / sizeof(*sun_data) != sun_info.length || !sun_info.length)
+    if ((sun_info.length*sizeof(*sun_data))/sizeof(*sun_data) != sun_info.length || !sun_info.length)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    sun_data=(unsigned char *)
-      AcquireMagickMemory((size_t) sun_info.length*sizeof(*sun_data));
+    sun_data=(unsigned char *) AcquireMagickMemory((size_t) sun_info.length*
+      sizeof(*sun_data));
     if (sun_data == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     count=(ssize_t) ReadBlob(image,sun_info.length,sun_data);
