@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color-private.h"
@@ -53,6 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -68,6 +68,41 @@ static MagickBooleanType
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   I s T G A                                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  IsTGA() returns MagickTrue if the image format type, identified by the
+%  magick string, is a Microsoft Windows Enhanced MetaFile (TGA) file.
+%
+%  The format of the ReadTGAImage method is:
+%
+%      MagickBooleanType IsTGA(const unsigned char *magick,const size_t length)
+%
+%  A description of each parameter follows:
+%
+%    o magick: This string is generally the first few bytes of an image file
+%      or blob.
+%
+%    o length: Specifies the length of the magick string.
+%
+*/
+static MagickBooleanType IsTGA(const unsigned char *magick,const size_t length)
+{
+  if (length < 4)
+    return(MagickFalse);
+  if (memcmp(magick,"\000\000\002\000",4) == 0)
+    return(MagickTrue);
+  return(MagickFalse);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   R e a d T G A I m a g e                                                   %
 %                                                                             %
 %                                                                             %
@@ -257,12 +292,13 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           TGA image comment.
         */
-        comment=(char *) AcquireMagickMemory(tga_info.id_length+MaxTextExtent);
+        comment=(char *) AcquireMagickMemory((size_t) (tga_info.id_length+
+          MaxTextExtent)*sizeof(*comment));
         if (comment == (char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         count=ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
         comment[tga_info.id_length]='\0';
-        (void) SetImageAttribute(image,"Comment",comment);
+        (void) SetImageProperty(image,"Comment",comment);
         comment=(char *) RelinquishMagickMemory(comment);
       }
     (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
@@ -297,10 +333,10 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               j=(unsigned char) ReadBlobByte(image);
               k=(unsigned char) ReadBlobByte(image);
-              pixel.red=ScaleAnyToQuantum((int) (k & 0x7c) >> 2,31);
-              pixel.green=ScaleAnyToQuantum(((int) (k & 0x03) << 3)+
-                ((int) (j & 0xe0) >> 5),31);
-              pixel.blue=ScaleAnyToQuantum((int) (j & 0x1f),31);
+              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,31);
+              pixel.green=ScaleAnyToQuantum((1UL*(k & 0x03) << 3)+
+                (1UL*(j & 0xe0) >> 5),31);
+              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),31);
               break;
             }
             case 24:
@@ -394,10 +430,13 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               j=(unsigned char) ReadBlobByte(image);
               k=(unsigned char) ReadBlobByte(image);
-              pixel.red=ScaleAnyToQuantum((int) (k & 0x7c) >> 2,31);
-              pixel.green=ScaleAnyToQuantum(((int) (k & 0x03) << 3)+
-                ((int) (j & 0xe0) >> 5),31);
-              pixel.blue=ScaleAnyToQuantum((int) (j & 0x1f),31);
+              pixel.red=ScaleAnyToQuantum(1UL*(k & 0x7c) >> 2,31);
+              pixel.green=ScaleAnyToQuantum((1UL*(k & 0x03) << 3)+
+                (1UL*(j & 0xe0) >> 5),31);
+              pixel.blue=ScaleAnyToQuantum(1UL*(j & 0x1f),31);
+              if (image->matte != MagickFalse)
+                pixel.opacity=(k & 0x80) != 0? OpaqueOpacity :
+                  TransparentOpacity; 
               if (image->storage_class == PseudoClass)
                 index=ConstrainColormapIndex(image,((unsigned long) k << 8)+j);
               break;
@@ -423,7 +462,12 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
           ThrowReaderException(CorruptImageError,"UnableToReadImageData");
         if (image->storage_class == PseudoClass)
           indexes[x]=index;
-        *q++=pixel;
+        q->red=pixel.red;
+        q->green=pixel.green;
+        q->blue=pixel.blue;
+        if (image->matte != MagickFalse)
+          q->opacity=pixel.opacity;
+        q++;
       }
       if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 4)
         offset+=4;
@@ -506,8 +550,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterTGAImage() adds attributes for the TGA image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterTGAImage() adds properties for the TGA image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -526,24 +570,28 @@ ModuleExport void RegisterTGAImage(void)
   entry=SetMagickInfo("ICB");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("TGA");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("VDA");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("VST");
   entry->decoder=(DecoderHandler *) ReadTGAImage;
   entry->encoder=(EncoderHandler *) WriteTGAImage;
+  entry->magick=(MagickHandler *) IsTGA;
   entry->description=ConstantString("Truevision Targa image");
   entry->module=ConstantString("TGA");
   (void) RegisterMagickInfo(entry);
@@ -636,8 +684,8 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
       attributes;
   } TargaInfo;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   long
     y;
@@ -695,9 +743,9 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     targa_info.id_length=0;
-    attribute=GetImageAttribute(image,"Comment");
-    if (attribute != (const ImageAttribute *) NULL)
-      targa_info.id_length=(unsigned char) Min(strlen(attribute->value),255);
+    value=GetImageProperty(image,"Comment");
+    if (value != (const char *) NULL)
+      targa_info.id_length=(unsigned char) Min(strlen(value),255);
     targa_info.colormap_type=0;
     targa_info.colormap_index=0;
     targa_info.colormap_length=0;
@@ -755,7 +803,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobByte(image,targa_info.attributes);
     if (targa_info.id_length != 0)
       (void) WriteBlob(image,targa_info.id_length,(unsigned char *)
-        attribute->value);
+        value);
     if (targa_info.image_type == TargaColormap)
       {
         unsigned char
@@ -764,8 +812,8 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
         /*
           Dump colormap to file (blue, green, red byte order).
         */
-        targa_colormap=(unsigned char *)
-          AcquireMagickMemory(3*targa_info.colormap_length);
+        targa_colormap=(unsigned char *) AcquireMagickMemory((size_t)
+          (3*targa_info.colormap_length)*sizeof(*targa_colormap));
         if (targa_colormap == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         q=targa_colormap;
@@ -775,7 +823,8 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
           *q++=ScaleQuantumToChar(image->colormap[i].green);
           *q++=ScaleQuantumToChar(image->colormap[i].red);
         }
-        (void) WriteBlob(image,3*targa_info.colormap_length,targa_colormap);
+        (void) WriteBlob(image,(size_t) (3*targa_info.colormap_length),
+          targa_colormap);
         targa_colormap=(unsigned char *) RelinquishMagickMemory(targa_colormap);
       }
     /*
@@ -805,7 +854,8 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
               *q++=ScaleQuantumToChar(p->green);
               *q++=ScaleQuantumToChar(p->red);
               if (image->matte != MagickFalse)
-                *q++=QuantumRange-ScaleQuantumToChar(p->opacity);
+                *q++=(unsigned char) ScaleQuantumToChar(QuantumRange-
+                  p->opacity);
               if (image->colorspace == CMYKColorspace)
                 *q++=ScaleQuantumToChar(indexes[x]);
             }
