@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -59,11 +58,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/option.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/profile.h"
 #include "magick/resize.h"
 #include "magick/splay-tree.h"
-#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
@@ -304,6 +303,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
   {
     ReadSingleSampleMethod,
     ReadRGBAMethod,
+    ReadCMYKAMethod,
     ReadStripMethod,
     ReadTileMethod,
     ReadGenericMethod
@@ -415,6 +415,23 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
       return((Image *) NULL);
     }
   debug=IsEventLogging();
+  if (image_info->number_scenes != 0)
+    {
+      /*
+        Generate blank images for subimage specification (e.g. image.tif[4].
+      */
+      for (i=0; i < (long) image_info->scene; i++)
+      {
+        (void) TIFFReadDirectory(tiff);
+        AllocateNextImage(image_info,image);
+        if (GetNextImageInList(image) == (Image *) NULL)
+          {
+            image=DestroyImageList(image);
+            return((Image *) NULL);
+          }
+        image=SyncNextImageInList(image);
+      }
+    }
   do
   {
     GetQuantumInfo(image_info,&quantum_info);
@@ -612,7 +629,6 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
       associated_alpha=LocaleCompare(option,"associate") ? MagickTrue :
         MagickFalse;
     if ((samples_per_pixel <= 2) && (TIFFIsTiled(tiff) == MagickFalse) &&
-        (image->compression != JPEGCompression) &&
         ((photometric == PHOTOMETRIC_MINISBLACK) ||
          (photometric == PHOTOMETRIC_MINISWHITE) ||
          (photometric == PHOTOMETRIC_PALETTE)))
@@ -634,25 +650,25 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_PAGENUMBER,&value,&pages);
     image->scene=value;
     if (TIFFGetField(tiff,TIFFTAG_ARTIST,&text) == 1)
-      (void) SetImageAttribute(image,"Artist",text);
+      (void) SetImageProperty(image,"Artist",text);
     if (TIFFGetField(tiff,TIFFTAG_DATETIME,&text) == 1)
-      (void) SetImageAttribute(image,"Timestamp",text);
+      (void) SetImageProperty(image,"Timestamp",text);
     if (TIFFGetField(tiff,TIFFTAG_SOFTWARE,&text) == 1)
-      (void) SetImageAttribute(image,"Software",text);
+      (void) SetImageProperty(image,"Software",text);
     if (TIFFGetField(tiff,TIFFTAG_HOSTCOMPUTER,&text) == 1)
-      (void) SetImageAttribute(image,"HostComputer",text);
+      (void) SetImageProperty(image,"HostComputer",text);
     if (TIFFGetField(tiff,TIFFTAG_DOCUMENTNAME,&text) == 1)
-      (void) SetImageAttribute(image,"Document",text);
+      (void) SetImageProperty(image,"Document",text);
     if (TIFFGetField(tiff,TIFFTAG_MAKE,&text) == 1)
-      (void) SetImageAttribute(image,"Make",text);
+      (void) SetImageProperty(image,"Make",text);
     if (TIFFGetField(tiff,TIFFTAG_MODEL,&text) == 1)
-      (void) SetImageAttribute(image,"Model",text);
+      (void) SetImageProperty(image,"Model",text);
     if (TIFFGetField(tiff,33432,&text) == 1)
-      (void) SetImageAttribute(image,"Copyright",text);
+      (void) SetImageProperty(image,"Copyright",text);
     if (TIFFGetField(tiff,TIFFTAG_PAGENAME,&text) == 1)
-      (void) SetImageAttribute(image,"Label",text);
+      (void) SetImageProperty(image,"Label",text);
     if (TIFFGetField(tiff,TIFFTAG_IMAGEDESCRIPTION,&text) == 1)
-      (void) SetImageAttribute(image,"Comment",text);
+      (void) SetImageProperty(image,"Comment",text);
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
@@ -661,14 +677,15 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
       method=ReadStripMethod;
     if ((samples_per_pixel >= 2) && (interlace == PLANARCONFIG_CONTIG))
       method=ReadRGBAMethod;
-    if (TIFFIsTiled(tiff) != MagickFalse)
-      method=ReadTileMethod;
-    if (photometric != PHOTOMETRIC_RGB)
+    if ((samples_per_pixel >= 2) && (interlace == PLANARCONFIG_SEPARATE))
+      method=ReadCMYKAMethod;
+    if ((photometric != PHOTOMETRIC_RGB) &&
+        (photometric != PHOTOMETRIC_SEPARATED))
       method=ReadGenericMethod;
-    if (image->colorspace == CMYKColorspace)
-      method=ReadRGBAMethod;
     if (image->storage_class == PseudoClass)
       method=ReadSingleSampleMethod;
+    if (TIFFIsTiled(tiff) != MagickFalse)
+      method=ReadTileMethod;
     switch (method)
     {
       case ReadSingleSampleMethod:
@@ -717,8 +734,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
               {
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  image->colormap[i].red=
-                    ScaleAnyToQuantum(image->colors-i-1,image->colors-1);
+                  image->colormap[i].red=ScaleAnyToQuantum(image->colors-i-1,
+                    image->colors-1);
                   image->colormap[i].green=image->colormap[i].red;
                   image->colormap[i].blue=image->colormap[i].red;
                   image->colormap[i].opacity=OpaqueOpacity;
@@ -759,25 +776,26 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             }
           }
         quantum_type=IndexQuantum;
-        quantum_info.pad=(size_t) samples_per_pixel-1;
+        quantum_info.pad=(size_t) Max((long) samples_per_pixel-1L,0);
         if (image->matte != MagickFalse)
           {
             if (image->storage_class != PseudoClass)
               {
-                quantum_type=GrayAlphaQuantum;
-                quantum_info.pad=(size_t) samples_per_pixel-2;
+                quantum_type=samples_per_pixel == 1 ? AlphaQuantum :
+                  GrayAlphaQuantum;
+                quantum_info.pad=(size_t) Max((long) samples_per_pixel-2L,0);
               }
             else
               {
                 quantum_type=IndexAlphaQuantum;
-                quantum_info.pad=(size_t) samples_per_pixel-2;
+                quantum_info.pad=(size_t) Max((long) samples_per_pixel-2L,0);
               }
           }
         else
           if (image->storage_class != PseudoClass)
             {
               quantum_type=GrayQuantum;
-              quantum_info.pad=(size_t) samples_per_pixel-1;
+              quantum_info.pad=(size_t) Max((long) samples_per_pixel-1L,0);
             }
         for (y=0; y < (long) image->rows; y++)
         {
@@ -814,34 +832,30 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         /*
           Convert TIFF image to DirectClass MIFF image.
         */
-        scanline=(unsigned char *)
-          AcquireMagickMemory((size_t) (8*TIFFScanlineSize(tiff)));
+        scanline=(unsigned char *) AcquireMagickMemory((size_t)
+          TIFFScanlineSize(tiff));
         if (scanline == (unsigned char *) NULL)
           {
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        quantum_info.pad=(size_t) samples_per_pixel-3;
+        quantum_info.pad=(size_t) Max((long) samples_per_pixel-3L,0);
         quantum_type=RGBQuantum;
+        if (image->matte != MagickFalse)
+          {
+            quantum_type=RGBAQuantum;
+            quantum_info.pad=(size_t) Max((long) samples_per_pixel-4L,0);
+          }
         if (image->colorspace == CMYKColorspace)
           {
-            if (image->matte == MagickFalse)
-              {
-                quantum_type=CMYKQuantum;
-                quantum_info.pad=(size_t) samples_per_pixel-4;
-              }
-            else
+            quantum_info.pad=(size_t) Max((long) samples_per_pixel-4L,0);
+            quantum_type=CMYKQuantum;
+            if (image->matte != MagickFalse)
               {
                 quantum_type=CMYKAQuantum;
-                quantum_info.pad=(size_t) samples_per_pixel-5;
+                quantum_info.pad=(size_t) Max((long) samples_per_pixel-5L,0);
               }
           }
-        else
-          if (image->matte != MagickFalse)
-            {
-              quantum_type=RGBAQuantum;
-              quantum_info.pad=(size_t) samples_per_pixel-4;
-            }
         for (y=0; y < (long) image->rows; y++)
         {
           int
@@ -869,6 +883,69 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         scanline=(unsigned char *) RelinquishMagickMemory(scanline);
         break;
       }
+      case ReadCMYKAMethod:
+      {
+        /*
+          Convert TIFF image to DirectClass MIFF image.
+        */
+        scanline=(unsigned char *) AcquireMagickMemory((size_t)
+          TIFFScanlineSize(tiff));
+        if (scanline == (unsigned char *) NULL)
+          {
+            TIFFClose(tiff);
+            ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+          }
+        for (y=0; y < (long) image->rows; y++)
+        {
+          for (i=0; i < (long) samples_per_pixel; i++)
+          {
+            int
+              status;
+
+            status=TIFFReadPixels(tiff,bits_per_sample,(tsample_t) i,y,(char *)
+              scanline);
+            if (status == -1)
+              break;
+            q=GetImagePixels(image,0,y,image->columns,1);
+            if (q == (PixelPacket *) NULL)
+              break;
+            if (image->colorspace != CMYKColorspace)
+              switch (i)
+              {
+                case 0: quantum_type=RedQuantum; break;
+                case 1: quantum_type=GreenQuantum; break;
+                case 2: quantum_type=BlueQuantum; break;
+                case 3: quantum_type=AlphaQuantum; break;
+                default: quantum_type=UndefinedQuantum; break;
+              }
+           else
+              switch (i)
+              {
+                case 0: quantum_type=CyanQuantum; break;
+                case 1: quantum_type=MagentaQuantum; break;
+                case 2: quantum_type=YellowQuantum; break;
+                case 3: quantum_type=BlackQuantum; break;
+                case 4: quantum_type=AlphaQuantum; break;
+                default: quantum_type=UndefinedQuantum; break;
+              }
+            (void) ExportQuantumPixels(image,&quantum_info,quantum_type,
+              scanline);
+            if (SyncImagePixels(image) == MagickFalse)
+              break;
+          }
+          if (image->previous == (Image *) NULL)
+            if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                (QuantumTick(y,image->rows) != MagickFalse))
+              {
+                status=image->progress_monitor(LoadImageTag,y,image->rows,
+                  image->client_data);
+                if (status == MagickFalse)
+                  break;
+              }
+        }
+        scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+        break;
+      }
       case ReadStripMethod:
       {
         register uint32
@@ -884,8 +961,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        pixels=(uint32 *) AcquireMagickMemory((size_t)
-          number_pixels*sizeof(uint32));
+        pixels=(uint32 *) AcquireMagickMemory((size_t) number_pixels*
+          sizeof(uint32));
         if (pixels == (uint32 *) NULL)
           {
             TIFFClose(tiff);
@@ -959,8 +1036,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         image->extract_info.width=columns;
         image->extract_info.height=rows;
         number_pixels=columns*rows;
-        tile_pixels=(uint32 *)
-          AcquireMagickMemory((size_t) columns*rows*sizeof(uint32));
+        tile_pixels=(uint32 *) AcquireMagickMemory((size_t) columns*rows*
+          sizeof(uint32));
         if (tile_pixels == (uint32 *) NULL)
           {
             TIFFClose(tiff);
@@ -976,7 +1053,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             rows_remaining;
 
           rows_remaining=image->rows-y;
-          if ((y+rows) < (long) image->rows)
+          if ((long) (y+rows) < (long) image->rows)
             rows_remaining=rows;
           tile=SetImagePixels(image,0,y,image->columns,rows_remaining);
           if (tile == (PixelPacket *) NULL)
@@ -990,7 +1067,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             if (TIFFReadRGBATile(tiff,(uint32) x,(uint32) y,tile_pixels) == 0)
               break;
             columns_remaining=image->columns-x;
-            if ((x+columns) < (long) image->columns)
+            if ((long) (x+columns) < (long) image->columns)
               columns_remaining=columns;
             p=tile_pixels+(rows-rows_remaining)*columns;
             q=tile+(image->columns*(rows_remaining-1)+x);
@@ -1168,8 +1245,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterTIFFImage() adds attributes for the TIFF image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterTIFFImage() adds properties for the TIFF image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -1208,17 +1285,6 @@ ModuleExport void RegisterTIFFImage(void)
     version[i]='\0';
   }
 #endif
-  entry=SetMagickInfo("DNG");
-#if defined(HasTIFF)
-  entry->decoder=(DecoderHandler *) ReadTIFFImage;
-#endif
-  entry->adjoin=MagickFalse;
-  entry->endian_support=MagickTrue;
-  entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
-  entry->description=ConstantString("Digital Negative");
-  entry->module=ConstantString("DNG");
-  (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PTIF");
 #if defined(HasTIFF)
   entry->decoder=(DecoderHandler *) ReadTIFFImage;
@@ -1227,7 +1293,7 @@ ModuleExport void RegisterTIFFImage(void)
   entry->adjoin=MagickFalse;
   entry->endian_support=MagickTrue;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
   entry->description=ConstantString("Pyramid encoded TIFF");
   entry->module=ConstantString("TIFF");
   (void) RegisterMagickInfo(entry);
@@ -1239,7 +1305,7 @@ ModuleExport void RegisterTIFFImage(void)
   entry->endian_support=MagickTrue;
   entry->seekable_stream=MagickTrue;
   entry->stealth=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
   entry->description=ConstantString(TIFFDescription);
   if (*version != '\0')
     entry->version=ConstantString(version);
@@ -1253,7 +1319,7 @@ ModuleExport void RegisterTIFFImage(void)
   entry->magick=(MagickHandler *) IsTIFF;
   entry->endian_support=MagickTrue;
   entry->seekable_stream=MagickTrue;
-  entry->thread_support=MagickFalse;
+  entry->thread_support=NoThreadSupport;
   entry->description=ConstantString(TIFFDescription);
   if (*version != '\0')
     entry->version=ConstantString(version);
@@ -1282,7 +1348,6 @@ ModuleExport void RegisterTIFFImage(void)
 */
 ModuleExport void UnregisterTIFFImage(void)
 {
-  (void) UnregisterMagickInfo("DNG");
   (void) UnregisterMagickInfo("PTIF");
   (void) UnregisterMagickInfo("TIF");
   (void) UnregisterMagickInfo("TIFF");
@@ -1384,10 +1449,59 @@ static MagickBooleanType WritePTIFImage(const ImageInfo *image_info,
 %
 %    o image:  The image.
 %
-%
 */
 
-static int32 TIFFWritePixels(TIFF *tiff,tdata_t scanline,long row,
+typedef struct _TIFFInfo
+{
+  unsigned char
+    *scanline,
+    *scanlines,
+    *pixels;
+} TIFFInfo;
+
+static void DestroyTIFFInfo(TIFFInfo *tiff_info)
+{
+  assert(tiff_info != (TIFFInfo *) NULL);
+  if (tiff_info->scanline != (unsigned char *) NULL)
+    tiff_info->scanline=(unsigned char *) RelinquishMagickMemory(
+      tiff_info->scanline);
+  if (tiff_info->scanlines != (unsigned char *) NULL)
+    tiff_info->scanlines=(unsigned char *) RelinquishMagickMemory(
+      tiff_info->scanlines);
+  if (tiff_info->pixels != (unsigned char *) NULL)
+    tiff_info->pixels=(unsigned char *) RelinquishMagickMemory(
+      tiff_info->pixels);
+}
+
+static MagickBooleanType GetTIFFInfo(Image *image,TIFF *tiff,
+  TIFFInfo *tiff_info)
+{
+  assert(tiff_info != (TIFFInfo *) NULL);
+  (void) ResetMagickMemory(tiff_info,0,sizeof(*tiff_info));
+  tiff_info->scanline=(unsigned char *) AcquireMagickMemory((size_t)
+    TIFFScanlineSize(tiff));
+  if (tiff_info->scanline == (unsigned char *) NULL)
+    {
+      DestroyTIFFInfo(tiff_info);
+      return(MagickFalse);
+    }
+  if (TIFFIsTiled(tiff) != 0)
+    {
+      tiff_info->scanlines=(unsigned char *) AcquireMagickMemory((size_t)
+        image->extract_info.height*TIFFScanlineSize(tiff));
+      tiff_info->pixels=(unsigned char *) AcquireMagickMemory((size_t)
+        TIFFTileSize(tiff));
+      if ((tiff_info->scanlines == (unsigned char *) NULL) ||
+          (tiff_info->pixels == (unsigned char *) NULL))
+        {
+          DestroyTIFFInfo(tiff_info);
+          return(MagickFalse);
+        }
+    }
+  return(MagickTrue);
+}
+
+static int32 TIFFWritePixels(TIFF *tiff,TIFFInfo *tiff_info,long row,
   tsample_t sample,Image *image)
 {
   int32
@@ -1406,32 +1520,18 @@ static int32 TIFFWritePixels(TIFF *tiff,tdata_t scanline,long row,
     *p,
     *q;
 
-  static unsigned char
-    *scanlines = (unsigned char *) NULL,
-    *tile_pixels = (unsigned char *) NULL;
-
   unsigned long
     number_tiles,
     tile_width;
 
   if (TIFFIsTiled(tiff) == 0)
-    return(TIFFWriteScanline(tiff,scanline,(uint32) row,sample));
-  if (scanlines == (unsigned char *) NULL)
-    scanlines=(unsigned char *) AcquireMagickMemory((size_t)
-      image->extract_info.height*TIFFScanlineSize(tiff));
-  if (scanlines == (unsigned char *) NULL)
-    return(-1);
-  if (tile_pixels == (unsigned char *) NULL)
-    tile_pixels=(unsigned char *)
-      AcquireMagickMemory((size_t) TIFFTileSize(tiff));
-  if (tile_pixels == (unsigned char *) NULL)
-    return(-1);
+    return(TIFFWriteScanline(tiff,tiff_info->scanline,(uint32) row,sample));
   /*
     Fill scanlines to tile height.
   */
   i=(long) (row % image->extract_info.height)*TIFFScanlineSize(tiff);
-  (void) CopyMagickMemory(scanlines+i,(char *) scanline,(size_t)
-    TIFFScanlineSize(tiff));
+  (void) CopyMagickMemory(tiff_info->scanlines+i,(char *) tiff_info->scanline,
+    (size_t) TIFFScanlineSize(tiff));
   if (((unsigned long) (row % image->extract_info.height) !=
       (image->extract_info.height-1)) && (row != (long) (image->rows-1)))
     return(0);
@@ -1449,27 +1549,26 @@ static int32 TIFFWritePixels(TIFF *tiff,tdata_t scanline,long row,
     for (j=0; j < (long) ((row % image->extract_info.height)+1); j++)
       for (k=0; k < (long) tile_width; k++)
       {
-        p=scanlines+(j*TIFFScanlineSize(tiff)+(i*image->extract_info.width+k)*
-          bytes_per_pixel);
-        q=tile_pixels+(j*(TIFFTileSize(tiff)/image->extract_info.height)+k*
-          bytes_per_pixel);
+        if (bytes_per_pixel == 0)
+          {
+             p=tiff_info->scanlines+(j*TIFFScanlineSize(tiff)+
+               (i*image->extract_info.width+k)/8);
+             q=tiff_info->pixels+(j*TIFFTileRowSize(tiff)+k/8);
+             *q++=(*p++);
+             continue;
+          }
+        p=tiff_info->scanlines+(j*TIFFScanlineSize(tiff)+
+          (i*image->extract_info.width+k)*bytes_per_pixel);
+        q=tiff_info->pixels+(j*TIFFTileRowSize(tiff)+k*bytes_per_pixel);
         for (l=0; l < bytes_per_pixel; l++)
           *q++=(*p++);
       }
-    status=TIFFWriteTile(tiff,tile_pixels,(uint32) (i*
+    status=TIFFWriteTile(tiff,tiff_info->pixels,(uint32) (i*
       image->extract_info.width),(uint32) ((row/image->extract_info.height)*
       image->extract_info.height),0,sample);
     if (status < 0)
       break;
   }
-  if (row == (long) (image->rows-1))
-    {
-      /*
-        Free resources.
-      */
-      scanlines=(unsigned char *) RelinquishMagickMemory(scanlines);
-      tile_pixels=(unsigned char *) RelinquishMagickMemory(tile_pixels);
-    }
   return(status);
 }
 
@@ -1484,8 +1583,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
     *mode,
     *option;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   CompressionType
     compression;
@@ -1512,15 +1611,15 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
   TIFF
     *tiff;
 
+  TIFFInfo
+    tiff_info;
+
   uint16
     bits_per_sample,
     compress_tag,
     endian,
     photometric;
 
-  unsigned char
-    *scanline;
-
   unsigned long
     lsb_first,
     rows_per_strip;
@@ -1564,11 +1663,6 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
         (void) TIFFSetField(tiff,TIFFTAG_SUBFILETYPE,FILETYPE_REDUCEDIMAGE);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGELENGTH,(uint32) image->rows);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGEWIDTH,(uint32) image->columns);
-    if (image_info->extract != (char *) NULL)
-      {
-        (void) TIFFSetField(tiff,TIFFTAG_TILEWIDTH,image->extract_info.width);
-        (void) TIFFSetField(tiff,TIFFTAG_TILELENGTH,image->extract_info.height);
-      }
     compression=image->compression;
     switch (image->compression)
     {
@@ -1577,6 +1671,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       {
         if (IsMonochromeImage(image,&image->exception) == MagickFalse)
           compression=RLECompression;
+        if (IsOpaqueImage(image,&image->exception) == MagickFalse)
+          compression=RLECompression;
 #if !defined(CCITT_SUPPORT)
         compression=RLECompression;
 #endif
@@ -1658,7 +1754,6 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       }
     }
     (void) TIFFSetField(tiff,TIFFTAG_COMPRESSION,compress_tag);
-    (void) TIFFSetField(tiff,TIFFTAG_BITSPERSAMPLE,image->depth);
     if (((image_info->colorspace == UndefinedColorspace) &&
          (image->colorspace == CMYKColorspace)) ||
          (image_info->colorspace == CMYKColorspace))
@@ -1681,8 +1776,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
             photometric=PHOTOMETRIC_RGB;
           }
         (void) TIFFSetField(tiff,TIFFTAG_SAMPLESPERPIXEL,3);
-        if ((image_info->type != TrueColorType) &&
-            (compress_tag != COMPRESSION_JPEG))
+        if (image_info->type != TrueColorType)
           {
             if ((image_info->type != PaletteType) &&
                 (IsGrayImage(image,&image->exception) != MagickFalse))
@@ -1691,11 +1785,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 photometric=PHOTOMETRIC_MINISBLACK;
                 if ((image_info->depth == 0) &&
                     (IsMonochromeImage(image,&image->exception) != MagickFalse))
-                  {
-                    image->depth=1;
-                    (void) TIFFSetField(tiff,TIFFTAG_BITSPERSAMPLE,
-                      image->depth);
-                  }
+                  image->depth=1;
                 if (image->depth == 1)
                   photometric=PHOTOMETRIC_MINISWHITE;
               }
@@ -1707,10 +1797,17 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                   */
                   (void) TIFFSetField(tiff,TIFFTAG_SAMPLESPERPIXEL,1);
                   photometric=PHOTOMETRIC_PALETTE;
-                  (void) TIFFSetField(tiff,TIFFTAG_BITSPERSAMPLE,image->depth);
                 }
           }
       }
+    if (image_info->extract != (char *) NULL)
+      {
+        (void) TIFFSetField(tiff,TIFFTAG_TILEWIDTH,image->extract_info.width);
+        (void) TIFFSetField(tiff,TIFFTAG_TILELENGTH,image->extract_info.height);
+        if (image->depth != 1)
+          image->depth=GetImageQuantumDepth(image,MagickTrue);
+      }
+    (void) TIFFSetField(tiff,TIFFTAG_BITSPERSAMPLE,image->depth);
     if (image->matte != MagickFalse)
       {
         uint16
@@ -1911,7 +2008,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               length=profile->length+4-(profile->length & 0x03);
               SetStringInfoLength(iptc_profile,length);
               if (TIFFIsByteSwapped(tiff))
-                TIFFSwabArrayOfLong((uint32 *) iptc_profile->datum,length/4);
+                TIFFSwabArrayOfLong((uint32 *) iptc_profile->datum,
+                  (unsigned long) (length/4));
               (void) TIFFSetField(tiff,TIFFTAG_RICHTIFFIPTC,
                 (uint32) iptc_profile->length/4,iptc_profile->datum);
               iptc_profile=DestroyStringInfo(iptc_profile);
@@ -1941,45 +2039,43 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       }
     if (image->orientation != UndefinedOrientation)
       (void) TIFFSetField(tiff,TIFFTAG_ORIENTATION,(uint16) image->orientation);
-    attribute=GetImageAttribute(image,"HostComputer");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_HOSTCOMPUTER,attribute->value);
-    attribute=GetImageAttribute(image,"Artist");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_ARTIST,attribute->value);
-    attribute=GetImageAttribute(image,"Timestamp");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_DATETIME,attribute->value);
-    attribute=GetImageAttribute(image,"Make");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_MAKE,attribute->value);
-    attribute=GetImageAttribute(image,"Model");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_MODEL,attribute->value);
+    value=GetImageProperty(image,"HostComputer");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_HOSTCOMPUTER,value);
+    value=GetImageProperty(image,"Artist");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_ARTIST,value);
+    value=GetImageProperty(image,"Timestamp");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_DATETIME,value);
+    value=GetImageProperty(image,"Make");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_MAKE,value);
+    value=GetImageProperty(image,"Model");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_MODEL,value);
     (void) TIFFSetField(tiff,TIFFTAG_SOFTWARE,
       GetMagickVersion((unsigned long *) NULL));
     (void) TIFFSetField(tiff,TIFFTAG_DOCUMENTNAME,image->filename);
-    attribute=GetImageAttribute(image,"Copyright");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,33432,attribute->value);
-    attribute=GetImageAttribute(image,"Kodak-33423");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,33423,attribute->value);
-    attribute=GetImageAttribute(image,"Kodak-36867");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,36867,attribute->value);
-    attribute=GetImageAttribute(image,"Label");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_PAGENAME,attribute->value);
-    attribute=GetImageAttribute(image,"Comment");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) TIFFSetField(tiff,TIFFTAG_IMAGEDESCRIPTION,attribute->value);
+    value=GetImageProperty(image,"Copyright");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,33432,value);
+    value=GetImageProperty(image,"Kodak-33423");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,33423,value);
+    value=GetImageProperty(image,"Kodak-36867");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,36867,value);
+    value=GetImageProperty(image,"Label");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_PAGENAME,value);
+    value=GetImageProperty(image,"Comment");
+    if (value != (const char *) NULL)
+      (void) TIFFSetField(tiff,TIFFTAG_IMAGEDESCRIPTION,value);
     /*
       Write image scanlines.
     */
-    scanline=(unsigned char *)
-      AcquireMagickMemory(8*(size_t) TIFFScanlineSize(tiff));
-    if (scanline == (unsigned char *) NULL)
+    if (GetTIFFInfo(image,tiff,&tiff_info) == MagickFalse)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     switch (photometric)
     {
@@ -2002,11 +2098,11 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 break;
               if (image->matte == MagickFalse)
                 (void) ImportQuantumPixels(image,&quantum_info,RGBQuantum,
-                  scanline);
+                  tiff_info.scanline);
               else
                 (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,
-                  scanline);
-              if (TIFFWritePixels(tiff,(char *) scanline,y,0,image) < 0)
+                  tiff_info.scanline);
+              if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
                 break;
               if (image->previous == (Image *) NULL)
                 if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -2033,8 +2129,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (p == (const PixelPacket *) NULL)
                 break;
               (void) ImportQuantumPixels(image,&quantum_info,RedQuantum,
-                scanline);
-              if (TIFFWritePixels(tiff,(char *) scanline,y,0,image) < 0)
+                tiff_info.scanline);
+              if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
                 break;
             }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2051,8 +2147,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (p == (const PixelPacket *) NULL)
                 break;
               (void) ImportQuantumPixels(image,&quantum_info,GreenQuantum,
-                scanline);
-              if (TIFFWritePixels(tiff,(char *) scanline,y,1,image) < 0)
+                tiff_info.scanline);
+              if (TIFFWritePixels(tiff,&tiff_info,y,1,image) < 0)
                 break;
             }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2069,8 +2165,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
               if (p == (const PixelPacket *) NULL)
                 break;
               (void) ImportQuantumPixels(image,&quantum_info,BlueQuantum,
-                scanline);
-              if (TIFFWritePixels(tiff,(char *) scanline,y,2,image) < 0)
+                tiff_info.scanline);
+              if (TIFFWritePixels(tiff,&tiff_info,y,2,image) < 0)
                 break;
             }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2088,8 +2184,8 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
                 if (p == (const PixelPacket *) NULL)
                   break;
                 (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
-                  scanline);
-                if (TIFFWritePixels(tiff,(char *) scanline,y,3,image) < 0)
+                  tiff_info.scanline);
+                if (TIFFWritePixels(tiff,&tiff_info,y,3,image) < 0)
                   break;
               }
             if (image->progress_monitor != (MagickProgressMonitor) NULL)
@@ -2118,11 +2214,11 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
             break;
           if (image->matte == MagickFalse)
             (void) ImportQuantumPixels(image,&quantum_info,CMYKQuantum,
-              scanline);
+              tiff_info.scanline);
           else
             (void) ImportQuantumPixels(image,&quantum_info,CMYKAQuantum,
-              scanline);
-          if (TIFFWritePixels(tiff,(char *) scanline,y,0,image) < 0)
+              tiff_info.scanline);
+          if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
             break;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -2183,19 +2279,19 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
              {
                if (photometric != PHOTOMETRIC_PALETTE)
                  (void) ImportQuantumPixels(image,&quantum_info,
-                   GrayAlphaQuantum,scanline);
+                   GrayAlphaQuantum,tiff_info.scanline);
                else
                  (void) ImportQuantumPixels(image,&quantum_info,
-                   IndexAlphaQuantum,scanline);
+                   IndexAlphaQuantum,tiff_info.scanline);
              }
            else
              if (photometric != PHOTOMETRIC_PALETTE)
                (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,
-                 scanline);
+                 tiff_info.scanline);
              else
                (void) ImportQuantumPixels(image,&quantum_info,IndexQuantum,
-                 scanline);
-          if (TIFFWritePixels(tiff,(char *) scanline,y,0,image) < 0)
+                 tiff_info.scanline);
+          if (TIFFWritePixels(tiff,&tiff_info,y,0,image) < 0)
             break;
           if (image->previous == (Image *) NULL)
             if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -2210,7 +2306,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
         break;
       }
     }
-    scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+    DestroyTIFFInfo(&tiff_info);
     if (image_info->verbose == MagickTrue)
       TIFFPrintDirectory(tiff,stdout,MagickFalse);
     (void) TIFFWriteDirectory(tiff);
