@@ -40,7 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/constitute.h"
@@ -168,7 +168,7 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     CatchException(exception);
     if (next_image == (Image *) NULL)
       break;
-    (void) SetImageAttribute(next_image,"Label",DefaultTileLabel);
+    (void) SetImageProperty(next_image,"Label",DefaultTileLabel);
     if (image_info->debug != MagickFalse)
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),"geometry: %ldx%ld",
         next_image->columns,next_image->rows);
@@ -205,8 +205,8 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),"creating montage");
-  montage_image=MontageImages(GetFirstImageInList(images),montage_info,
-    exception);
+  montage_image=MontageImageList(image_info,montage_info,
+    GetFirstImageInList(images),exception);
   montage_info=DestroyMontageInfo(montage_info);
   images=DestroyImageList(images);
   return(montage_image);
@@ -302,6 +302,9 @@ static MagickBooleanType WriteVIDImage(const ImageInfo *image_info,Image *image)
   Image
     *montage_image;
 
+  ImageInfo
+    *write_info;
+
   MagickBooleanType
     status;
 
@@ -315,14 +318,21 @@ static MagickBooleanType WriteVIDImage(const ImageInfo *image_info,Image *image)
     Create the visual image directory.
   */
   for (p=image; p != (Image *) NULL; p=GetNextImageInList(p))
-    (void) SetImageAttribute(p,"Label",DefaultTileLabel);
+    (void) SetImageProperty(p,"Label",DefaultTileLabel);
   montage_info=CloneMontageInfo(image_info,(MontageInfo *) NULL);
-  montage_image=MontageImages(image,montage_info,&image->exception);
+  montage_image=MontageImageList(image_info,montage_info,image,
+    &image->exception);
   if (montage_image == (Image *) NULL)
     ThrowWriterException(CorruptImageError,image->exception.reason);
-  (void) FormatMagickString(montage_image->filename,MaxTextExtent,
-    "miff:%s",image->filename);
-  status=WriteImage(image_info,montage_image);
-  (void) DestroyImageList(montage_image);
+  (void) CopyMagickString(montage_image->filename,image_info->filename,
+    MaxTextExtent);
+  write_info=CloneImageInfo(image_info);
+  (void) SetImageInfo(write_info,MagickTrue,&image->exception);
+  if (LocaleCompare(write_info->magick,"VID") == 0)
+    (void) FormatMagickString(montage_image->filename,MaxTextExtent,
+      "miff:%s",image_info->filename);
+  status=WriteImage(write_info,montage_image);
+  montage_image=DestroyImage(montage_image);
+  write_info=DestroyImageInfo(write_info);
   return(status);
 }
