@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -54,6 +53,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -290,7 +290,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
     count=ReadBlob(image,512,(unsigned char *) viff_info.comment);
     viff_info.comment[511]='\0';
     if (strlen(viff_info.comment) > 4)
-      (void) SetImageAttribute(image,"Comment",viff_info.comment);
+      (void) SetImageProperty(image,"Comment",viff_info.comment);
     if ((viff_info.machine_dependency == VFF_DEP_DECORDER) ||
         (viff_info.machine_dependency == VFF_DEP_NSORDER))
       {
@@ -344,7 +344,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
       (void) ReadBlobByte(image);
     image->columns=viff_info.rows;
     image->rows=viff_info.columns;
-    image->depth=viff_info.x_bits_per_pixel <= 8 ? 8 : QuantumDepth;
+    image->depth=viff_info.x_bits_per_pixel <= 8 ? 8UL : QuantumDepth;
     /*
       Verify that we can read this VIFF image.
     */
@@ -388,7 +388,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
             /*
               Create linear color ramp.
             */
-            image->colors=image->depth <= 8 ? 256 : 65536L;
+            image->colors=image->depth <= 8 ? 256UL : 65536UL;
             if (viff_info.data_storage_type == VFF_TYP_BIT)
               image->colors=2;
             if (AllocateImageColormap(image,image->colors) == MagickFalse)
@@ -451,11 +451,11 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
         {
           switch ((int) viff_info.map_storage_type)
           {
-            case VFF_MAPTYP_2_BYTE: value=((short *) viff_colormap)[i]; break;
-            case VFF_MAPTYP_4_BYTE: value=((int *) viff_colormap)[i]; break;
+            case VFF_MAPTYP_2_BYTE: value=1.0*((short *) viff_colormap)[i]; break;
+            case VFF_MAPTYP_4_BYTE: value=1.0*((int *) viff_colormap)[i]; break;
             case VFF_MAPTYP_FLOAT: value=((float *) viff_colormap)[i]; break;
             case VFF_MAPTYP_DOUBLE: value=((double *) viff_colormap)[i]; break;
-            default: value=viff_colormap[i]; break;
+            default: value=1.0*viff_colormap[i]; break;
           }
           if (i < (long) image->colors)
             {
@@ -502,9 +502,9 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
       default: bytes_per_pixel=1; break;
     }
     if (viff_info.data_storage_type == VFF_TYP_BIT)
-      max_packets=((image->columns+7) >> 3)*image->rows;
+      max_packets=((image->columns+7UL) >> 3UL)*image->rows;
     else
-      max_packets=number_pixels*viff_info.number_data_bands;
+      max_packets=(unsigned long) (number_pixels*viff_info.number_data_bands);
     viff_pixels=(unsigned char *)
       AcquireMagickMemory(bytes_per_pixel*max_packets*sizeof(Quantum));
     if (viff_pixels == (unsigned char *) NULL)
@@ -542,11 +542,11 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
         */
         switch ((int) viff_info.data_storage_type)
         {
-          case VFF_TYP_2_BYTE: value=((short *) viff_pixels)[0]; break;
-          case VFF_TYP_4_BYTE: value=((int *) viff_pixels)[0]; break;
+          case VFF_TYP_2_BYTE: value=1.0*((short *) viff_pixels)[0]; break;
+          case VFF_TYP_4_BYTE: value=1.0*((int *) viff_pixels)[0]; break;
           case VFF_TYP_FLOAT: value=((float *) viff_pixels)[0]; break;
           case VFF_TYP_DOUBLE: value=((double *) viff_pixels)[0]; break;
-          default: value=viff_pixels[0]; break;
+          default: value=1.0*viff_pixels[0]; break;
         }
         max_value=value;
         min_value=value;
@@ -554,11 +554,11 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
         {
           switch ((int) viff_info.data_storage_type)
           {
-            case VFF_TYP_2_BYTE: value=((short *) viff_pixels)[i]; break;
-            case VFF_TYP_4_BYTE: value=((int *) viff_pixels)[i]; break;
+            case VFF_TYP_2_BYTE: value=1.0*((short *) viff_pixels)[i]; break;
+            case VFF_TYP_4_BYTE: value=1.0*((int *) viff_pixels)[i]; break;
             case VFF_TYP_FLOAT: value=((float *) viff_pixels)[i]; break;
             case VFF_TYP_DOUBLE: value=((double *) viff_pixels)[i]; break;
-            default: value=viff_pixels[i]; break;
+            default: value=1.0*viff_pixels[i]; break;
           }
           if (value > max_value)
             max_value=value;
@@ -585,11 +585,11 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
     {
       switch ((int) viff_info.data_storage_type)
       {
-        case VFF_TYP_2_BYTE: value=((short *) viff_pixels)[i]; break;
-        case VFF_TYP_4_BYTE: value=((int *) viff_pixels)[i]; break;
+        case VFF_TYP_2_BYTE: value=1.0*((short *) viff_pixels)[i]; break;
+        case VFF_TYP_4_BYTE: value=1.0*((int *) viff_pixels)[i]; break;
         case VFF_TYP_FLOAT: value=((float *) viff_pixels)[i]; break;
         case VFF_TYP_DOUBLE: value=((double *) viff_pixels)[i]; break;
-        default: value=viff_pixels[i]; break;
+        default: value=1.0*viff_pixels[i]; break;
       }
       if (viff_info.map_scheme == VFF_MS_NONE)
         {
@@ -600,7 +600,7 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
             if (value < 0)
               value=0;
         }
-      *p=(Quantum) value;
+      *p=(unsigned char) value;
       p++;
     }
     /*
@@ -609,17 +609,19 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
     p=(unsigned char *) viff_pixels;
     if (viff_info.data_storage_type == VFF_TYP_BIT)
       {
-        unsigned int
+        IndexPacket
           polarity;
 
         /*
           Convert bitmap scanline.
         */
-        SetImageType(image,BilevelType);
-        polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+        (void) SetImageType(image,PaletteType);
+        (void) SetImageType(image,BilevelType);
+        polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
+          (QuantumRange/2) ? 1 : 0);
         if (image->colors >= 2)
-          polarity=PixelIntensityToQuantum(&image->colormap[0]) >
-            PixelIntensityToQuantum(&image->colormap[1]);
+          polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) >
+            PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
         for (y=0; y < (long) image->rows; y++)
         {
           q=SetImagePixels(image,0,y,image->columns,1);
@@ -767,8 +769,8 @@ static Image *ReadVIFFImage(const ImageInfo *image_info,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterVIFFImage() adds attributes for the VIFF image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterVIFFImage() adds properties for the VIFF image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -906,8 +908,8 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
       color_space_model;
   } ViffInfo;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   long
     y;
@@ -965,16 +967,17 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
     */
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
+    if (IsGrayImage(image,&image->exception) != MagickFalse)
+      (void) SetImageStorageClass(image,DirectClass);
     viff_info.identifier=(char) 0xab;
     viff_info.file_type=1;
     viff_info.release=1;
     viff_info.version=3;
     viff_info.machine_dependency=VFF_DEP_IEEEORDER;  /* IEEE byte ordering */
     *viff_info.comment='\0';
-    attribute=GetImageAttribute(image,"Comment");
-    if (attribute != (const ImageAttribute *) NULL)
-      (void) CopyMagickString(viff_info.comment,attribute->value,
-        Min(strlen(attribute->value),511)+1);
+    value=GetImageProperty(image,"Comment");
+    if (value != (const char *) NULL)
+      (void) CopyMagickString(viff_info.comment,value,Min(strlen(value),511)+1);
     viff_info.rows=image->columns;
     viff_info.columns=image->rows;
     viff_info.subrows=0;
@@ -999,7 +1002,7 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
         /*
           Full color VIFF raster.
         */
-        viff_info.number_data_bands=image->matte ? 4 : 3;
+        viff_info.number_data_bands=image->matte ? 4UL : 3UL;
         viff_info.color_space_model=VFF_CM_genericRGB;
         viff_info.data_storage_type=VFF_TYP_1_BYTE;
         packets=viff_info.number_data_bands*number_pixels;
@@ -1033,14 +1036,14 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
     /*
       Write VIFF image header (pad to 1024 bytes).
     */
-    buffer[0]=viff_info.identifier;
-    buffer[1]=viff_info.file_type;
-    buffer[2]=viff_info.release;
-    buffer[3]=viff_info.version;
-    buffer[4]=viff_info.machine_dependency;
-    buffer[5]=viff_info.reserve[0];
-    buffer[6]=viff_info.reserve[1];
-    buffer[7]=viff_info.reserve[2];
+    buffer[0]=(unsigned char) viff_info.identifier;
+    buffer[1]=(unsigned char) viff_info.file_type;
+    buffer[2]=(unsigned char) viff_info.release;
+    buffer[3]=(unsigned char) viff_info.version;
+    buffer[4]=(unsigned char) viff_info.machine_dependency;
+    buffer[5]=(unsigned char) viff_info.reserve[0];
+    buffer[6]=(unsigned char) viff_info.reserve[1];
+    buffer[7]=(unsigned char) viff_info.reserve[2];
     (void) WriteBlob(image,8,buffer);
     (void) WriteBlob(image,512,(unsigned char *) viff_info.comment);
     (void) WriteBlobMSBLong(image,viff_info.rows);
@@ -1048,9 +1051,9 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
     (void) WriteBlobMSBLong(image,viff_info.subrows);
     (void) WriteBlobMSBLong(image,(unsigned long) viff_info.x_offset);
     (void) WriteBlobMSBLong(image,(unsigned long) viff_info.y_offset);
-    viff_info.x_bits_per_pixel=(63 << 24) | (128 << 16);
+    viff_info.x_bits_per_pixel=1U*(63 << 24) | (128 << 16);
     (void) WriteBlobMSBLong(image,(unsigned long) viff_info.x_bits_per_pixel);
-    viff_info.y_bits_per_pixel=(63 << 24) | (128 << 16);
+    viff_info.y_bits_per_pixel=1U*(63 << 24) | (128 << 16);
     (void) WriteBlobMSBLong(image,(unsigned long) viff_info.y_bits_per_pixel);
     (void) WriteBlobMSBLong(image,viff_info.location_type);
     (void) WriteBlobMSBLong(image,viff_info.location_dimension);
@@ -1141,7 +1144,7 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
               break;
             indexes=GetIndexes(image);
             for (x=0; x < (long) image->columns; x++)
-              *q++=indexes[x];
+              *q++=(unsigned char) indexes[x];
             if (image->previous == (Image *) NULL)
               if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
                   (QuantumTick(y,image->rows) != MagickFalse))
@@ -1156,23 +1159,28 @@ static MagickBooleanType WriteVIFFImage(const ImageInfo *image_info,
       else
         if (image->colors <= 2)
           {
+            IndexPacket
+              polarity;
+
             long
               x,
               y;
 
             register unsigned char
               bit,
-              byte,
-              polarity;
+              byte;
 
             /*
               Convert PseudoClass image to a VIFF monochrome image.
             */
-            SetImageType(image,BilevelType);
-            polarity=PixelIntensityToQuantum(&image->colormap[0]) < (QuantumRange/2);
+            (void) SetImageType(image,PaletteType);
+            (void) SetImageType(image,BilevelType);
+            polarity=(IndexPacket) (PixelIntensityToQuantum(
+              &image->colormap[0]) < (QuantumRange/2) ? 1 : 0);
             if (image->colors == 2)
-              polarity=PixelIntensityToQuantum(&image->colormap[0]) <
-                PixelIntensityToQuantum(&image->colormap[1]);
+              polarity=(IndexPacket) (
+                PixelIntensityToQuantum(&image->colormap[0]) <
+                PixelIntensityToQuantum(&image->colormap[1]) ? 1 : 0);
             for (y=0; y < (long) image->rows; y++)
             {
               p=AcquireImagePixels(image,0,y,image->columns,1,
