@@ -43,7 +43,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color.h"
@@ -185,7 +185,7 @@ struct _wmf_magick_t
 
   /* Clip path ID */
   unsigned long
-    clip_path_id;
+    clip_mask_id;
 
   /* Push depth */
   long
@@ -643,11 +643,11 @@ static void ipa_device_open(wmfAPI * API)
   DrawInfo
     *draw_info;
 
-  draw_info = CloneDrawInfo((ImageInfo*)NULL,(DrawInfo*)NULL);
+  draw_info=CloneDrawInfo((ImageInfo *) NULL,(DrawInfo *) NULL);
 
   ddata->pattern_id = 0;
   ddata->clipping = MagickFalse;
-  ddata->clip_path_id = 0;
+  ddata->clip_mask_id = 0;
 
   ddata->push_depth = 0;
 
@@ -1191,14 +1191,14 @@ static void ipa_region_clip(wmfAPI *API, wmfPolyRectangle_t *poly_rect)
   if (poly_rect->count > 0)
     {
       char
-        clip_path_id[30];
+        clip_mask_id[30];
 
       /* Define clip path */
-      ddata->clip_path_id++;
+      ddata->clip_mask_id++;
       DrawPushDefs(WmfDrawingWand);
-      (void) FormatMagickString(clip_path_id,MaxTextExtent,"clip_%lu",
-        ddata->clip_path_id);
-      DrawPushClipPath(WmfDrawingWand,clip_path_id);
+      (void) FormatMagickString(clip_mask_id,MaxTextExtent,"clip_%lu",
+        ddata->clip_mask_id);
+      DrawPushClipPath(WmfDrawingWand,clip_mask_id);
       (void) PushDrawingWand(WmfDrawingWand);
       for (i = 0; i < (long) poly_rect->count; i++)
         {
@@ -1212,7 +1212,7 @@ static void ipa_region_clip(wmfAPI *API, wmfPolyRectangle_t *poly_rect)
 
       /* Push wand for new clip paths */
       (void) PushDrawingWand(WmfDrawingWand);
-      (void) DrawSetClipPath(WmfDrawingWand,clip_path_id);
+      (void) DrawSetClipPath(WmfDrawingWand,clip_mask_id);
       ddata->clipping = MagickTrue;
     }
 }
@@ -1326,10 +1326,10 @@ static void ipa_draw_text(wmfAPI * API, wmfDrawText_t * draw_text)
       }
     dx = ((TR.x - TL.x) + (BR.x - BL.x)) / 2;
     dy = ((TR.y - TL.y) + (BR.y - BL.y)) / 2;
-    bbox_width = sqrt(dx * dx + dy * dy);
+    bbox_width = hypot(dx,dy);
     dx = ((BL.x - TL.x) + (BR.x - TR.x)) / 2;
     dy = ((BL.y - TL.y) + (BR.y - TR.y)) / 2;
-    bbox_height = sqrt(dx * dx + dy * dy);
+    bbox_height = hypot(dx,dy);
   }
 
   font = WMF_DC_FONT(draw_text->dc);
