@@ -51,6 +51,7 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/option.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -94,10 +95,16 @@ static MagickBooleanType
 */
 static Image *ReadXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
+  const char
+    *option;
+
   XImportInfo
     ximage_info;
 
   XGetImportInfo(&ximage_info);
+  option=GetImageOption(image_info,"x:screen");
+  if (option != (const char *) NULL)
+    ximage_info.screen=IsMagickTrue(option);
   return(XImportImage(image_info,&ximage_info));
 }
 #endif
