@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,6 +51,7 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -84,7 +85,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -115,7 +115,8 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -139,7 +140,7 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) QueryColorDatabase((char *) image_info->filename,
         &image->background_color,exception);
       image->colormap[0]=image->background_color;
-      color.index=0;
+      color.index=0.0;
     }
   for (y=0; y < (long) image->rows; y++)
   {
@@ -147,16 +148,16 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (q == (PixelPacket *) NULL)
       break;
     indexes=GetIndexes(image);
-    for (x=(long) image->columns-1; x >= 0; x--)
+    for (x=0; x < (long) image->columns; x++)
     {
-      q->red=(Quantum) (color.red+0.5);
-      q->green=(Quantum) (color.green+0.5);
-      q->blue=(Quantum) (color.blue+0.5);
+      q->red=RoundToQuantum(color.red);
+      q->green=RoundToQuantum(color.green);
+      q->blue=RoundToQuantum(color.blue);
       if (image->matte)
-        q->opacity=(Quantum) (color.opacity+0.5);
+        q->opacity=RoundToQuantum(color.opacity);
       if ((image->storage_class == PseudoClass) ||
           (image->colorspace == CMYKColorspace))
-        indexes[x]=(IndexPacket) (color.index+0.5);
+        indexes[x]=(IndexPacket) RoundToQuantum(color.index);
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -198,8 +199,8 @@ ModuleExport void RegisterXCImage(void)
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
-  entry->description=AcquireString("Constant image uniform color");
-  entry->module=AcquireString("XC");
+  entry->description=ConstantString("Constant image uniform color");
+  entry->module=ConstantString("XC");
   (void) RegisterMagickInfo(entry);
 }
 
