@@ -294,7 +294,7 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
     string[i]=(char) c;
   }
   string[i]='\0';
-  (void) SeekBlob(image, length-i, SEEK_CUR);
+  (void) SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
   return(string);
 }
 
@@ -800,7 +800,7 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   /* clear the image based on the layer opacity */
   outLayer->image->background_color.opacity=
     ScaleCharToQuantum((unsigned char) (255-outLayer->opacity));    
-  SetImageBackgroundColor(outLayer->image);
+  (void) SetImageBackgroundColor(outLayer->image);
 
   /* set the compositing mode */
   outLayer->image->compose = GIMPBlendModeToCompositeOperator( outLayer->mode );
@@ -950,7 +950,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     else
       if ( image_type == GIMP_INDEXED )
         ThrowReaderException(CoderError,"ColormapTypeNotSupported");
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   /*
     Read properties.
   */
