@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/color-private.h"
@@ -53,6 +52,8 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/property.h"
+#include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #if defined(HasX11)
@@ -152,10 +153,13 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   IndexPacket
     index;
 
+  int
+    x_status;
+
   long
     y;
 
-  MagickBooleanType
+  MagickStatusType
     status;
 
   register IndexPacket
@@ -197,7 +201,8 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info != (const ImageInfo *) NULL);
   assert(image_info->signature == MagickSignature);
   if (image_info->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image_info->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
@@ -235,7 +240,7 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   count=ReadBlob(image,length,(unsigned char *) comment);
   comment[length]='\0';
-  (void) SetImageAttribute(image,"Comment",comment);
+  (void) SetImageProperty(image,"Comment",comment);
   comment=(char *) RelinquishMagickMemory(comment);
   if (count == 0)
     ThrowReaderException(CorruptImageError,
@@ -261,8 +266,8 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ximage->red_mask=header.red_mask;
   ximage->green_mask=header.green_mask;
   ximage->blue_mask=header.blue_mask;
-  status=(MagickBooleanType) XInitImage(ximage);
-  if (status == MagickFalse)
+  x_status=XInitImage(ximage);
+  if (x_status == 0)
     ThrowReaderException(CorruptImageError,"UnableToReadImageHeader");
   /*
     Read colormap.
@@ -348,21 +353,21 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
         */
         red_mask=ximage->red_mask;
         red_shift=0;
-        while ((red_mask & 0x01) == 0)
+        while ((red_mask != 0) && ((red_mask & 0x01) == 0))
         {
           red_mask>>=1;
           red_shift++;
         }
         green_mask=ximage->green_mask;
         green_shift=0;
-        while ((green_mask & 0x01) == 0)
+        while ((green_mask != 0) && ((green_mask & 0x01) == 0))
         {
           green_mask>>=1;
           green_shift++;
         }
         blue_mask=ximage->blue_mask;
         blue_shift=0;
-        while ((blue_mask & 0x01) == 0)
+        while ((blue_mask != 0) && ((blue_mask & 0x01) == 0))
         {
           blue_mask>>=1;
           blue_shift++;
@@ -409,11 +414,14 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
             {
               pixel=XGetPixel(ximage,(int) x,(int) y);
               color=(pixel >> red_shift) & red_mask;
-              q->red=ScaleShortToQuantum((color*65535L)/red_mask);
+              color=(color*65535UL)/red_mask;
+              q->red=ScaleShortToQuantum((unsigned short) color);
               color=(pixel >> green_shift) & green_mask;
-              q->green=ScaleShortToQuantum((color*65535L)/green_mask);
+              color=(color*65535UL)/green_mask;
+              q->green=ScaleShortToQuantum((unsigned short) color);
               color=(pixel >> blue_shift) & blue_mask;
-              q->blue=ScaleShortToQuantum((color*65535L)/blue_mask);
+              color=(color*65535UL)/blue_mask;
+              q->blue=ScaleShortToQuantum((unsigned short) color);
               q++;
             }
             if (SyncImagePixels(image) == MagickFalse)
@@ -497,8 +505,8 @@ static Image *ReadXWDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  RegisterXWDImage() adds attributes for the XWD image format to
-%  the list of supported formats.  The attributes include the image format
+%  RegisterXWDImage() adds properties for the XWD image format to
+%  the list of supported formats.  The properties include the image format
 %  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
@@ -521,8 +529,8 @@ ModuleExport void RegisterXWDImage(void)
 #endif
   entry->magick=(MagickHandler *) IsXWD;
   entry->adjoin=MagickFalse;
-  entry->description=AcquireString("X Windows system window dump (color)");
-  entry->module=AcquireString("XWD");
+  entry->description=ConstantString("X Windows system window dump (color)");
+  entry->module=ConstantString("XWD");
   (void) RegisterMagickInfo(entry);
 }
 
@@ -579,8 +587,8 @@ ModuleExport void UnregisterXWDImage(void)
 */
 static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
 {
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   long
     y;
@@ -626,18 +634,19 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),image->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  (void) SetImageColorspace(image,RGBColorspace);
+  if (image_info->colorspace == UndefinedColorspace)
+    (void) SetImageColorspace(image,RGBColorspace);
   /*
     Initialize XWD file header.
   */
   xwd_info.header_size=(CARD32) sz_XWDheader;
-  attribute=GetImageAttribute(image,"Comment");
-  if (attribute != (const ImageAttribute *) NULL)
-    xwd_info.header_size+=strlen(attribute->value);
+  value=GetImageProperty(image,"Comment");
+  if (value != (const char *) NULL)
+    xwd_info.header_size+=(CARD32) strlen(value);
   xwd_info.header_size++;
   xwd_info.file_version=(CARD32) XWD_FILE_VERSION;
   xwd_info.pixmap_format=(CARD32) ZPixmap;
@@ -679,9 +688,8 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
   if ((int) (*(char *) &lsb_first) != 0)
     MSBOrderLong((unsigned char *) &xwd_info,sizeof(xwd_info));
   (void) WriteBlob(image,sz_XWDheader,(unsigned char *) &xwd_info);
-  if (attribute != (const ImageAttribute *) NULL)
-    (void) WriteBlob(image,strlen(attribute->value),(unsigned char *)
-      attribute->value);
+  if (value != (const char *) NULL)
+    (void) WriteBlob(image,strlen(value),(unsigned char *) value);
   (void) WriteBlob(image,1,(const unsigned char *) "\0");
   if (image->storage_class == PseudoClass)
     {
@@ -734,6 +742,7 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
   pixels=(unsigned char *) AcquireMagickMemory(length);
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+  (void) ResetMagickMemory(pixels,0,length);
   /*
     Convert MIFF to XWD raster pixels.
   */
@@ -751,7 +760,7 @@ static MagickBooleanType WriteXWDImage(const ImageInfo *image_info,Image *image)
           *q++=(unsigned char) indexes[x];
       }
     else
-      for (x=(long) image->columns-1; x >= 0; x--)
+      for (x=0; x < (long) image->columns; x++)
       {
         *q++=ScaleQuantumToChar(p->red);
         *q++=ScaleQuantumToChar(p->green);
