@@ -52,7 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/pixel.h"
+#include "magick/quantum.h"
 #include "magick/quantum.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
@@ -108,6 +108,9 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
   MagickOffsetType
     offset;
 
+  QuantumInfo
+    quantum_info;
+
   register long
     i;
 
@@ -121,7 +124,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
     packet_size;
 
   unsigned char
-    *scanline;
+    *pixels;
 
   unsigned long
     depth,
@@ -152,7 +155,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         (void) ReadBlobByte(image);
     }
   /*
-    Allocate memory for a scanline.
+    Allocate memory for a pixels.
   */
   depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (3*depth/8);
@@ -161,9 +164,9 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
       packet_size+=depth/8;
       image->matte=MagickTrue;
     }
-  scanline=(unsigned char *)
+  pixels=(unsigned char *)
     AcquireMagickMemory(packet_size*image->extract_info.width);
-  if (scanline == (unsigned char *) NULL)
+  if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
     while (image->scene < image_info->scene)
@@ -173,7 +176,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
       */
       image->scene++;
       for (y=0; y < (long) image->rows; y++)
-        count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+        count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
     }
   offset=(MagickOffsetType) (packet_size*image->extract_info.x);
   do
@@ -181,6 +184,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
     /*
       Convert raster image to pixel packets.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     image->colorspace=YCbCrColorspace;
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
@@ -194,19 +198,21 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
           No interlacing:  YCbCrYCbCrYCbCrYCbCrYCbCrYCbCr...
         */
         for (y=0; y < image->extract_info.y; y++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             count=ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+              pixels);
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
           if (image->matte == MagickFalse)
-            (void) ExportQuantumPixels(image,RGBQuantum,0,scanline+offset);
+            (void) ExportQuantumPixels(image,&quantum_info,RGBQuantum,
+              pixels+offset);
           else
-            (void) ExportQuantumPixels(image,RGBAQuantum,0,scanline+offset);
+            (void) ExportQuantumPixels(image,&quantum_info,RGBAQuantum,
+              pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -221,7 +227,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         break;
       }
       case LineInterlace:
@@ -231,25 +237,29 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         */
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             count=ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+              pixels);
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,RedQuantum,0,scanline+offset);
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
-          (void) ExportQuantumPixels(image,GreenQuantum,0,scanline+offset);
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
-          (void) ExportQuantumPixels(image,BlueQuantum,0,scanline+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,RedQuantum,
+            pixels+offset);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
+          (void) ExportQuantumPixels(image,&quantum_info,GreenQuantum,
+            pixels+offset);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
+          (void) ExportQuantumPixels(image,&quantum_info,BlueQuantum,
+            pixels+offset);
           if (image->matte != MagickFalse)
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
-                scanline);
-              (void) ExportQuantumPixels(image,AlphaQuantum,0,scanline+offset);
+                pixels);
+              (void) ExportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels+offset);
             }
           if (SyncImagePixels(image) == MagickFalse)
             break;
@@ -265,7 +275,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         break;
       }
       case PlaneInterlace:
@@ -289,18 +299,19 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
           }
         packet_size=(size_t) (image->depth > 8 ? 2 : 1);
         for (y=0; y < image->extract_info.y; y++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         i=0;
         span=image->rows*(image->matte != MagickFalse ? 5 : 4);
         for (y=0; y < (long) image->rows; y++)
         {
           if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             count=ReadBlob(image,packet_size*image->extract_info.width,
-              scanline);
+              pixels);
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,RedQuantum,0,scanline+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,RedQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -316,7 +327,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -329,14 +340,15 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         for (y=0; y < (long) image->rows; y++)
         {
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,GreenQuantum,0,scanline+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,GreenQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -352,7 +364,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         if (image_info->interlace == PartitionInterlace)
           {
             CloseBlob(image);
@@ -365,14 +377,15 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
               }
           }
         for (y=0; y < image->extract_info.y; y++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         for (y=0; y < (long) image->rows; y++)
         {
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
           q=GetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          (void) ExportQuantumPixels(image,BlueQuantum,0,scanline+offset);
+          (void) ExportQuantumPixels(image,&quantum_info,BlueQuantum,
+            pixels+offset);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -388,7 +401,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         }
         width=image->extract_info.height-image->rows-image->extract_info.y;
         for (i=0; i < (long) width; i++)
-          count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+          count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
         if (image->matte != MagickFalse)
           {
             /*
@@ -407,15 +420,16 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
               }
             for (y=0; y < image->extract_info.y; y++)
               count=ReadBlob(image,packet_size*image->extract_info.width,
-                scanline);
+                pixels);
             for (y=0; y < (long) image->rows; y++)
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
-                scanline);
+                pixels);
               q=GetImagePixels(image,0,y,image->columns,1);
               if (q == (PixelPacket *) NULL)
                 break;
-              (void) ExportQuantumPixels(image,AlphaQuantum,0,scanline+offset);
+              (void) ExportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels+offset);
               if (SyncImagePixels(image) == MagickFalse)
                 break;
               if (image->previous == (Image *) NULL)
@@ -432,7 +446,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
             width=image->extract_info.height-image->rows-image->extract_info.y;
             for (i=0; i < (long) width; i++)
               count=ReadBlob(image,packet_size*image->extract_info.width,
-                scanline);
+                pixels);
           }
         if (image_info->interlace == PartitionInterlace)
           (void) CopyMagickString(image->filename,image_info->filename,
@@ -454,7 +468,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
         break;
     if (image_info->interlace == PartitionInterlace)
       break;
-    count=ReadBlob(image,packet_size*image->extract_info.width,scanline);
+    count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
     if (count != 0)
       {
         /*
@@ -476,7 +490,7 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
           }
       }
   } while (count != 0);
-  scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   CloseBlob(image);
   return(GetFirstImageInList(image));
 }
@@ -589,6 +603,9 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
   MagickOffsetType
     scene;
 
+  QuantumInfo
+    quantum_info;
+
   register const PixelPacket
     *p;
 
@@ -614,7 +631,8 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
   packet_size=(size_t) (3*depth/8);
   if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
     packet_size+=depth/8;
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
+  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->interlace != PartitionInterlace)
@@ -632,11 +650,12 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
     /*
       Convert to YCbCr pixels.
     */
+    GetQuantumInfo(image_info,&quantum_info);
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,YCbCrColorspace);
     if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
       if (image->matte == MagickFalse)
-        SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageOpacity(image,OpaqueOpacity);
     switch (image_info->interlace)
     {
       case NoInterlace:
@@ -652,12 +671,13 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
             break;
           if (LocaleCompare(image_info->magick,"YCbCrA") != 0)
             {
-              (void) ImportQuantumPixels(image,RGBQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,RGBQuantum,pixels);
               (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           else
             {
-              (void) ImportQuantumPixels(image,RGBAQuantum,0,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,
+                pixels);
               (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           if (image->previous == (Image *) NULL)
@@ -677,21 +697,23 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
         /*
           Line interlacing:  YYY...CbCbCb...CrCrCr...YYY...CbCbCb...CrCrCr...
         */
+        packet_size=depth/8;
         for (y=0; y < (long) image->rows; y++)
         {
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,RedQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,GreenQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
-          (void) ImportQuantumPixels(image,BlueQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,RedQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,GreenQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,BlueQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
           if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
             {
-              (void) ImportQuantumPixels(image,AlphaQuantum,0,pixels);
-              (void) WriteBlob(image,(size_t) image->columns,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels);
+              (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
               (QuantumTick(y,image->rows) != MagickFalse))
@@ -710,6 +732,7 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
         /*
           Plane interlacing:  YYYYYY...CbCbCbCbCbCb...CrCrCrCrCrCr...
         */
+        packet_size=depth/8;
         if (image_info->interlace == PartitionInterlace)
           {
             AppendImageFormat("Y",image->filename);
@@ -723,8 +746,8 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,RedQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,RedQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
         }
         if (image_info->interlace == PartitionInterlace)
           {
@@ -747,8 +770,8 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,GreenQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,GreenQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
         }
         if (image_info->interlace == PartitionInterlace)
           {
@@ -771,8 +794,8 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
           p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
           if (p == (const PixelPacket *) NULL)
             break;
-          (void) ImportQuantumPixels(image,BlueQuantum,0,pixels);
-          (void) WriteBlob(image,(size_t) image->columns,pixels);
+          (void) ImportQuantumPixels(image,&quantum_info,BlueQuantum,pixels);
+          (void) WriteBlob(image,packet_size*image->columns,pixels);
         }
         if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
           {
@@ -798,8 +821,9 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
                 &image->exception);
               if (p == (const PixelPacket *) NULL)
                 break;
-              (void) ImportQuantumPixels(image,AlphaQuantum,0,pixels);
-              (void) WriteBlob(image,(size_t) image->columns,pixels);
+              (void) ImportQuantumPixels(image,&quantum_info,AlphaQuantum,
+                pixels);
+              (void) WriteBlob(image,packet_size*image->columns,pixels);
             }
           }
         if (image_info->interlace == PartitionInterlace)
