@@ -44,7 +44,6 @@
 */
 #include "magick/studio.h"
 #include "magick/annotate.h"
-#include "magick/attribute.h"
 #include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
@@ -61,6 +60,7 @@
 #include "magick/image-private.h"
 #include "magick/log.h"
 #include "magick/quantum.h"
+#include "magick/property.h"
 #include "magick/resource_.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
@@ -155,7 +155,6 @@ static MagickBooleanType
 %
 %    o draw_info: The draw info.
 %
-%
 */
 MagickExport MagickBooleanType AnnotateImage(Image *image,
   const DrawInfo *draw_info)
@@ -386,7 +385,7 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
         undercolor_info->affine.tx=offset.x-draw_info->affine.ry*metrics.ascent;
         undercolor_info->affine.ty=offset.y-draw_info->affine.sy*metrics.ascent;
         (void) FormatMagickString(primitive,MaxTextExtent,
-          "rectangle 0,0 %g,%ld",metrics.width,height);
+          "rectangle 0,0 %g,%ld",metrics.origin.x,height);
         (void) CloneString(&undercolor_info->primitive,primitive);
         (void) DrawImage(image,undercolor_info);
         (void) DestroyDrawInfo(undercolor_info);
@@ -467,7 +466,6 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
 %
 %    o count: return the number of characters generated by the encoding.
 %
-%
 */
 
 static int GetOneCharacter(const unsigned char *text,size_t *length)
@@ -567,7 +565,6 @@ static unsigned long *EncodeSJIS(const Image *image,const char *text,
 %
 %    o count: return the number of characters generated by the encoding.
 %
-%
 */
 static unsigned long *EncodeText(const Image *image,const char *text,
   size_t *count)
@@ -731,6 +728,87 @@ static unsigned long *EncodeUnicode(const Image *image,const char *text,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%  F o r m a t M a g i c k C a p t i o n                                      %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  FormatMagickCaption() formats a caption so that it fits within the image
+%  width.  It returns the number of lines in the formatted caption.
+%
+%  The format of the FormatMagickCaption method is:
+%
+%      long FormatMagickCaption(Image *image,DrawInfo *draw_info,char *caption,
+%        TypeMetric *metrics)
+%
+%  A description of each parameter follows.
+%
+%    o image:  The image.
+%
+%    o draw_info: The draw info.
+%
+%    o metrics: Return the font metrics in this structure.
+%
+*/
+MagickExport long FormatMagickCaption(Image *image,DrawInfo *draw_info,
+  char *caption,TypeMetric *metrics)
+{
+  MagickBooleanType
+    status;
+
+  register char
+    *p,
+    *q,
+    *s;
+
+  register long
+    i;
+
+  unsigned long
+    width;
+
+  q=draw_info->text;
+  s=(char *) NULL;
+  for (p=caption; *p != '\0'; p++)
+  {
+    if (isspace((int) ((unsigned char) *p)) != 0)
+      s=p;
+    *q++=(*p);
+    *q='\0';
+    status=GetTypeMetrics(image,draw_info,metrics);
+    if (status == MagickFalse)
+      break;
+    width=(unsigned long) (metrics->width+0.5);
+    if (*p != '\n')
+      if (width <= image->columns)
+        continue;
+    if (s == (char *) NULL)
+      {
+        s=p;
+        while ((isspace((int) ((unsigned char) *s)) == 0) && (*s != '\0'))
+          s++;
+      }
+    if (*s != '\0')
+      {
+        *s='\n';
+        p=s;
+        s=(char *) NULL;
+      }
+    q=draw_info->text;
+  }
+  i=0;
+  for (p=caption; *p != '\0'; p++)
+    if (*p == '\n')
+      i++;
+  return(i);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t M u l t i l i n e T y p e M e t r i c s                             %
 %                                                                             %
 %                                                                             %
@@ -773,21 +851,18 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
   char
     **textlist;
 
-  double
-    max_width;
-
   DrawInfo
     *annotate_info;
 
   MagickBooleanType
     status;
 
-  PointInfo
-    offset;
-
   register long
     i;
 
+  TypeMetric
+    extent;
+
   unsigned long
     number_lines;
 
@@ -810,25 +885,23 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
     return(MagickFalse);
   annotate_info->render=MagickFalse;
   (void) ResetMagickMemory(metrics,0,sizeof(*metrics));
-  offset.x=0.0;
-  offset.y=0.0;
+  (void) ResetMagickMemory(&extent,0,sizeof(extent));
   /*
     Find the widest of the text lines.
   */
   annotate_info->text=textlist[0];
-  status=RenderType(image,annotate_info,&offset,metrics);
-  max_width=metrics->width;
+  status=GetTypeMetrics(image,annotate_info,&extent);
+  *metrics=extent;
   for (i=1; textlist[i] != (char *) NULL; i++)
   {
     annotate_info->text=textlist[i];
-    status=RenderType(image,annotate_info,&offset,metrics);
-    if (metrics->width > max_width)
-      max_width=metrics->width;
+    status=GetTypeMetrics(image,annotate_info,&extent);
+    if (extent.width > metrics->width)
+      *metrics=extent;
   }
   number_lines=(unsigned long) i;
-  metrics->width=max_width;
   metrics->height=(double) number_lines*(long) (metrics->ascent-
-    metrics->descent+0.5)+1;
+    metrics->descent+0.5);
   /*
     Free resources.
   */
@@ -877,7 +950,6 @@ MagickExport MagickBooleanType GetMultilineTypeMetrics(Image *image,
 %
 %    o metrics: Return the font metrics in this structure.
 %
-%
 */
 MagickExport MagickBooleanType GetTypeMetrics(Image *image,
   const DrawInfo *draw_info,TypeMetric *metrics)
@@ -1114,8 +1186,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       image;
   } GlyphInfo;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   DrawInfo
     *annotate_info;
@@ -1177,9 +1249,6 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   register PixelPacket
     *q;
 
-  register unsigned char
-    *p;
-
   size_t
     length;
 
@@ -1204,10 +1273,13 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     ThrowBinaryException(TypeError,"UnableToInitializeFreetypeLibrary",
       image->filename);
   args.flags=FT_OPEN_PATHNAME;
-  if (*draw_info->font != '@')
-    args.pathname=draw_info->font;
+  if (draw_info->font == (char *) NULL)
+    args.pathname="helvetica";
   else
-    args.pathname=draw_info->font+1;
+    if (*draw_info->font != '@')
+      args.pathname=draw_info->font;
+    else
+      args.pathname=draw_info->font+1;
   face=(FT_Face) NULL;
   status=FT_Open_Face(library,&args,draw_info->face,&face);
   if (status != 0)
@@ -1285,6 +1357,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   metrics->ascent=(double) face->size->metrics.ascender/64.0;
   metrics->descent=(double) face->size->metrics.descender/64.0;
   metrics->width=0;
+  metrics->origin.x=0;
+  metrics->origin.y=0;
   metrics->height=(double) face->size->metrics.height/64.0;
   metrics->max_advance=0.0;
   if (face->size->metrics.max_advance > MagickEpsilon)
@@ -1359,9 +1433,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       draw_info->encoding != (char *) NULL ? draw_info->encoding : "none",
       draw_info->pointsize);
   flags=FT_LOAD_NO_BITMAP;
-  attribute=GetImageAttribute(image,"type:hinting");
-  if ((attribute != (const ImageAttribute *) NULL) &&
-      (LocaleCompare(attribute->value,"off") == 0))
+  value=GetImageProperty(image,"type:hinting");
+  if (LocaleCompare(value,"off") == 0)
     flags|=FT_LOAD_NO_HINTING;
   glyph.id=0;
   glyph.image=NULL;
@@ -1369,15 +1442,26 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   last_glyph.image=NULL;
   origin.x=0;
   origin.y=0;
-  affine.xx=(FT_Fixed) (65536L*draw_info->affine.sx+0.5);
-  affine.yx=(FT_Fixed) (-65536L*draw_info->affine.rx+0.5);
-  affine.xy=(FT_Fixed) (-65536L*draw_info->affine.ry+0.5);
-  affine.yy=(FT_Fixed) (65536L*draw_info->affine.sy+0.5);
+  affine.xx=65536L;
+  affine.yx=0L;
+  affine.xy=0L;
+  affine.yy=65536L;
+  if (draw_info->render != MagickFalse)
+    {
+      affine.xx=(FT_Fixed) (65536L*draw_info->affine.sx+0.5);
+      affine.yx=(FT_Fixed) (-65536L*draw_info->affine.rx+0.5);
+      affine.xy=(FT_Fixed) (-65536L*draw_info->affine.ry+0.5);
+      affine.yy=(FT_Fixed) (65536L*draw_info->affine.sy+0.5);
+    }
   annotate_info=CloneDrawInfo((ImageInfo *) NULL,draw_info);
-  (void) QueryColorDatabase("#000000ff",&annotate_info->fill,&image->exception);
   (void) CloneString(&annotate_info->primitive,"path '");
-  if ((draw_info->render != MagickFalse) && (image->matte == MagickFalse))
-    SetImageOpacity(image,OpaqueOpacity);
+  if (draw_info->render != MagickFalse)
+    {
+  	  if (image->storage_class != DirectClass)
+        (void) SetImageStorageClass(image,DirectClass);
+  	  if (image->matte == MagickFalse)
+        (void) SetImageOpacity(image,OpaqueOpacity);
+    }
   for (i=0; i < (long) length; i++)
   {
     glyph.id=FT_Get_Char_Index(face,text[i]);
@@ -1425,27 +1509,28 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         }
     FT_Vector_Transform(&glyph.origin,&affine);
     (void) FT_Glyph_Transform(glyph.image,&affine,&glyph.origin);
+    status=FT_Glyph_To_Bitmap(&glyph.image,ft_render_mode_normal,
+      (FT_Vector *) NULL,MagickTrue);
+    if (status != 0)
+      continue;
+    bitmap=(FT_BitmapGlyph) glyph.image;
+    point.x=offset->x+bitmap->left;
+    point.y=offset->y-bitmap->top;
     if (draw_info->render != MagickFalse)
       {
         long
           x_offset,
           y_offset;
 
+        register unsigned char
+          *p;
+
         ViewInfo
           *image_view;
 
         /*
           Rasterize the glyph.
         */
-        status=FT_Glyph_To_Bitmap(&glyph.image,ft_render_mode_normal,
-          (FT_Vector *) NULL,MagickTrue);
-        if (status != 0)
-          continue;
-        bitmap=(FT_BitmapGlyph) glyph.image;
-        if (SetImageStorageClass(image,DirectClass) == MagickFalse)
-          return(MagickFalse);
-        point.x=offset->x+bitmap->left;
-        point.y=offset->y-bitmap->top;
         p=bitmap->bitmap.buffer;
         image_view=OpenCacheView(image);
         for (y=0; y < (long) bitmap->bitmap.rows; y++)
@@ -1494,25 +1579,32 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         }
         image_view=CloseCacheView(image_view);
       }
+    if ((point.x+bitmap->bitmap.width-offset->x) > metrics->width)
+      metrics->width=point.x+bitmap->bitmap.width-offset->x;
     origin.x+=face->glyph->advance.x;
-    if (origin.x > metrics->width)
-      metrics->width=origin.x;
+    metrics->origin.x=origin.x;
+    metrics->origin.y=origin.y;
     if (last_glyph.id != 0)
       FT_Done_Glyph(last_glyph.image);
     last_glyph=glyph;
   }
-  metrics->width/=64.0;
+  metrics->width-=metrics->bounds.x1/64.0;
+  metrics->width+=1.0;
   metrics->bounds.x1/=64.0;
   metrics->bounds.y1/=64.0;
   metrics->bounds.x2/=64.0;
   metrics->bounds.y2/=64.0;
+  metrics->origin.x/=64.0;
+  metrics->origin.y/=64.0;
   if ((draw_info->stroke.opacity != TransparentOpacity) ||
       (draw_info->stroke_pattern != (Image *) NULL))
     {
+      metrics->width+=draw_info->stroke_width;
       metrics->bounds.x1-=draw_info->stroke_width/2.0;
       metrics->bounds.y1-=draw_info->stroke_width/2.0;
       metrics->bounds.x2+=draw_info->stroke_width/2.0;
       metrics->bounds.y2+=draw_info->stroke_width/2.0;
+      metrics->origin.x+=draw_info->stroke_width;
       if (draw_info->render != MagickFalse)
         {
           /*
@@ -1537,11 +1629,11 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
 }
 #else
 static MagickBooleanType RenderFreetype(Image *image,
-  const DrawInfo *magick_unused(draw_info),const char *magick_unused(encoding),
+  const DrawInfo *draw_info,const char *magick_unused(encoding),
   const PointInfo *magick_unused(offset),TypeMetric *magick_unused(metrics))
 {
   ThrowBinaryException(MissingDelegateError,"FreeTypeLibraryIsNotAvailable",
-    image->filename)
+    draw_info->font)
 }
 #endif
 
@@ -1789,9 +1881,9 @@ static MagickBooleanType RenderPostscript(Image *image,
         Render fill color.
       */
       if (image->matte == MagickFalse)
-        SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageOpacity(image,OpaqueOpacity);
       if (annotate_image->matte == MagickFalse)
-        SetImageOpacity(annotate_image,OpaqueOpacity);
+        (void) SetImageOpacity(annotate_image,OpaqueOpacity);
       fill_color=draw_info->fill;
       annotate_view=OpenCacheView(annotate_image);
       for (y=0; y < (long) annotate_image->rows; y++)
