@@ -85,7 +85,6 @@ static const char
     "  <coder magick=\"CUR\" name=\"ICON\" />"
     "  <coder magick=\"DCX\" name=\"PCX\" />"
     "  <coder magick=\"DFONT\" name=\"TTF\" />"
-    "  <coder magick=\"DNG\" name=\"TIFF\" />"
     "  <coder magick=\"EMF\" name=\"EMF\" />"
     "  <coder magick=\"EPDF\" name=\"PDF\" />"
     "  <coder magick=\"EPI\" name=\"PS\" />"
@@ -97,6 +96,7 @@ static const char
     "  <coder magick=\"FILE\" name=\"URL\" />"
     "  <coder magick=\"FRACTAL\" name=\"PLASMA\" />"
     "  <coder magick=\"FTP\" name=\"URL\" />"
+    "  <coder magick=\"FTS\" name=\"FITS\" />"
     "  <coder magick=\"G3\" name=\"FAX\" />"
     "  <coder magick=\"GIF87\" name=\"GIF\" />"
     "  <coder magick=\"G\" name=\"GRAY\" />"
@@ -275,13 +275,13 @@ MagickExport const CoderInfo *GetCoderInfo(const char *name,
 %  The format of the GetCoderInfoList function is:
 %
 %      const CoderInfo **GetCoderInfoList(const char *pattern,
-%        unsigned long *number_coder_map,ExceptionInfo *exception)
+%        unsigned long *number_coders,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o pattern: Specifies a pointer to a text string containing a pattern.
 %
-%    o number_coder_map:  This integer returns the number of coder_map in the list.
+%    o number_coders:  This integer returns the number of coders in the list.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -301,7 +301,7 @@ static int CoderInfoCompare(const void *x,const void *y)
 }
 
 MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
-  unsigned long *number_coder_map,ExceptionInfo *exception)
+  unsigned long *number_coders,ExceptionInfo *exception)
 {
   const CoderInfo
     **coder_map;
@@ -317,8 +317,8 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
   */
   assert(pattern != (char *) NULL);
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
-  assert(number_coder_map != (unsigned long *) NULL);
-  *number_coder_map=0;
+  assert(number_coders != (unsigned long *) NULL);
+  *number_coders=0;
   p=GetCoderInfo("*",exception);
   if (p == (const CoderInfo *) NULL)
     return((const CoderInfo **) NULL);
@@ -342,7 +342,7 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
   RelinquishSemaphoreInfo(coder_semaphore);
   qsort((void *) coder_map,(size_t) i,sizeof(*coder_map),CoderInfoCompare);
   coder_map[i]=(CoderInfo *) NULL;
-  *number_coder_map=(unsigned long) i;
+  *number_coders=(unsigned long) i;
   return(coder_map);
 }
 
@@ -361,14 +361,14 @@ MagickExport const CoderInfo **GetCoderInfoList(const char *pattern,
 %
 %  The format of the GetCoderList function is:
 %
-%      char **GetCoderList(const char *pattern,unsigned long *number_coder_map,
+%      char **GetCoderList(const char *pattern,unsigned long *number_coders,
 %        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o pattern: Specifies a pointer to a text string containing a pattern.
 %
-%    o number_coder_map:  This integer returns the number of coder_map in the list.
+%    o number_coders:  This integer returns the number of coders in the list.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -386,7 +386,7 @@ static int CoderCompare(const void *x,const void *y)
 }
 
 MagickExport char **GetCoderList(const char *pattern,
-  unsigned long *number_coder_map,ExceptionInfo *exception)
+  unsigned long *number_coders,ExceptionInfo *exception)
 {
   char
     **coder_map;
@@ -402,8 +402,8 @@ MagickExport char **GetCoderList(const char *pattern,
   */
   assert(pattern != (char *) NULL);
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",pattern);
-  assert(number_coder_map != (unsigned long *) NULL);
-  *number_coder_map=0;
+  assert(number_coders != (unsigned long *) NULL);
+  *number_coders=0;
   p=GetCoderInfo("*",exception);
   if (p == (const CoderInfo *) NULL)
     return((char **) NULL);
@@ -427,7 +427,7 @@ MagickExport char **GetCoderList(const char *pattern,
   RelinquishSemaphoreInfo(coder_semaphore);
   qsort((void *) coder_map,(size_t) i,sizeof(*coder_map),CoderCompare);
   coder_map[i]=(char *) NULL;
-  *number_coder_map=(unsigned long) i;
+  *number_coders=(unsigned long) i;
   return(coder_map);
 }
 
@@ -510,15 +510,15 @@ MagickExport MagickBooleanType ListCoderInfo(FILE *file,
     i;
 
   unsigned long
-    number_coder_map;
+    number_coders;
 
   if (file == (const FILE *) NULL)
     file=stdout;
-  coder_info=GetCoderInfoList("*",&number_coder_map,exception);
+  coder_info=GetCoderInfoList("*",&number_coders,exception);
   if (coder_info == (const CoderInfo **) NULL)
     return(MagickFalse);
   path=(const char *) NULL;
-  for (i=0; i < (long) number_coder_map; i++)
+  for (i=0; i < (long) number_coders; i++)
   {
     if (coder_info[i]->stealth != MagickFalse)
       continue;
