@@ -40,7 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
@@ -337,8 +337,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
 #define ReferenceWhite  685.0
 #define DisplayGamma  (1.0/1.7)
 
-      const ImageAttribute
-        *attribute;
+      const char
+        *value;
 
       double
         black,
@@ -355,19 +355,19 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       */
       density=2.03728;
       gamma=DisplayGamma;
-      attribute=GetImageAttribute(image,"Gamma");
-      if (attribute != (const ImageAttribute *) NULL)
-        gamma=1.0/atof(attribute->value) != 0.0 ? atof(attribute->value) : 1.0;
+      value=GetImageProperty(image,"Gamma");
+      if (value != (const char *) NULL)
+        gamma=1.0/atof(value) != 0.0 ? atof(value) : 1.0;
       reference_black=ReferenceBlack;
-      attribute=GetImageAttribute(image,"reference-black");
-      if (attribute != (const ImageAttribute *) NULL)
-        reference_black=atof(attribute->value);
+      value=GetImageProperty(image,"reference-black");
+      if (value != (const char *) NULL)
+        reference_black=atof(value);
       reference_white=ReferenceWhite;
-      attribute=GetImageAttribute(image,"reference-white");
-      if (attribute != (const ImageAttribute *) NULL)
-        reference_white=atof(attribute->value);
-      logmap=(Quantum *)
-        AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*logmap));
+      value=GetImageProperty(image,"reference-white");
+      if (value != (const char *) NULL)
+        reference_white=atof(value);
+      logmap=(Quantum *) AcquireMagickMemory((size_t) (MaxMap+1)*
+        sizeof(*logmap));
       if (logmap == (Quantum *) NULL)
         ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
           image->filename);
@@ -1184,8 +1184,8 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
     }
     case LogColorspace:
     {
-      const ImageAttribute
-        *attribute;
+      const char
+        *value;
 
       double
         black,
@@ -1202,19 +1202,19 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       */
       density=2.03728;
       gamma=DisplayGamma;
-      attribute=GetImageAttribute(image,"Gamma");
-      if (attribute != (const ImageAttribute *) NULL)
-        gamma=1.0/atof(attribute->value) != 0.0 ? atof(attribute->value) : 1.0;
+      value=GetImageProperty(image,"Gamma");
+      if (value != (const char *) NULL)
+        gamma=1.0/atof(value) != 0.0 ? atof(value) : 1.0;
       reference_black=ReferenceBlack;
-      attribute=GetImageAttribute(image,"reference-black");
-      if (attribute != (const ImageAttribute *) NULL)
-        reference_black=atof(attribute->value);
+      value=GetImageProperty(image,"reference-black");
+      if (value != (const char *) NULL)
+        reference_black=atof(value);
       reference_white=ReferenceWhite;
-      attribute=GetImageAttribute(image,"reference-white");
-      if (attribute != (const ImageAttribute *) NULL)
-        reference_white=atof(attribute->value);
-      logmap=(Quantum *)
-        AcquireMagickMemory((size_t) (MaxMap+1)*sizeof(*logmap));
+      value=GetImageProperty(image,"reference-white");
+      if (value != (const char *) NULL)
+        reference_white=atof(value);
+      logmap=(Quantum *) AcquireMagickMemory((size_t) (MaxMap+1)*
+        sizeof(*logmap));
       if (logmap == (Quantum *) NULL)
         ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
           image->filename);
@@ -1549,20 +1549,20 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
                 (pixel.blue > MaxYCC) ? MaxYCC : pixel.blue+0.5);
               if (colorspace == sRGBColorspace)
                 {
-                  q->red=(Quantum)
-                    ScaleToQuantum(sRGBMap[ScaleQuantum(quantum.red)]);
-                  q->green=(Quantum)
-                    ScaleToQuantum(sRGBMap[ScaleQuantum(quantum.green)]);
-                  q->blue=(Quantum)
-                    ScaleToQuantum(sRGBMap[ScaleQuantum(quantum.blue)]);
+                  q->red=(Quantum) ScaleToQuantum(sRGBMap[
+                    ScaleQuantumToChar((Quantum) quantum.red)]);
+                  q->green=(Quantum) ScaleToQuantum(sRGBMap[
+                    ScaleQuantumToChar((Quantum) quantum.green)]);
+                  q->blue=(Quantum) ScaleToQuantum(sRGBMap[
+                    ScaleQuantumToChar((Quantum) quantum.blue)]);
                   break;
                 }
-              q->red=(Quantum)
-                ScaleToQuantum(YCCMap[ScaleQuantum(quantum.red)]);
-              q->green=(Quantum)
-                ScaleToQuantum(YCCMap[ScaleQuantum(quantum.green)]);
-              q->blue=(Quantum)
-                ScaleToQuantum(YCCMap[ScaleQuantum(quantum.blue)]);
+              q->red=(Quantum) ScaleToQuantum(YCCMap[
+                ScaleQuantumToChar((Quantum) quantum.red)]);
+              q->green=(Quantum) ScaleToQuantum(YCCMap[
+                ScaleQuantumToChar((Quantum) quantum.green)]);
+              q->blue=(Quantum) ScaleToQuantum(YCCMap[
+                ScaleQuantumToChar((Quantum) quantum.blue)]);
               break;
             }
             default:
@@ -1620,20 +1620,20 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
               (pixel.blue > MaxYCC) ? MaxYCC : pixel.blue+0.5);
             if (colorspace == sRGBColorspace)
               {
-                image->colormap[i].red=(Quantum)
-                  ScaleToQuantum(sRGBMap[ScaleQuantum(quantum.red)]);
-                image->colormap[i].green=(Quantum)
-                  ScaleToQuantum(sRGBMap[ScaleQuantum(quantum.green)]);
-                image->colormap[i].blue=(Quantum)
-                  ScaleToQuantum(sRGBMap[ScaleQuantum(quantum.blue)]);
+                image->colormap[i].red=(Quantum) ScaleToQuantum(sRGBMap[
+                  ScaleQuantumToChar((Quantum) quantum.red)]);
+                image->colormap[i].green=(Quantum) ScaleToQuantum(sRGBMap[
+                  ScaleQuantumToChar((Quantum) quantum.green)]);
+                image->colormap[i].blue=(Quantum) ScaleToQuantum(sRGBMap[
+                  ScaleQuantumToChar((Quantum) quantum.blue)]);
                 break;
               }
-            image->colormap[i].red=(Quantum)
-              ScaleToQuantum(YCCMap[ScaleQuantum(quantum.red)]);
-            image->colormap[i].green=(Quantum)
-              ScaleToQuantum(YCCMap[ScaleQuantum(quantum.green)]);
-            image->colormap[i].blue=(Quantum)
-              ScaleToQuantum(YCCMap[ScaleQuantum(quantum.blue)]);
+            image->colormap[i].red=(Quantum) ScaleToQuantum(YCCMap[
+              ScaleQuantumToChar((Quantum) quantum.red)]);
+            image->colormap[i].green=(Quantum) ScaleToQuantum(YCCMap[
+              ScaleQuantumToChar((Quantum) quantum.green)]);
+            image->colormap[i].blue=(Quantum) ScaleToQuantum(YCCMap[
+              ScaleQuantumToChar((Quantum) quantum.blue)]);
             break;
           }
           default:
