@@ -41,7 +41,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/cache-view.h"
 #include "magick/client.h"
 #include "magick/color.h"
@@ -60,6 +59,7 @@
 #include "magick/memory_.h"
 #include "magick/option.h"
 #include "magick/pixel-private.h"
+#include "magick/property.h"
 #include "magick/quantum.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
@@ -729,7 +729,7 @@ static MagickRealType SoftLight(const MagickRealType p,
       return(QuantumRange*pixel);
     }
   pixel=(QuantumScale*(1.0-QuantumScale*beta)*q*(1.0-QuantumScale*alpha)+
-    (pow(QuantumScale*(1.0-QuantumScale*beta)*q/(1.0-QuantumScale*beta),0*5)*
+    (pow(QuantumScale*(1.0-QuantumScale*beta)*q/(1.0-QuantumScale*beta),0.5)*
     (1.0-QuantumScale*beta)-QuantumScale*(1.0-QuantumScale*beta)*q)*
     (2.0*QuantumScale*(1.0-QuantumScale*alpha)*p-(1.0-QuantumScale*alpha)))+
     QuantumScale*(1.0-QuantumScale*alpha)*p*(1.0-(1.0-QuantumScale*beta))+
@@ -935,8 +935,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   const ChannelType magick_unused(channel),const CompositeOperator compose,
   const Image *composite_image,const long x_offset,const long y_offset)
 {
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   const PixelPacket
     *pixels;
@@ -1034,7 +1034,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     case CopyOpacityCompositeOp:
     {
       if (image->matte == MagickFalse)
-        SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageOpacity(image,OpaqueOpacity);
       modify_outside_overlay=MagickTrue;
       break;
     }
@@ -1110,14 +1110,15 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
               continue;
             }
           x_displace=(horizontal_scale*(PixelIntensityToQuantum(p)-
-            (((MagickRealType) QuantumRange+1.0)/2)))/
+            (((MagickRealType) QuantumRange+1.0)/2.0)))/
             (((MagickRealType) QuantumRange+1.0)/2.0);
           if (composite_image->matte != MagickFalse)
             y_displace=(-vertical_scale*(p->opacity-(((MagickRealType)
-              QuantumRange+1.0)/2.0)))/(((MagickRealType) QuantumRange+1.0)/2);
+              QuantumRange+1.0)/2.0)))/(((MagickRealType) QuantumRange+1.0)/
+              2.0);
           else
             y_displace=(vertical_scale*(PixelIntensityToQuantum(p)-
-              (((MagickRealType) QuantumRange+1.0)/2)))/
+              (((MagickRealType) QuantumRange+1.0)/2.0)))/
               (((MagickRealType) QuantumRange+1.0)/2.0);
           pixel=InterpolatePixelColor(image,image_view,image->interpolate,
             (double) (x_offset+x+x_displace),(double) (y_offset+y+y_displace),
@@ -1223,8 +1224,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     default:
       break;
   }
-  attribute=GetImageAttribute(composite_image,"[modify-outside-overlay]");
-  if (attribute != (ImageAttribute *) NULL)
+  value=GetImageProperty(composite_image,"[modify-outside-overlay]");
+  if (value != (const char *) NULL)
     modify_outside_overlay=MagickFalse;
   /*
     Composite image.
