@@ -1029,156 +1029,6 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
 }
 #endif
 
-#if defined(HasJPEG)
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   J P E G E n c o d e I m a g e                                             %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  JPEGEncodeImage() compresses an image via JPEG compression.
-%
-%  The format of the JPEGEncodeImage method is:
-%
-%      MagickBooleanType JPEGEncodeImage(const ImageInfo *image_info,
-%        Image *image)
-%
-%  A description of each parameter follows:
-%
-%    o image_info: The image info..
-%
-%    o image: The image.
-%
-*/
-MagickExport MagickBooleanType JPEGEncodeImage(const ImageInfo *image_info,
-  Image *image)
-{
-  Image
-    *jpeg_image;
-
-  ImageInfo
-    *jpeg_info;
-
-  size_t
-    length;
-
-  unsigned char
-    *blob;
-
-  /*
-    Write image as JPEG image to a temporary file.
-  */
-  jpeg_image=CloneImage(image,0,0,MagickTrue,&image->exception);
-  if (jpeg_image == (Image *) NULL)
-    ThrowWriterException(CoderError,image->exception.reason);
-  DestroyBlob(jpeg_image);
-  jpeg_image->blob=CloneBlobInfo((BlobInfo *) NULL);
-  jpeg_info=CloneImageInfo(image_info);
-  *jpeg_info->filename='\0';
-  (void) CopyMagickString(jpeg_info->magick,"JPEG",MaxTextExtent);
-  length=0;
-  blob=ImageToBlob(jpeg_info,jpeg_image,&length,&image->exception);
-  jpeg_info=DestroyImageInfo(jpeg_info);
-  if (blob == (void *) NULL)
-    ThrowWriterException(CoderError,image->exception.reason);
-  (void) WriteBlob(image,length,blob);
-  jpeg_image=DestroyImage(jpeg_image);
-  blob=(unsigned char *) RelinquishMagickMemory(blob);
-  return(MagickTrue);
-}
-#else
-MagickExport MagickBooleanType JPEGEncodeImage(const ImageInfo *image_info,
-  Image *image)
-{
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  ThrowBinaryException(MissingDelegateError,"JPEGLibraryIsNotAvailable",
-    image->filename);
-}
-#endif
-
-#if defined(HasJP2)
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   J P 2 E n c o d e I m a g e                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  JP2EncodeImage() compresses an image via JPEG-2000 compression.
-%
-%  The format of the JP2EncodeImage method is:
-%
-%      MagickBooleanType JP2EncodeImage(const ImageInfo *image_info,
-%        Image *image)
-%
-%  A description of each parameter follows:
-%
-%    o image_info: The image info..
-%
-%    o image: The image.
-%
-*/
-MagickExport MagickBooleanType JP2EncodeImage(const ImageInfo *image_info,
-  Image *image)
-{
-  Image
-    *jp2_image;
-
-  ImageInfo
-    *jp2_info;
-
-  size_t
-    length;
-
-  unsigned char
-    *blob;
-
-  /*
-    Write image as JP2 image to a temporary file.
-  */
-  jp2_image=CloneImage(image,0,0,MagickTrue,&image->exception);
-  if (jp2_image == (Image *) NULL)
-    ThrowWriterException(CoderError,image->exception.reason);
-  DestroyBlob(jp2_image);
-  jp2_image->blob=CloneBlobInfo((BlobInfo *) NULL);
-  jp2_info=CloneImageInfo(image_info);
-  *jp2_info->filename='\0';
-  (void) CopyMagickString(jp2_info->magick,"JP2",MaxTextExtent);
-  length=0;
-  blob=ImageToBlob(jp2_info,jp2_image,&length,&image->exception);
-  jp2_info=DestroyImageInfo(jp2_info);
-  if (blob == (void *) NULL)
-    ThrowWriterException(CoderError,image->exception.reason);
-  (void) WriteBlob(image,length,blob);
-  jp2_image=DestroyImage(jp2_image);
-  blob=(unsigned char *) RelinquishMagickMemory(blob);
-  return(MagickTrue);
-}
-#else
-MagickExport MagickBooleanType JP2EncodeImage(
-  const ImageInfo *magick_unused(image_info),Image *image)
-{
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  ThrowBinaryException(MissingDelegateError,"JP2LibraryIsNotAvailable",
-    image->filename);
-}
-#endif
-
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -1560,7 +1410,7 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
     for (i=0; i < (long) compressed_packets; i++)
       (void) WriteBlobByte(image,compressed_pixels[i]);
   compressed_pixels=(unsigned char *) RelinquishMagickMemory(compressed_pixels);
-  return((MagickBooleanType) (status == Z_OK));
+  return(status == Z_OK ? MagickTrue : MagickFalse);
 }
 #else
 MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,
