@@ -17,7 +17,7 @@
 %                                 July 2003                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -48,11 +48,11 @@
 #include "magick/hashmap.h"
 #include "magick/log.h"
 #include "magick/memory_.h"
-#include "magick/nt-feature.h"
 #include "magick/semaphore.h"
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#include "magick/xml-tree.h"
 
 /*
   Define declarations.
@@ -102,7 +102,6 @@ static MagickBooleanType
 %
 %      DestroyConfigureList(void)
 %
-%
 */
 
 static void *DestroyConfigureElement(void *configure_info)
@@ -123,7 +122,7 @@ static void *DestroyConfigureElement(void *configure_info)
 
 MagickExport void DestroyConfigureList(void)
 {
-  configure_semaphore=AcquireSemaphoreInfo(configure_semaphore);
+  AcquireSemaphoreInfo(&configure_semaphore);
   if (configure_list != (LinkedListInfo *) NULL)
     configure_list=DestroyLinkedList(configure_list,DestroyConfigureElement);
   configure_list=(LinkedListInfo *) NULL;
@@ -154,7 +153,6 @@ MagickExport void DestroyConfigureList(void)
 %
 %    o image: The image.
 %
-%
 */
 
 static void *DestroyOptions(void *option)
@@ -197,7 +195,6 @@ MagickExport LinkedListInfo *DestroyConfigureOptions(LinkedListInfo *options)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport const ConfigureInfo *GetConfigureInfo(const char *name,
   ExceptionInfo *exception)
@@ -218,7 +215,7 @@ MagickExport const ConfigureInfo *GetConfigureInfo(const char *name,
   /*
     Search for named configure.
   */
-  configure_semaphore=AcquireSemaphoreInfo(configure_semaphore);
+  AcquireSemaphoreInfo(&configure_semaphore);
   ResetLinkedListIterator(configure_list);
   p=(const ConfigureInfo *) GetNextValueInLinkedList(configure_list);
   while (p != (const ConfigureInfo *) NULL)
@@ -229,7 +226,7 @@ MagickExport const ConfigureInfo *GetConfigureInfo(const char *name,
   }
   if (p == (ConfigureInfo *) NULL)
     (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
-      "UnrecognizedConfigure","`%s'",name);
+      "NoSuchElement","`%s'",name);
   RelinquishSemaphoreInfo(configure_semaphore);
   return(p);
 }
@@ -314,7 +311,7 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
   /*
     Generate configure list.
   */
-  configure_semaphore=AcquireSemaphoreInfo(configure_semaphore);
+  AcquireSemaphoreInfo(&configure_semaphore);
   ResetLinkedListIterator(configure_list);
   p=(const ConfigureInfo *) GetNextValueInLinkedList(configure_list);
   for (i=0; p != (const ConfigureInfo *) NULL; )
@@ -358,7 +355,6 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 #if defined(__cplusplus) || defined(c_plusplus)
@@ -402,20 +398,20 @@ MagickExport char **GetConfigureList(const char *pattern,
   p=GetConfigureInfo("*",exception);
   if (p == (const ConfigureInfo *) NULL)
     return((char **) NULL);
-  configure_semaphore=AcquireSemaphoreInfo(configure_semaphore);
+  AcquireSemaphoreInfo(&configure_semaphore);
   RelinquishSemaphoreInfo(configure_semaphore);
   options=(char **) AcquireMagickMemory((size_t)
     (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(*options));
   if (options == (char **) NULL)
     return((char **) NULL);
-  configure_semaphore=AcquireSemaphoreInfo(configure_semaphore);
+  AcquireSemaphoreInfo(&configure_semaphore);
   ResetLinkedListIterator(configure_list);
   p=(const ConfigureInfo *) GetNextValueInLinkedList(configure_list);
   for (i=0; p != (const ConfigureInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
         (GlobExpression(p->name,pattern) != MagickFalse))
-      options[i++]=ConstantString(AcquireString(p->name));
+      options[i++]=ConstantString(p->name);
     p=(const ConfigureInfo *) GetNextValueInLinkedList(configure_list);
   }
   RelinquishSemaphoreInfo(configure_semaphore);
@@ -450,7 +446,6 @@ MagickExport char **GetConfigureList(const char *pattern,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
   ExceptionInfo *exception)
@@ -486,7 +481,7 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",element,filename);
         (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),
           "Searching for configure file: \"%s\"",path);
-        xml=FileToStringInfo(path);
+        xml=ConfigureFileToStringInfo(path);
         if (xml != (StringInfo *) NULL)
           (void) AppendValueToLinkedList(options,xml);
         element=(const char *) GetNextValueInLinkedList(paths);
@@ -502,6 +497,7 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
     if (blob != (char *) NULL)
       {
         xml=StringToStringInfo(blob);
+        (void) CopyMagickString(xml->path,filename,MaxTextExtent);
         (void) AppendValueToLinkedList(options,xml);
         blob=(char *) RelinquishMagickMemory(blob);
       }
@@ -539,7 +535,6 @@ MagickExport LinkedListInfo *GetConfigureOptions(const char *filename,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
   ExceptionInfo *exception)
@@ -556,46 +551,47 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
   (void) CopyMagickString(path,filename,MaxTextExtent);
   paths=NewLinkedList(0);
   {
-    const char
+    char
       *configure_path;
 
-    register char
-      *q;
-
-    register const char
-      *p;
-
     /*
       Search $MAGICK_CONFIGURE_PATH.
     */
-    configure_path=getenv("MAGICK_CONFIGURE_PATH");
-    if (configure_path != (const char *) NULL)
-      for (p=configure_path-1; p != (char *) NULL; )
+    configure_path=GetEnvironmentValue("MAGICK_CONFIGURE_PATH");
+    if (configure_path != (char *) NULL)
       {
-        (void) CopyMagickString(path,p+1,MaxTextExtent);
-        q=strchr(path,DirectoryListSeparator);
-        if (q != (char *) NULL)
-          *q='\0';
-        q=path+strlen(path)-1;
-        if ((q >= path) && (*q != *DirectorySeparator))
-          (void) ConcatenateMagickString(path,DirectorySeparator,
-            MaxTextExtent);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
-        p=strchr(p+1,DirectoryListSeparator);
+        register char
+          *p,
+          *q;
+
+        for (p=configure_path-1; p != (char *) NULL; )
+        {
+          (void) CopyMagickString(path,p+1,MaxTextExtent);
+          q=strchr(path,DirectoryListSeparator);
+          if (q != (char *) NULL)
+            *q='\0';
+          q=path+strlen(path)-1;
+          if ((q >= path) && (*q != *DirectorySeparator))
+            (void) ConcatenateMagickString(path,DirectorySeparator,
+              MaxTextExtent);
+          (void) AppendValueToLinkedList(paths,ConstantString(path));
+          p=strchr(p+1,DirectoryListSeparator);
+        }
+        configure_path=(char *) RelinquishMagickMemory(configure_path);
       }
   }
 #if defined(UseInstalledMagick)
 #if defined(MagickLibConfigPath)
-  (void) AppendValueToLinkedList(paths,AcquireString(MagickLibConfigPath));
+  (void) AppendValueToLinkedList(paths,ConstantString(MagickLibConfigPath));
 #endif
 #if defined(MagickShareConfigPath)
-  (void) AppendValueToLinkedList(paths,AcquireString(MagickShareConfigPath));
+  (void) AppendValueToLinkedList(paths,ConstantString(MagickShareConfigPath));
 #endif
 #if defined(MagickDocumentPath)
-  (void) AppendValueToLinkedList(paths,AcquireString(MagickDocumentPath));
+  (void) AppendValueToLinkedList(paths,ConstantString(MagickDocumentPath));
 #endif
 #if defined(MagickSharePath)
-  (void) AppendValueToLinkedList(paths,AcquireString(MagickSharePath));
+  (void) AppendValueToLinkedList(paths,ConstantString(MagickSharePath));
 #endif
 #if defined(__WINDOWS__) && !(defined(MagickLibConfigPath) || defined(MagickShareConfigPath))
   {
@@ -612,33 +608,34 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
       {
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",key_value,
           DirectorySeparator);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
       }
   }
 #endif
 #else
   {
-    const char
+    char
       *home;
 
     /*
       Search under MAGICK_HOME.
     */
-    home=getenv("MAGICK_HOME");
-    if (home != (const char *) NULL)
+    home=GetEnvironmentValue("MAGICK_HOME");
+    if (home != (char *) NULL)
       {
 #if !defined(POSIX)
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",home,
           DirectorySeparator);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
 #else
         (void) FormatMagickString(path,MaxTextExtent,"%s/lib/%s/",home,
           MagickLibConfigSubDir);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
         (void) FormatMagickString(path,MaxTextExtent,"%s/share/%s/",home,
           MagickShareConfigSubDir);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
 #endif
+        home=(char *) RelinquishMagickMemory(home);
       }
     }
   if (*GetClientPath() != '\0')
@@ -646,7 +643,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
 #if !defined(POSIX)
       (void) FormatMagickString(path,MaxTextExtent,"%s%s",GetClientPath(),
         DirectorySeparator);
-      (void) AppendValueToLinkedList(paths,AcquireString(path));
+      (void) AppendValueToLinkedList(paths,ConstantString(path));
 #else
       char
         prefix[MaxTextExtent];
@@ -658,26 +655,29 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
       ChopPathComponents(prefix,1);
       (void) FormatMagickString(path,MaxTextExtent,"%s/lib/%s/",prefix,
         MagickLibConfigSubDir);
-      (void) AppendValueToLinkedList(paths,AcquireString(path));
+      (void) AppendValueToLinkedList(paths,ConstantString(path));
       (void) FormatMagickString(path,MaxTextExtent,"%s/share/%s/",prefix,
         MagickShareConfigSubDir);
-      (void) AppendValueToLinkedList(paths,AcquireString(path));
+      (void) AppendValueToLinkedList(paths,ConstantString(path));
 #endif
     }
 #endif
   {
-    const char
+    char
       *home;
 
-    home=getenv("HOME");
-    if (home != (const char *) NULL)
+    home=GetEnvironmentValue("HOME");
+    if (home == (char *) NULL)
+      home=GetEnvironmentValue("USERPROFILE");
+    if (home != (char *) NULL)
       {
         /*
           Search $HOME/.magick.
         */
         (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",home,
           *home == '/' ? "/.magick" : "",DirectorySeparator);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
+        home=(char *) RelinquishMagickMemory(home);
       }
   }
 #if defined(__WINDOWS__)
@@ -698,7 +698,7 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
         element=(char *) RemoveElementByValueFromLinkedList(paths,path);
         if (element != (char *) NULL)
           element=(char *) RelinquishMagickMemory(element);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
       }
     if (NTGetModulePath("Magick.dll",module_path) != MagickFalse)
       {
@@ -707,17 +707,17 @@ MagickExport LinkedListInfo *GetConfigurePaths(const char *filename,
         */
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",module_path,
           DirectorySeparator);
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
         (void) FormatMagickString(path,MaxTextExtent,"%s%s",module_path,
           "\\inc\\lib\\auto\\Image\\Magick\\");
-        (void) AppendValueToLinkedList(paths,AcquireString(path));
+        (void) AppendValueToLinkedList(paths,ConstantString(path));
       }
   }
 #endif
   /*
     Search current directory.
   */
-  (void) AppendValueToLinkedList(paths,AcquireString(""));
+  (void) AppendValueToLinkedList(paths,ConstantString(""));
   return(paths);
 }
 
@@ -778,7 +778,7 @@ static MagickBooleanType InitializeConfigureList(ExceptionInfo *exception)
   if ((configure_list == (LinkedListInfo *) NULL) &&
       (instantiate_configure == MagickFalse))
     {
-      configure_semaphore=AcquireSemaphoreInfo(configure_semaphore);
+      AcquireSemaphoreInfo(&configure_semaphore);
       if ((configure_list == (LinkedListInfo *) NULL) &&
           (instantiate_configure == MagickFalse))
         {
@@ -813,7 +813,6 @@ static MagickBooleanType InitializeConfigureList(ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType ListConfigureInfo(FILE *file,
   ExceptionInfo *exception)
@@ -903,30 +902,31 @@ MagickExport MagickBooleanType ListConfigureInfo(FILE *file,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
   const unsigned long depth,ExceptionInfo *exception)
 {
-  char
-    keyword[MaxTextExtent],
-    *q,
-    *token;
+  const char
+    *attribute;
 
   ConfigureInfo
     *configure_info = (ConfigureInfo *) NULL;
 
-  MagickStatusType
+  MagickBooleanType
     status;
 
-  size_t
-    length;
+  XMLTreeInfo
+    *configure,
+    *configure_map,
+    *include;
 
   /*
     Load the configure map file.
   */
   (void) LogMagickEvent(ConfigureEvent,GetMagickModule(),
-    "Loading configure file \"%s\" ...",filename);
+    "Loading configure map \"%s\" ...",filename);
+  if (xml == (const char *) NULL)
+    return(MagickFalse);
   if (configure_list == (LinkedListInfo *) NULL)
     {
       configure_list=NewLinkedList(0);
@@ -937,136 +937,74 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
           return(MagickFalse);
         }
     }
+  configure_map=NewXMLTree(xml,exception);
+  if (configure_map == (XMLTreeInfo *) NULL)
+    return(MagickFalse);
   status=MagickTrue;
-  if (xml == (char *) NULL)
-    xml=AcquireString(ConfigureMap);
-  token=AcquireString((char *) xml);
-  for (q=(char *) xml; *q != '\0'; )
+  include=GetXMLTreeChild(configure_map,"include");
+  while (include != (XMLTreeInfo *) NULL)
   {
     /*
-      Interpret XML.
+      Process include element.
     */
-    GetMagickToken(q,&q,token);
-    if (*token == '\0')
-      break;
-    (void) CopyMagickString(keyword,token,MaxTextExtent);
-    if (LocaleNCompare(keyword,"<!--",4) == 0)
+    attribute=GetXMLTreeAttribute(include,"file");
+    if (attribute != (const char *) NULL)
       {
-        /*
-          Comment element.
-        */
-        while ((LocaleNCompare(q,"->",2) != 0) && (*q != '\0'))
-          GetMagickToken(q,&q,token);
-        continue;
-      }
-    if (LocaleCompare(keyword,"<include") == 0)
-      {
-        /*
-          Include element.
-        */
-        while (((*token != '/') && (*(token+1) != '>')) && (*q != '\0'))
-        {
-          (void) CopyMagickString(keyword,token,MaxTextExtent);
-          GetMagickToken(q,&q,token);
-          if (*token != '=')
-            continue;
-          GetMagickToken(q,&q,token);
-          if (LocaleCompare(keyword,"file") == 0)
-            {
-              if (depth > 200)
-                (void) ThrowMagickException(exception,GetMagickModule(),
-                  ConfigureError,"IncludeElementNestedTooDeeply","`%s'",token);
-              else
-                {
-                  char
-                    path[MaxTextExtent],
-                    *xml;
-
-                  GetPathComponent(filename,HeadPath,path);
-                  if (*path != '\0')
-                    (void) ConcatenateMagickString(path,DirectorySeparator,
-                      MaxTextExtent);
-                  (void) ConcatenateMagickString(path,token,MaxTextExtent);
-                  xml=(char *) FileToBlob(path,&length,exception);
-                  status|=LoadConfigureList(xml,path,depth+1,exception);
-                  xml=(char *) RelinquishMagickMemory(xml);
-                }
-            }
-        }
-        continue;
-      }
-    if (LocaleCompare(keyword,"<configure") == 0)
-      {
-        /*
-          Allocate memory for the configure list.
-        */
-        configure_info=(ConfigureInfo *)
-          AcquireMagickMemory(sizeof(*configure_info));
-        if (configure_info == (ConfigureInfo *) NULL)
-          ThrowMagickFatalException(ResourceLimitFatalError,
-            "MemoryAllocationFailed",filename);
-        (void) ResetMagickMemory(configure_info,0,sizeof(*configure_info));
-        configure_info->path=ConstantString(AcquireString(filename));
-        configure_info->signature=MagickSignature;
-        continue;
-      }
-    if (configure_info == (ConfigureInfo *) NULL)
-      continue;
-    if (LocaleCompare(keyword,"/>") == 0)
-      {
-        status=AppendValueToLinkedList(configure_list,configure_info);
-        if (status == MagickFalse)
+        if (depth > 200)
           (void) ThrowMagickException(exception,GetMagickModule(),
-            ResourceLimitError,"MemoryAllocationFailed","`%s'",
-            configure_info->name);
-        configure_info=(ConfigureInfo *) NULL;
-      }
-    GetMagickToken(q,(char **) NULL,token);
-    if (*token != '=')
-      continue;
-    GetMagickToken(q,&q,token);
-    GetMagickToken(q,&q,token);
-    switch (*keyword)
-    {
-      case 'N':
-      case 'n':
-      {
-        if (LocaleCompare((char *) keyword,"name") == 0)
+            ConfigureError,"IncludeElementNestedTooDeeply","`%s'",filename);
+        else
           {
-            configure_info->name=ConstantString(AcquireString(token));
-            break;
+            char
+              path[MaxTextExtent],
+              *xml;
+
+            GetPathComponent(filename,HeadPath,path);
+            if (*path != '\0')
+              (void) ConcatenateMagickString(path,DirectorySeparator,
+                MaxTextExtent);
+            (void) ConcatenateMagickString(path,attribute,MaxTextExtent);
+            xml=FileToString(path,~0,exception);
+            status=LoadConfigureList(xml,path,depth+1,exception);
+            xml=(char *) RelinquishMagickMemory(xml);
           }
-        break;
       }
-      case 'S':
-      case 's':
-      {
-        if (LocaleCompare((char *) keyword,"stealth") == 0)
-          {
-            configure_info->stealth=(MagickBooleanType)
-              (LocaleCompare(token,"True") == 0);
-            break;
-          }
-        break;
-      }
-      case 'V':
-      case 'v':
-      {
-        if (LocaleCompare((char *) keyword,"value") == 0)
-          {
-            configure_info->value=ConstantString(AcquireString(token));
-            break;
-          }
-        break;
-      }
-      default:
-        break;
-    }
+    include=GetNextXMLTreeTag(include);
   }
-  token=(char *) RelinquishMagickMemory(token);
-  if (configure_list == (LinkedListInfo *) NULL)
-    return(MagickFalse);
-  return(status != 0 ? MagickTrue : MagickFalse);
+  configure=GetXMLTreeChild(configure_map,"configure");
+  while (configure != (XMLTreeInfo *) NULL)
+  {
+    const char
+      *attribute;
+
+    /*
+      Process configure element.
+    */
+    configure_info=(ConfigureInfo *) AcquireMagickMemory(
+      sizeof(*configure_info));
+    if (configure_info == (ConfigureInfo *) NULL)
+      ThrowMagickFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed",filename);
+    (void) ResetMagickMemory(configure_info,0,sizeof(*configure_info));
+    configure_info->path=ConstantString(filename);
+    configure_info->signature=MagickSignature;
+    attribute=GetXMLTreeAttribute(configure,"name");
+    if (attribute != (const char *) NULL)
+      configure_info->name=ConstantString(attribute);
+    attribute=GetXMLTreeAttribute(configure,"stealth");
+    if (attribute != (const char *) NULL)
+      configure_info->stealth=IsMagickTrue(attribute);
+    attribute=GetXMLTreeAttribute(configure,"value");
+    if (attribute != (const char *) NULL)
+      configure_info->value=ConstantString(attribute);
+    status=AppendValueToLinkedList(configure_list,configure_info);
+    if (status == MagickFalse)
+      (void) ThrowMagickException(exception,GetMagickModule(),
+        ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
+    configure=GetNextXMLTreeTag(configure);
+  }
+  configure_map=DestroyXMLTree(configure_map);
+  return(status);
 }
 
 /*
@@ -1094,14 +1032,13 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 static MagickBooleanType LoadConfigureLists(const char *filename,
   ExceptionInfo *exception)
 {
-  char
-    path[MaxTextExtent];
-
+#if defined(UseEmbeddableMagick)
+  return(LoadConfigureList(ConfigureMap,"built-in",0,exception));
+#else
   const StringInfo
     *option;
 
@@ -1112,12 +1049,10 @@ static MagickBooleanType LoadConfigureLists(const char *filename,
     status;
 
   status=MagickFalse;
-  *path='\0';
   options=GetConfigureOptions(filename,exception);
   option=(const StringInfo *) GetNextValueInLinkedList(options);
   while (option != (const StringInfo *) NULL)
   {
-    (void) CopyMagickString(path,option->path,MaxTextExtent);
     status|=LoadConfigureList((const char *) option->datum,option->path,0,
       exception);
     option=(const StringInfo *) GetNextValueInLinkedList(options);
@@ -1125,10 +1060,7 @@ static MagickBooleanType LoadConfigureLists(const char *filename,
   options=DestroyConfigureOptions(options);
   if ((configure_list == (LinkedListInfo *) NULL) ||
       (IsLinkedListEmpty(configure_list) != MagickFalse))
-    {
-      (void) ThrowMagickException(exception,GetMagickModule(),ConfigureWarning,
-        "UnableToOpenConfigureFile","`%s'",path);
-      status|=LoadConfigureList(ConfigureMap,"built-in",0,exception);
-    }
+    status|=LoadConfigureList(ConfigureMap,"built-in",0,exception);
   return(status != 0 ? MagickTrue : MagickFalse);
+#endif
 }
