@@ -40,7 +40,6 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/exception.h"
@@ -58,6 +57,8 @@
 #include "magick/monitor.h"
 #include "magick/option.h"
 #include "magick/pixel.h"
+#include "magick/profile.h"
+#include "magick/property.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
 #include "magick/semaphore.h"
@@ -151,7 +152,7 @@ MagickExport Image *ConstituteImage(const unsigned long columns,
     ThrowImageException(OptionError,"NonZeroWidthAndHeightRequired");
   image->columns=columns;
   image->rows=rows;
-  SetImageBackgroundColor(image);
+  (void) SetImageBackgroundColor(image);
   status=ImportImagePixels(image,0,0,columns,rows,map,storage,pixels);
   if (status == MagickFalse)
     {
@@ -197,7 +198,7 @@ MagickExport void DestroyConstitute(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  PingImage() returns all the attributes of an image or image sequence
+%  PingImage() returns all the properties of an image or image sequence
 %  except for the pixels.  It is much faster and consumes far less memory
 %  than ReadImage().  On failure, a NULL image is returned and exception
 %  describes the reason for the failure.
@@ -300,9 +301,6 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
   const DelegateInfo
     *delegate_info;
 
-  const ImageAttribute
-    *attribute;
-
   const MagickInfo
     *magick_info;
 
@@ -384,10 +382,10 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
   if ((magick_info != (const MagickInfo *) NULL) &&
       (GetMagickDecoder(magick_info) != (DecoderHandler *) NULL))
     {
-      if (GetMagickThreadSupport(magick_info) == MagickFalse)
+      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
       image=GetMagickDecoder(magick_info)(read_info,exception);
-      if (GetMagickThreadSupport(magick_info) == MagickFalse)
+      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
   else
@@ -447,10 +445,10 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
           read_info=DestroyImageInfo(read_info);
           return((Image *) NULL);
         }
-      if (GetMagickThreadSupport(magick_info) == MagickFalse)
+      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
       image=(Image *) (GetMagickDecoder(magick_info))(read_info,exception);
-      if (GetMagickThreadSupport(magick_info) == MagickFalse)
+      if ((GetMagickThreadSupport(magick_info) & DecoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
   if (read_info->temporary != MagickFalse)
@@ -513,100 +511,57 @@ MagickExport Image *ReadImage(const ImageInfo *image_info,
       next->magick_columns=next->columns;
     if (next->magick_rows == 0)
       next->magick_rows=next->rows;
-    attribute=GetImageAttribute(next,"EXIF:Orientation");
-    if ((attribute != (const ImageAttribute *) NULL) &&
-        (attribute->value != (char *) NULL))
+    value=GetImageProperty(next,"EXIF:Orientation");
+    if (value != (char *) NULL)
       {
-        next->orientation=(OrientationType) atol(attribute->value);
-        (void) DeleteImageAttribute(next,"EXIF:Orientation");
+        next->orientation=(OrientationType) atol(value);
+        (void) DeleteImageProperty(next,"EXIF:Orientation");
       }
-    attribute=GetImageAttribute(next,"EXIF:XResolution");
-    if ((attribute != (const ImageAttribute *) NULL) &&
-        (attribute->value != (char *) NULL))
+    value=GetImageProperty(next,"EXIF:XResolution");
+    if (value != (char *) NULL)
       {
         geometry_info.rho=next->x_resolution;
         geometry_info.sigma=1.0;
-        flags=ParseGeometry(attribute->value,&geometry_info);
+        flags=ParseGeometry(value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->x_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) DeleteImageAttribute(next,"EXIF:XResolution");
+        (void) DeleteImageProperty(next,"EXIF:XResolution");
       }
-    attribute=GetImageAttribute(next,"EXIF:YResolution");
-    if ((attribute != (const ImageAttribute *) NULL) &&
-        (attribute->value != (char *) NULL))
+    value=GetImageProperty(next,"EXIF:YResolution");
+    if (value != (char *) NULL)
       {
         geometry_info.rho=next->y_resolution;
         geometry_info.sigma=1.0;
-        flags=ParseGeometry(attribute->value,&geometry_info);
+        flags=ParseGeometry(value,&geometry_info);
         if (geometry_info.sigma != 0)
           next->y_resolution=geometry_info.rho/geometry_info.sigma;
-        (void) DeleteImageAttribute(next,"EXIF:YResolution");
+        (void) DeleteImageProperty(next,"EXIF:YResolution");
       }
-    attribute=GetImageAttribute(next,"EXIF:ResolutionUnit");
-    if ((attribute != (const ImageAttribute *) NULL) &&
-        (attribute->value != (char *) NULL))
+    value=GetImageProperty(next,"EXIF:ResolutionUnit");
+    if (value != (char *) NULL)
       {
-        switch (atoi(attribute->value))
-        {
-          case 2: next->units=PixelsPerInchResolution; break;
-          case 3: next->units=PixelsPerCentimeterResolution; break;
-          default: next->units=UndefinedResolution; break;
-        }
-        (void) DeleteImageAttribute(next,"EXIF:ResolutionUnit");
+        next->units=(ResolutionType) (atoi(value)-1);
+        (void) DeleteImageProperty(next,"EXIF:ResolutionUnit");
       }
-    (void) SyncImageOptions(image_info,next);
-    value=GetImageOption(read_info,"comment");
-    if (value != (const char *) NULL)
+    value=GetImageProperty(next,"EXIF:ColorSpace");
+    if (LocaleCompare(value,"1") != 0)
       {
-        (void) DeleteImageAttribute(next,"comment");
-        (void) SetImageAttribute(next,"comment",value);
+        (void) CreatesRGBImageProfile(next);
+        (void) DeleteImageProperty(next,"EXIF:ColorSpace");
       }
-    value=GetImageOption(read_info,"delay");
-    if (value != (const char *) NULL)
+    value=GetImageProperty(next,"EXIF:InteroperabilityIndex");
+    if (LocaleCompare(value,"R98.") != 0)
       {
-        flags=ParseGeometry(value,&geometry_info);
-        if ((flags & GreaterValue) != 0)
-          {
-            if (next->delay > (unsigned long) (geometry_info.rho+0.5))
-              next->delay=(unsigned long) (geometry_info.rho+0.5);
-          }
-        else
-          if ((flags & LessValue) != 0)
-            {
-              if (next->delay < (unsigned long) (geometry_info.rho+0.5))
-                next->ticks_per_second=(unsigned long)
-                  (geometry_info.sigma+0.5);
-            }
-          else
-            next->delay=(unsigned long) (geometry_info.rho+0.5);
-        if ((flags & SigmaValue) != 0)
-          next->ticks_per_second=(unsigned long) (geometry_info.sigma+0.5);
-      }
-    value=GetImageOption(read_info,"dispose");
-    if (value != (const char *) NULL)
-      next->dispose=(DisposeType) ParseMagickOption(MagickDisposeOptions,
-        MagickFalse,value);
-    value=GetImageOption(read_info,"label");
-    if (value != (const char *) NULL)
-      {
-        (void) DeleteImageAttribute(next,"label");
-        (void) SetImageAttribute(next,"label",value);
+        (void) CreatesRGBImageProfile(next);
+        (void) DeleteImageProperty(next,"EXIF:InteroperabilityIndex");
       }
     if (next->page.width == 0)
       next->page.width=next->columns;
     if (next->page.height == 0)
       next->page.height=next->rows;
-    value=GetImageOption(read_info,"page");
-    if ((value != (const char *) NULL) &&
-        (LocaleCompare(next->magick,"TEXT") != 0))
-      {
-        char
-          *geometry;
-
-        geometry=GetPageGeometry(value);
-        flags=ParseAbsoluteGeometry(geometry,&next->page);
-        geometry=(char *) RelinquishMagickMemory(geometry);
-      }
+    (void) SyncImageOptions(read_info,next);
+    if (LocaleCompare(next->magick,"TEXT") == 0)
+      (void) ParseAbsoluteGeometry("0x0+0+0",&next->page);
     if ((read_info->extract != (char *) NULL) &&
         (read_info->stream == (StreamHandler) NULL))
       {
@@ -829,7 +784,6 @@ MagickExport Image *ReadInlineImage(const ImageInfo *image_info,
 %
 %    o image: The image.
 %
-%
 */
 
 static void SyncImageInfo(const ImageInfo *image_info,Image *image,
@@ -910,6 +864,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
     }
   (void) CopyMagickString(filename,image->filename,MaxTextExtent);
   SyncImageInfo(write_info,image,&sans_exception);
+  SyncImageProfiles(image);
   if ((GetPreviousImageInList(image) == (Image *) NULL) &&
       (GetNextImageInList(image) == (Image *) NULL) &&
       (write_info->page == (char *) NULL) &&
@@ -967,10 +922,10 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       /*
         Call appropriate image writer based on image type.
       */
-      if (GetMagickThreadSupport(magick_info) == MagickFalse)
+      if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
         AcquireSemaphoreInfo(&constitute_semaphore);
       status=GetMagickEncoder(magick_info)(write_info,image);
-      if (GetMagickThreadSupport(magick_info) == MagickFalse)
+      if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
         RelinquishSemaphoreInfo(constitute_semaphore);
     }
   else
@@ -1011,10 +966,10 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
               /*
                 Call appropriate image writer based on image type.
               */
-              if (GetMagickThreadSupport(magick_info) == MagickFalse)
+              if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
                 AcquireSemaphoreInfo(&constitute_semaphore);
               status=GetMagickEncoder(magick_info)(write_info,image);
-              if (GetMagickThreadSupport(magick_info) == MagickFalse)
+              if ((GetMagickThreadSupport(magick_info) & EncoderThreadSupport) == 0)
                 RelinquishSemaphoreInfo(constitute_semaphore);
             }
         }
