@@ -46,7 +46,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/client.h"
 #include "magick/configure.h"
@@ -275,7 +275,7 @@ MagickExport char *GetDelegateCommand(const ImageInfo *image_info,Image *image,
         decode ? decode : encode);
       return((char *) NULL);
     }
-  command=InterpretImageAttributes(image_info,image,commands[0]);
+  command=InterpretImageProperties(image_info,image,commands[0]);
   if (command == (char *) NULL)
     (void) ThrowMagickException(exception,GetMagickModule(),ResourceLimitError,
       "MemoryAllocationFailed","`%s'",commands[0]);
@@ -884,7 +884,7 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
             "UnableToCreateTemporaryFile",image_info->zero);
           return(MagickFalse);
         }
-      magick=InterpretImageAttributes(image_info,image,decode != (char *) NULL ?
+      magick=InterpretImageProperties(image_info,image,decode != (char *) NULL ?
         delegate_info->encode : delegate_info->decode);
       if (magick == (char *) NULL)
         {
@@ -972,7 +972,7 @@ MagickExport MagickBooleanType InvokeDelegate(ImageInfo *image_info,
           "UnableToCreateTemporaryFile",input_filename);
         break;
       }
-    command=InterpretImageAttributes(image_info,image,commands[i]);
+    command=InterpretImageProperties(image_info,image,commands[i]);
     if (command == (char *) NULL)
       break;
     /*
