@@ -1323,6 +1323,114 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%     L i n e a r S t r e t c h I m a g e                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  The LinearStretchImage() discards any pixels below the black point and
+%  above the white point and levels the remaining pixels.
+%
+%  The format of the LinearStretchImage method is:
+%
+%      MagickBooleanType LinearStretchImage(Image *image,
+%        const double black_point,const double white_point)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o black_point: The black point.
+%
+%    o white_point: The white point.
+%
+*/
+MagickExport MagickBooleanType LinearStretchImage(Image *image,
+  const double black_point,const double white_point)
+{
+#define LinearStretchImageTag  "LinearStretch/Image"
+
+  long
+    black,
+    white,
+    y;
+
+  MagickBooleanType
+    status;
+
+  MagickRealType
+    *histogram,
+    intensity;
+
+  MagickSizeType
+    number_pixels;
+
+  register const PixelPacket
+    *p;
+
+  register long
+    x;
+
+  SegmentInfo
+    threshold_intensity;
+
+  /*
+    Allocate histogram and linear map.
+  */
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  histogram=(MagickRealType *) AcquireMagickMemory((MaxMap+1)*
+    sizeof(*histogram));
+  if (histogram == (MagickRealType *) NULL)
+    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
+      image->filename);
+  /*
+    Form histogram.
+  */
+  ResetMagickMemory(histogram,0,(MaxMap+1)*sizeof(*histogram));
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
+    if (p == (const PixelPacket *) NULL)
+      break;
+    for (x=(long) image->columns-1; x >= 0; x--)
+    {
+      histogram[ScaleQuantumToMap(PixelIntensityToQuantum(p))]++;
+      p++;
+    }
+  }
+  /*
+    Find the histogram boundaries by locating the 0.1 percent levels.
+  */
+  number_pixels=(MagickSizeType) image->columns*image->rows;
+  threshold_intensity.x1=QuantumScale*black_point*number_pixels/100;
+  threshold_intensity.x2=QuantumScale*white_point*number_pixels/100;
+  (void) ResetMagickMemory(&intensity,0,sizeof(intensity));
+  for (black=0; black < (long) MaxMap; black++)
+  {
+    intensity+=histogram[black];
+    if (intensity > threshold_intensity.x1)
+      break;
+  }
+  (void) ResetMagickMemory(&intensity,0,sizeof(intensity));
+  for (white=(long) MaxRange(QuantumRange); white != 0; white--)
+  {
+    intensity+=histogram[white];
+    if (intensity > threshold_intensity.x2)
+      break;
+  }
+  histogram=(MagickRealType *) RelinquishMagickMemory(histogram);
+  status=LevelImageChannel(image,DefaultChannels,(double) black,(double) white,
+    1.0);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %     M o d u l a t e I m a g e                                               %
 %                                                                             %
 %                                                                             %
