@@ -171,10 +171,10 @@ MagickExport void ClearMagickException(ExceptionInfo *exception)
     exception->exceptions);
   while (p != (ExceptionInfo *) NULL)
   {
-    DestroyExceptionElement(p);
+    (void) DestroyExceptionElement(p);
     p=(ExceptionInfo *) RemoveLastElementFromLinkedList((LinkedListInfo *)
       exception->exceptions);
-	}
+  }
   exception->severity=UndefinedException;
   exception->reason=(char *) NULL;
   exception->description=(char *) NULL;
@@ -228,7 +228,7 @@ MagickExport void CatchException(ExceptionInfo *exception)
       exception->exceptions);
   }
   RelinquishSemaphoreInfo(exception->semaphore);
-	ClearMagickException(exception);
+  ClearMagickException(exception);
 }
 
 /*
@@ -605,7 +605,7 @@ MagickExport void InheritException(ExceptionInfo *exception,
     relative->exceptions);
   while (p != (const ExceptionInfo *) NULL)
   {
-    ThrowException(exception,p->severity,p->reason,p->description);
+    (void) ThrowException(exception,p->severity,p->reason,p->description);
     p=(const ExceptionInfo *) GetNextValueInLinkedList((LinkedListInfo *)
       relative->exceptions);
   }
@@ -958,7 +958,7 @@ MagickExport MagickBooleanType ThrowMagickExceptionList(
   if (n < 0)
     reason[MaxTextExtent-1]='\0';
   status=LogMagickEvent(ExceptionEvent,module,function,line,"%s",reason);
-  ThrowException(exception,severity,reason,(char *) NULL);
+  (void) ThrowException(exception,severity,reason,(char *) NULL);
   return(status);
 }
 
