@@ -813,18 +813,6 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
     case BilinearInterpolatePixel:
     default:
     {
-      delta.x=x-floor(x);
-      delta.y=y-floor(y);
-      if ((delta.x == 0.0) && (delta.y == 0.0))
-        {
-          p=AcquireCacheView(image_view,(long) x,(long) y,1,1,exception);
-          if (p == (const PixelPacket *) NULL)
-            return(pixel);
-          indexes=GetCacheViewIndexes(image_view);
-          GetMagickPixelPacket(image,pixels);
-          SetMagickPixelPacket(p,indexes,&pixel);
-          return(pixel);
-        }
       p=AcquireCacheView(image_view,(long) floor(x),(long) floor(y),2,2,
         exception);
       if (p == (const PixelPacket *) NULL)
@@ -846,26 +834,28 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
           }
         p++;
       }
-      gamma=(((1.0-delta.y)*((1.0-delta.x)*alpha[0]+delta.x*alpha[1])+
-        delta.y*((1.0-delta.x)*alpha[2]+delta.x*alpha[3])));
+      delta.x=x-floor(x);
+      delta.y=y-floor(y);
+      gamma=(((1.0-delta.y)*((1.0-delta.x)*alpha[0]+delta.x*alpha[1])+delta.y*
+        ((1.0-delta.x)*alpha[2]+delta.x*alpha[3])));
       gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
       pixel.red=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].red+delta.x*
         pixels[1].red)+delta.y*((1.0-delta.x)*pixels[2].red+delta.x*
         pixels[3].red));
-      pixel.green=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].green+
-        delta.x*pixels[1].green)+delta.y*((1.0-delta.x)*pixels[2].green+
+      pixel.green=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].green+delta.x*
+        pixels[1].green)+delta.y*((1.0-delta.x)*pixels[2].green+
         delta.x*pixels[3].green));
       pixel.blue=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].blue+delta.x*
         pixels[1].blue)+delta.y*((1.0-delta.x)*pixels[2].blue+delta.x*
         pixels[3].blue));
       if (image->matte != MagickFalse)
-        pixel.opacity=((1.0-delta.y)*((1.0-delta.x)*pixels[0].opacity+
-          delta.x*pixels[1].opacity)+delta.y*((1.0-delta.x)*
-          pixels[2].opacity+delta.x*pixels[3].opacity));
+        pixel.opacity=((1.0-delta.y)*((1.0-delta.x)*pixels[0].opacity+delta.x*
+          pixels[1].opacity)+delta.y*((1.0-delta.x)*pixels[2].opacity+delta.x*
+          pixels[3].opacity));
       if (image->colorspace == CMYKColorspace)
-        pixel.index=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].index+
-          delta.x*pixels[1].index)+delta.y*((1.0-delta.x)*pixels[2].index+
-          delta.x*pixels[3].index));
+        pixel.index=gamma*((1.0-delta.y)*((1.0-delta.x)*pixels[0].index+delta.x*
+          pixels[1].index)+delta.y*((1.0-delta.x)*pixels[2].index+delta.x*
+          pixels[3].index));
       break;
     }
     case FilterInterpolatePixel:
@@ -940,113 +930,141 @@ MagickExport MagickPixelPacket InterpolatePixelColor(const Image *image,
       delta.x=x-floor(x);
       delta.y=y-floor(y);
       luminance.x=MagickPixelLuminance(pixels+0)-MagickPixelLuminance(pixels+3);
-      luminance.y=MagickPixelLuminance(pixels+2)-MagickPixelLuminance(pixels+1);
-      if (AbsoluteValue(luminance.x) < AbsoluteValue(luminance.y))
+      luminance.y=MagickPixelLuminance(pixels+1)-MagickPixelLuminance(pixels+2);
+      if (AbsoluteValue(luminance.x) > AbsoluteValue(luminance.y))
+        {
+          if (delta.x <= (1.0-delta.y))
+            {
+              /*
+                Left.
+              */
+              gamma=(alpha[0]*(1.0-delta.x)*(1.0-delta.y)+alpha[2]*(1.0-
+                delta.x)*delta.y+alpha[3]*delta.x*(1.0-delta.y)+(alpha[2]+
+                alpha[3])/2.0*delta.x*delta.y);
+              gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
+              pixel.red=gamma*(pixels[0].red*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[2].red*(1.0-delta.x)*delta.y+pixels[3].red*delta.x*
+                (1.0-delta.y)+(pixels[2].red+pixels[3].red)/2.0*
+                delta.x*delta.y);
+              pixel.green=gamma*(pixels[0].green*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[2].green*(1.0-delta.x)*delta.y+pixels[3].green*delta.x*
+                (1.0-delta.y)+(pixels[2].green+pixels[3].green)/2.0*
+                delta.x*delta.y);
+              pixel.blue=gamma*(pixels[0].blue*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[2].blue*(1.0-delta.x)*delta.y+pixels[3].blue*delta.x*
+                (1.0-delta.y)+(pixels[2].blue+pixels[3].blue)/2.0*
+                delta.x*delta.y);
+              if (image->matte != MagickFalse)
+                pixel.opacity=gamma*(pixels[0].opacity*(1.0-delta.x)*(1.0-
+                  delta.y)+pixels[2].opacity*(1.0-delta.x)*delta.y+
+                  pixels[3].opacity*delta.x*(1.0-delta.y)+(pixels[2].opacity+
+                  pixels[3].opacity)/2.0*delta.x*delta.y);
+              if (image->colorspace == CMYKColorspace)
+                pixel.index=gamma*(pixels[0].index*(1.0-delta.x)*(1.0-delta.y)+
+                  pixels[2].index*(1.0-delta.x)*delta.y+pixels[3].index*delta.x*
+                  (1.0-delta.y)+(pixels[2].index+pixels[3].index)/2.0*
+                  delta.x*delta.y);
+            }
+          else
+            {
+              /*
+                Right.
+              */
+              gamma=(alpha[2]*(1.0-delta.x)*delta.y+alpha[1]*delta.x*delta.y+
+                alpha[3]*delta.x*(1.0-delta.y)+(alpha[2]+alpha[3])/2.0*
+                (1.0-delta.x)*(1.0-delta.y));
+              gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
+              pixel.red=gamma*(pixels[2].red*(1.0-delta.x)*delta.y+
+                pixels[1].red*delta.x*delta.y+pixels[3].red*delta.x*
+                (1.0-delta.y)+(pixels[2].red+pixels[3].red)/2.0*
+                (1.0-delta.x)*(1.0-delta.y));
+              pixel.green=gamma*(pixels[2].green*(1.0-delta.x)*delta.y+
+                pixels[1].green*delta.x*delta.y+pixels[3].green*delta.x*
+                (1.0-delta.y)+(pixels[2].green+pixels[3].green)/2.0*
+                (1.0-delta.x)*(1.0-delta.y));
+              pixel.blue=gamma*(pixels[2].blue*(1.0-delta.x)*delta.y+
+                pixels[1].blue*delta.x*delta.y+pixels[3].blue*delta.x*
+                (1.0-delta.y)+(pixels[2].blue+pixels[3].blue)/2.0*
+                (1.0-delta.x)*(1.0-delta.y));
+              if (image->matte != MagickFalse)
+                pixel.opacity=gamma*(pixels[2].opacity*(1.0-delta.x)*delta.y+
+                  pixels[1].opacity*delta.x*delta.y+pixels[3].opacity*delta.x*
+                  (1.0-delta.y)+(pixels[2].opacity+pixels[3].opacity)/2.0*
+                  (1.0-delta.x)*(1.0-delta.y));
+              if (image->colorspace == CMYKColorspace)
+                pixel.index=gamma*(pixels[2].index*(1.0-delta.x)*delta.y+
+                  pixels[1].index*delta.x*delta.y+pixels[3].index*delta.x*
+                  (1.0-delta.y)+(pixels[2].index+pixels[3].index)/2.0*
+                  (1.0-delta.x)*(1.0-delta.y));
+           }
+        }
+      else
         {
           if (delta.x <= delta.y)
             {
-              gamma=((1.0-delta.x)*(1.0-delta.y)*alpha[0]+(1.0-delta.x)*
-                delta.y*alpha[2]+delta.x*delta.y*alpha[3]+(alpha[0]+
-                alpha[3])/2.0*delta.x*(1.0-delta.y));
+              /*
+                Left.
+              */
+              gamma=(alpha[0]*(1.0-delta.x)*(1.0-delta.y)+alpha[2]*(1.0-
+                delta.x)*delta.y+alpha[1]*delta.x*delta.y+(alpha[0]+alpha[1])/
+                2.0*delta.x*(1.0-delta.y));
               gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-              pixel.red=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].red+(1.0-
-                delta.x)*delta.y*pixels[2].red+delta.x*delta.y*pixels[3].red+
-                (pixels[0].red+pixels[3].red)/2.0*delta.x*(1.0-delta.y);
-              pixel.green=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].green+
-                (1.0-delta.x)*delta.y*pixels[2].green+delta.x*delta.y*
-                pixels[3].green+(pixels[0].green+pixels[3].green)/2.0*delta.x*
-                (1.0-delta.y);
-              pixel.blue=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].blue+(1.0-
-                delta.x)*delta.y*pixels[2].blue+delta.x*delta.y*pixels[3].blue+
-                (pixels[0].blue+pixels[3].blue)/2.0*delta.x*(1.0-delta.y);
+              pixel.red=gamma*(pixels[0].red*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[2].red*(1.0-delta.x)*delta.y+pixels[1].red*
+                delta.x*delta.y+(pixels[0].red+pixels[1].red)/2.0*
+                delta.x*(1.0-delta.y));
+              pixel.green=gamma*(pixels[0].green*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[2].green*(1.0-delta.x)*delta.y+pixels[1].green*
+                delta.x*delta.y+(pixels[0].green+pixels[1].green)/2.0*
+                delta.x*(1.0-delta.y));
+              pixel.blue=gamma*(pixels[0].blue*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[2].blue*(1.0-delta.x)*delta.y+pixels[1].blue*
+                delta.x*delta.y+(pixels[0].blue+pixels[1].blue)/2.0*
+                delta.x*(1.0-delta.y));
               if (image->matte != MagickFalse)
-                pixel.opacity=((1.0-delta.x)*(1.0-delta.y)*pixels[0].opacity+
-                  (1.0-delta.x)*delta.y*pixels[2].opacity+delta.x*delta.y*
-                  pixels[3].opacity+(pixels[0].opacity+pixels[3].opacity)/2.0*
-                  delta.x*(1.0-delta.y));
+                pixel.opacity=gamma*(pixels[0].opacity*(1.0-delta.x)*(1.0-
+                  delta.y)+pixels[2].opacity*(1.0-delta.x)*delta.y+
+                  pixels[1].opacity*delta.x*delta.y+(pixels[0].opacity+
+                  pixels[1].opacity)/2.0*delta.x*(1.0-delta.y));
               if (image->colorspace == CMYKColorspace)
-                pixel.index=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].index+
-                  (1.0-delta.x)*delta.y*pixels[2].index+delta.x*delta.y*
-                  pixels[3].index+(pixels[0].index+pixels[3].index)/2.0*
-                  delta.x*(1.0-delta.y);
-              break;
+                pixel.index=gamma*(pixels[0].index*(1.0-delta.x)*(1.0-delta.y)+
+                  pixels[2].index*(1.0-delta.x)*delta.y+pixels[1].index*
+                  delta.x*delta.y+(pixels[0].index+pixels[1].index)/2.0*
+                  delta.x*(1.0-delta.y));
+            }
+          else
+            {
+              /*
+                Right.
+              */
+              gamma=(alpha[0]*(1.0-delta.x)*(1.0-delta.y)+alpha[1]*delta.x*
+                delta.y+alpha[3]*delta.x*(1.0-delta.y)+(alpha[0]+alpha[1])/2.0*
+                (1.0-delta.x)*delta.y);
+              gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
+              pixel.red=gamma*(pixels[0].red*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[1].red*delta.x*delta.y+pixels[3].red*delta.x*
+                (1.0-delta.y)+(pixels[0].red+pixels[1].red)/2.0*
+                (1.0-delta.x)*delta.y);
+              pixel.green=gamma*(pixels[0].green*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[1].green*delta.x*delta.y+pixels[3].green*delta.x*
+                (1.0-delta.y)+(pixels[0].green+pixels[1].green)/2.0*
+                (1.0-delta.x)*delta.y);
+              pixel.blue=gamma*(pixels[0].blue*(1.0-delta.x)*(1.0-delta.y)+
+                pixels[1].blue*delta.x*delta.y+pixels[3].blue*delta.x*
+                (1.0-delta.y)+(pixels[0].blue+pixels[1].blue)/2.0*
+                (1.0-delta.x)*delta.y);
+              if (image->matte != MagickFalse)
+                pixel.opacity=gamma*(pixels[0].opacity*(1.0-delta.x)*(1.0-
+                  delta.y)+pixels[1].opacity*delta.x*delta.y+pixels[3].opacity*
+                  delta.x*(1.0-delta.y)+(pixels[0].opacity+pixels[1].opacity)/
+                  2.0*(1.0-delta.x)*delta.y);
+              if (image->colorspace == CMYKColorspace)
+                pixel.index=gamma*(pixels[0].index*(1.0-delta.x)*(1.0-delta.y)+
+                  pixels[1].index*delta.x*delta.y+pixels[3].index*delta.x*
+                  (1.0-delta.y)+(pixels[0].index+pixels[1].index)/2.0*
+                  (1.0-delta.x)*delta.y);
             }
-          gamma=((1.0-delta.x)*(1.0-delta.y)*alpha[0]+delta.x*delta.y*
-            alpha[3]+delta.x*(1.0-delta.y)*alpha[1]+(alpha[0]+alpha[3])/2.0*
-            (1.0-delta.x)*delta.y);
-          gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-          pixel.red=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].red+delta.x*
-            delta.y*pixels[3].red+delta.x*(1.0-delta.y)*pixels[1].red+
-            (pixels[0].red+pixels[3].red)/2.0*(1.0-delta.x)*delta.y;
-          pixel.green=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].green+delta.x*
-            delta.y*pixels[3].green+delta.x*(1.0-delta.y)*pixels[1].green+
-            (pixels[0].green+pixels[3].green)/2.0*(1.0-delta.x)*delta.y;
-          pixel.blue=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].blue+
-            delta.x*delta.y*pixels[3].blue+delta.x*(1.0-delta.y)*
-            pixels[1].blue+(pixels[0].blue+pixels[3].blue)/2.0*(1.0-delta.x)*
-            delta.y;
-          if (image->matte != MagickFalse)
-            pixel.opacity=(1.0-delta.x)*(1.0-delta.y)*pixels[0].opacity+
-              delta.x*delta.y*pixels[3].opacity+delta.x*(1.0-delta.y)*
-              pixels[1].opacity+(pixels[0].opacity+pixels[3].opacity)/2.0*
-              (1.0-delta.x)*delta.y;
-          if (image->colorspace == CMYKColorspace)
-            pixel.index=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].index+
-              delta.x*delta.y*pixels[3].index+delta.x*(1.0-delta.y)*
-              pixels[1].index+(pixels[0].index+pixels[3].index)/2.0*(1.0-
-              delta.x)*delta.y;
-          break;
         }
-      if (delta.x <= (1.0-delta.y))
-        {
-          gamma=(1.0-delta.x)*(1.0-delta.y)*alpha[0]+(1.0-delta.x)*delta.y*
-            alpha[2]+delta.x*(1.0-delta.y)*alpha[1]+(alpha[1]+alpha[2])/2.0*
-            delta.x*delta.y;
-          gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-          pixel.red=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].red+(1.0-
-            delta.x)*delta.y*pixels[2].red+delta.x*(1.0-delta.y)*pixels[1].red+
-            (pixels[1].red+pixels[2].red)/2.0*delta.x*delta.y;
-          pixel.green=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].green+(1.0-
-            delta.x)*delta.y*pixels[2].green+delta.x*(1.0-delta.y)*
-            pixels[1].green+(pixels[1].green+pixels[2].green)/2.0*delta.x*
-            delta.y;
-          pixel.blue=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].blue+(1.0-
-            delta.x)*delta.y*pixels[2].blue+delta.x*(1.0-delta.y)*
-            pixels[1].blue+(pixels[1].blue+pixels[2].blue)/2.0*delta.x*delta.y;
-          if (image->matte != MagickFalse)
-            pixel.opacity=(1.0-delta.x)*(1.0-delta.y)*pixels[0].opacity+(1.0-
-              delta.x)*delta.y*pixels[2].opacity+delta.x*(1.0-delta.y)*
-              pixels[1].opacity+(pixels[1].opacity+pixels[2].opacity)/2.0*
-              delta.x*delta.y;
-          if (image->colorspace == CMYKColorspace)
-            pixel.index=gamma*(1.0-delta.x)*(1.0-delta.y)*pixels[0].index+(1.0-
-              delta.x)*delta.y*pixels[2].index+delta.x*(1.0-delta.y)*
-              pixels[1].index+(pixels[1].index+pixels[2].index)/2.0*delta.x*
-              delta.y;
-          break;
-        }
-      gamma=((1.0-delta.x)*delta.y*alpha[2]+delta.x*delta.y*alpha[3]+
-        delta.x*(1.0-delta.y)*alpha[1]+(alpha[1]+alpha[2])/2.0*(1.0-delta.x)*
-        (1.0-delta.y));
-      gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
-      pixel.red=gamma*(1.0-delta.x)*delta.y*pixels[2].red+delta.x*delta.y*
-        pixels[3].red+delta.x*(1.0-delta.y)*pixels[1].red+(pixels[1].red+
-        pixels[2].red)/2.0*(1.0-delta.x)*(1.0-delta.y);
-      pixel.green=gamma*(1.0-delta.x)*delta.y*pixels[2].green+delta.x*delta.y*
-        pixels[3].green+delta.x*(1.0-delta.y)*pixels[1].green+(pixels[1].green+
-        pixels[2].green)/2.0*(1.0-delta.x)*(1.0-delta.y);
-      pixel.blue=gamma*(1.0-delta.x)*delta.y*pixels[2].blue+delta.x*delta.y*
-        pixels[3].blue+delta.x*(1.0-delta.y)*pixels[1].blue+(pixels[1].blue+
-        pixels[2].blue)/2.0*(1.0-delta.x)*(1.0-delta.y);
-      if (image->matte != MagickFalse)
-        pixel.opacity=(1.0-delta.x)*delta.y*pixels[2].opacity+delta.x*delta.y*
-          pixels[3].opacity+delta.x*(1.0-delta.y)*pixels[1].opacity+
-          (pixels[1].opacity+pixels[2].opacity)/2.0*(1.0-delta.x)*(1.0-
-          delta.y);
-      if (image->colorspace == CMYKColorspace)
-        pixel.index=gamma*(1.0-delta.x)*delta.y*pixels[2].index+delta.x*delta.y*
-          pixels[3].index+delta.x*(1.0-delta.y)*pixels[1].index+
-          (pixels[1].index+pixels[2].index)/2.0*(1.0-delta.x)*(1.0-delta.y);
       break;
     }
     case NearestNeighborInterpolatePixel:
