@@ -530,7 +530,7 @@ MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
   double
     value;
 
-  int
+  MagickStatusType
     flags;
 
   register long
@@ -862,7 +862,7 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
         geometry_info;
 
       MagickStatusType
-        flags;
+        status;
 
       PointInfo
         scale;
@@ -870,12 +870,14 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
       /*
         Geometry is a percentage of the image size.
       */
-      flags=ParseGeometry(geometry,&geometry_info);
+      if (image->gravity != UndefinedGravity)
+        flags|=XValue | YValue;
+      status=ParseGeometry(geometry,&geometry_info);
       scale.x=geometry_info.rho;
-      if ((flags & RhoValue) == 0)
+      if ((status & RhoValue) == 0)
         scale.x=100.0;
       scale.y=geometry_info.sigma;
-      if ((flags & SigmaValue) == 0)
+      if ((status & SigmaValue) == 0)
         scale.y=scale.x;
       region_info->width=(unsigned long) ((scale.x*image->columns/100.0)+0.5);
       region_info->height=(unsigned long) ((scale.y*image->rows/100.0)+0.5);
@@ -1151,6 +1153,11 @@ MagickExport MagickStatusType ParsePageGeometry(Image *image,
         OptionError,"InvalidGeometry","`%s'",geometry);
       return(flags);
     }
+  if ((flags & PercentValue) != 0)
+    {
+      region_info->width=image->columns;
+      region_info->height=image->rows;
+    }
   flags=ParseMetaGeometry(geometry,&region_info->x,&region_info->y,
     &region_info->width,&region_info->height);
   return(flags);
