@@ -44,7 +44,6 @@
 */
 #include "magick/studio.h"
 #include "magick/annotate.h"
-#include "magick/attribute.h"
 #include "magick/blob.h"
 #include "magick/client.h"
 #include "magick/coder.h"
@@ -75,6 +74,7 @@
 #include "magick/pixel-private.h"
 #include "magick/prepress.h"
 #include "magick/profile.h"
+#include "magick/property.h"
 #include "magick/quantize.h"
 #include "magick/quantum.h"
 #include "magick/random_.h"
@@ -139,8 +139,9 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
   ColorspaceType
     colorspace;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *property,
+    *value;
 
   const MagickInfo
     *magick_info;
@@ -236,7 +237,6 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     Display verbose info about the image.
   */
   type=GetImageType(image,&image->exception);
-  (void) SetImageType(image,type);
   (void) SignatureImage(image);
   image->total_colors=GetNumberColors(image,(FILE *) NULL,&image->exception);
     (void) fprintf(file,"Image: %s\n",image->filename);
@@ -258,7 +258,8 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
       GetMagickDescription(magick_info));
   (void) fprintf(file,"  Class: %s\n",
     MagickOptionToMnemonic(MagickClassOptions,(long) image->storage_class));
-  (void) fprintf(file,"  Geometry: %lux%lu\n",image->columns,image->rows);
+  (void) fprintf(file,"  Geometry: %lux%lu%+ld%+ld\n",image->columns,
+    image->rows,image->origin.x,image->origin.y);
   if ((image->magick_columns != 0) || (image->magick_rows != 0))
     if ((image->magick_columns != image->columns) ||
         (image->magick_rows != image->rows))
@@ -474,7 +475,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           SetMagickPixelPacket(p,indexes+x,&pixel);
           (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickFalse,
             tuple,&image->exception);
-          (void) fprintf(file,"  Alpha: %-45.45s  ",tuple);
+          (void) fprintf(file,"  Alpha: %s  ",tuple);
           (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickTrue,
             tuple,&image->exception);
           (void) fprintf(file,"  %s\n",tuple);
@@ -510,7 +511,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
               color,&image->exception);
             (void) QueryMagickColorname(image,&pixel,SVGCompliance,MagickTrue,
               hex,&image->exception);
-            (void) fprintf(file,"  %8ld: %-45.45s %s\n",i,color,hex);
+            (void) fprintf(file,"  %8ld: %s %s\n",i,hex,color);
             p++;
           }
         }
@@ -641,46 +642,50 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         (void) fprintf(file," %lux%lu %s\n",tile->magick_columns,
           tile->magick_rows,tile->magick);
         (void) SignatureImage(tile);
-        ResetImageAttributeIterator(tile);
-        attribute=GetNextImageAttribute(tile);
-        while (attribute != (const ImageAttribute *) NULL)
+        ResetImagePropertyIterator(tile);
+        property=GetNextImageProperty(tile);
+        while (property != (const char *) NULL)
         {
-          if (*attribute->key == '[')
+          if (*property == '[')
             continue;
-          (void) fprintf(file,"  %s:\n",attribute->key);
-          (void) fprintf(file,"%s\n",attribute->value);
-          attribute=GetNextImageAttribute(tile);
+          (void) fprintf(file,"  %s:\n",property);
+          value=GetImageProperty(tile,property);
+          if (value != (const char *) NULL)
+             (void) fprintf(file,"%s\n",value);
+          property=GetNextImageProperty(tile);
         }
         tile=DestroyImage(tile);
       }
       image_info=DestroyImageInfo(image_info);
     }
   /*
-    Display image attributes.
+    Display image properties.
   */
-  ResetImageAttributeIterator(image);
-  attribute=GetNextImageAttribute(image);
-  while (attribute != (const ImageAttribute *) NULL)
+  ResetImagePropertyIterator(image);
+  property=GetNextImageProperty(image);
+  while (property != (const char *) NULL)
   {
-    if (*attribute->key != '[')
+    if (*property != '[')
       {
-        (void) fprintf(file,"  %c",toupper(*attribute->key));
-        if (strlen(attribute->key) > 1)
-          (void) fprintf(file,"%s: ",attribute->key+1);
-        if (strlen(attribute->value) > 80)
+        (void) fprintf(file,"  %c",toupper(*property));
+        if (strlen(property) > 1)
+          (void) fprintf(file,"%s: ",property+1);
+        if (strlen(property) > 80)
           (void) fputc('\n',file);
-        (void) fprintf(file,"%s\n",attribute->value);
+        value=GetImageProperty(image,property);
+        if (value != (const char *) NULL)
+          (void) fprintf(file,"%s\n",value);
       }
-    attribute=GetNextImageAttribute(image);
+    property=GetNextImageProperty(image);
   }
   (void) FormatMagickString(key,MaxTextExtent,"8BIM:1999,2998:#1");
-  attribute=GetImageAttribute(image,key);
-  if (attribute != (const ImageAttribute *) NULL)
+  value=GetImageProperty(image,key);
+  if (value != (const char *) NULL)
     {
       (void) fprintf(file,"  Clipping path: ");
-      if (strlen(attribute->value) > 80)
+      if (strlen(value) > 80)
         (void) fputc('\n',file);
-      (void) fprintf(file,"%s\n",attribute->value);
+      (void) fprintf(file,"%s\n",value);
     }
   if (image->profiles != (void *) NULL)
     {
@@ -699,23 +704,28 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         profile=GetImageProfile(image,name);
         if (profile == (StringInfo *) NULL)
           continue;
-        (void) fprintf(file,"  Profile-%s: %lu bytes\n",name,
-          (unsigned long) profile->length);
+        (void) fprintf(file,"  Profile-%s: %lu bytes\n",name,(unsigned long)
+          profile->length);
         PrintStringInfo(file,name,profile);
         if (LocaleCompare(name,"exif") == 0)
           {
-            attribute=GetImageAttribute(image,"EXIF:*");
-            if (attribute != (const ImageAttribute *) NULL)
+            char
+              *value;
+
+            value=InterpretImageProperties((ImageInfo *) NULL,image,
+              "%[exif:*]");
+            if (value != (char *) NULL)
               {
                 char
                   **values;
 
-                register char
-                  *p;
-
-                values=StringToList(attribute->value);
+                values=StringToList(value);
+                value=(char *) RelinquishMagickMemory(value);
                 if (values != (char **) NULL)
                   {
+                    register char
+                      *p;
+
                     for (x=0; values[x] != (char *) NULL; x++)
                     {
                       (void) fprintf(file,"    ");
