@@ -590,7 +590,7 @@ static MagickBooleanType InitializeLocaleList(ExceptionInfo *exception)
             *p;
 
           locale=(char *) NULL;
-          p=setlocale(LC_CTYPE,0);
+          p=setlocale(LC_CTYPE,(const char *) NULL);
           if (p != (const char *) NULL)
             locale=ConstantString(p);
           if (locale == (char *) NULL)
