@@ -697,7 +697,7 @@ MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
           (void) fprintf(file," ");
       }
     (void) fprintf(file,"%9lu  ",log_info[i]->generations);
-    FormatMagickSize(MegabytesToBytes(log_info[i]->limit),limit);
+    (void) FormatMagickSize(MegabytesToBytes(log_info[i]->limit),limit);
     (void) fprintf(file,"%8s  ",limit);
     if (log_info[i]->format != (char *) NULL)
       (void) fprintf(file,"%s",log_info[i]->format);
@@ -750,7 +750,7 @@ static unsigned long GetLogThreadId(void)
 #if defined(__WINDOWS__)
   return((unsigned long) GetCurrentThreadId());
 #endif
-  return(0);
+  return((unsigned long) getpid());
 }
 
 static char *TranslateEvent(const LogEventType magick_unused(type),
@@ -764,12 +764,12 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
     elapsed_time,
     user_time;
 
-  LogInfo
-    *log_info;
-
   ExceptionInfo
     exception;
 
+  LogInfo
+    *log_info;
+
   register char
     *q;
 
@@ -777,7 +777,7 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
     *p;
 
   size_t
-    length;
+    extent;
 
   struct tm
     *time_meridian;
@@ -792,9 +792,10 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
   time_meridian=localtime(&seconds);
   elapsed_time=GetElapsedTime(&log_info->timer);
   user_time=GetUserTime(&log_info->timer);
-  text=AcquireString((char *) NULL);
+  text=AcquireString(event);
   if (log_info->format == (char *) NULL)
     return(text);
+  extent=strlen(event)+MaxTextExtent;
   if (LocaleCompare(log_info->format,"xml") == 0)
     {
       char
@@ -803,8 +804,8 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
       /*
         Translate event in "XML" format.
       */
-      (void) FormatMagickTime(seconds,MaxTextExtent,timestamp);
-      (void) FormatMagickString(text,MaxTextExtent,
+      (void) FormatMagickTime(seconds,extent,timestamp);
+      (void) FormatMagickString(text,extent,
         "<entry>\n"
         "  <timestamp>%s</timestamp>\n"
         "  <elapsed-time>%ld:%02ld</elapsed-time>\n"
@@ -824,15 +825,14 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
   /*
     Translate event in "human readable" format.
   */
-  length=MaxTextExtent;
   q=text;
   for (p=log_info->format; *p != '\0'; p++)
   {
     *q='\0';
-    if ((size_t) (q-text+MaxTextExtent) >= length)
+    if ((size_t) (q-text+MaxTextExtent) >= extent)
       {
-        length<<=1;
-        text=(char *) ResizeMagickMemory(text,(length+MaxTextExtent)*
+        extent+=MaxTextExtent;
+        text=(char *) ResizeMagickMemory(text,(extent+MaxTextExtent)*
           sizeof(*text));
         if (text == (char *) NULL)
           return((char *) NULL);
@@ -880,42 +880,43 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
     {
       case 'c':
       {
-        (void) CopyMagickString(q,GetClientName(),MaxTextExtent);
+        (void) CopyMagickString(q,GetClientName(),extent);
         q+=strlen(GetClientName());
         break;
       }
       case 'd':
       {
-        (void) CopyMagickString(q,domain,MaxTextExtent);
+        (void) CopyMagickString(q,domain,extent);
         q+=strlen(domain);
         break;
       }
       case 'e':
       {
-        (void) CopyMagickString(q,event,MaxTextExtent);
+        (void) CopyMagickString(q,event,extent);
         q+=strlen(event);
         break;
       }
       case 'f':
       {
-        (void) CopyMagickString(q,function,MaxTextExtent);
+        (void) CopyMagickString(q,function,extent);
         q+=strlen(function);
         break;
       }
       case 'g':
       {
         if (log_info->generations == 0)
-          (void) CopyMagickString(q,"0",MaxTextExtent);
-        else
-          (void) FormatMagickString(q,MaxTextExtent,"%lu",
-            log_info->generation % log_info->generations);
-        while (*q != '\0')
-          q++;
+          {
+            (void) CopyMagickString(q,"0",extent);
+            q++;
+            break;
+          }
+        q+=FormatMagickString(q,extent,"%lu",log_info->generation %
+          log_info->generations);
         break;
       }
       case 'l':
       {
-        q+=FormatMagickString(q,MaxTextExtent,"%lu",line);
+        q+=FormatMagickString(q,extent,"%lu",line);
         break;
       }
       case 'm':
@@ -929,40 +930,40 @@ static char *TranslateEvent(const LogEventType magick_unused(type),
               p++;
               break;
             }
-        (void) CopyMagickString(q,p,MaxTextExtent);
+        (void) CopyMagickString(q,p,extent);
         q+=strlen(p);
         break;
       }
       case 'n':
       {
-        (void) CopyMagickString(q,GetLogName(),MaxTextExtent);
+        (void) CopyMagickString(q,GetLogName(),extent);
         q+=strlen(GetLogName());
         break;
       }
       case 'p':
       {
-        q+=FormatMagickString(q,MaxTextExtent,"%ld",(long) getpid());
+        q+=FormatMagickString(q,extent,"%ld",(long) getpid());
         break;
       }
       case 'r':
       {
-        q+=FormatMagickString(q,MaxTextExtent,"%ld:%02ld",
-          (long) (elapsed_time/60.0),(long) ceil(fmod(elapsed_time,60.0)));
+        q+=FormatMagickString(q,extent,"%ld:%02ld",(long)
+          (elapsed_time/60.0),(long) ceil(fmod(elapsed_time,60.0)));
         break;
       }
       case 't':
       {
-        q+=FormatMagickTime(seconds,MaxTextExtent,q);
+        q+=FormatMagickTime(seconds,extent,q);
         break;
       }
       case 'u':
       {
-        q+=FormatMagickString(q,MaxTextExtent,"%0.3fu",user_time);
+        q+=FormatMagickString(q,extent,"%0.3fu",user_time);
         break;
       }
       case 'v':
       {
-        (void) CopyMagickString(q,MagickLibVersionText,MaxTextExtent);
+        (void) CopyMagickString(q,MagickLibVersionText,extent);
         q+=strlen(MagickLibVersionText);
         break;
       }
@@ -988,30 +989,30 @@ static char *TranslateFilename(const LogInfo *log_info)
   char
     *filename;
 
-  size_t
-    length;
-
   register char
     *q;
 
   register const char
     *p;
 
+  size_t
+    extent;
+
   /*
     Translate event in "human readable" format.
   */
   assert(log_info != (LogInfo *) NULL);
   assert(log_info->filename != (char *) NULL);
   filename=AcquireString((char *) NULL);
-  length=MaxTextExtent;
+  extent=MaxTextExtent;
   q=filename;
   for (p=log_info->filename; *p != '\0'; p++)
   {
     *q='\0';
-    if ((size_t) (q-filename+MaxTextExtent) >= length)
+    if ((size_t) (q-filename+MaxTextExtent) >= extent)
       {
-        length<<=1;
-        filename=(char *) ResizeMagickMemory(filename,(length+MaxTextExtent)*
+        extent+=MaxTextExtent;
+        filename=(char *) ResizeMagickMemory(filename,(extent+MaxTextExtent)*
           sizeof(*filename));
         if (filename == (char *) NULL)
           return((char *) NULL);
@@ -1037,35 +1038,36 @@ static char *TranslateFilename(const LogInfo *log_info)
     {
       case 'c':
       {
-        (void) CopyMagickString(q,GetClientName(),MaxTextExtent);
+        (void) CopyMagickString(q,GetClientName(),extent);
         q+=strlen(GetClientName());
         break;
       }
       case 'g':
       {
         if (log_info->generations == 0)
-          (void) CopyMagickString(q,"0",MaxTextExtent);
-        else
-          (void) FormatMagickString(q,MaxTextExtent,"%lu",
-            log_info->generation % log_info->generations);
-        while (*q != '\0')
-          q++;
+          {
+            (void) CopyMagickString(q,"0",extent);
+            q++;
+            break;
+          }
+        q+=FormatMagickString(q,extent,"%lu",log_info->generation %
+          log_info->generations);
         break;
       }
       case 'n':
       {
-        (void) CopyMagickString(q,GetLogName(),MaxTextExtent);
+        (void) CopyMagickString(q,GetLogName(),extent);
         q+=strlen(GetLogName());
         break;
       }
       case 'p':
       {
-        q+=FormatMagickString(q,MaxTextExtent,"%ld",(long) getpid());
+        q+=FormatMagickString(q,extent,"%ld",(long) getpid());
         break;
       }
       case 'v':
       {
-        (void) CopyMagickString(q,MagickLibVersionText,MaxTextExtent);
+        (void) CopyMagickString(q,MagickLibVersionText,extent);
         q+=strlen(MagickLibVersionText);
         break;
       }
@@ -1176,7 +1178,7 @@ MagickBooleanType LogMagickEventList(const LogEventType type,const char *module,
               return(MagickFalse);
             }
           log_info->append=IsAccessible(filename);
-          log_info->file=fopen(filename,"ab");
+          log_info->file=MagickOpenStream(filename,"ab");
           filename=(char  *) RelinquishMagickMemory(filename);
           if (log_info->file == (FILE *) NULL)
             {
