@@ -57,6 +57,7 @@
 #include "magick/magic.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/mime.h"
 #include "magick/module.h"
 #if defined(__WINDOWS__)
 # include "magick/nt-feature.h"
@@ -140,6 +141,7 @@ MagickExport void DestroyMagick(void)
   DestroyXResources();
 #endif
   DestroyConstitute();
+  DestroyMimeList();
   DestroyConfigureList();
   DestroyTypeList();
   DestroyColorList();
@@ -744,14 +746,14 @@ MagickExport MagickBooleanType GetMagickSeekableStream(
 %
 %  The format of the GetMagickThreadSupport method is:
 %
-%      MagickBooleanType GetMagickThreadSupport(const MagickInfo *magick_info)
+%      MagickStatusType GetMagickThreadSupport(const MagickInfo *magick_info)
 %
 %  A description of each parameter follows:
 %
 %    o magick_info:  The magick info.
 %
 */
-MagickExport MagickBooleanType GetMagickThreadSupport(
+MagickExport MagickStatusType GetMagickThreadSupport(
   const MagickInfo *magick_info)
 {
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
@@ -784,11 +786,6 @@ MagickExport MagickBooleanType GetMagickThreadSupport(
 %
 */
 
-static void MagickExitHandler(void)
-{
-  DestroyMagick();
-}
-
 static SignalHandler *SetMagickSignalHandler(int signal_number,
   SignalHandler *handler)
 {
@@ -881,7 +878,7 @@ MagickExport void InitializeMagick(const char *path)
     filename[MaxTextExtent];
 
   ExceptionInfo
-    exception;
+    *exception;
 
   time_t
     seconds;
@@ -889,8 +886,6 @@ MagickExport void InitializeMagick(const char *path)
   /*
     Initialize the Magick environment.
   */
-  (void) setlocale(LC_ALL,"");
-  (void) setlocale(LC_NUMERIC,"C");
   seconds=time((time_t *) NULL);
   srand((unsigned int) (seconds+getpid()));
   InitializeSemaphore();
@@ -968,14 +963,13 @@ MagickExport void InitializeMagick(const char *path)
   if (signal_handlers[SIGXFSZ] == (SignalHandler *) NULL)
     signal_handlers[SIGXFSZ]=RegisterMagickSignalHandler(SIGXFSZ);
 #endif
-  (void) atexit(MagickExitHandler);
   /*
     Initialize magick resources.
   */
   InitializeMagickResources();
-  GetExceptionInfo(&exception);
-  (void) GetMagickInfo((char *) NULL,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  (void) GetMagickInfo((char *) NULL,exception);
+  exception=DestroyExceptionInfo(exception);
 }
 
 /*
@@ -1190,6 +1184,7 @@ MagickExport MagickBooleanType ListMagickInfo(FILE *file,
   magick_info=GetMagickInfoList("*",&number_formats,exception);
   if (magick_info == (const MagickInfo **) NULL)
     return(MagickFalse);
+  ClearMagickException(exception);
 #if !defined(SupportMagickModules)
   (void) fprintf(file,"   Format  Mode  Description\n");
 #else
@@ -1279,89 +1274,6 @@ MagickExport MagickBooleanType IsMagickInstantiated(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-+  M a g i c k T o M i m e                                                    %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  MagickToMime() returns the officially registered (or de facto) MIME
-%  media-type corresponding to a magick string.  If there is no registered
-%  media-type, then the string "image/x-magick" (all lower case) is returned.
-%  The returned string must be deallocated by the user.
-%
-%  The format of the MagickToMime method is:
-%
-%      char *MagickToMime(const char *magick)
-%
-%  A description of each parameter follows.
-%
-%   o  magick:  ImageMagick format specification "magick" tag.
-%
-%
-*/
-MagickExport char *MagickToMime(const char *magick)
-{
-  typedef struct _MediaType
-  {
-    const char
-      *magick,
-      *media;
-  } MediaType;
-
-  char
-    media[MaxTextExtent];
-
-  MediaType
-    *entry;
-
-  static MediaType
-    MediaTypes[] =
-    {
-      { "avi",   "video/avi" },
-      { "cgm",   "image/cgm;Version=4;ProfileId=WebCGM" }, /* W3 WebCGM */
-      { "dcm",   "application/dicom" }, /* Incomplete.  See RFC 3240 */
-      { "epdf",  "application/pdf" },
-      { "epi",   "application/postscript" },
-      { "eps",   "application/postscript" },
-      { "eps2",  "application/postscript" },
-      { "eps3",  "application/postscript" },
-      { "epsf",  "application/postscript" },
-      { "ept",   "application/postscript" },
-      { "fax",   "image/g3fax" },
-      { "fpx",   "image/vnd.fpx" },
-      { "g3",    "image/g3fax" },
-      { "gif",   "image/gif" },
-      { "gif87", "image/gif" },
-      { "jpg",   "image/jpeg" },
-      { "jpeg",  "image/jpeg" },
-      { "mng",   "video/x-mng" },
-      { "mpeg",  "video/mpeg" },
-      { "png",   "image/png" },
-      { "pdf",   "application/pdf" },
-      { "ps",    "application/postscript" },
-      { "ps2",   "application/postscript" },
-      { "ps3",   "application/postscript" },
-      { "svg",   "image/svg+xml" },
-      { "tif",   "image/tiff" },
-      { "tiff",  "image/tiff" },
-      { "wbmp",  "image/vnd.wap.wbmp" },
-      { (char *) NULL, (char *) NULL }
-    };
-
-  for (entry=MediaTypes; entry->magick != (char *) NULL; entry++)
-    if (LocaleCompare(entry->magick,magick) == 0)
-      return(AcquireString(entry->media));
-  (void) FormatMagickString(media,MaxTextExtent,"image/x-%s",magick);
-  LocaleLower(media+8);
-  return(AcquireString(media));
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +   R e g i s t e r M a g i c k I n f o                                       %
 %                                                                             %
 %                                                                             %
@@ -1447,7 +1359,8 @@ MagickExport MagickInfo *SetMagickInfo(const char *name)
   magick_info->name=ConstantString(name);
   magick_info->adjoin=MagickTrue;
   magick_info->blob_support=MagickTrue;
-  magick_info->thread_support=MagickTrue;
+  magick_info->thread_support=(MagickStatusType) (DecoderThreadSupport |
+    EncoderThreadSupport);
   magick_info->signature=MagickSignature;
   return(magick_info);
 }
