@@ -17,7 +17,7 @@
 %                                 July 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -43,7 +43,7 @@
 %  sizes.  It is based on the paper, "Fast Memory Allocation using Lazy Fits."
 %  written by Yoo C. Chung.
 %
-%  By default, ANSI memory methods are called (e.g. malloc()).  Use the
+%  By default, ANSI memory methods are called (e.g. malloc).  Use the
 %  custom memory allocator by defining UseEmbeddableMagick.  The custom memory
 %  allocator has the advantage of using memory-mapped heap allocation which
 %  permits the virtual memory to be returned to the system in all cases, unlike
@@ -247,7 +247,7 @@ static void *AcquireBlock(size_t size)
   /*
     Find free block.
   */
-  size=(size_t) (size+sizeof(size_t)+6*sizeof(size_t)-1) & -(4*sizeof(size_t));
+  size=(size_t) (size+sizeof(size_t)+6*sizeof(size_t)-1) & -(4U*sizeof(size_t));
   i=AllocationPolicy(size);
   block=memory_info.blocks[i];
   while ((block != (void *) NULL) && (SizeOfBlock(block) < size))
@@ -322,14 +322,14 @@ MagickExport void *AcquireMagickMemory(const size_t size)
 #else
   if (free_segments == (DataSegmentInfo *) NULL)
     {
-      memory_semaphore=AcquireSemaphoreInfo(memory_semaphore);
+      AcquireSemaphoreInfo(&memory_semaphore);
       if (free_segments == (DataSegmentInfo *) NULL)
         {
           register long
             i;
 
           assert(2*sizeof(size_t) > (size_t) (~SizeMask));
-          (void) ResetMagickMemory(&memory_info,0,sizeof(MemoryInfo));
+          (void) ResetMagickMemory(&memory_info,0,sizeof(memory_info));
           memory_info.allocation=SegmentSize;
           memory_info.blocks[MaxBlocks]=(void *) (-1);
           for (i=0; i < MaxSegments; i++)
@@ -344,7 +344,7 @@ MagickExport void *AcquireMagickMemory(const size_t size)
         }
       RelinquishSemaphoreInfo(memory_semaphore);
     }
-  memory_semaphore=AcquireSemaphoreInfo(memory_semaphore);
+  AcquireSemaphoreInfo(&memory_semaphore);
   memory=AcquireBlock(size == 0 ? 1UL : size);
   if (memory == (void *) NULL)
     {
@@ -430,7 +430,7 @@ MagickExport void DestroyMagickMemory(void)
   register long
     i;
 
-  memory_semaphore=AcquireSemaphoreInfo(memory_semaphore);
+  AcquireSemaphoreInfo(&memory_semaphore);
   RelinquishSemaphoreInfo(memory_semaphore);
   for (i=0; i < (long) memory_info.number_segments; i++)
     if (memory_info.segments[i]->mapped == MagickFalse)
@@ -439,7 +439,7 @@ MagickExport void DestroyMagickMemory(void)
       (void) UnmapBlob(memory_info.segments[i]->allocation,
         memory_info.segments[i]->length);
   free_segments=(DataSegmentInfo *) NULL;
-  (void) ResetMagickMemory(&memory_info,0,sizeof(MemoryInfo));
+  (void) ResetMagickMemory(&memory_info,0,sizeof(memory_info));
   memory_semaphore=DestroySemaphoreInfo(memory_semaphore);
 #endif
 }
@@ -461,7 +461,7 @@ MagickExport void DestroyMagickMemory(void)
 %
 %  The format of the ExpandHeap method is:
 %
-%      MagickBooleanType ExpandHeap(const size_t size)
+%      MagickBooleanType ExpandHeap(size_t size)
 %
 %  A description of each parameter follows:
 %
@@ -552,7 +552,7 @@ MagickExport void *RelinquishMagickMemory(void *memory)
 #else
   assert((SizeOfBlock(memory) % (4*sizeof(size_t))) == 0);
   assert((*BlockHeader(NextBlock(memory)) & PreviousBlockBit) != 0);
-  memory_semaphore=AcquireSemaphoreInfo(memory_semaphore);
+  AcquireSemaphoreInfo(&memory_semaphore);
   if ((*BlockHeader(memory) & PreviousBlockBit) == 0)
     {
       void
@@ -677,8 +677,10 @@ MagickExport void *ResizeMagickMemory(void *memory,const size_t size)
     return(AcquireMagickMemory(size));
 #if !defined(UseEmbeddableMagick)
   block=realloc(memory,size == 0 ? 1UL : size);
+  if (block == (void *) NULL)
+    memory=RelinquishMagickMemory(memory);
 #else
-  memory_semaphore=AcquireSemaphoreInfo(memory_semaphore);
+  AcquireSemaphoreInfo(&memory_semaphore);
   block=ResizeBlock(memory,size == 0 ? 1UL : size);
   if (block == (void *) NULL)
     {
@@ -687,14 +689,13 @@ MagickExport void *ResizeMagickMemory(void *memory,const size_t size)
           RelinquishSemaphoreInfo(memory_semaphore);
           memory=RelinquishMagickMemory(memory);
           ThrowMagickFatalException(ResourceLimitFatalError,
-            "MemoryAllocationFailed",strerror(errno));
+            "MemoryAllocationFailed",GetExceptionMessage(errno));
         }
       block=ResizeBlock(memory,size == 0 ? 1UL : size);
       assert(block != (void *) NULL);
     }
   RelinquishSemaphoreInfo(memory_semaphore);
+  memory=RelinquishMagickMemory(memory);
 #endif
-  if (block == (void *) NULL)
-    memory=RelinquishMagickMemory(memory);
   return(block);
 }
