@@ -42,7 +42,6 @@
 */
 #include "magick/studio.h"
 #include "magick/annotate.h"
-#include "magick/attribute.h"
 #include "magick/client.h"
 #include "magick/color.h"
 #include "magick/composite.h"
@@ -53,6 +52,7 @@
 #include "magick/enhance.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
+#include "magick/fx.h"
 #include "magick/gem.h"
 #include "magick/geometry.h"
 #include "magick/image.h"
@@ -63,6 +63,7 @@
 #include "magick/montage.h"
 #include "magick/option.h"
 #include "magick/quantize.h"
+#include "magick/property.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
@@ -95,7 +96,6 @@
 %
 %    o montage_info: The montage info.
 %
-%
 */
 MagickExport MontageInfo *CloneMontageInfo(const ImageInfo *image_info,
   const MontageInfo *montage_info)
@@ -242,28 +242,30 @@ MagickExport void GetMontageInfo(const ImageInfo *image_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   M o n t a g e I m a g e s                                                 %
+%   M o n t a g e I m a g e L i s t                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Montageimages() is a layout manager that lets you tile one or more
+%  MontageImageList() is a layout manager that lets you tile one or more
 %  thumbnails across an image canvas.
 %
-%  The format of the MontageImages method is:
+%  The format of the MontageImageList method is:
 %
-%      Image *MontageImages(const Image *images,const MontageInfo *montage_info,
+%      Image *MontageImageList(const ImageInfo *image_info,
+%        const MontageInfo *montage_info,Image *images,
 %        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o images: Specifies a pointer to an array of Image structures.
+%    o image_info: The image info.
 %
 %    o montage_info: Specifies a pointer to a MontageInfo structure.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o images: Specifies a pointer to an array of Image structures.
 %
+%    o exception: Return any errors or warnings in this structure.
 %
 */
 
@@ -305,6 +307,21 @@ static int SceneCompare(const void *x,const void *y)
 
 MagickExport Image *MontageImages(const Image *images,
   const MontageInfo *montage_info,ExceptionInfo *exception)
+{
+  Image
+    *montage_image;
+
+  ImageInfo
+    *image_info;
+
+  image_info=AcquireImageInfo();
+  montage_image=MontageImageList(image_info,montage_info,images,exception);
+  image_info=DestroyImageInfo(image_info);
+  return(montage_image);
+}
+
+MagickExport Image *MontageImageList(const ImageInfo *image_info,
+  const MontageInfo *montage_info,const Image *images,ExceptionInfo *exception)
 {
 #define MontageImageTag  "Montage/Image"
 #define TileImageTag  "Tile/Image"
@@ -313,8 +330,8 @@ MagickExport Image *MontageImages(const Image *images,
     tile_geometry[MaxTextExtent],
     *title;
 
-  const ImageAttribute
-    *attribute;
+  const char
+    *value;
 
   DrawInfo
     *draw_info;
@@ -332,7 +349,7 @@ MagickExport Image *MontageImages(const Image *images,
     *thumbnail;
 
   ImageInfo
-    *image_info;
+    *clone_info;
 
   long
     x,
@@ -357,9 +374,6 @@ MagickExport Image *MontageImages(const Image *images,
   register long
     i;
 
-  register PixelPacket
-    *q;
-
   RectangleInfo
     bounds,
     geometry,
@@ -513,13 +527,14 @@ MagickExport Image *MontageImages(const Image *images,
   /*
     Initialize draw attributes.
   */
-  image_info=CloneImageInfo((ImageInfo *) NULL);
-  image_info->background_color=montage_info->background_color;
-  image_info->border_color=montage_info->border_color;
-  draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
+  clone_info=CloneImageInfo(image_info);
+  clone_info->background_color=montage_info->background_color;
+  clone_info->border_color=montage_info->border_color;
+  draw_info=CloneDrawInfo(clone_info,(DrawInfo *) NULL);
   if (montage_info->font != (char *) NULL)
     (void) CloneString(&draw_info->font,montage_info->font);
-  draw_info->pointsize=montage_info->pointsize;
+  if (montage_info->pointsize != 0.0)
+    draw_info->pointsize=montage_info->pointsize;
   draw_info->gravity=CenterGravity;
   draw_info->stroke=montage_info->stroke;
   draw_info->fill=montage_info->fill;
@@ -528,14 +543,14 @@ MagickExport Image *MontageImages(const Image *images,
   texture=NewImageList();
   if (montage_info->texture != (char *) NULL)
     {
-      (void) CopyMagickString(image_info->filename,montage_info->texture,
+      (void) CopyMagickString(clone_info->filename,montage_info->texture,
         MaxTextExtent);
-      texture=ReadImage(image_info,exception);
+      texture=ReadImage(clone_info,exception);
     }
   /*
     Determine the number of lines in an next label.
   */
-  title=InterpretImageAttributes(image_info,image_list[0],montage_info->title);
+  title=InterpretImageProperties(clone_info,image_list[0],montage_info->title);
   title_offset=0;
   if (montage_info->title != (char *) NULL)
     title_offset=(unsigned long) (2*(metrics.ascent-metrics.descent)*
@@ -543,17 +558,17 @@ MagickExport Image *MontageImages(const Image *images,
   number_lines=0;
   for (i=0; i < (long) number_images; i++)
   {
-    attribute=GetImageAttribute(image_list[i],"label");
-    if (attribute == (ImageAttribute *) NULL)
+    value=GetImageProperty(image_list[i],"Label");
+    if (value == (const char *) NULL)
       continue;
-    if (MultilineCensus(attribute->value) > number_lines)
-      number_lines=MultilineCensus(attribute->value);
+    if (MultilineCensus(value) > number_lines)
+      number_lines=MultilineCensus(value);
   }
   /*
     Allocate next structure.
   */
   tile_image=AllocateImage(NULL);
-  montage=AllocateImage(image_info);
+  montage=AllocateImage(clone_info);
   montage->scene=0;
   images_per_page=(number_images-1)/(tiles_per_row*tiles_per_column)+1;
   tiles=0;
@@ -611,7 +626,7 @@ MagickExport Image *MontageImages(const Image *images,
       MaxTextExtent);
     montage->columns=bounds.width;
     montage->rows=bounds.height;
-    SetImageBackgroundColor(montage);
+    (void) SetImageBackgroundColor(montage);
     /*
       Set montage geometry.
     */
@@ -746,10 +761,10 @@ MagickExport Image *MontageImages(const Image *images,
           extract_info=frame_info;
           extract_info.width=width+2*frame_info.width;
           extract_info.height=height+2*frame_info.height;
-          attribute=GetImageAttribute(image,"label");
-          if (attribute != (const ImageAttribute *) NULL)
+          value=GetImageProperty(image,"Label");
+          if (value != (const char *) NULL)
             extract_info.height+=(unsigned long) ((metrics.ascent-
-              metrics.descent+4)*MultilineCensus(attribute->value));
+              metrics.descent+4)*MultilineCensus(value));
           frame_image=FrameImage(image,&extract_info,exception);
           if (frame_image != (Image *) NULL)
             {
@@ -766,47 +781,27 @@ MagickExport Image *MontageImages(const Image *images,
           */
           if (montage_info->shadow != MagickFalse)
             {
-              register long
-                columns,
-                rows;
+              Image
+                *shadow_image;
 
               /*
-                Put a shadow under the tile to show depth.
+                Shadow image.
               */
-              for (rows=0; rows < (long) (image->rows-4); rows++)
-              {
-                q=GetImagePixels(montage,(long) (x_offset+x+image->columns),
-                  (long) (y_offset+y+rows+4),(unsigned long)
-                  Min(extract_info.x,4),1);
-                if (q == (PixelPacket *) NULL)
-                  break;
-                for (columns=0; columns < Min(extract_info.x,4); columns++)
+              (void) QueryColorDatabase("black",&image->background_color,
+                exception);
+              shadow_image=ShadowImage(image,80.0,2.0,5,5,exception);
+              if (shadow_image != (Image *) NULL)
                 {
-                  ModulateHSB(100.0,100.0,53.0,&q->red,&q->green,&q->blue);
-                  q++;
+                  InheritException(&shadow_image->exception,exception);
+                  (void) CompositeImage(shadow_image,OverCompositeOp,image,0,0);
+                  image=DestroyImage(image);
+                  image=shadow_image;
                 }
-                if (SyncImagePixels(montage) == MagickFalse)
-                  break;
-              }
-              for (rows=0; rows < (long) Min(extract_info.y,4); rows++)
-              {
-                q=GetImagePixels(montage,(long) (x_offset+x+Min(extract_info.x,
-                  4)),(long) (y_offset+y+image->rows+rows),image->columns,1);
-                if (q == (PixelPacket *) NULL)
-                  break;
-                for (columns=0; columns < (long) image->columns; columns++)
-                {
-                  ModulateHSB(100.0,100.0,53.0,&q->red,&q->green,&q->blue);
-                  q++;
-                }
-                if (SyncImagePixels(montage) == MagickFalse)
-                  break;
-              }
-            }
+          }
           (void) CompositeImage(montage,OverCompositeOp,image,x_offset+x,
             y_offset+y);
-          attribute=GetImageAttribute(image,"label");
-          if (attribute != (const ImageAttribute *) NULL)
+          value=GetImageProperty(image,"Label");
+          if (value != (const char *) NULL)
             {
               char
                 geometry[MaxTextExtent];
@@ -817,12 +812,12 @@ MagickExport Image *MontageImages(const Image *images,
               (void) FormatMagickString(geometry,MaxTextExtent,
                 "%lux%lu%+ld%+ld",(montage_info->frame ? image->columns :
                 width)-2*border_width,(unsigned long) (metrics.ascent-
-                metrics.descent+4)*MultilineCensus(attribute->value),x_offset+
+                metrics.descent+4)*MultilineCensus(value),x_offset+
                 border_width,(montage_info->frame ? y_offset+height+
                 border_width+4 : y_offset+extract_info.height+border_width+
                 (montage_info->shadow != MagickFalse ? 4 : 0)));
               (void) CloneString(&draw_info->geometry,geometry);
-              (void) CloneString(&draw_info->text,attribute->value);
+              (void) CloneString(&draw_info->text,value);
               (void) AnnotateImage(montage,draw_info);
             }
         }
@@ -852,7 +847,7 @@ MagickExport Image *MontageImages(const Image *images,
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,montage);
+        AllocateNextImage(clone_info,montage);
         if (GetNextImageInList(montage) == (Image *) NULL)
           {
             montage=DestroyImageList(montage);
@@ -868,7 +863,7 @@ MagickExport Image *MontageImages(const Image *images,
     texture=DestroyImage(texture);
   master_list=(Image **) RelinquishMagickMemory(master_list);
   draw_info=DestroyDrawInfo(draw_info);
-  image_info=DestroyImageInfo(image_info);
+  clone_info=DestroyImageInfo(clone_info);
   while (GetPreviousImageInList(montage) != (Image *) NULL)
     montage=GetPreviousImageInList(montage);
   return(montage);
