@@ -471,65 +471,6 @@ MagickExport int NTExitLibrary(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   N T F i l e T r u n c a t e                                               %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  NTFileTruncate() truncates a file to a specified length.
-%
-%  The format of the NTFileTruncate method is:
-%
-%      int NTFileTruncate(int file,off_t length)
-%
-%  A description of each parameter follows:
-%
-%    o file: The file.
-%
-%    o length: The file length.
-%
-*/
-MagickExport int NTFileTruncate(int file,off_t length)
-{
-  HANDLE
-    handle;
-
-  unsigned int
-    offset;
-
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
-  if (file < 0)
-    return(-1);
-  handle=(HANDLE) _get_osfhandle(file);
-  offset=SetFilePointer(handle,0,NULL,FILE_CURRENT);
-  if ((offset == 0xFFFFFFFF) ||
-      (SetFilePointer(handle,length,NULL,FILE_BEGIN) == 0xFFFFFFFF) ||
-      (SetEndOfFile(handle) == 0))
-    {
-      switch (GetLastError())
-      {
-        case ERROR_INVALID_HANDLE:
-        {
-          errno=EBADF;
-          break;
-        }
-        default:
-        {
-          errno=EIO;
-          break;
-        }
-      }
-      return(-1);
-    }
-  return(0);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   N T G e t E x e c u t i o n P a t h                                       %
 %                                                                             %
 %                                                                             %
@@ -725,13 +666,13 @@ MagickExport MagickBooleanType NTGetModulePath(const char *module,char *path)
 %
 %  The format of the NTGhostscriptDLL method is:
 %
-%      int NTGhostscriptDLL(char *path, int path_length)
+%      int NTGhostscriptDLL(char *path, int length)
 %
 %  A description of each parameter follows:
 %
 %    o path: Pointer to buffer in which to return result.
 %
-%    o path_length: Length of buffer
+%    o length: Length of buffer
 %
 */
 
@@ -990,16 +931,16 @@ static int NTGetLatestGhostscript( void )
 %
 %  The format of the NTGhostscriptDLL method is:
 %
-%      int NTGhostscriptDLL( char *path, int path_length)
+%      int NTGhostscriptDLL( char *path, int length)
 %
 %  A description of each parameter follows:
 %
 %    o path: Pointer to path buffer to update
 %
-%    o path_length: Allocation size of path buffer.
+%    o length: Allocation size of path buffer.
 %
 */
-MagickExport int NTGhostscriptDLL(char *path, int path_length)
+MagickExport int NTGhostscriptDLL(char *path, int length)
 {
   int
     gsver;
@@ -1015,7 +956,7 @@ MagickExport int NTGhostscriptDLL(char *path, int path_length)
   if (!NTGhostscriptGetString(gsver, "GS_DLL", buf, sizeof(buf)))
     return FALSE;
 
-  (void) CopyMagickString(path,buf,path_length+1);
+  (void) CopyMagickString(path,buf,length+1);
   return(TRUE);
 }
 
@@ -1063,16 +1004,16 @@ MagickExport const GhostscriptVectors *NTGhostscriptDLLVectors( void )
 %
 %  The format of the NTGhostscriptEXE method is:
 %
-%      int NTGhostscriptEXE(char *path, int path_length)
+%      int NTGhostscriptEXE(char *path, int length)
 %
 %  A description of each parameter follows:
 %
 %    o path: Pointer to buffer in which to return result.
 %
-%    o path_length: Length of buffer
+%    o length: Length of buffer
 %
 */
-MagickExport int NTGhostscriptEXE(char *path, int path_length)
+MagickExport int NTGhostscriptEXE(char *path,int length)
 {
   int
     gsver;
@@ -1081,20 +1022,18 @@ MagickExport int NTGhostscriptEXE(char *path, int path_length)
     buf[256],
     *p;
 
-  (void) CopyMagickString(path,"gswin32c.exe",path_length);
-  gsver = NTGetLatestGhostscript();
+  (void) CopyMagickString(path,"gswin32c.exe",length);
+  gsver=NTGetLatestGhostscript();
   if ((gsver == FALSE) || (gsver < GS_MINIMUM_VERSION))
-    return FALSE;
-
+    return(FALSE);
   if (!NTGhostscriptGetString(gsver, "GS_DLL", buf, sizeof(buf)))
-    return FALSE;
-
-  p = strrchr(buf, '\\');
+    return(FALSE);
+  p=strrchr(buf, '\\');
   if (p) {
     p++;
     *p = 0;
     (void) CopyMagickString(p,"gswin32c.exe",sizeof(buf));
-    (void) CopyMagickString(path,buf,path_length+1);
+    (void) CopyMagickString(path,buf,length+1);
     return TRUE;
   }
 
@@ -1117,16 +1056,16 @@ MagickExport int NTGhostscriptEXE(char *path, int path_length)
 %
 %  The format of the NTGhostscriptFonts method is:
 %
-%      int NTGhostscriptFonts(char *path, int path_length)
+%      int NTGhostscriptFonts(char *path,int length)
 %
 %  A description of each parameter follows:
 %
 %    o path: Pointer to buffer in which to return result.
 %
-%    o path_length: Length of buffer.
+%    o length: Length of buffer.
 %
 */
-MagickExport int NTGhostscriptFonts(char *path,int path_length)
+MagickExport int NTGhostscriptFonts(char *path,int length)
 {
   char
     buffer[MaxTextExtent],
@@ -1147,7 +1086,7 @@ MagickExport int NTGhostscriptFonts(char *path,int path_length)
     return(FALSE);
   for (p=buffer-1; p != (char *) NULL; p=strchr(p+1,DirectoryListSeparator))
   {
-    (void) CopyMagickString(path,p+1,path_length+1);
+    (void) CopyMagickString(path,p+1,length+1);
     q=strchr(path,DirectoryListSeparator);
     if (q != (char *) NULL)
       *q='\0';
@@ -1286,8 +1225,8 @@ MagickExport void *NTMapMemory(char *address,size_t length,int protection,
   int flags,int file,MagickOffsetType offset)
 {
   DWORD
-    low,
     high,
+    low,
     mode;
 
   HANDLE
@@ -1430,7 +1369,7 @@ MagickExport DIR *NTOpenDirectory(const char *path)
 static const char *GetSearchPath( void )
 {
 #ifdef HasLTDL
-  return(lt_dlGetSearchPath());
+  return(lt_dlgetsearchpath());
 #else
   return(lt_slsearchpath);
 #endif
@@ -1945,8 +1884,8 @@ MagickExport int NTSystemCommand(const char *command)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Sysconf() provides  a  way for the application to determine values for
-%  system limits or options at runtime.
+%  NTSystemConfiguration() provides a way for the application to determine
+%  values for system limits or options at runtime.
 %
 %  The format of the exit method is:
 %
@@ -1968,7 +1907,6 @@ MagickExport long NTSystemConfiguration(int name)
 
       GetSystemInfo(&system_info);
       return(system_info.dwPageSize);
-      break;
     }
     case _SC_PHYS_PAGES:
     {
@@ -1978,6 +1916,9 @@ MagickExport long NTSystemConfiguration(int name)
       LPFNDLLFUNC2
         module;
 
+      NTMEMORYSTATUSEX
+        status;
+
       SYSTEM_INFO
         system_info;
 
@@ -1992,24 +1933,19 @@ MagickExport long NTSystemConfiguration(int name)
             status;
 
           GlobalMemoryStatus(&status);
-          return((long) status.dwAvailPhys/system_info.dwPageSize);
+          return((long) status.dwTotalPhys/system_info.dwPageSize);
         }
-      else
-        {
-          NTMEMORYSTATUSEX
-            status;
-
-          status.dwLength=sizeof(status);
-          if (module(&status) == 0)
-            return(0L);
-          return((long) status.ullAvailPhys/system_info.dwPageSize);
-        }
-      break;
+      status.dwLength=sizeof(status);
+      if (module(&status) == 0)
+        return(0L);
+      return((long) status.ullTotalPhys/system_info.dwPageSize);
     }
+    case _SC_OPEN_MAX:
+      return(2048);
     default:
       break;
   }
-  return(0);
+  return(-1);
 }
 
 
@@ -2047,6 +1983,53 @@ MagickExport long NTTellDirectory(DIR *entry)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   N T T r u n c a t e F i l e                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  NTTruncateFile() truncates a file to a specified length.
+%
+%  The format of the NTTruncateFile method is:
+%
+%      int NTTruncateFile(int file,const MagickSizeType length)
+%
+%  A description of each parameter follows:
+%
+%    o file: The file.
+%
+%    o length: The file length.
+%
+*/
+MagickExport int NTTruncateFile(int file,const MagickSizeType length)
+{
+  DWORD
+    file_pointer;
+
+  long
+    file_handle,
+    high,
+    low;
+
+  file_handle=_get_osfhandle(file);
+  if (file_handle == -1L)
+    return(-1);
+  low=(long) (length & 0xffffffffUL);
+  high=(long) ((((MagickOffsetType) length) >> 32) & 0xffffffffUL);
+  file_pointer=SetFilePointer((HANDLE) file_handle,low,&high,FILE_BEGIN);
+  if ((file_pointer == 0xFFFFFFFF) && (GetLastError() != NO_ERROR))
+    return(-1);
+  if (SetEndOfFile((HANDLE) file_handle) == 0)
+    return(-1);
+  return(0);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 +  N T U n m a p M e m o r y                                                  %
 %                                                                             %
 %                                                                             %
@@ -2068,7 +2051,7 @@ MagickExport long NTTellDirectory(DIR *entry)
 */
 MagickExport int NTUnmapMemory(void *map,size_t length)
 {
-  if (!UnmapViewOfFile(map))
+  if (UnmapViewOfFile(map) == 0)
     return(-1);
   return(0);
 }
