@@ -41,7 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/cache.h"
 #include "magick/color.h"
 #include "magick/compare.h"
@@ -54,6 +54,7 @@
 #include "magick/gem.h"
 #include "magick/geometry.h"
 #include "magick/layer.h"
+#include "magick/mime-private.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/montage.h"
@@ -178,9 +179,9 @@ static const OptionInfo
     { "+chop", 0L },
     { "-chop", 1L },
     { "+clip", 0L },
-    { "-clip", 1L },
+    { "-clip", 0L },
     { "+clip-mask", 0L },
-    { "-clip-mask", 0L },
+    { "-clip-mask", 1L },
     { "+clip-path", 0L },
     { "-clip-path", 1L },
     { "+clone", 0L },
@@ -293,6 +294,8 @@ static const OptionInfo
     { "-gamma", 1L },
     { "+gaussian", 0L },
     { "-gaussian", 1L },
+    { "+gaussian-blur", 0L },
+    { "-gaussian-blur", 1L },
     { "+geometry", 0L },
     { "-geometry", 1L },
     { "+gravity", 0L },
@@ -329,6 +332,8 @@ static const OptionInfo
     { "-level", 1L },
     { "+limit", 0L },
     { "-limit", 2L },
+    { "+linear-stretch", 0L },
+    { "-linear-stretch", 1L },
     { "+linewidth", 0L },
     { "-linewidth", 1L },
     { "+list", 0L },
@@ -356,7 +361,7 @@ static const OptionInfo
     { "+modulate", 0L },
     { "-modulate", 1L },
     { "+monitor", 0L },
-    { "-monitor", 1L },
+    { "-monitor", 0L },
     { "+monochrome", 0L },
     { "-monochrome", 0L },
     { "+morph", 0L },
@@ -385,6 +390,8 @@ static const OptionInfo
     { "-page", 1L },
     { "+paint", 0L },
     { "-paint", 1L },
+    { "+path", 0L },
+    { "-path", 1L },
     { "+pause", 0L },
     { "-pause", 1L },
     { "+pen", 0L },
@@ -393,6 +400,8 @@ static const OptionInfo
     { "-ping", 0L },
     { "+pointsize", 0L },
     { "-pointsize", 1L },
+    { "+polaroid", 0L },
+    { "-polaroid", 1L },
     { "+posterize", 0L },
     { "-posterize", 1L },
     { "+preview", 0L },
@@ -411,6 +420,8 @@ static const OptionInfo
     { "-raise", 1L },
     { "+random-threshold", 0L },
     { "-random-threshold", 1L },
+    { "+recolor", 0L },
+    { "-recolor", 1L },
     { "+red-primary", 0L },
     { "-red-primary", 1L },
     { "+regard-warnings", 0L },
@@ -681,6 +692,15 @@ static const OptionInfo
     { "YUV", (long) YUVColorspace },
     { (char *) NULL, (long) UndefinedColorspace }
   },
+  DataTypeOptions[] =
+  {
+    { "Undefined", (long) UndefinedData },
+    { "Byte", (long) ByteData },
+    { "Long", (long) LongData },
+    { "Short", (long) ShortData },
+    { "String", (long) StringData },
+    { (char *) NULL, (long) UndefinedData }
+  },
   DecorationOptions[] =
   {
     { "Undefined", (long) UndefinedDecoration },
@@ -845,7 +865,7 @@ static const OptionInfo
     { (char *) NULL, (long) UndefinedJoin }
   },
   ListOptions[] =
-  { /* lookup value is a index to a specific List Function */
+  {
     { "Undefined",     MagickUndefinedOptions },
     { "Align",         MagickAlignOptions },
     { "Boolean",       MagickBooleanOptions },
@@ -856,6 +876,7 @@ static const OptionInfo
     { "Composite",     MagickCompositeOptions },
     { "Command",       MagickCommandOptions },
     { "Compression",   MagickCompressionOptions },
+    { "DataType",      MagickDataTypeOptions },
     { "Decoration",    MagickDecorationOptions },
     { "Dispose",       MagickDisposeOptions },
     { "Endian",        MagickEndianOptions },
@@ -874,6 +895,7 @@ static const OptionInfo
     { "LogEvent",      MagickLogEventOptions },
     { "Metric",        MagickMetricOptions },
     { "Method",        MagickMethodOptions },
+    { "Mime",          MagickMimeOptions },
     { "Mode",          MagickModeOptions },
     { "Mogrify",       MagickMogrifyOptions },
     { "Noise",         MagickNoiseOptions },
@@ -887,7 +909,6 @@ static const OptionInfo
     { "Stretch",       MagickStretchOptions },
     { "Style",         MagickStyleOptions },
     { "VirtualPixel",  MagickVirtualPixelOptions },
-    /* Option has a specific function to List these Options or Values */
     { "Coder",         MagickCoderOptions },
     { "Color",         MagickColorOptions },
     { "Configure",     MagickConfigureOptions },
@@ -897,12 +918,8 @@ static const OptionInfo
     { "Log",           MagickLogOptions },
     { "Magic",         MagickMagicOptions },
     { "Module",        MagickModuleOptions },
-    /*{ "Resource",      MagickResourceOptions }, -- duplicate */
     { "Threshold",     MagickThresholdOptions },
     { "Type",          MagickTypeOptions },
-    /* Future option names to reference appropraite option list
-     * EG:   "OrderedDither", MagickThresholdOptions,
-     */
     { (char *) NULL,   MagickUndefinedOptions }
   },
   LogEventOptions[] =
@@ -961,7 +978,6 @@ static const OptionInfo
   {
     { "append", MagickTrue },
     { "average", MagickTrue },
-    { "clip-mask", MagickTrue },
     { "coalesce", MagickTrue },
     { "combine", MagickTrue },
     { "composite", MagickTrue },
@@ -1177,7 +1193,7 @@ MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
   if (clone_info->options == (void *) NULL)
     return(MagickTrue);
   ResetImageOptionIterator(clone_info);
-  for (key=GetNextImageOption(clone_info); key != (char *) NULL; )
+  for (key=GetNextImageOption(clone_info); key != (const char *) NULL; )
   {
     value=GetImageOption(clone_info,key);
     if (value != (const char *) NULL)
@@ -1211,7 +1227,6 @@ MagickExport MagickBooleanType CloneImageOptions(ImageInfo *image_info,
 %
 %    o option: The image option.
 %
-%
 */
 MagickExport MagickBooleanType DefineImageOption(ImageInfo *image_info,
   const char *option)
@@ -1295,7 +1310,6 @@ MagickExport MagickBooleanType DeleteImageOption(ImageInfo *image_info,
 %
 %    o image_info: The image info.
 %
-%
 */
 MagickExport void DestroyImageOptions(ImageInfo *image_info)
 {
@@ -1346,8 +1360,8 @@ MagickExport const char *GetImageOption(const ImageInfo *image_info,
       image_info->filename);
   if (image_info->options == (void *) NULL)
     return((const char *) NULL);
-  option=(const char *)
-    GetValueFromSplayTree((SplayTreeInfo *) image_info->options,key);
+  option=(const char *) GetValueFromSplayTree((SplayTreeInfo *)
+    image_info->options,key);
   return(option);
 }
 
@@ -1372,7 +1386,6 @@ MagickExport const char *GetImageOption(const ImageInfo *image_info,
 %
 %    o value: The value.
 %
-%
 */
 
 static const OptionInfo *GetOptionInfo(const MagickOption value)
@@ -1388,6 +1401,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption value)
     case MagickCommandOptions: return(CommandOptions);
     case MagickCompositeOptions: return(CompositeOptions);
     case MagickCompressionOptions: return(CompressionOptions);
+    case MagickDataTypeOptions: return(DataTypeOptions);
     case MagickDecorationOptions: return(DecorationOptions);
     case MagickDisposeOptions: return(DisposeOptions);
     case MagickEndianOptions: return(EndianOptions);
@@ -1544,7 +1558,6 @@ MagickExport MagickBooleanType IsMagickOption(const char *option)
 %
 %    o type: one or more values separated by commas.
 %
-%
 */
 MagickExport const char *MagickOptionToMnemonic(const MagickOption value,
   const long type)
@@ -1577,10 +1590,10 @@ MagickExport const char *MagickOptionToMnemonic(const MagickOption value,
 %
 %  ListMagickOptionInfo() lists the contents of enumerated option type(s).
 %
-%  The format of the ParseMagickOption method is:
+%  The format of the ListMagickOptionInfo method is:
 %
 %      MagickBooleanType ListMagickOptionInfo(FILE *file,
-%           const MagickOption option, ExceptionInfo *exception)
+%           const MagickOption option,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -1592,7 +1605,7 @@ MagickExport const char *MagickOptionToMnemonic(const MagickOption value,
 %
 */
 MagickExport MagickBooleanType ListMagickOptionInfo(FILE *file,
-  const MagickOption option, ExceptionInfo *exception)
+  const MagickOption option,ExceptionInfo *exception)
 {
   const OptionInfo
     *option_info;
@@ -1600,18 +1613,16 @@ MagickExport MagickBooleanType ListMagickOptionInfo(FILE *file,
   register long
     i;
 
-  if ( file == (FILE *)NULL )
-    file = stdout;
-
+  if (file == (FILE *) NULL)
+    file=stdout;
   option_info=GetOptionInfo(option);
   if (option_info == (const OptionInfo *) NULL)
     return(MagickFalse);
-
   for (i=0; option_info[i].mnemonic != (char *) NULL; i++)
   {
-    if ( i==0 && strcmp(option_info[i].mnemonic, "Undefined") == 0 )
+    if ((i == 0) && (strcmp(option_info[i].mnemonic,"Undefined") == 0))
       continue;
-    fprintf(file, "%s\n", option_info[i].mnemonic);
+    (void) fprintf(file,"%s\n",option_info[i].mnemonic);
   }
   return(MagickTrue);
 }
@@ -1638,7 +1649,6 @@ MagickExport MagickBooleanType ListMagickOptionInfo(FILE *file,
 %
 %    o options: One or more values separated by commas.
 %
-%
 */
 MagickExport long ParseChannelOption(const char *channels)
 {
@@ -1784,8 +1794,6 @@ MagickExport long ParseMagickOption(const MagickOption option,
     while (((isspace((int) ((unsigned char) *p)) != 0) || (*p == ',')) &&
            (*p != '\0'))
       p++;
-    if ((*p == '-') || (*p == '+'))
-      p++;
     negate=(*p == '!') ? MagickTrue : MagickFalse;
     if (negate != MagickFalse)
       p++;
@@ -1799,7 +1807,6 @@ MagickExport long ParseMagickOption(const MagickOption option,
     }
     *q='\0';
     for (i=0; option_info[i].mnemonic != (char *) NULL; i++)
-    {
       if (LocaleCompare(token,option_info[i].mnemonic) == 0)
         {
           if (*token == '!')
@@ -1808,16 +1815,13 @@ MagickExport long ParseMagickOption(const MagickOption option,
             option_types=option_types | option_info[i].type;
           break;
         }
-    }
     if ((option_info[i].mnemonic == (char *) NULL) &&
         ((strchr(token+1,'-') != (char *) NULL) || 
          (strchr(token+1,'_') != (char *) NULL)))
       {
-        q=strchr(token+1,'-');
-        if (q != (char *) NULL)
+        while ((q=strchr(token+1,'-')) != (char *) NULL)
           (void) CopyMagickString(q,q+1,MaxTextExtent-strlen(q));
-        q=strchr(token+1,'_');
-        if (q != (char *) NULL)
+        while ((q=strchr(token+1,'_')) != (char *) NULL)
           (void) CopyMagickString(q,q+1,MaxTextExtent-strlen(q));
         for (i=0; option_info[i].mnemonic != (char *) NULL; i++)
           if (LocaleCompare(token,option_info[i].mnemonic) == 0)
@@ -1962,18 +1966,19 @@ MagickExport MagickBooleanType SetImageOption(ImageInfo *image_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   S y n c I m a g e O p t i o n                                             %
+%   S y n c I m a g e O p t i o n s                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  SyncImageOption() syncs the image settings with a particular image.
+%  SyncImageOptions() set options in the ImageInfo structure as attributes in
+%  the image.
 %
-%  The format of the SyncImageOption method is:
+%  The format of the SyncImageOptions method is:
 %
-%      MagickBooleanType SyncImageOption(const ImageInfo *image_info,
-%        const char *option,const char *value)
+%      MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
+%        Image *image)
 %
 %  A description of each parameter follows:
 %
@@ -1988,12 +1993,88 @@ MagickExport MagickBooleanType SyncImageOptions(const ImageInfo *image_info,
   const char
     *option;
 
+  MagickStatusType
+    flags;
+
+  /*
+    Sync image options.
+  */
+  assert(image_info != (const ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  option=GetImageOption(image_info,"caption");
+  if (option != (const char *) NULL)
+    (void) SetImageProperty(image,"caption",option);
+  option=GetImageOption(image_info,"comment");
+  if (option != (const char *) NULL)
+    (void) SetImageProperty(image,"comment",option);
   option=GetImageOption(image_info,"depth");
   if (option != (const char *) NULL)
     image->depth=(unsigned long) atol(option);
+  option=GetImageOption(image_info,"delay");
+  if (option != (const char *) NULL)
+    {
+      GeometryInfo
+        geometry_info;
+
+      flags=ParseGeometry(option,&geometry_info);
+      if ((flags & GreaterValue) != 0)
+        {
+          if (image->delay > (unsigned long) (geometry_info.rho+0.5))
+            image->delay=(unsigned long) (geometry_info.rho+0.5);
+        }
+      else
+        if ((flags & LessValue) != 0)
+          {
+            if (image->delay < (unsigned long) (geometry_info.rho+0.5))
+              image->ticks_per_second=(unsigned long) (geometry_info.sigma+0.5);
+          }
+        else
+          image->delay=(unsigned long) (geometry_info.rho+0.5);
+      if ((flags & SigmaValue) != 0)
+        image->ticks_per_second=(unsigned long) (geometry_info.sigma+0.5);
+    }
+  option=GetImageOption(image_info,"dispose");
+  if (option != (const char *) NULL)
+    image->dispose=(DisposeType) ParseMagickOption(MagickDisposeOptions,
+      MagickFalse,option);
   option=GetImageOption(image_info,"gravity");
   if (option != (const char *) NULL)
     image->gravity=(GravityType) ParseMagickOption(MagickGravityOptions,
       MagickFalse,option);
+  option=GetImageOption(image_info,"intent");
+  if (option != (const char *) NULL)
+    image->rendering_intent=(RenderingIntent) ParseMagickOption(
+      MagickIntentOptions,MagickFalse,option);
+  option=GetImageOption(image_info,"interpolate");
+  if (option != (const char *) NULL)
+    image->interpolate=(InterpolatePixelMethod) ParseMagickOption(
+      MagickInterpolateOptions,MagickFalse,option);
+  option=GetImageOption(image_info,"label");
+  if (option != (const char *) NULL)
+    (void) SetImageProperty(image,"label",option);
+  option=GetImageOption(image_info,"origin");
+  if (option != (const char *) NULL)
+    {
+      char
+        *geometry;
+
+      geometry=GetPageGeometry(option);
+      flags=ParseAbsoluteGeometry(geometry,&image->origin);
+      geometry=(char *) RelinquishMagickMemory(geometry);
+    }
+  option=GetImageOption(image_info,"page");
+  if (option != (const char *) NULL)
+    {
+      char
+        *geometry;
+
+      geometry=GetPageGeometry(option);
+      flags=ParseAbsoluteGeometry(geometry,&image->page);
+      geometry=(char *) RelinquishMagickMemory(geometry);
+    }
   return(MagickTrue);
 }
