@@ -41,11 +41,14 @@
 */
 #include "magick/studio.h"
 #include "magick/color.h"
+#include "magick/configure.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
+#include "magick/hashmap.h"
 #include "magick/image.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
+#include "magick/option.h"
 #include "magick/profile.h"
 #include "magick/quantum.h"
 #include "magick/splay-tree.h"
@@ -118,6 +121,62 @@ MagickExport MagickBooleanType CloneImageProfiles(Image *image,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   C r e a t e s R G B I m a g e P r o f i l e                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  CreatesRGBImageProfile() adds a sRGB profile to the image.
+%
+%  The format of the CreatesRGBImageProfile method is:
+%
+%      MagickBooleanType CreatesRGBImageProfile(Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+*/
+MagickExport MagickBooleanType CreatesRGBImageProfile(Image *image)
+{
+#define sRGBProfileFilename  "sRGB.icm"
+
+  const StringInfo
+    *option;
+
+  ExceptionInfo
+    *exception;
+
+  LinkedListInfo
+    *options;
+
+  MagickBooleanType
+    status;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (GetImageProfile(image,"icm") != (const StringInfo *) NULL)
+    return(MagickFalse);
+  status=MagickFalse;
+  exception=AcquireExceptionInfo();
+  options=GetConfigureOptions(sRGBProfileFilename,exception);
+  option=(const StringInfo *) GetNextValueInLinkedList(options);
+  while (option != (const StringInfo *) NULL)
+  {
+    status=SetImageProfile(image,"icm",option);
+    option=(const StringInfo *) GetNextValueInLinkedList(options);
+  }
+  options=DestroyConfigureOptions(options);
+  exception=DestroyExceptionInfo(exception);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   D e s t r o y I m a g e P r o f i l e s                                   %
 %                                                                             %
 %                                                                             %
@@ -134,7 +193,6 @@ MagickExport MagickBooleanType CloneImageProfiles(Image *image,
 %
 %    o image: The image.
 %
-%
 */
 MagickExport void DestroyImageProfiles(Image *image)
 {
@@ -570,6 +628,8 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             for (x=0; x < (long) image->columns; x++)
             {
               q->red=ScaleShortToQuantum(*p);
+              q->green=q->red;
+              q->blue=q->red;
               p++;
               if (target_channels > 1)
                 {
@@ -589,10 +649,10 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               break;
           }
           image->colorspace=target_colorspace;
-          target_pixels=(unsigned short *)
-            RelinquishMagickMemory(target_pixels);
-          source_pixels=(unsigned short *)
-            RelinquishMagickMemory(source_pixels);
+          target_pixels=(unsigned short *) RelinquishMagickMemory(
+            target_pixels);
+          source_pixels=(unsigned short *) RelinquishMagickMemory(
+            source_pixels);
           cmsDeleteTransform(transform);
         }
 #endif
@@ -778,3 +838,307 @@ MagickExport MagickBooleanType SetImageProfile(Image *image,const char *name,
     }
   return(status);
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   S y n c I m a g e P r o f i l e s                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SyncImageProfiles() synchronizes image properties with the image profiles.
+%  Currently we only support updating the EXIF resolution and orientation.
+%
+%  The format of the SyncImageProfiles method is:
+%
+%      MagickBooleanType SyncImageProfiles(Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+*/
+
+static int ReadProfileByte(unsigned char **p,size_t *length)
+{
+  int
+    c;
+
+  if (*length < 1)
+    return(EOF);
+  c=(int) (*(*p)++);
+  (*length)--;
+  return(c);
+}
+
+static unsigned short ReadProfileShort(const MagickBooleanType msb_order,
+  unsigned char *buffer)
+{
+  unsigned short
+    value;
+
+  if (msb_order != MagickFalse)
+    {
+      value=(unsigned short) ((((unsigned char *) buffer)[0] << 8) |
+        ((unsigned char *) buffer)[1]);
+      return((unsigned short) (value & 0xffff));
+    }
+  value=(unsigned short) ((buffer[1] << 8) | buffer[0]);
+  return((unsigned short) (value & 0xffff));
+}
+
+static unsigned long ReadProfileLong(const MagickBooleanType msb_order,
+  unsigned char *buffer)
+{
+  unsigned long
+    value;
+
+  if (msb_order != MagickFalse)
+    {
+      value=(unsigned long) ((buffer[0] << 24) | (buffer[1] << 16) |
+        (buffer[2] << 8) | buffer[3]);
+      return((unsigned long) (value & 0xffffffff));
+    }
+  value=(unsigned long) ((buffer[3] << 24) | (buffer[2] << 16) |
+    (buffer[1] << 8 ) | (buffer[0]));
+  return((unsigned long) (value & 0xffffffff));
+}
+
+static void WriteProfileLong(const MagickBooleanType msb_order,
+  const unsigned long value,unsigned char *p)
+{
+  unsigned char
+    buffer[4];
+    
+  if (msb_order == MagickFalse)
+    {
+      buffer[0]=(unsigned char) value;
+      buffer[1]=(unsigned char) (value >> 8);
+      buffer[2]=(unsigned char) (value >> 16);
+      buffer[3]=(unsigned char) (value >> 24);
+      (void) memcpy(p,buffer,4);
+      return;
+    }
+  buffer[0]=(unsigned char) (value >> 24);
+  buffer[1]=(unsigned char) (value >> 16);
+  buffer[2]=(unsigned char) (value >> 8);
+  buffer[3]=(unsigned char) value; 
+  (void) memcpy(p,buffer,4);
+}
+
+static void WriteProfileShort(const MagickBooleanType msb_order,
+  const unsigned short value,unsigned char *p)
+{
+  unsigned char
+    buffer[2];
+    
+  if (msb_order == MagickFalse)
+    {
+      buffer[0]=(unsigned char) value;
+      buffer[1]=(unsigned char) (value >> 8);
+      (void) memcpy(p,buffer,2);
+      return;
+    }
+  buffer[0]=(unsigned char) (value >> 8);
+  buffer[1]=(unsigned char) value; 
+  (void) memcpy(p,buffer,2);
+}
+
+MagickExport MagickBooleanType SyncImageProfiles(Image *image)
+{
+#define DE_STACK_SIZE  16
+#define EXIF_DELIMITER  "\n"
+#define EXIF_NUM_FORMATS  12
+#define TAG_EXIF_OFFSET  0x8769
+#define TAG_INTEROP_OFFSET  0xa005
+
+  int
+    id,
+    level;
+
+  MagickBooleanType
+    msb_order;
+
+  size_t
+    length;
+
+  static int
+    format_bytes[] = {0, 1, 1, 2, 4, 8, 1, 1, 2, 4, 8, 4, 8};
+
+  StringInfo
+    *profile;
+
+  unsigned long
+    offset;
+
+  unsigned char
+    *ifd_stack[DE_STACK_SIZE],
+    *ifdp,
+    *info,
+    *tiffp;
+
+  unsigned int
+    de,
+    de_stack[DE_STACK_SIZE],
+    number_entries;
+
+  /*
+    Set EXIF resolution tag.
+  */
+  profile=(StringInfo *) GetImageProfile(image,"EXIF");
+  if (profile == (StringInfo *) NULL)
+    return(MagickTrue);
+  length=profile->length;
+  info=(unsigned char *) profile->datum;
+  while (length != 0)
+  {
+    if (ReadProfileByte(&info,&length) != 0x45)
+      continue;
+    if (ReadProfileByte(&info,&length) != 0x78)
+      continue;
+    if (ReadProfileByte(&info,&length) != 0x69)
+      continue;
+    if (ReadProfileByte(&info,&length) != 0x66)
+      continue;
+    if (ReadProfileByte(&info,&length) != 0x00)
+      continue;
+    if (ReadProfileByte(&info,&length) != 0x00)
+      continue;
+    break;
+  }
+  if (length < 16)
+    return(MagickFalse);
+  tiffp=info;
+  id=(int) ReadProfileShort(MagickFalse,tiffp);
+  msb_order=MagickFalse;
+  if (id == 0x4949)
+    msb_order=MagickFalse;
+  else
+    if (id == 0x4D4D)
+      msb_order=MagickTrue;
+    else
+      return(MagickFalse);
+  if (ReadProfileShort(msb_order,tiffp+2) != 0x002a)
+    return(MagickFalse);
+  /*
+    This is the offset to the first IFD.
+  */
+  offset=ReadProfileLong(msb_order,tiffp+4);
+  if ((size_t) offset >= length)
+    return(MagickFalse);
+  /*
+    Set the pointer to the first IFD and follow it were it leads.
+  */
+  ifdp=tiffp+offset;
+  level=0;
+  de=0;
+  do
+  {
+    /*
+      If there is anything on the stack then pop it off.
+    */
+    if (level > 0)
+      {
+        level--;
+        ifdp=ifd_stack[level];
+        de=de_stack[level];
+      }
+    /*
+      Determine how many entries there are in the current IFD.
+    */
+    number_entries=ReadProfileShort(msb_order,ifdp);
+    for ( ; de < number_entries; de++)
+    {
+      long
+        components,
+        format,
+        n,
+        tag_value;
+
+      register unsigned char
+        *p,
+        *q;
+
+      q=(unsigned char *) (ifdp+2+(12*de));
+      tag_value=(long) ReadProfileShort(msb_order,q);
+      format=(long) ReadProfileShort(msb_order,q+2);
+      if ((format-1) >= EXIF_NUM_FORMATS)
+        break;
+      components=(long) ReadProfileLong(msb_order,q+4);
+      n=components*format_bytes[format];
+      if (n <= 4)
+        p=q+8;
+      else
+        {
+          unsigned long
+            oval;
+
+          /*
+            The directory entry contains an offset.
+          */
+          oval=ReadProfileLong(msb_order,q+8);
+          if ((size_t) (oval+n) > length)
+            continue;
+          p=(unsigned char *) (tiffp+oval);
+        }
+      switch (tag_value)
+      {
+        case 0x011a:
+        {
+          (void) WriteProfileLong(msb_order,(unsigned long)
+            (image->x_resolution+0.5),p);
+          break;
+        }
+        case 0x011b:
+        {
+          (void) WriteProfileLong(msb_order,(unsigned long)
+            (image->y_resolution+0.5),p);
+          break;
+        }
+        case 0x0112:
+        {
+          (void) WriteProfileShort(msb_order,(unsigned short)
+            image->orientation,p);
+          break;
+        }
+        case 0x0128:
+        {
+          (void) WriteProfileShort(msb_order,(unsigned short)
+            image->units+1,p);
+          break;
+        }
+        default:
+          break;
+      }
+      if ((tag_value == TAG_EXIF_OFFSET) || (tag_value == TAG_INTEROP_OFFSET))
+        {
+          size_t
+            offset;
+
+          offset=(size_t) ReadProfileLong(msb_order,p);
+          if ((offset < length) && (level < (DE_STACK_SIZE-2)))
+            {
+              /*
+                Push our current directory state onto the stack.
+              */
+              ifd_stack[level]=ifdp;
+              de++;
+              de_stack[level]=de;
+              level++;
+              /*
+                Push new state onto of stack to cause a jump.
+              */
+              ifd_stack[level]=tiffp+offset;
+              de_stack[level]=0;
+              level++;
+            }
+          break;
+        }
+    }
+  } while (level > 0);
+  return(MagickTrue);
+}
