@@ -39,7 +39,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/cache-view.h"
 #include "magick/color.h"
@@ -90,8 +90,8 @@ typedef struct _FilterInfo
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  AdaptiveResizeImage() adaptively resize image with data
-%  dependent triangulation.
+%  AdaptiveResizeImage() adaptively resize image with data dependent
+%  triangulation.
 %
 %  The format of the AdaptiveResizeImage method is:
 %
@@ -176,7 +176,7 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
     {
       offset.x=(MagickRealType) x*image->columns/resize_image->columns;
       pixel=InterpolatePixelColor(image,image_view,MeshInterpolatePixel,
-        offset.x,offset.y,exception);
+        offset.x-0.5,offset.y-0.5,exception);
       SetPixelPacket(&pixel,q,resize_indexes+x);
       q++;
     }
@@ -1804,7 +1804,7 @@ MagickExport Image *ThumbnailImage(const Image *image,
   char
     value[MaxTextExtent];
 
-  const ImageAttribute
+  const char
     *attribute;
 
   Image
@@ -1844,7 +1844,7 @@ MagickExport Image *ThumbnailImage(const Image *image,
   if (thumbnail_image == (Image *) NULL)
     return(thumbnail_image);
   if (thumbnail_image->matte == MagickFalse)
-    SetImageOpacity(thumbnail_image,OpaqueOpacity);
+    (void) SetImageOpacity(thumbnail_image,OpaqueOpacity);
   thumbnail_image->depth=8;
   thumbnail_image->interlace=NoInterlace;
   (void) StripImage(thumbnail_image);
@@ -1852,32 +1852,32 @@ MagickExport Image *ThumbnailImage(const Image *image,
   if (strstr(image->magick_filename,"///") == (char *) NULL)
     (void) FormatMagickString(value,MaxTextExtent,"file:///%s",
       image->magick_filename);
-  (void) SetImageAttribute(thumbnail_image,"Thumb::URI",value);
+  (void) SetImageProperty(thumbnail_image,"Thumb::URI",value);
   (void) CopyMagickString(value,image->magick_filename,MaxTextExtent);
   if (stat(image->filename,&attributes) == 0)
     {
       (void) FormatMagickString(value,MaxTextExtent,"%ld",attributes.st_mtime);
-      (void) SetImageAttribute(thumbnail_image,"Thumb::MTime",value);
+      (void) SetImageProperty(thumbnail_image,"Thumb::MTime",value);
     }
   (void) FormatMagickString(value,MaxTextExtent,"%ld",attributes.st_mtime);
   (void) FormatMagickSize(GetBlobSize(image),value);
-  (void) SetImageAttribute(thumbnail_image,"Thumb::Size",value);
+  (void) SetImageProperty(thumbnail_image,"Thumb::Size",value);
   (void) FormatMagickString(value,MaxTextExtent,"image/%s",image->magick);
   LocaleLower(value);
-  (void) SetImageAttribute(thumbnail_image,"Thumb::Mimetype",value);
-  attribute=GetImageAttribute(image,"comment");
-  if ((attribute != (const ImageAttribute *) NULL) &&
-      (attribute->value != (char *) NULL))
-    (void) SetImageAttribute(thumbnail_image,"Description",attribute->value);
-  (void) SetImageAttribute(thumbnail_image,"Software",
+  (void) SetImageProperty(thumbnail_image,"Thumb::Mimetype",value);
+  attribute=GetImageProperty(image,"comment");
+  if ((attribute != (const char *) NULL) &&
+      (value != (char *) NULL))
+    (void) SetImageProperty(thumbnail_image,"Description",value);
+  (void) SetImageProperty(thumbnail_image,"Software",
     GetMagickVersion(&version));
   (void) FormatMagickString(value,MaxTextExtent,"%lu",image->magick_columns);
-  (void) SetImageAttribute(thumbnail_image,"Thumb::Image::Width",value);
+  (void) SetImageProperty(thumbnail_image,"Thumb::Image::Width",value);
   (void) FormatMagickString(value,MaxTextExtent,"%lu",image->magick_rows);
-  (void) SetImageAttribute(thumbnail_image,"Thumb::Image::height",value);
+  (void) SetImageProperty(thumbnail_image,"Thumb::Image::height",value);
   (void) FormatMagickString(value,MaxTextExtent,"%lu",
     GetImageListLength(image));
-  (void) SetImageAttribute(thumbnail_image,"Thumb::Document::Pages",value);
+  (void) SetImageProperty(thumbnail_image,"Thumb::Document::Pages",value);
   return(thumbnail_image);
 }
 
