@@ -698,7 +698,6 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   char
     area_limit[MaxTextExtent],
     disk_limit[MaxTextExtent],
-    file_limit[MaxTextExtent],
     map_limit[MaxTextExtent],
     memory_limit[MaxTextExtent];
 
@@ -709,14 +708,13 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
     area_limit);
   (void) FormatMagickSize(GigabytesToBytes(resource_info.disk_limit),
     disk_limit);
-  (void) FormatMagickSize((MagickSizeType) resource_info.file_limit,file_limit);
   (void) FormatMagickSize(MegabytesToBytes(resource_info.map_limit),map_limit);
   (void) FormatMagickSize(MegabytesToBytes(resource_info.memory_limit),
     memory_limit);
   (void) fprintf(file,"File       Area     Memory        Map       Disk\n");
   (void) fprintf(file,"------------------------------------------------\n");
-  (void) fprintf(file,"%4s  %9s  %9s  %9s  %9s\n",file_limit,area_limit,
-    memory_limit,map_limit,disk_limit);
+  (void) fprintf(file,"%4lu  %9s  %9s  %9s  %9s\n",resource_info.file_limit,
+    area_limit,memory_limit,map_limit,disk_limit);
   (void) fflush(file);
   RelinquishSemaphoreInfo(resource_semaphore);
   return(MagickTrue);
