@@ -953,7 +953,7 @@ MagickExport MagickPixelPacket GetImageDynamicThreshold(const Image *image,
   cluster=(Cluster *) NULL;
   head=(Cluster *) NULL;
   (void) ResetMagickMemory(&red,0,sizeof(red));
-	(void) ResetMagickMemory(&green,0,sizeof(green));
+  (void) ResetMagickMemory(&green,0,sizeof(green));
   (void) ResetMagickMemory(&blue,0,sizeof(blue));
   while (DefineRegion(extrema[Red],&red) != 0)
   {
@@ -1710,18 +1710,17 @@ static void ScaleSpace(const long *histogram,const MagickRealType tau,
 %
 %    o colorspace: Indicate the colorspace.
 %
-%    o verbose:  A value greater than zero prints detailed information about
-%      the identified classes.
+%    o verbose:  Set to MagickTrue to print detailed information about the
+%      identified classes.
 %
-%    o cluster_threshold:  This MagickRealType represents the minimum number of
-%      pixels contained in a hexahedra before it can be considered valid
-%      (expressed as a percentage).
+%    o cluster_threshold:  This represents the minimum number of pixels
+%      contained in a hexahedra before it can be considered valid (expressed
+%      as a percentage).
 %
 %    o smooth_threshold: the smoothing threshold eliminates noise in the second
 %      derivative of the histogram.  As the value is increased, you can expect a
 %      smoother second derivative.
 %
-%
 */
 MagickExport MagickBooleanType SegmentImage(Image *image,
   const ColorspaceType colorspace,const MagickBooleanType verbose,
