@@ -361,6 +361,11 @@ MagickExport MagickBooleanType LockSemaphoreInfo(SemaphoreInfo *semaphore_info)
       id;
 
     id=pthread_self();
+    if ((semaphore_info->reference_count > 0) && (semaphore_info->id == id))
+      {
+        (void) fprintf(stderr,"Warning: recursive semaphore lock detected!\n");
+        (void) fflush(stderr);
+      }
     status=pthread_mutex_lock(&semaphore_info->mutex);
     if (status != 0)
       return(MagickFalse);
@@ -368,8 +373,14 @@ MagickExport MagickBooleanType LockSemaphoreInfo(SemaphoreInfo *semaphore_info)
   }
 #endif
 #if defined(__WINDOWS__)
-  EnterCriticalSection(&semaphore_info->mutex);
-  semaphore_info->id=GetCurrentThreadId();
+  {
+    DWORD
+      id;
+
+    id=GetCurrentThreadId();
+    EnterCriticalSection(&semaphore_info->mutex);
+    semaphore_info->id=id;
+  }
 #endif
   semaphore_info->reference_count++;
   return(MagickTrue);
@@ -442,7 +453,10 @@ MagickExport MagickBooleanType UnlockSemaphoreInfo(
     assert(pthread_equal(semaphore_info->id,pthread_self()));
     status=pthread_mutex_unlock(&semaphore_info->mutex);
     if (status != 0)
-      return(MagickFalse);
+      {
+        semaphore_info->reference_count++;
+        return(MagickFalse);
+      }
   }
 #endif
 #if defined(__WINDOWS__)
