@@ -16,7 +16,7 @@
 %                           T    R  R   EEEEE  EEEEE                          %
 %                                                                             %
 %                                                                             %
-%                 See Self-adjusting Binary Search Tree Methods               %
+%            ImageMagick Self-adjusting Binary Search Tree Methods            %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -284,7 +284,8 @@ static void BalanceSplayTree(SplayTreeInfo *splay_info)
       splay_info->balance=MagickFalse;
       return;
     }
-  nodes=(NodeInfo **) AcquireMagickMemory(splay_info->nodes*sizeof(*nodes));
+  nodes=(NodeInfo **) AcquireMagickMemory((size_t) splay_info->nodes*
+    sizeof(*nodes));
   if (nodes == (NodeInfo **) NULL)
     {
       char
@@ -314,8 +315,8 @@ static void BalanceSplayTree(SplayTreeInfo *splay_info)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Specify the CompareSplayTreeString() method in NewSplayTree() to find a node
-%  in a splay-tree based on the contents of a string.
+%  CompareSplayTreeString() method finds a node in a splay-tree based on the
+%  contents of a string.
 %
 %  The format of the CompareSplayTreeString method is:
 %
@@ -350,8 +351,8 @@ MagickExport int CompareSplayTreeString(const void *target,const void *source)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Specify the CompareSplayTreeStringInfo() method in NewSplayTree() to find a
-%  node in a splay-tree based on the contents of a string.
+%  CompareSplayTreeStringInfo() finds a node in a splay-tree based on the
+%  contents of a string.
 %
 %  The format of the CompareSplayTreeStringInfo method is:
 %
@@ -719,9 +720,10 @@ static int IterateOverSplayTree(SplayTreeInfo *splay_info,
 
   if (splay_info->root == (NodeInfo *) NULL)
     return(0);
-  nodes=(NodeInfo **) AcquireMagickMemory(splay_info->nodes*sizeof(*nodes));
-  transitions=(unsigned char *)
-    AcquireMagickMemory(splay_info->nodes*sizeof(*transitions));
+  nodes=(NodeInfo **) AcquireMagickMemory((size_t) splay_info->nodes*
+    sizeof(*nodes));
+  transitions=(unsigned char *) AcquireMagickMemory((size_t) splay_info->nodes*
+    sizeof(*transitions));
   if ((nodes == (NodeInfo **) NULL) || (transitions == (unsigned char *) NULL))
     {
       char
