@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -85,7 +85,7 @@ MagickExport MagickBooleanType ExecuteStaticModuleProcess(const char *tag,
   assert(image != (Image **) NULL);
   assert((*image)->signature == MagickSignature);
   if ((*image)->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),(*image)->filename);
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",(*image)->filename);
   status=MagickFalse;
 #if !defined(BuildMagickModules)
   {
@@ -149,6 +149,9 @@ MagickExport void RegisterStaticModules(void)
   RegisterCUTImage();
   RegisterDCMImage();
   RegisterDIBImage();
+#if defined(HasDJVU)
+  RegisterDJVUImage();
+#endif
   RegisterDPSImage();
   RegisterDPXImage();
 #if defined(HasWINGDI32)
@@ -168,6 +171,7 @@ MagickExport void RegisterStaticModules(void)
   RegisterHISTOGRAMImage();
   RegisterHTMLImage();
   RegisterICONImage();
+  RegisterINFOImage();
 #if defined(HasJBIG)
   RegisterJBIGImage();
 #endif
@@ -297,6 +301,9 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterCUTImage();
   UnregisterDCMImage();
   UnregisterDIBImage();
+#if defined(HasDJVU)
+  UnregisterDJVUImage();
+#endif
   UnregisterDPSImage();
   UnregisterDPXImage();
 #if defined(HasWINGDI32)
@@ -316,6 +323,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterHISTOGRAMImage();
   UnregisterHTMLImage();
   UnregisterICONImage();
+  UnregisterINFOImage();
 #if defined(HasJBIG)
   UnregisterJBIGImage();
 #endif
