@@ -41,7 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/animate.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
@@ -181,7 +181,10 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
       p++;
     }
   }
-  if ((bounds.width != 0) || (bounds.height != 0))
+  if ((bounds.width == 0) || (bounds.height == 0))
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
+      "GeometryDoesNotContainImage","`%s'",image->filename);
+  else
     {
       bounds.width-=(bounds.x-1);
       bounds.height-=(bounds.y-1);
