@@ -40,7 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/blob-private.h"
 #include "magick/exception.h"
@@ -191,11 +191,11 @@ MagickExport StringInfo *AcquireStringInfo(const size_t length)
   if (string_info->length != 0)
     {
       size_t
-        length;
+        extent;
 
-      length=CheckOverflowException(string_info->length,MaxTextExtent);
-      string_info->datum=(unsigned char *)
-        AcquireMagickMemory(length*sizeof(*string_info->datum));
+      extent=CheckOverflowException(string_info->length,MaxTextExtent);
+      string_info->datum=(unsigned char *) AcquireMagickMemory(extent*
+        sizeof(*string_info->datum));
       if (string_info->datum == (unsigned char *) NULL)
         {
           char
@@ -234,7 +234,6 @@ MagickExport StringInfo *AcquireStringInfo(const size_t length)
 %
 %    o source: A character string.
 %
-%
 */
 MagickExport char *CloneString(char **destination,const char *source)
 {
@@ -297,7 +296,7 @@ MagickExport StringInfo *CloneStringInfo(const StringInfo *string_info)
   clone_info=AcquireStringInfo(string_info->length);
   if (string_info->length != 0)
     (void) CopyMagickMemory(clone_info->datum,string_info->datum,
-      string_info->length+MaxTextExtent);
+      string_info->length);
   return(clone_info);
 }
 
@@ -330,29 +329,20 @@ MagickExport StringInfo *CloneStringInfo(const StringInfo *string_info)
 MagickExport int CompareStringInfo(const StringInfo *target,
   const StringInfo *source)
 {
-  register unsigned char
-    *p,
-    *q;
-
-  register size_t
-    i;
+  int
+    status;
 
+  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(target != (StringInfo *) NULL);
-  assert(target->signature == MagickSignature);
+  assert(target->signature == MagickSignature); 
   assert(source != (StringInfo *) NULL);
   assert(source->signature == MagickSignature);
-  p=target->datum;
-  q=source->datum;
-  for (i=0; i < Min(source->length,target->length); i++)
-  {
-    if (*p != *q)
-      break;
-    p++;
-    q++;
-  }
-  if ((i == source->length) && (source->length == target->length))
+  status=memcmp(target->datum,source->datum,Min(target->length,source->length));
+  if (status != 0)
+    return(status);
+  if (target->length == source->length)
     return(0);
-  return(*p-(int) *q);
+  return(target->length < source->length ? -1 : 1);
 }
 
 /*
@@ -387,7 +377,6 @@ MagickExport int CompareStringInfo(const StringInfo *target,
 MagickExport size_t ConcatenateMagickString(char *destination,
   const char *source,const size_t length)
 {
-#if !defined(HAVE_STRLCAT)
   register char
     *q;
 
@@ -423,9 +412,6 @@ MagickExport size_t ConcatenateMagickString(char *destination,
   }
   *q='\0';
   return(count+(p-source));
-#else
-  return(strlcat(destination,source,length));
-#endif
 }
 
 /*
@@ -453,7 +439,6 @@ MagickExport size_t ConcatenateMagickString(char *destination,
 %
 %    o source: A character string.
 %
-%
 */
 MagickExport MagickBooleanType ConcatenateString(char **destination,
   const char *source)
@@ -471,8 +456,8 @@ MagickExport MagickBooleanType ConcatenateString(char **destination,
     }
   length=CheckOverflowException(strlen(*destination)+strlen(source),
     MaxTextExtent);
-  *destination=(char *) ResizeMagickMemory(*destination,
-    length*sizeof(*destination));
+  *destination=(char *) ResizeMagickMemory(*destination,length*
+    sizeof(*destination));
   if (*destination == (char *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,
       "UnableToConcatenateString",source);
@@ -511,6 +496,7 @@ MagickExport void ConcatenateStringInfo(StringInfo *string_info,
   const StringInfo *source)
 {
   size_t
+    extent,
     length;
 
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
@@ -518,8 +504,8 @@ MagickExport void ConcatenateStringInfo(StringInfo *string_info,
   assert(string_info->signature == MagickSignature);
   assert(source != (const StringInfo *) NULL);
   length=string_info->length;
-  (void) CheckOverflowException(string_info->length,source->length);
-  SetStringInfoLength(string_info,string_info->length+source->length);
+  extent=CheckOverflowException(string_info->length,source->length);
+  SetStringInfoLength(string_info,extent);
   (void) CopyMagickMemory(string_info->datum+length,source->datum,
     source->length);
 }
@@ -560,6 +546,7 @@ MagickExport StringInfo *ConfigureFileToStringInfo(const char *filename)
     offset;
 
   size_t
+    extent,
     length;
 
   StringInfo
@@ -579,7 +566,8 @@ MagickExport StringInfo *ConfigureFileToStringInfo(const char *filename)
       return((StringInfo *) NULL);
     }
   length=(size_t) offset;
-  string=(char *) AcquireMagickMemory((length+1)*sizeof(*string));
+  extent=CheckOverflowException(length,MaxTextExtent);
+  string=(char *) AcquireMagickMemory(extent*sizeof(*string));
   if (string == (char *) NULL)
     {
       file=close(file)-1;
@@ -621,7 +609,7 @@ MagickExport StringInfo *ConfigureFileToStringInfo(const char *filename)
   file=close(file)-1;
   string_info=AcquireStringInfo(0);
   (void) CopyMagickString(string_info->path,filename,MaxTextExtent);
-  string_info->length=strlen(string)+1;
+  string_info->length=length;
   string_info->datum=(unsigned char *) string;
   return(string_info);
 }
@@ -704,7 +692,6 @@ MagickExport char *ConstantString(const char *source)
 MagickExport size_t CopyMagickString(char *destination,const char *source,
   const size_t length)
 {
-#if !defined(HAVE_STRLCPY)
   register char
     *q;
 
@@ -712,30 +699,41 @@ MagickExport size_t CopyMagickString(char *destination,const char *source,
     *p;
 
   register size_t
-    i;
+    n;
 
-  assert(destination != (char *) NULL);
-  assert(source != (const char *) NULL);
-  assert(length >= 1);
   p=source;
   q=destination;
-  i=length;
-  if ((i != 0) && (--i != 0))
-    do
+  for (n=length; n > 4; n-=4)
+  {
+    *q=(*p++);
+    if (*q == '\0')
+      return((size_t) (p-source-1));
+    q++;
+    *q=(*p++);
+    if (*q == '\0')
+      return((size_t) (p-source-1));
+    q++;
+    *q=(*p++);
+    if (*q == '\0')
+      return((size_t) (p-source-1));
+    q++;
+    *q=(*p++);
+    if (*q == '\0')
+      return((size_t) (p-source-1));
+    q++;
+  }
+  if (n != 0)
+    for (n--; n != 0; n--)
     {
-      if ((*q++=(*p++)) == '\0')
-        break;
-    } while (--i != 0);
-  if (i == 0)
-    {
-      if (length != 0)
-        *q='\0';
-      while (*p++ != '\0');
+      *q=(*p++);
+      if (*q == '\0')
+        return((size_t) (p-source-1));
+      q++;
     }
+  if (length != 0)
+    *q='\0';
+  while (*p++ != '\0');
   return((size_t) (p-source-1));
-#else
-  return(strlcpy(destination,source,length));
-#endif
 }
 
 /*
@@ -796,8 +794,8 @@ MagickExport StringInfo *DestroyStringInfo(StringInfo *string_info)
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   if (string_info->datum != (unsigned char *) NULL)
-    string_info->datum=(unsigned char *)
-      RelinquishMagickMemory(string_info->datum);
+    string_info->datum=(unsigned char *) RelinquishMagickMemory(
+      string_info->datum);
   string_info->signature=(~MagickSignature);
   string_info=(StringInfo *) RelinquishMagickMemory(string_info);
   return(string_info);
@@ -897,7 +895,7 @@ MagickExport char *EscapeString(const char *source,const char escape)
       for (p=source; *p != '\0'; p++)
       {
         if ((*p == '\\') || (*p == escape))
-          *q++= '\\';
+          *q++='\\';
         *q++=(*p);
       }
       *q='\0';
@@ -1534,8 +1532,8 @@ MagickExport void SetStringInfo(StringInfo *string_info,
   assert(source != (StringInfo *) NULL);
   assert(source->signature == MagickSignature);
   (void) ResetMagickMemory(string_info->datum,0,string_info->length);
-  (void) CopyMagickMemory(string_info->datum,source->datum,
-    Min(string_info->length,source->length));
+  (void) CopyMagickMemory(string_info->datum,source->datum,Min(
+    string_info->length,source->length));
 }
 
 /*
@@ -1601,17 +1599,20 @@ MagickExport void SetStringInfoDatum(StringInfo *string_info,
 MagickExport void SetStringInfoLength(StringInfo *string_info,
   const size_t length)
 {
+  size_t
+    extent;
+
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   string_info->length=length;
-  (void) CheckOverflowException(length,MaxTextExtent);
+  extent=CheckOverflowException(length,MaxTextExtent);
   if (string_info->datum == (unsigned char *) NULL)
-    string_info->datum=(unsigned char *)
-      AcquireMagickMemory((length+MaxTextExtent)*sizeof(*string_info->datum));
+    string_info->datum=(unsigned char *) AcquireMagickMemory(extent*
+      sizeof(*string_info->datum));
   else
     string_info->datum=(unsigned char *) ResizeMagickMemory(string_info->datum,
-      (length+MaxTextExtent)*sizeof(*string_info->datum));
+      extent*sizeof(*string_info->datum));
   if (string_info->datum == (unsigned char *) NULL)
     {
       char
@@ -2016,8 +2017,8 @@ MagickExport char **StringToList(const char *text)
       for (p=text; *p != '\0'; p++)
         if (*p == '\n')
           lines++;
-      textlist=(char **)
-        AcquireMagickMemory((size_t) (lines+1)*sizeof(*textlist));
+      textlist=(char **) AcquireMagickMemory((size_t) (lines+1)*
+        sizeof(*textlist));
       if (textlist == (char **) NULL)
         ThrowMagickFatalException(ResourceLimitFatalError,"UnableToConvertText",
           text);
@@ -2027,8 +2028,8 @@ MagickExport char **StringToList(const char *text)
         for (q=(char *) p; *q != '\0'; q++)
           if ((*q == '\r') || (*q == '\n'))
             break;
-        textlist[i]=(char *)
-          AcquireMagickMemory(((q-p)+MaxTextExtent)*sizeof(*textlist));
+        textlist[i]=(char *) AcquireMagickMemory(((q-p)+MaxTextExtent)*
+          sizeof(*textlist));
         if (textlist[i] == (char *) NULL)
           ThrowMagickFatalException(ResourceLimitFatalError,
             "UnableToConvertText",text);
@@ -2050,16 +2051,16 @@ MagickExport char **StringToList(const char *text)
         Convert string to a HEX list.
       */
       lines=(unsigned long) (strlen(text)/0x14)+1;
-      textlist=(char **)
-        AcquireMagickMemory((size_t) (lines+1)*sizeof(*textlist));
+      textlist=(char **) AcquireMagickMemory((size_t) (lines+1)*
+        sizeof(*textlist));
       if (textlist == (char **) NULL)
         ThrowMagickFatalException(ResourceLimitFatalError,"UnableToConvertText",
           text);
       p=text;
       for (i=0; i < (long) lines; i++)
       {
-        textlist[i]=(char *)
-          AcquireMagickMemory(2*MaxTextExtent*sizeof(*textlist));
+        textlist[i]=(char *) AcquireMagickMemory(2*MaxTextExtent*
+          sizeof(*textlist));
         if (textlist[i] == (char *) NULL)
           ThrowMagickFatalException(ResourceLimitFatalError,
             "UnableToConvertText",text);
@@ -2194,8 +2195,8 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
     destination_offset;
 
   size_t
-    allocate_length,
     copy_length,
+    extent,
     replace_length,
     result_length,
     search_length;
@@ -2211,8 +2212,8 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
   match=strstr(source,search);
   if (match == (char *) NULL)
     return(MagickFalse);
-  allocate_length=CheckOverflowException(strlen(source),MaxTextExtent);
-  result=(char *) AcquireMagickMemory(allocate_length*sizeof(*result));
+  extent=CheckOverflowException(strlen(source),MaxTextExtent);
+  result=(char *) AcquireMagickMemory(extent*sizeof(*result));
   if (result == (char *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
       search);
@@ -2229,11 +2230,11 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
     if (copy_length != 0)
       {
         result_length+=copy_length;
-        if ((result_length+MaxTextExtent) >= allocate_length)
+        if ((result_length+MaxTextExtent) >= extent)
           {
-            allocate_length+=copy_length;
-            result=(char *) ResizeMagickMemory(result,
-              (allocate_length+MaxTextExtent)*sizeof(*result));
+            extent+=copy_length;
+            result=(char *) ResizeMagickMemory(result,(extent+MaxTextExtent)*
+              sizeof(*result));
             if (result == (char *) NULL)
               ThrowMagickFatalException(ResourceLimitFatalError,
                 "UnableToAcquireString",search);
@@ -2245,17 +2246,17 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
       Copy replacement.
     */
     result_length+=replace_length;
-    if ((result_length+MaxTextExtent) >= allocate_length)
+    if ((result_length+MaxTextExtent) >= extent)
       {
-        allocate_length+=replace_length;
-        result=(char *) ResizeMagickMemory(result,(allocate_length+
-          MaxTextExtent)*sizeof(*result));
+        extent+=replace_length;
+        result=(char *) ResizeMagickMemory(result,(extent+MaxTextExtent)*
+          sizeof(*result));
         if (result == (char *) NULL)
           ThrowMagickFatalException(ResourceLimitFatalError,
             "UnableToAcquireString",search);
       }
     (void) ConcatenateMagickString(result+destination_offset,replace,
-      (allocate_length+MaxTextExtent)*sizeof(*result));
+      (extent+MaxTextExtent)*sizeof(*result));
     destination_offset+=replace_length;
     /*
       Find next match.
@@ -2269,17 +2270,17 @@ MagickExport MagickBooleanType SubstituteString(char **buffer,
   */
   copy_length=strlen(source);
   result_length+=copy_length;
-  if ((result_length+MaxTextExtent) >= allocate_length)
+  if ((result_length+MaxTextExtent) >= extent)
     {
-      allocate_length+=copy_length;
-      result=(char *) ResizeMagickMemory(result,
-        (allocate_length+MaxTextExtent)*sizeof(*result));
+      extent+=copy_length;
+      result=(char *) ResizeMagickMemory(result,(extent+MaxTextExtent)*
+        sizeof(*result));
       if (result == (char *) NULL)
         ThrowMagickFatalException(ResourceLimitFatalError,
           "UnableToAcquireString",search);
     }
-  (void) ConcatenateMagickString(result+destination_offset,source,
-    (allocate_length+MaxTextExtent-destination_offset)*sizeof(*result));
+  (void) ConcatenateMagickString(result+destination_offset,source,(size_t)
+    (extent+MaxTextExtent-destination_offset)*sizeof(*result));
   (void) RelinquishMagickMemory(*buffer);
   *buffer=result;
   return(MagickTrue);
