@@ -52,12 +52,14 @@ extern MagickExport char
   *GetEnvironmentValue(const char *),
   **StringToArgv(const char *,int *),
   **StringToList(const char *),
-  *StringInfoToString(const StringInfo *);
+  *StringInfoToString(const StringInfo *),
+  *StringToken(const char *,char **);
 
 extern MagickExport double
   StringToDouble(const char *,const double);
 
 extern MagickExport long
+  FormatMagickSize(const MagickSizeType,char *),
   FormatMagickString(char *,const size_t,const char *,...)
     magick_attribute((format (printf,3,4))),
   FormatMagickStringList(char *,const size_t,const char *,va_list)
