@@ -126,7 +126,9 @@ extern "C" {
 #endif
 
 #define MagickSignature  0xabacadabUL
-#define MaxTextExtent  4096
+#if !defined(MaxTextExtent)
+# define MaxTextExtent  4096
+#endif
 
 #include <stdarg.h>
 #include <stdio.h>
@@ -351,7 +353,7 @@ extern size_t
 #define O_BINARY  0x00
 #endif
 
-#if defined(HasLTDL) || (defined(__WINDOWS__) && defined(_DLL))
+#if defined(HasLTDL) || (defined(__WINDOWS__) && defined(_DLL) && !defined(_LIB))
 #  define SupportMagickModules
 #endif
 
