@@ -41,7 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/cache-view.h"
 #include "magick/color.h"
@@ -599,14 +599,14 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   }
   description = GetXMLTreeChild(threshold,"description");
   if ( description == (XMLTreeInfo *)NULL ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingElement", "<description>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     return(map);
   }
   levels = GetXMLTreeChild(threshold,"levels");
   if ( levels == (XMLTreeInfo *)NULL ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingElement", "<levels>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     return(map);
@@ -632,7 +632,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
 
   attr = GetXMLTreeAttribute(levels, "width");
   if ( attr == (char *)NULL ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingAttribute", "<levels width>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -640,7 +640,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   }
   map->width = atoi(attr);
   if ( map->width == 0 ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlInvalidAttribute", "<levels width>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -649,7 +649,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
 
   attr = GetXMLTreeAttribute(levels, "height");
   if ( attr == (char *)NULL ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingAttribute", "<levels height>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -657,7 +657,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   }
   map->height = atoi(attr);
   if ( map->height == 0 ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlInvalidAttribute", "<levels height>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -666,7 +666,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
 
   attr = GetXMLTreeAttribute(levels, "divisor");
   if ( attr == (char *)NULL ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingAttribute", "<levels divisor>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -674,7 +674,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   }
   map->divisor = atoi(attr);
   if ( map->divisor < 2 ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlInvalidAttribute", "<levels divisor>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -684,7 +684,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   /* Allocate the theshold levels array */
   content = GetXMLTreeContent(levels);
   if ( content == (char *)NULL ) {
-    ThrowMagickException(exception,GetMagickModule(),OptionError,
+   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingContent", "<levels>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
@@ -702,14 +702,14 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
     for( i=0; i<map->width*map->height; i++) {
       map->levels[i] = (int)strtol(content, &p, 10);
       if ( p == content ) {
-        ThrowMagickException(exception,GetMagickModule(),OptionError,
+       (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
           "XmlInvalidContent", "<level> too few values, map \"%s\"", map_id);
         thresholds = DestroyXMLTree(thresholds);
         map = DestroyThresholdMap(map);
         return(map);
       }
       if ( map->levels[i] < 0 || map->levels[i] > map->divisor ) {
-        ThrowMagickException(exception,GetMagickModule(),OptionError,
+       (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
           "XmlInvalidContent", "<level> %d out of range, map \"%s\"",
           map->levels[i], map_id);
         thresholds = DestroyXMLTree(thresholds);
@@ -720,7 +720,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
     }
     (void) strtol(content, &p, 10);
     if ( p != content ) {
-        ThrowMagickException(exception,GetMagickModule(),OptionError,
+       (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
           "XmlInvalidContent", "<level> too many values, map \"%s\"", map_id);
       thresholds = DestroyXMLTree(thresholds);
       map = DestroyThresholdMap(map);
@@ -825,16 +825,16 @@ MagickBooleanType ListThresholdMapFile(FILE *file,const char *xml,
   if ( thresholds == (XMLTreeInfo *)NULL )
     return(MagickFalse);
 
-  (void) fprintf(file, "  %-16s %-12s %s\n", "Map", "Alias", "Description");
-  (void) fprintf(file, "---------------------------------------------------\n");
+  (void) fprintf(file,"%-16s %-12s %s\n", "Map", "Alias", "Description");
+  (void) fprintf(file,"----------------------------------------------------\n");
 
   for( threshold = GetXMLTreeChild(thresholds,"threshold");
        threshold != (XMLTreeInfo *)NULL;
        threshold = GetNextXMLTreeTag(threshold) )
   {
     map = GetXMLTreeAttribute(threshold, "map");
-    if ( map == (char *)NULL ) {
-      ThrowMagickException(exception,GetMagickModule(),OptionError,
+    if (map == (char *) NULL) {
+     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingAttribute", "<map>");
       thresholds=DestroyXMLTree(thresholds);
       return(MagickFalse);
@@ -843,21 +843,20 @@ MagickBooleanType ListThresholdMapFile(FILE *file,const char *xml,
     /* alias is optional, no if test needed */
     description=GetXMLTreeChild(threshold,"description");
     if ( description == (XMLTreeInfo *)NULL ) {
-      ThrowMagickException(exception,GetMagickModule(),OptionError,
+     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingElement", "<description>, map \"%s\"", map);
       thresholds=DestroyXMLTree(thresholds);
       return(MagickFalse);
     }
     content=GetXMLTreeContent(description);
     if ( content == (char *)NULL ) {
-      ThrowMagickException(exception,GetMagickModule(),OptionError,
+     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
          "XmlMissingContent", "<description>, map \"%s\"", map);
       thresholds=DestroyXMLTree(thresholds);
       return(MagickFalse);
     }
-    (void) fprintf(file, "  %-16s %-12s %s\n", map, alias?alias:"", content );
+    (void) fprintf(file,"%-16s %-12s %s\n",map,alias ? alias : "", content);
   }
-  (void)fprintf(file,"---------------------------------------------------\n\n");
   thresholds=DestroyXMLTree(thresholds);
   return(MagickTrue);
 }
@@ -1037,8 +1036,7 @@ MagickExport MagickBooleanType OrderedPosterizeImage(Image *image,
 }
 
 MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
-  const ChannelType channel, const char *threshold_map,
-  ExceptionInfo *exception)
+  const ChannelType channel,const char *threshold_map,ExceptionInfo *exception)
 {
 #define DitherImageTag  "Dither/Image"
   ThresholdMap
@@ -1084,17 +1082,12 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
     token[p-threshold_map] = '\0';
     map = GetThresholdMap(token, exception);
     if ( map == (ThresholdMap *)NULL ) {
-      ThrowMagickException(exception,GetMagickModule(),
+     (void) ThrowMagickException(exception,GetMagickModule(),
           OptionError,"InvalidArgument","%s : '%s'",
           "ordered-dither", threshold_map);
       return(MagickFalse);
     }
   }
-#if 0
-printf("DEBUG: map = %s \"%s\" (%d,%d)/%d\n", map->map_id, map->description,
-               map->width, map->height, map->divisor);
-#endif
-
   /* Set channel levels from extra comma seperated arguments
      Default to 2, or single value given, or individual channel values
   */
@@ -1121,15 +1114,15 @@ printf("DEBUG: map = %s \"%s\" (%d,%d)/%d\n", map->map_id, map->description,
       p=strchr(threshold_map,',');
       p++;
       if ((channel & RedChannel) != 0)
-        levels.red = strtol(p, &p, 10),   (void)(*p == ',' && p++);
+        levels.red = (Quantum) strtol(p, &p, 10),   (void)(*p == ',' && p++);
       if ((channel & GreenChannel) != 0)
-        levels.green = strtol(p, &p, 10), (void)(*p == ',' && p++);
+        levels.green = (Quantum) strtol(p, &p, 10), (void)(*p == ',' && p++);
       if ((channel & BlueChannel) != 0)
-        levels.blue = strtol(p, &p, 10),  (void)(*p == ',' && p++);
+        levels.blue = (Quantum) strtol(p, &p, 10),  (void)(*p == ',' && p++);
       if ((channel & OpacityChannel) != 0)
-        levels.opacity = strtol(p, &p, 10), (void)(*p == ',' && p++);
+        levels.opacity = (Quantum) strtol(p, &p, 10), (void)(*p == ',' && p++);
       if ((channel & IndexChannel) != 0 && image->colorspace == CMYKColorspace)
-        levels.index = strtol(p, &p, 10), (void)(*p == ',' && p++);
+        levels.index=(IndexPacket) strtol(p, &p, 10), (void)(*p == ',' && p++);
     }
   }
 #else
@@ -1199,29 +1192,31 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
               NB: All input levels and divisor are already had 1 subtracted
         */
         if (levels.red) {
-          t = q->red*(levels.red*d+1)/(QuantumRange+1);
+          t = (int) (QuantumScale*q->red*(levels.red*d+1));
           l = t/d;  t = t-l*d;
-          q->red = ( l+(t>=threshold) ) * QuantumRange / levels.red;
+          q->red=(Quantum) ((l+(t >= threshold))*QuantumRange/levels.red);
         }
         if (levels.green) {
-          t = q->green*(levels.green*d+1)/(QuantumRange+1);
+          t = (int) (QuantumScale*q->green*(levels.green*d+1));
           l = t/d;  t = t-l*d;
-          q->green = ( l+(t>=threshold) ) * QuantumRange / levels.green;
+          q->green=(Quantum) ((l+(t >= threshold))*QuantumRange/levels.green);
         }
         if (levels.blue) {
-          t = q->blue*(levels.blue*d+1)/(QuantumRange+1);
+          t = (int) (QuantumScale*q->blue*(levels.blue*d+1));
           l = t/d;  t = t-l*d;
-          q->blue = ( l+(t>=threshold) ) * QuantumRange / levels.blue;
+          q->blue=(Quantum) ((l+(t >= threshold))*QuantumRange/levels.blue);
         }
         if (levels.opacity) {
-          t = q->opacity*(levels.opacity*d+1)/(QuantumRange+1);
+          t = (int) (QuantumScale*q->opacity*(levels.opacity*d+1));
           l = t/d;  t = t-l*d;
-          q->opacity = ( l+(t>=threshold) ) * QuantumRange / levels.opacity;
+          q->opacity=(Quantum) ((l+(t >= threshold))*QuantumRange/
+            levels.opacity);
         }
         if (levels.index) {
-          t = indexes[x]*(levels.index*d+1)/(QuantumRange+1);
+          t = (int) (QuantumScale*indexes[x]*(levels.index*d+1));
           l = t/d;  t = t-l*d;
-          indexes[x] = ( l+(t>=threshold) ) * QuantumRange / levels.index;
+          indexes[x]=(IndexPacket) ((l+(t>=threshold))*QuantumRange/
+            levels.index);
         }
         q++;
       }
@@ -1238,8 +1233,7 @@ printf("DEBUG levels  r=%ld g=%ld b=%ld a=%ld i=%ld\n",
         }
     }
   }
-
-  DestroyThresholdMap(map);
+  map=DestroyThresholdMap(map);
   return(MagickTrue);
 }
 
@@ -1353,8 +1347,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
         Backward Compatibility -- ordered-dither -- IM v 6.2.9-6
         outputing a WARNING here may be appropriate -- discontinue in future
       */
-      status=OrderedPosterizeImageChannel(image,channel,thresholds,
-            exception);
+      status=OrderedPosterizeImageChannel(image,channel,thresholds,exception);
       return(status);
     }
 
