@@ -40,6 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/cache-view.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/composite.h"
@@ -85,7 +86,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
   ExceptionInfo *exception)
@@ -235,180 +235,6 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%     C o a l e s c e I m a g e s                                             %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  CoalesceImages() composites a set of images while respecting any page
-%  offsets and disposal methods.  GIF, MIFF, and MNG animation sequences
-%  typically start with an image background and each subsequent image
-%  varies in size and offset.  CoalesceImages() returns a new sequence
-%  where each image in the sequence is the same size as the first and
-%  composited with the next image in the sequence.
-%
-%  The format of the CoalesceImages method is:
-%
-%      Image *CoalesceImages(Image *image,ExceptionInfo *exception)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image sequence.
-%
-%    o exception: Return any errors or warnings in this structure.
-%
-*/
-MagickExport Image *CoalesceImages(Image *image,ExceptionInfo *exception)
-{
-  Image
-    *coalesce_image;
-
-  Image
-    *dispose_image;
-
-  long
-    y;
-
-  register const PixelPacket
-    *p;
-
-  register Image
-    *next;
-
-  register long
-    x;
-
-  register PixelPacket
-    *q;
-
-  RectangleInfo
-    region;
-
-  /*
-    Coalesce the image sequence.
-  */
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  assert(exception != (ExceptionInfo *) NULL);
-  assert(exception->signature == MagickSignature);
-  coalesce_image=CloneImage(image,image->page.width,image->page.height,
-    MagickTrue,exception);
-  if (coalesce_image == (Image *) NULL)
-    return((Image *) NULL);
-  coalesce_image->page=image->page;
-  coalesce_image->page.x=0;
-  coalesce_image->page.y=0;
-  coalesce_image->dispose=NoneDispose;
-  coalesce_image->background_color.opacity=TransparentOpacity;
-  SetImageBackgroundColor(coalesce_image);
-  dispose_image=CloneImage(coalesce_image,0,0,MagickTrue,exception);
-  (void) CompositeImage(coalesce_image,CopyCompositeOp,image,image->page.x,
-    image->page.y);
-  next=GetNextImageInList(image);
-  for ( ; next != (Image *) NULL; next=GetNextImageInList(next))
-  {
-    /*
-      Determine the region that was overlaid in the previous image.
-    */
-    region=GetPreviousImageInList(next)->page;
-    region.width=GetPreviousImageInList(next)->columns;
-    region.height=GetPreviousImageInList(next)->rows;
-    if (region.x < 0)
-      {
-        region.width+=region.x;
-        region.x=0;
-      }
-    if ((region.x+region.width) > (long) coalesce_image->columns)
-      region.width=coalesce_image->columns-region.x;
-    if (region.y < 0)
-      {
-        region.height+=region.y;
-        region.y=0;
-      }
-    if ((region.y+region.height) > (long) coalesce_image->rows)
-      region.height=coalesce_image->rows-region.y;
-    if (GetPreviousImageInList(next)->dispose != PreviousDispose)
-      {
-        /*
-          Replace the dispose image with the new coalesced image.
-        */
-        dispose_image=DestroyImage(dispose_image);
-        dispose_image=CloneImage(coalesce_image,0,0,MagickTrue,exception);
-        if (dispose_image == (Image *) NULL)
-          {
-            coalesce_image=DestroyImageList(coalesce_image);
-            return((Image *) NULL);
-          }
-      }
-    /*
-      Background: Clear the overlaid area of the coalesced region,
-    */
-    if (next->previous->dispose == BackgroundDispose)
-      for (y=0; y < (long) region.height; y++)
-      {
-        q=GetImagePixels(dispose_image,region.x,region.y+y,region.width,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        for (x=0; x < (long) region.width; x++)
-        {
-          q->opacity=TransparentOpacity;
-          q++;
-        }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-      }
-    /*
-      Next image is the dispose image, overlay with next image in sequence.
-    */
-    coalesce_image->next=CloneImage(dispose_image,0,0,MagickTrue,exception);
-    coalesce_image->next->previous=coalesce_image;
-    coalesce_image=GetNextImageInList(coalesce_image);
-    coalesce_image->matte=MagickTrue;
-    coalesce_image->delay=next->delay;
-    coalesce_image->ticks_per_second=next->ticks_per_second;
-    coalesce_image->start_loop=next->start_loop;
-    (void) CompositeImage(coalesce_image,next->matte != MagickFalse ?
-      OverCompositeOp : CopyCompositeOp,next,next->page.x,next->page.y);
-    /*
-      Fix disposal setting of previous image, for correct animation.
-    */
-    for (y=0; y < (long) region.height; y++)
-    {
-      p=AcquireImagePixels(GetPreviousImageInList(coalesce_image),region.x,
-        region.y+y,region.width,1,exception);
-      q=GetImagePixels(coalesce_image,region.x,region.y+y,region.width,1);
-      if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-        break;
-      for (x=0; x < (long) region.width; x++)
-      {
-        if (((double) p->opacity <= (QuantumRange/2.0)) &&
-            ((double) q->opacity > (QuantumRange/2.0)))
-          break;
-        p++;
-        q++;
-      }
-      if (x < (long) region.width)
-        break;
-    }
-    /*
-      If pixel goes opaque to transparent, use background dispose.
-    */
-    GetPreviousImageInList(coalesce_image)->dispose=y < (long) region.height ?
-      BackgroundDispose : NoneDispose;
-    coalesce_image->dispose=GetPreviousImageInList(coalesce_image)->dispose;
-  }
-  dispose_image=DestroyImage(dispose_image);
-  return(GetFirstImageInList(coalesce_image));
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 +     C o n s o l i d a t e C M Y K I m a g e                                 %
 %                                                                             %
 %                                                                             %
@@ -576,7 +402,6 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
   ExceptionInfo *exception)
@@ -606,6 +431,10 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
   register PixelPacket
     *q;
 
+  ViewInfo
+    *crop_view,
+    *image_view;
+
   /*
     Check crop geometry.
   */
@@ -627,10 +456,10 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
     page.width=bounding_box.width;
   if (page.height == 0)
     page.height=bounding_box.height;
-  if (((bounding_box.x-page.x) > (long) page.width) ||
-      ((bounding_box.y-page.y) > (long) page.height) ||
-      ((page.x-bounding_box.x) >= (long) image->columns) ||
-      ((page.y-bounding_box.y) >= (long) image->rows))
+  if (((bounding_box.x-page.x) >= (long) page.width) ||
+      ((bounding_box.y-page.y) >= (long) page.height) ||
+      ((page.x-bounding_box.x) > (long) image->columns) ||
+      ((page.y-bounding_box.y) > (long) image->rows))
     {
       (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
         "GeometryDoesNotContainImage","`%s'",image->filename);
@@ -638,13 +467,13 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       if (crop_image == (Image *) NULL)
         return((Image *) NULL);
       crop_image->background_color.opacity=TransparentOpacity;
-      SetImageBackgroundColor(crop_image);
+      (void) SetImageBackgroundColor(crop_image);
       crop_image->page=bounding_box;
       crop_image->page.x=(-1);
       crop_image->page.y=(-1);
       return(crop_image);
     }
-  if (page.x < 0)
+  if ((page.x < 0) && (bounding_box.x >= 0))
     {
       page.width+=page.x-bounding_box.x;
       page.x=0;
@@ -656,7 +485,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       if (page.x < 0)
         page.x=0;
     }
-  if (page.y < 0)
+  if ((page.y < 0) && (bounding_box.y >= 0))
     {
       page.height+=page.y-bounding_box.y;
       page.y=0;
@@ -689,21 +518,33 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
   /*
     Extract crop image.
   */
-  crop_image->page=bounding_box;
+  crop_image->page.width=image->page.width;
+  crop_image->page.height=image->page.height;
+  if (((long) (bounding_box.x+bounding_box.width) > (long) image->page.width) ||
+      ((long) (bounding_box.y+bounding_box.height) > (long) image->page.height))
+    {
+      crop_image->page.width=bounding_box.width;
+      crop_image->page.height=bounding_box.height;
+    }
+  crop_image->page.x=bounding_box.x;
+  crop_image->page.y=bounding_box.y;
+  image_view=OpenCacheView(image);
+  crop_view=OpenCacheView(crop_image);
   for (y=0; y < (long) crop_image->rows; y++)
   {
-    p=AcquireImagePixels(image,page.x,page.y+y,crop_image->columns,1,exception);
-    q=SetImagePixels(crop_image,0,y,crop_image->columns,1);
+    p=AcquireCacheView(image_view,page.x,page.y+y,crop_image->columns,1,
+      exception);
+    q=SetCacheView(crop_view,0,y,crop_image->columns,1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
     (void) CopyMagickMemory(q,p,(size_t) crop_image->columns*sizeof(*q));
-    indexes=GetIndexes(image);
-    crop_indexes=GetIndexes(crop_image);
+    indexes=GetCacheViewIndexes(image_view);
+    crop_indexes=GetCacheViewIndexes(crop_view);
     if ((indexes != (IndexPacket *) NULL) &&
         (crop_indexes != (IndexPacket *) NULL))
       (void) CopyMagickMemory(crop_indexes,indexes,(size_t) crop_image->columns*
         sizeof(*crop_indexes));
-    if (SyncImagePixels(crop_image) == MagickFalse)
+    if (SyncCacheView(crop_view) == MagickFalse)
       break;
     if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
         (QuantumTick(y,image->rows) != MagickFalse))
@@ -714,6 +555,8 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
           break;
       }
   }
+  crop_view=CloseCacheView(crop_view);
+  image_view=CloseCacheView(image_view);
   return(crop_image);
 }
 
@@ -722,218 +565,61 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%     D e c o n s t r u c t I m a g e s                                       %
+%   E x t e n t I m a g e                                                     %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  DeconstructImages() compares each image with the next in a sequence and
-%  returns the maximum bounding region of any pixel differences it discovers.
+%  ExtentImage() extends the image as defined by the geometry and gravity.
 %
-%  The format of the DeconstructImages method is:
+%  The format of the ExtentImage method is:
 %
-%      Image *DeconstructImages(const Image *image,ExceptionInfo *exception)
+%      Image *ExtentImage(const Image *image,const RectangleInfo *geometry,
+%        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
+%    o geometry: Define the region of the image to extend with members
+%      x, y, width, and height.
+%
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
-MagickExport Image *DeconstructImages(const Image *image,
-  ExceptionInfo *exception)
+MagickExport Image *ExtentImage(const Image *image,
+  const RectangleInfo *geometry,ExceptionInfo *exception)
 {
   Image
-    *crop_image,
-    *crop_next,
-    *deconstruct_image;
-
-  long
-    y;
-
-  MagickPixelPacket
-    pixel,
-    target;
-
-  RectangleInfo
-    *bounds;
-
-  register const Image
-    *next;
-
-  register const PixelPacket
-    *p,
-    *q;
-
-  register IndexPacket
-    *indexes,
-    *next_indexes;
-
-  register long
-    i,
-    x;
+    *extent_image;
 
+  /*
+    Allocate extent image.
+  */
   assert(image != (const Image *) NULL);
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(geometry != (const RectangleInfo *) NULL);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  /*
-    Ensure the image are the same size.
-  */
-  for (next=image; next != (Image *) NULL; next=GetNextImageInList(next))
-  {
-    if ((next->columns != image->columns) || (next->rows != image->rows))
-      ThrowImageException(OptionError,"ImagesAreNotTheSameSize");
-  }
-  /*
-    Allocate memory.
-  */
-  bounds=(RectangleInfo *) AcquireMagickMemory((size_t)
-    GetImageListLength(image)*sizeof(*bounds));
-  if (bounds == (RectangleInfo *) NULL)
-    ThrowImageException(ResourceLimitError,"MemoryAllocationFailed");
-  /*
-    Compute the bounding box for each next in the sequence.
-  */
-  i=0;
-  GetMagickPixelPacket(image,&pixel);
-  GetMagickPixelPacket(image,&target);
-  next=GetNextImageInList(image);
-  for ( ; next != (const Image *) NULL; next=GetNextImageInList(next))
-  {
-    /*
-      Set bounding box to the next dimensions.
-    */
-    for (x=0; x < (long) next->columns; x++)
+  extent_image=CloneImage(image,geometry->width,geometry->height,MagickTrue,
+    exception);
+  if (extent_image == (Image *) NULL)
+    return((Image *) NULL);
+  if (SetImageStorageClass(extent_image,DirectClass) == MagickFalse)
     {
-      p=AcquireImagePixels(next,x,0,1,next->rows,exception);
-      q=AcquireImagePixels(next->previous,x,0,1,next->previous->rows,exception);
-      if ((p == (const PixelPacket *) NULL) ||
-          (q == (const PixelPacket *) NULL))
-        break;
-      indexes=GetIndexes(next);
-      next_indexes=GetIndexes(next->previous);
-      for (y=0; y < (long) next->rows; y++)
-      {
-        SetMagickPixelPacket(p,indexes+x,&pixel);
-        SetMagickPixelPacket(q,next_indexes+x,&target);
-        if (IsMagickColorSimilar(&pixel,&target) == MagickFalse)
-          break;
-        p++;
-        q++;
-      }
-      if (y < (long) next->rows)
-        break;
-    }
-    bounds[i].x=x;
-    for (y=0; y < (long) next->rows; y++)
-    {
-      p=AcquireImagePixels(next,0,y,next->columns,1,exception);
-      q=AcquireImagePixels(next->previous,0,y,next->previous->columns,1,
-        exception);
-      if ((p == (const PixelPacket *) NULL) ||
-          (q == (const PixelPacket *) NULL))
-        break;
-      indexes=GetIndexes(next);
-      next_indexes=GetIndexes(next->previous);
-      for (x=0; x < (long) next->columns; x++)
-      {
-        SetMagickPixelPacket(p,indexes+x,&pixel);
-        SetMagickPixelPacket(q,next_indexes+x,&target);
-        if (IsMagickColorSimilar(&pixel,&target) == MagickFalse)
-          break;
-        p++;
-        q++;
-      }
-      if (x < (long) next->columns)
-        break;
-    }
-    bounds[i].y=y;
-    for (x=(long) next->columns-1; x >= 0; x--)
-    {
-      p=AcquireImagePixels(next,x,0,1,next->rows,exception);
-      q=AcquireImagePixels(next->previous,x,0,1,next->previous->rows,exception);
-      if ((p == (const PixelPacket *) NULL) ||
-          (q == (const PixelPacket *) NULL))
-        break;
-      indexes=GetIndexes(next);
-      next_indexes=GetIndexes(next->previous);
-      for (y=0; y < (long) next->rows; y++)
-      {
-        SetMagickPixelPacket(p,indexes+x,&pixel);
-        SetMagickPixelPacket(q,next_indexes+x,&target);
-        if (IsMagickColorSimilar(&pixel,&target) == MagickFalse)
-          break;
-        p++;
-        q++;
-      }
-      if (y < (long) next->rows)
-        break;
-    }
-    bounds[i].width=(unsigned long) (x-bounds[i].x+1);
-    for (y=(long) next->rows-1; y >= 0; y--)
-    {
-      p=AcquireImagePixels(next,0,y,next->columns,1,exception);
-      q=AcquireImagePixels(next->previous,0,y,next->previous->columns,1,
-        exception);
-      if ((p == (const PixelPacket *) NULL) ||
-          (q == (const PixelPacket *) NULL))
-        break;
-      indexes=GetIndexes(next);
-      next_indexes=GetIndexes(next->previous);
-      for (x=0; x < (long) next->columns; x++)
-      {
-        SetMagickPixelPacket(p,indexes+x,&pixel);
-        SetMagickPixelPacket(q,next_indexes+x,&target);
-        if (IsMagickColorSimilar(&pixel,&target) == MagickFalse)
-          break;
-        p++;
-        q++;
-      }
-      if (x < (long) next->columns)
-        break;
-    }
-    bounds[i].height=(unsigned long) (y-bounds[i].y+1);
-    i++;
-  }
-  /*
-    Clone first image in sequence.
-  */
-  deconstruct_image=CloneImage(image,0,0,MagickTrue,exception);
-  if (deconstruct_image == (Image *) NULL)
-    {
-      bounds=(RectangleInfo *) RelinquishMagickMemory(bounds);
+      InheritException(exception,&extent_image->exception);
+      extent_image=DestroyImage(extent_image);
       return((Image *) NULL);
     }
-  /*
-    Deconstruct the image sequence.
-  */
-  i=0;
-  next=GetNextImageInList(image);
-  for ( ; next != (const Image *) NULL; next=GetNextImageInList(next))
-  {
-    crop_image=CloneImage(next,0,0,MagickTrue,exception);
-    if (crop_image == (Image *) NULL)
-      break;
-    crop_next=CropImage(crop_image,&bounds[i],exception);
-    crop_image=DestroyImage(crop_image);
-    if (crop_next == (Image *) NULL)
-      break;
-    AppendImageToList(&deconstruct_image,crop_next);
-    i++;
-  }
-  bounds=(RectangleInfo *) RelinquishMagickMemory(bounds);
-  if (next != (Image *) NULL)
-    {
-      deconstruct_image=DestroyImageList(deconstruct_image);
-      return((Image *) NULL);
-    }
-  return(GetFirstImageInList(deconstruct_image));
+  if (image->background_color.opacity != OpaqueOpacity)
+    extent_image->matte=MagickTrue;
+  (void) SetImageBackgroundColor(extent_image);
+  (void) CompositeImage(extent_image,image->compose,image,-geometry->x,
+    -geometry->y);
+  return(extent_image);
 }
 
 /*
@@ -1002,7 +688,7 @@ MagickExport Image *FlattenImages(Image *image,ExceptionInfo *exception)
   flatten_image=CloneImage(image,page.width,page.height,MagickTrue,exception);
   if (flatten_image == (Image *) NULL)
     return((Image *) NULL);
-  SetImageBackgroundColor(flatten_image);
+  (void) SetImageBackgroundColor(flatten_image);
   flatten_image->page=page;
   /*
     Flatten the images.
@@ -1049,7 +735,6 @@ MagickExport Image *FlattenImages(Image *image,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
 {
@@ -1141,7 +826,6 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
 {
@@ -1240,7 +924,6 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *MosaicImages(Image *image,ExceptionInfo *exception)
 {
@@ -1297,7 +980,7 @@ MagickExport Image *MosaicImages(Image *image,ExceptionInfo *exception)
   mosaic_image=CloneImage(image,page.width,page.height,MagickTrue,exception);
   if (mosaic_image == (Image *) NULL)
     return((Image *) NULL);
-  SetImageBackgroundColor(mosaic_image);
+  (void) SetImageBackgroundColor(mosaic_image);
   mosaic_image->page=page;
   /*
     Mosaic the images.
@@ -1348,7 +1031,6 @@ MagickExport Image *MosaicImages(Image *image,ExceptionInfo *exception)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *RollImage(const Image *image,const long x_offset,
   const long y_offset,ExceptionInfo *exception)
@@ -1474,11 +1156,13 @@ MagickExport Image *RollImage(const Image *image,const long x_offset,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *ShaveImage(const Image *image,
   const RectangleInfo *shave_info,ExceptionInfo *exception)
 {
+  Image
+    *shave_image;
+
   RectangleInfo
     geometry;
 
@@ -1492,9 +1176,16 @@ MagickExport Image *ShaveImage(const Image *image,
   SetGeometry(image,&geometry);
   geometry.width-=2*shave_info->width;
   geometry.height-=2*shave_info->height;
-  geometry.x=(long) shave_info->width;
-  geometry.y=(long) shave_info->height;
-  return(CropImage(image,&geometry,exception));
+  geometry.x=(long) shave_info->width+image->page.x;
+  geometry.y=(long) shave_info->height+image->page.y;
+  shave_image=CropImage(image,&geometry,exception);
+  if (shave_image == (Image *) NULL)
+    return((Image *) NULL);
+  shave_image->page.width-=2*shave_info->width;
+  shave_image->page.height-=2*shave_info->height;
+  shave_image->page.x-=shave_info->width;
+  shave_image->page.y-=shave_info->height;
+  return(shave_image);
 }
 
 /*
@@ -1525,7 +1216,6 @@ MagickExport Image *ShaveImage(const Image *image,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *SpliceImage(const Image *image,
   const RectangleInfo *geometry,ExceptionInfo *exception)
@@ -1541,6 +1231,9 @@ MagickExport Image *SpliceImage(const Image *image,
   MagickBooleanType
     status;
 
+  RectangleInfo
+    splice_geometry;
+
   register const PixelPacket
     *p;
 
@@ -1568,17 +1261,79 @@ MagickExport Image *SpliceImage(const Image *image,
   if ((geometry->x < 0) || (geometry->x > (long) image->columns) ||
       (geometry->y < 0) || (geometry->y > (long) image->rows))
      ThrowImageException(OptionError,"GeometryDoesNotContainImage");
-  splice_image=CloneImage(image,image->columns+geometry->width,image->rows+
-    geometry->height,MagickTrue,exception);
+  splice_geometry=(*geometry);
+  splice_image=CloneImage(image,image->columns+splice_geometry.width,
+    image->rows+splice_geometry.height,MagickTrue,exception);
   if (splice_image == (Image *) NULL)
     return((Image *) NULL);
   if (SetImageStorageClass(splice_image,DirectClass) == MagickFalse)
-    return((Image *) NULL);
+    {
+      InheritException(exception,&splice_image->exception);
+      splice_image=DestroyImage(splice_image);
+      return((Image *) NULL);
+    }
+  if (image->background_color.opacity != OpaqueOpacity)
+    splice_image->matte=MagickTrue;
+  /*
+    Respect image geometry.
+  */
+  switch (image->gravity)
+  {
+    default:
+    case UndefinedGravity:
+    case NorthWestGravity:
+      break;
+    case NorthGravity:
+    {
+      splice_geometry.x+=splice_geometry.width/2;
+      break;
+    }
+    case NorthEastGravity:
+    {
+      splice_geometry.x+=splice_geometry.width;
+      break;
+    }
+    case WestGravity:
+    {
+      splice_geometry.y+=splice_geometry.width/2;
+      break;
+    }
+    case StaticGravity:
+    case CenterGravity:
+    {
+      splice_geometry.x+=splice_geometry.width/2;
+      splice_geometry.y+=splice_geometry.height/2;
+      break;
+    }
+    case EastGravity:
+    {
+      splice_geometry.x+=splice_geometry.width;
+      splice_geometry.y+=splice_geometry.height/2;
+      break;
+    }
+    case SouthWestGravity:
+    {
+      splice_geometry.y+=splice_geometry.height;
+      break;
+    }
+    case SouthGravity:
+    {
+      splice_geometry.x+=splice_geometry.width/2;
+      splice_geometry.y+=splice_geometry.height;
+      break;
+    }
+    case SouthEastGravity:
+    {
+      splice_geometry.x+=splice_geometry.width;
+      splice_geometry.y+=splice_geometry.height;
+      break;
+    }
+  }
   /*
     Splice image.
   */
   i=0;
-  for (y=0; y < (long) geometry->y; y++)
+  for (y=0; y < (long) splice_geometry.y; y++)
   {
     p=AcquireImagePixels(image,0,i++,image->columns,1,exception);
     q=SetImagePixels(splice_image,0,y,splice_image->columns,1);
@@ -1586,13 +1341,13 @@ MagickExport Image *SpliceImage(const Image *image,
       break;
     indexes=GetIndexes(image);
     splice_indexes=GetIndexes(splice_image);
-    for (x=0; x < geometry->x; x++)
+    for (x=0; x < splice_geometry.x; x++)
     {
       *q++=(*p++);
       if (splice_image->colorspace == CMYKColorspace)
         splice_indexes[x]=(*indexes++);
     }
-    for ( ; x < (long) (geometry->x+geometry->width); x++)
+    for ( ; x < (long) (splice_geometry.x+splice_geometry.width); x++)
     {
       *q++=image->background_color;
       if (splice_image->colorspace == CMYKColorspace)
@@ -1615,7 +1370,7 @@ MagickExport Image *SpliceImage(const Image *image,
           break;
       }
   }
-  for ( ; y < (long) (geometry->y+geometry->height); y++)
+  for ( ; y < (long) (splice_geometry.y+splice_geometry.height); y++)
   {
     q=SetImagePixels(splice_image,0,y,splice_image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -1646,13 +1401,13 @@ MagickExport Image *SpliceImage(const Image *image,
       break;
     indexes=GetIndexes(image);
     splice_indexes=GetIndexes(splice_image);
-    for (x=0; x < geometry->x; x++)
+    for (x=0; x < splice_geometry.x; x++)
     {
       *q++=(*p++);
       if (splice_image->colorspace == CMYKColorspace)
         splice_indexes[x]=(*indexes++);
     }
-    for ( ; x < (long) (geometry->x+geometry->width); x++)
+    for ( ; x < (long) (splice_geometry.x+splice_geometry.width); x++)
     {
       *q++=image->background_color;
       if (splice_image->colorspace == CMYKColorspace)
@@ -1686,7 +1441,8 @@ MagickExport Image *SpliceImage(const Image *image,
 %   T r a n s f o r m I m a g e                                               %
 %                                                                             %
 %                                                                             %
-%                                                                             % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  TransformImage() is a convenience method that behaves like ResizeImage() or
 %  CropImage() but accepts scaling and/or cropping information as a region
@@ -1708,7 +1464,6 @@ MagickExport Image *SpliceImage(const Image *image,
 %    o image_geometry: An image geometry string.  This geometry defines the
 %      final size of the image.
 %
-%
 */
 MagickExport MagickBooleanType TransformImage(Image **image,
   const char *crop_geometry,const char *image_geometry)
@@ -1742,8 +1497,7 @@ MagickExport MagickBooleanType TransformImage(Image **image,
       crop_image=NewImageList();
       flags=ParseGravityGeometry(transform_image,crop_geometry,&geometry);
       if (((geometry.width == 0) && (geometry.height == 0)) ||
-          ((flags & XValue) != 0) || ((flags & YValue) != 0) ||
-          ((flags & PercentValue) != 0))
+          ((flags & XValue) != 0) || ((flags & YValue) != 0))
         {
           crop_image=CropImage(transform_image,&geometry,&(*image)->exception);
           if ((crop_image != (Image *) NULL) && ((flags & AspectValue) != 0))
@@ -1855,7 +1609,6 @@ MagickExport MagickBooleanType TransformImage(Image **image,
 %    o image_geometry: An image geometry string.  This geometry defines the
 %      final size of the image.
 %
-%
 */
 MagickExport MagickBooleanType TransformImages(Image **images,
   const char *crop_geometry,const char *image_geometry)
@@ -1895,6 +1648,208 @@ MagickExport MagickBooleanType TransformImages(Image **images,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   T r a n s p o s e I m a g e                                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  TransposeImage() creates a horizontal mirror image by reflecting the pixels
+%  around the central y-axis while rotating them by 90 degrees.
+%
+%  The format of the TransposeImage method is:
+%
+%      Image *TransposeImage(const Image *image,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *TransposeImage(const Image *image,ExceptionInfo *exception)
+{
+#define TransposeImageTag  "Transpose/Image"
+
+  Image
+    *transpose_image;
+
+  long
+    y;
+
+  MagickBooleanType
+    status;
+
+  RectangleInfo
+    page;
+
+  register const PixelPacket
+    *p;
+
+  register IndexPacket
+    *transpose_indexes,
+    *indexes;
+
+  register PixelPacket
+    *q;
+
+  /*
+    Initialize transpose image attributes.
+  */
+  assert(image != (const Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  transpose_image=CloneImage(image,image->rows,image->columns,MagickTrue,
+    exception);
+  if (transpose_image == (Image *) NULL)
+    return((Image *) NULL);
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireImagePixels(image,0,(long) image->rows-y-1,image->columns,1,
+      exception);
+    q=SetImagePixels(transpose_image,(long) (image->rows-y-1),0,1,
+      transpose_image->rows);
+    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+      break;
+    (void) CopyMagickMemory(q,p,(size_t) image->columns*sizeof(*q));
+    indexes=GetIndexes(image);
+    transpose_indexes=GetIndexes(transpose_image);
+    if ((indexes != (IndexPacket *) NULL) &&
+        (transpose_indexes != (IndexPacket *) NULL))
+      (void) CopyMagickMemory(transpose_indexes,indexes,(size_t)
+        image->columns*sizeof(*transpose_indexes));
+    if (SyncImagePixels(transpose_image) == MagickFalse)
+      break;
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(y,image->rows) != MagickFalse))
+      {
+        status=image->progress_monitor(TransposeImageTag,y,image->rows,
+          image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
+  }
+  page=transpose_image->page;
+  Swap(page.width,page.height);
+  Swap(page.x,page.y);
+  if (page.width != 0)
+    page.x=(long) (page.width-transpose_image->columns-page.x);
+  transpose_image->page=page;
+  return(transpose_image);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   T r a n s v e r s e I m a g e                                             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  TransverseImage() creates a vertical mirror image by reflecting the pixels
+%  around the central x-axis while rotating them by 270 degrees.
+%
+%  The format of the TransverseImage method is:
+%
+%      Image *TransverseImage(const Image *image,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *TransverseImage(const Image *image,ExceptionInfo *exception)
+{
+#define TransverseImageTag  "Transverse/Image"
+
+  Image
+    *transverse_image;
+
+  long
+    y;
+
+  MagickBooleanType
+    status;
+
+  RectangleInfo
+    page;
+
+  register const PixelPacket
+    *p;
+
+  register IndexPacket
+    *transverse_indexes,
+    *indexes;
+
+  register long
+    x;
+
+  register PixelPacket
+    *q;
+
+  /*
+    Initialize transverse image attributes.
+  */
+  assert(image != (const Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  transverse_image=CloneImage(image,image->rows,image->columns,MagickTrue,
+    exception);
+  if (transverse_image == (Image *) NULL)
+    return((Image *) NULL);
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
+    q=SetImagePixels(transverse_image,(long) (image->rows-y-1),0,1,
+      transverse_image->rows);
+    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+      break;
+    q+=image->columns;
+    for (x=0; x < (long) image->columns; x++)
+      *--q=(*p++);
+    indexes=GetIndexes(image);
+    transverse_indexes=GetIndexes(transverse_image);
+    if ((indexes != (IndexPacket *) NULL) &&
+        (transverse_indexes != (IndexPacket *) NULL))
+      for (x=0; x < (long) image->columns; x++)
+        transverse_indexes[image->columns-x-1]=indexes[x];
+    if (SyncImagePixels(transverse_image) == MagickFalse)
+      break;
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(y,image->rows) != MagickFalse))
+      {
+        status=image->progress_monitor(TransposeImageTag,y,image->rows,
+          image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
+  }
+  page=transverse_image->page;
+  Swap(page.width,page.height);
+  Swap(page.x,page.y);
+  if (page.height != 0)
+    page.y=(long) (page.height-transverse_image->rows-page.y);
+  transverse_image->page=page;
+  return(transverse_image);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   T r i m I m a g e                                                         %
 %                                                                             %
 %                                                                             %
@@ -1915,7 +1870,6 @@ MagickExport MagickBooleanType TransformImages(Image **images,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
 {
