@@ -612,7 +612,10 @@ MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
     *family,
     *file,
     *style;
-   
+
+  FcConfig
+    *font_config;
+  
   FcFontSet
     *font_set;
 
@@ -621,7 +624,7 @@ MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
 
   FcPattern
     *pattern;
- 
+
   FcResult
     status;
 
@@ -629,17 +632,17 @@ MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
     slant,
     width,
     weight;
- 
+
   register long
     i;
 
   TypeInfo
     *type_info;
-  
+ 
   /*
     Load system fonts.
   */
-  (void) FcInit();
+  font_config=FcInitLoadConfigAndFonts();
   object_set=FcObjectSetBuild(FC_FAMILY,FC_STYLE,FC_SLANT,FC_WIDTH,FC_WEIGHT,
     FC_FILE,(char *) NULL);
   pattern=FcPatternCreate();
@@ -648,7 +651,7 @@ MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
   FcObjectSetDestroy(object_set);
   if (font_set == (FcFontSet *) NULL)
     {
-      FcFini();
+      FcConfigDestroy(font_config);
       return(MagickFalse);
     }
   for (i=0; i < (long) font_set->nfont; i++)
@@ -728,7 +731,7 @@ MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
       type_info);
   }
   FcFontSetDestroy(font_set);
-  FcFini();
+  FcConfigDestroy(font_config);
   return(MagickTrue);
 }
 #endif
@@ -1147,7 +1150,7 @@ static MagickBooleanType LoadTypeLists(const char *filename,
         }
       font_path=(char *) RelinquishMagickMemory(font_path);
     }
-  if ((type_list == (SplayTreeInfo *) NULL) || 
+  if ((type_list == (SplayTreeInfo *) NULL) ||
       (GetNumberOfNodesInSplayTree(type_list) == 0))
     status|=LoadTypeList(TypeMap,"built-in",0,exception);
   return(status != 0 ? MagickTrue : MagickFalse);
