@@ -40,7 +40,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
-#include "magick/attribute.h"
+#include "magick/property.h"
 #include "magick/blob.h"
 #include "magick/color.h"
 #include "magick/exception.h"
@@ -1084,8 +1084,8 @@ MagickExport char **GetPathComponents(const char *path,
     for (q=(char *) p; *q != '\0'; q++)
       if (IsBasenameSeparator(*q))
         break;
-    components[i]=(char *)
-      AcquireMagickMemory(((q-p)+MaxTextExtent)*sizeof(*components));
+    components[i]=(char *) AcquireMagickMemory(((q-p)+MaxTextExtent)*
+      sizeof(*components));
     if (components[i] == (char *) NULL)
       {
         char
@@ -1394,6 +1394,62 @@ MagickExport char **ListFiles(const char *directory,const char *pattern,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k O p e n S t r e a m                                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickOpenStream() opens the file whose name is the string pointed to by
+%  path and associates a stream with it.
+%
+%  The path of the MagickOpenStream method is:
+%
+%      FILE *MagickOpenStream(const char *path,const char *mode)
+%
+%  A description of each parameter follows.
+%
+%   o  path: the file path.
+%
+%   o  mode: the file mode.
+%
+*/
+MagickExport FILE *MagickOpenStream(const char *path,const char *mode)
+{
+  FILE
+    *file;
+
+  file=fopen(path,mode);
+#if defined(__WINDOWS__)
+  if (file == (FILE *) NULL)
+    {
+      register long
+        i;
+
+      wchar_t
+        wide_mode[MaxTextExtent],
+        wide_path[MaxTextExtent];
+
+      /*
+        Perhaps this is a UTF-8 encoded filename.
+      */
+      for (i=0; i < strlen(path); i++)
+        wide_path[i]=path[i];
+      wide_path[i]=0;
+      for (i=0; i < strlen(mode); i++)
+        wide_mode[i]=mode[i];
+      wide_mode[i]=0;
+      file=_wfopen(wide_path,wide_mode);
+    }
+#endif
+  return(file);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %  M u l t i l i n e C e n s u s                                              %
 %                                                                             %
 %                                                                             %
