@@ -17,7 +17,7 @@
 %                               September 2002                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -68,7 +68,6 @@
 %
 %      const char *GetMagickCopyright(void)
 %
-%
 */
 MagickExport const char *GetMagickCopyright(void)
 {
@@ -92,7 +91,6 @@ MagickExport const char *GetMagickCopyright(void)
 %
 %      char *GetMagickHomeURL(void)
 %
-%
 */
 MagickExport char *GetMagickHomeURL(void)
 {
@@ -110,19 +108,19 @@ MagickExport char *GetMagickHomeURL(void)
 
   GetExceptionInfo(&exception);
   paths=GetConfigurePaths(MagickURLFilename,&exception);
-  DestroyExceptionInfo(&exception);
+  (void) DestroyExceptionInfo(&exception);
   if (paths == (LinkedListInfo *) NULL)
-    return(AcquireString(MagickHomeURL));
+    return(ConstantString(MagickHomeURL));
   element=(const char *) GetNextValueInLinkedList(paths);
   while (element != (const char *) NULL)
   {
     (void) FormatMagickString(path,MaxTextExtent,"%s%s%s",element,
       DirectorySeparator,MagickURLFilename);
     if (IsAccessible(path) != MagickFalse)
-      return(AcquireString(path));
+      return(ConstantString(path));
     element=(const char *) GetNextValueInLinkedList(paths);
   }
-  return(AcquireString(MagickHomeURL));
+  return(ConstantString(MagickHomeURL));
 }
 
 /*
@@ -144,7 +142,6 @@ MagickExport char *GetMagickHomeURL(void)
 %
 %  No parameters are required.
 %
-%
 */
 MagickExport const char *GetMagickPackageName(void)
 {
@@ -172,12 +169,11 @@ MagickExport const char *GetMagickPackageName(void)
 %
 %    o depth: The quantum depth is returned as a number.
 %
-%
 */
 MagickExport const char *GetMagickQuantumDepth(unsigned long *depth)
 {
   if (depth != (unsigned long *) NULL)
-    *depth=QuantumDepth;
+    *depth=(unsigned long) QuantumDepth;
   return(MagickQuantumDepth);
 }
 
@@ -186,6 +182,35 @@ MagickExport const char *GetMagickQuantumDepth(unsigned long *depth)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t M a g i c k Q u a n t u m R a n g e                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetMagickQuantumRange() returns the ImageMagick quantum range.
+%
+%  The format of the GetMagickQuantumRange method is:
+%
+%      const char *GetMagickQuantumRange(unsigned long *range)
+%
+%  A description of each parameter follows:
+%
+%    o range: The quantum range is returned as a number.
+%
+*/
+MagickExport const char *GetMagickQuantumRange(unsigned long *range)
+{
+  if (range != (unsigned long *) NULL)
+    *range=(unsigned long) QuantumRange;
+  return(MagickQuantumRange);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t M a g i c k R e l e a s e D a t e                                   %
 %                                                                             %
 %                                                                             %
@@ -200,7 +225,6 @@ MagickExport const char *GetMagickQuantumDepth(unsigned long *depth)
 %
 %  No parameters are required.
 %
-%
 */
 MagickExport const char *GetMagickReleaseDate(void)
 {
