@@ -370,13 +370,13 @@ MagickExport char *CanonicalXMLContent(const char *content,
     Substitute predefined entities.
   */
   i=0;
-  extent=MaxTextExtent;
   canonical_content=AcquireString((char *) NULL);
+  extent=MaxTextExtent;
   for (p=utf8; *p != '\0'; p++)
   {
     if ((i+MaxTextExtent) > (long) extent)
       {
-        extent=i+MaxTextExtent;
+        extent+=MaxTextExtent;
         canonical_content=(char *) ResizeMagickMemory(canonical_content,
           extent*sizeof(*canonical_content));
         if (canonical_content == (char *) NULL)
@@ -408,7 +408,7 @@ MagickExport char *CanonicalXMLContent(const char *content,
       {
         if (pedantic == MagickFalse)
           {
-            canonical_content[i++]=(*p);
+            canonical_content[i++]=(char) (*p);
             break;
           }
         i+=FormatMagickString(canonical_content+i,extent,"&#xA;");
@@ -418,7 +418,7 @@ MagickExport char *CanonicalXMLContent(const char *content,
       {
         if (pedantic == MagickFalse)
           {
-            canonical_content[i++]=(*p);
+            canonical_content[i++]=(char) (*p);
             break;
           }
         i+=FormatMagickString(canonical_content+i,extent,"&#x9;");
@@ -431,7 +431,7 @@ MagickExport char *CanonicalXMLContent(const char *content,
       }
       default:
       {
-        canonical_content[i++]=(*p);
+        canonical_content[i++]=(char) (*p);
         break;
       }
     }
@@ -523,9 +523,17 @@ MagickExport XMLTreeInfo *DestroyXMLTree(XMLTreeInfo *xml_info)
       for (i=0; root->attributes[i] != (char **) NULL; i++)
       {
         attributes=root->attributes[i];
-        for (j=1; attributes[j++]; j+=2)
+        if (attributes[0] != (char *) NULL)
+          attributes[0]=(char *) RelinquishMagickMemory(attributes[0]);
+        for (j=1; attributes[j] != (char *) NULL; j+=3)
+        {
           if (attributes[j] != (char *) NULL)
             attributes[j]=(char *) RelinquishMagickMemory(attributes[j]);
+          if (attributes[j+1] != (char *) NULL)
+            attributes[j+1]=(char *) RelinquishMagickMemory(attributes[j+1]);
+          if (attributes[j+2] != (char *) NULL)
+            attributes[j+2]=(char *) RelinquishMagickMemory(attributes[j+2]);
+        }
         attributes=(char **) RelinquishMagickMemory(attributes);
       }
       if (root->attributes[0] != (char **) NULL)
@@ -1142,9 +1150,6 @@ static char *ParseEntities(char *xml,char **entities,char state)
     byte,
     c;
 
-  long
-    j;
-
   register char
     *p,
     *q;
@@ -1153,6 +1158,7 @@ static char *ParseEntities(char *xml,char **entities,char state)
     i;
 
   size_t
+    extent,
     length;
 
   ssize_t
@@ -1247,19 +1253,18 @@ static char *ParseEntities(char *xml,char **entities,char state)
               if (length > (size_t) (entity-xml))
                 {
                   offset=(ssize_t) (xml-p);
-                  j=(long) offset+length+strlen(entity);
+                  extent=(size_t) (offset+length+strlen(entity));
                   if (p != q)
-                    p=(char *) ResizeMagickMemory(p,(size_t) j*sizeof(*p));
+                    p=(char *) ResizeMagickMemory(p,extent*sizeof(*p));
                   else
                     {
                       char
                         *xml;
 
-                      xml=(char *) AcquireMagickMemory((size_t) j*sizeof(*xml));
+                      xml=(char *) AcquireMagickMemory(extent*sizeof(*xml));
                       if (xml != (char *) NULL)
                         {
-                          (void) CopyMagickString(xml,p,(size_t) j*
-                            sizeof(*xml));
+                          (void) CopyMagickString(xml,p,extent*sizeof(*xml));
                           p=xml;
                         }
                     }
@@ -1303,9 +1308,6 @@ static char *ParseEntities(char *xml,char **entities,char state)
 void ParseCharacterContent(XMLTreeRoot *root,char *xml,const size_t length,
   const char state)
 {
-  size_t
-    offset;
-
   XMLTreeInfo
     *xml_info;
 
@@ -1315,28 +1317,17 @@ void ParseCharacterContent(XMLTreeRoot *root,char *xml,const size_t length,
     return;
   xml[length]='\0';
   xml=ParseEntities(xml,root->entities,state);
-  if (*xml_info->content == '\0')
+  if (*xml_info->content != '\0')
+    {
+      (void) ConcatenateString(&xml_info->content,xml);
+      xml=(char *) RelinquishMagickMemory(xml);
+    }
+  else
     {
       if (xml_info->content != (char *) NULL)
         xml_info->content=(char *) RelinquishMagickMemory(xml_info->content);
       xml_info->content=xml;
     }
-  else
-    {
-      size_t
-        length;
-
-      offset=strlen(xml_info->content);
-      length=strlen(xml);
-      xml_info->content=(char *) ResizeMagickMemory(xml_info->content,
-        (offset+length+1)*sizeof(*xml_info->content));
-      if (xml_info->content == (char *) NULL)
-        ThrowMagickFatalException(ResourceLimitFatalError,
-          "UnableToAcquireString",xml);
-      (void) CopyMagickString(xml_info->content+offset,xml,
-        (length+1)*sizeof(*xml_info->content));
-      xml=(char *) RelinquishMagickMemory(xml);
-  }
 }
 
 static XMLTreeInfo *ParseCloseTag(XMLTreeRoot *root,char *tag,
@@ -2314,17 +2305,17 @@ MagickExport XMLTreeInfo *SetXMLTreeContent(XMLTreeInfo *xml_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   X M L T r e e T a g T o X M L                                             %
+%   X M L T r e e I n f o T o X M L                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  XMLTreeTagToXML() converts an xml-tree to an XML string.
+%  XMLTreeInfoToXML() converts an xml-tree to an XML string.
 %
-%  The format of the XMLTreeTagToXML method is:
+%  The format of the XMLTreeInfoToXML method is:
 %
-%      XMLTreeInfo *XMLTreeTagToXML(XMLTreeInfo *xml_info)
+%      XMLTreeInfo *XMLTreeInfoToXML(XMLTreeInfo *xml_info)
 %
 %  A description of each parameter follows:
 %
@@ -2337,24 +2328,33 @@ static char *EncodePredefinedEntities(const char *source,ssize_t offset,
   MagickBooleanType pedantic)
 {
   char
-    *content;
+    *canonical_content;
 
-  if (offset == -1)
-    content=CanonicalXMLContent(source,pedantic);
+  if (offset < 0)
+    canonical_content=CanonicalXMLContent(source,pedantic);
   else
-    content=CanonicalXMLContent(source+offset,pedantic);
-  if (content == (char *) NULL)
-    return(*destination);
-  if ((*length+strlen(content)+MaxTextExtent) > *max_length)
     {
-      *max_length=(*length)+strlen(content)+MaxTextExtent;
+      char
+        *content;
+
+      content=AcquireString(source);
+      content[offset]='\0';
+      canonical_content=CanonicalXMLContent(content,pedantic);
+      content=(char *) RelinquishMagickMemory(content);
+    }
+  if (canonical_content == (char *) NULL)
+    return(*destination);
+  if ((*length+strlen(canonical_content)+MaxTextExtent) > *max_length)
+    {
+      *max_length=(*length)+strlen(canonical_content)+MaxTextExtent;
       *destination=(char *) ResizeMagickMemory(*destination,*max_length*
         sizeof(**destination));
       if (*destination == (char *) NULL)
         return(*destination);
     }
-  *length+=FormatMagickString(*destination+(*length),*max_length,"%s",content);
-  content=(char *) RelinquishMagickMemory(content);
+  *length+=FormatMagickString(*destination+(*length),*max_length,"%s",
+    canonical_content);
+  canonical_content=(char *) RelinquishMagickMemory(canonical_content);
   return(*destination);
 }
 
@@ -2380,12 +2380,12 @@ static char *XMLTreeTagToXML(XMLTreeInfo *xml_info,char **source,size_t *length,
   if (xml_info->parent != (XMLTreeInfo *) NULL)
     content=xml_info->parent->content;
   offset=0;
-  *source=EncodePredefinedEntities(content+start,(size_t) (xml_info->offset-
+  *source=EncodePredefinedEntities(content+start,(ssize_t) (xml_info->offset-
     start),source,length,max_length,MagickFalse);
   if ((*length+strlen(xml_info->tag)+MaxTextExtent) > *max_length)
     {
       *max_length=(*length)+strlen(xml_info->tag)+MaxTextExtent;
-      *source=(char *) ResizeMagickMemory(*source,*max_length);
+      *source=(char *) ResizeMagickMemory(*source,*max_length*sizeof(*source));
       if (*source == (char *) NULL)
         return(*source);
     }
