@@ -100,17 +100,27 @@ static void AnimateUsage(void)
       "Press any button to map or unmap the Command widget",
       (char *) NULL
     },
-    *options[]=
+    *operators[]=
+    {
+      "-colors value        preferred number of colors in the image",
+      "-crop geometry       preferred size and location of the cropped image",
+      "-extract geometry    extract area from image",
+      "-monochrome          transform image to black and white",
+      "-repage geometry     size and location of an image canvas (operator)",
+      "-resample geometry   change the resolution of an image",
+      "-resize geometry     resize the image",
+      "-rotate degrees      apply Paeth rotation to the image",
+      "-strip               strip image of all profiles and comments",
+      "-trim                trim image edges",
+      (char *) NULL
+    },
+    *settings[]=
     {
       "-authenticate value  decrypt image with this password",
       "-backdrop            display image centered on a backdrop",
       "-channel type        apply option to select image channels",
-      "-clone index         clone an image",
-      "-coalesce            merge a sequence of images",
       "-colormap type       Shared or Private",
-      "-colors value        preferred number of colors in the image",
       "-colorspace type     alternate image colorspace",
-      "-crop geometry       preferred size and location of the cropped image",
       "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
@@ -119,9 +129,6 @@ static void AnimateUsage(void)
       "-depth value         image depth",
       "-display server      display image to this X server",
       "-dither              apply Floyd/Steinberg error diffusion to image",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
-      "-extract geometry    extract area from image",
-      "-flatten             flatten a sequence of images",
       "-format \"string\"     output formatted image characteristics",
       "-gamma value         level of gamma correction",
       "-geometry geometry   preferred size and location of the Image window",
@@ -135,28 +142,21 @@ static void AnimateUsage(void)
       "-matte               store matte channel if the image has one",
       "-map type            display image using this Standard Colormap",
       "-monitor             monitor progress",
-      "-monochrome          transform image to black and white",
       "-pause               seconds to pause before reanimating",
       "-page geometry       size and location of an image canvas (setting)",
       "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
-      "-repage geometry     size and location of an image canvas (operator)",
-      "-resample geometry   change the resolution of an image",
-      "-resize geometry     resize the image",
-      "-rotate degrees      apply Paeth rotation to the image",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
       "-set attribute value set an image attribute",
       "-size geometry       width and height of image",
-      "-strip               strip image of all profiles and comments",
       "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
-      "-trim                trim image edges",
       "-verbose             print detailed information about the image",
       "-version             print version information",
       "-visual type         display image using this visual type",
@@ -164,14 +164,26 @@ static void AnimateUsage(void)
       "                     virtual pixel access method",
       "-window id           display image to background of this window",
       (char *) NULL
+    },
+    *sequence_operators[]=
+    {
+      "-coalesce            merge a sequence of images",
+      "-flatten             flatten a sequence of images",
+      (char *) NULL
     };
 
   (void) printf("Version: %s\n",GetMagickVersion((unsigned long *) NULL));
   (void) printf("Copyright: %s\n\n",GetMagickCopyright());
   (void) printf("Usage: %s [options ...] file [ [options ...] file ...]\n",
     GetClientName());
-  (void) printf("\nWhere options include: \n");
-  for (p=options; *p != (char *) NULL; p++)
+  (void) printf("\nImage Settings:\n");
+  for (p=settings; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Operators:\n");
+  for (p=operators; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Sequence Operators:\n");
+  for (p=sequence_operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
   (void) printf(
     "\nIn addition to those listed above, you can specify these standard X\n");
@@ -731,7 +743,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             if (i == (long) argc)
               ThrowAnimateException(OptionError,"MissingArgument",option);
             resource_info.font=XGetResourceClass(resource_database,
-						  GetClientName(),"font",argv[i]);
+              GetClientName(),"font",argv[i]);
             break;
           }
         if (LocaleCompare("foreground",option+1) == 0)
@@ -1156,7 +1168,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             if (i == (long) argc)
               ThrowAnimateException(OptionError,"MissingArgument",option);
             resource_info.text_font=XGetResourceClass(resource_database,
-						  GetClientName(),"font",argv[i]);
+              GetClientName(),"font",argv[i]);
             break;
           }
         if (LocaleCompare("thumbnail",option+1) == 0)
