@@ -182,7 +182,7 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
               /*
                 Tile the composite image.
               */
-              (void) SetImageAttribute(composite_image,
+              (void) SetImageProperty(composite_image,
                 "[modify-outside-overlay]","false");
               columns=composite_image->columns;
               for (y=0; y < (long) (*image)->rows; y+=composite_image->rows)
@@ -223,14 +223,42 @@ static void CompositeUsage(void)
     **p;
 
   static const char
-    *options[]=
+    *operators[]=
+    {
+      "-blend geometry      blend images",
+      "-colors value        preferred number of colors in the image",
+      "-displace geometry   shift image pixels defined by a displacement map",
+      "-dissolve value      dissolve the two images a given percent",
+      "-extract geometry    extract area from image",
+      "-geometry geometry   location of the composite image",
+      "-help                print program options",
+      "-identify            identify the format and characteristics of the image",
+      "-monochrome          transform image to black and white",
+      "-negate              replace every pixel with its complementary color ",
+      "-profile filename    add ICM or IPTC information profile to image",
+      "-quantize colorspace reduce colors in this colorspace",
+      "-repage geometry     size and location of an image canvas (operator)",
+      "-rotate degrees      apply Paeth rotation to the image",
+      "-resize geometry     resize the image",
+      "-sharpen geometry    sharpen the image",
+      "-stegano offset      hide watermark within an image",
+      "-stereo              combine two image to create a stereo anaglyph",
+      "-strip               strip image of all profiles and comments",
+      "-thumbnail geometry  create a thumbnail of the image",
+      "-transform           affine transform image",
+      "-type type           image type",
+      "-unsharp geometry    sharpen the image",
+      "-version             print version information",
+      "-watermark geometry  percent brightness and saturation of a watermark",
+      "-write filename      write images to this file",
+      (char *) NULL
+    },
+    *settings[]=
     {
       "-affine matrix       affine transform matrix",
       "-authenticate value  decrypt image with this password",
-      "-blend geometry      blend images",
       "-blue-primary point  chromaticity blue primary point",
       "-channel type        apply option to select image channels",
-      "-colors value        preferred number of colors in the image",
       "-colorspace type     alternate image colorspace",
       "-comment string      annotate image with comment",
       "-compose operator    composite operator",
@@ -238,68 +266,44 @@ static void CompositeUsage(void)
       "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
-      "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
-      "-displace geometry   shift image pixels defined by a displacement map",
+      "-density geometry    horizontal and vertical density of the image",
       "-display server      get image or font from this X server",
       "-dispose method      GIF disposal method",
-      "-dissolve value      dissolve the two images a given percent",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-encoding type       text encoding type",
       "-endian type         endianness (MSB or LSB) of the image",
-      "-extract geometry    extract area from image",
       "-filter type         use this filter when resizing an image",
       "-font name           render text with this font",
       "-format \"string\"     output formatted image characteristics",
-      "-geometry geometry   location of the composite image",
       "-gravity type        which direction to gravitate towards",
       "-green-primary point chromaticity green primary point",
-      "-help                print program options",
-      "-identify            identify the format and characteristics of the image",
       "-interlace type      type of image interlacing scheme",
       "-interpolate method  pixel color interpolation method",
-      "-label name          assign a label to an image",
+      "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
       "-log format          format of debugging information",
       "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
-      "-monochrome          transform image to black and white",
-      "-negate              replace every pixel with its complementary color ",
       "-page geometry       size and location of an image canvas (setting)",
-      "-profile filename    add ICM or IPTC information profile to image",
       "-quality value       JPEG/MIFF/PNG compression level",
-      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
-      "-rotate degrees      apply Paeth rotation to the image",
-      "-repage geometry     size and location of an image canvas (operator)",
-      "-resize geometry     resize the image",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
-      "-sharpen geometry    sharpen the image",
       "-size geometry       width and height of image",
-      "-stegano offset      hide watermark within an image",
-      "-stereo              combine two image to create a stereo anaglyph",
-      "-strip               strip image of all profiles and comments",
       "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
-      "-thumbnail geometry  create a thumbnail of the image",
-      "-tile                repeat composite operation across and down image",
-      "-transform           affine transform image",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
-      "-type type           image type",
+      "-tile                repeat composite operation across and down image",
       "-units type          the units of image resolution",
-      "-unsharp geometry    sharpen the image",
       "-verbose             print detailed information about the image",
-      "-version             print version information",
       "-virtual-pixel method",
       "                     virtual pixel access method",
-      "-watermark geometry  percent brightness and saturation of a watermark",
       "-white-point point   chromaticity white point",
-      "-write filename      write images to this file",
       (char *) NULL
     };
 
@@ -308,9 +312,21 @@ static void CompositeUsage(void)
   (void) printf("Usage: %s [options ...] image [options ...] composite\n"
     "  [ [options ...] mask ] [options ...] composite\n",
     GetClientName());
-  (void) printf("\nWhere options include:\n");
-  for (p=options; *p != (char *) NULL; p++)
+  (void) printf("\nImage Settings:\n");
+  for (p=settings; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf("\nImage Operators:\n");
+  for (p=operators; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf(
+    "\nBy default, the image format of `file' is determined by its magic\n");
+  (void) printf(
+    "number.  To specify a particular image format, precede the filename\n");
+  (void) printf(
+    "with an image format name and a colon (i.e. ps:image) or specify the\n");
+  (void) printf(
+    "image type as the filename suffix (i.e. image.ps).  Specify 'file' as\n");
+  (void) printf("'-' for standard input or output.\n");
   exit(0);
 }
 
@@ -1378,8 +1394,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   mask_image=RemoveFirstImageFromList(image_stack+k);
   if (mask_image != (Image *) NULL)
     {
-      image->clip_mask=mask_image;
-      NegateImage(image->clip_mask,MagickFalse);
+      image->mask=mask_image;
+      (void) NegateImage(image->mask,MagickFalse);
     }
   status&=CompositeImageList(image_info,&image,composite_image,&option_info,
     exception);
@@ -1393,7 +1409,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       char
         *text;
 
-      text=InterpretImageAttributes(image_info,image,format);
+      text=InterpretImageProperties(image_info,image,format);
       if (text == (char *) NULL)
         {
           char
