@@ -115,7 +115,7 @@ static MagickBooleanType ConcatenateImages(int argc,char **argv,
   /*
     Open output file.
   */
-  output=fopen(argv[argc-1],"wb");
+  output=MagickOpenStream(argv[argc-1],"wb");
   if (output == (FILE *) NULL)
     {
       ThrowFileException(exception,FileOpenError,"UnableToOpenFile",
@@ -124,7 +124,7 @@ static MagickBooleanType ConcatenateImages(int argc,char **argv,
     }
   for (i=2; i < (long) (argc-1); i++)
   {
-    input=fopen(argv[i],"rb");
+    input=MagickOpenStream(argv[i],"rb");
     if (input == (FILE *) NULL)
       ThrowFileException(exception,FileOpenError,"UnableToOpenFile",argv[i]);
     for (c=fgetc(input); c != EOF; c=fgetc(input))
@@ -139,7 +139,7 @@ static MagickBooleanType ConcatenateImages(int argc,char **argv,
 static void ConvertUsage(void)
 {
   static const char
-    *options[]=
+    *operators[]=
     {
       "-adaptive-blur geometry",
       "                     adaptively blur pixels; decrease effect near edges",
@@ -147,113 +147,55 @@ static void ConvertUsage(void)
       "                     adaptively resize image with data dependent triangulation",
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
-      "-adjoin              join images into a single multi-image file",
-      "-affine matrix       affine transform matrix",
       "-annotate geometry text",
       "                     annotate the image with text",
-      "-antialias           remove pixel-aliasing",
-      "-append              append an image sequence",
-      "-authenticate value  decrypt image with this password",
       "-auto-orient         automatically orient image",
-      "-average             average an image sequence",
-      "-background color    background color",
-      "-bias value          add bias when convolving an image",
-      "-black-point-compensation",
-      "                     use black point compensation",
       "-black-threshold value",
       "                     force all pixels below the threshold into black",
-      "-blue-primary point  chromaticity blue primary point",
-      "-blur geometry       blur the image",
+      "-blur geometry       reduce image noise and reduce detail levels",
       "-border geometry     surround image with a border of color",
-      "-bordercolor color   border color",
-      "-channel type        apply option to select image channels",
       "-charcoal radius     simulate a charcoal drawing",
       "-chop geometry       remove pixels from the image interior",
       "-clip                clip along the first path from the 8BIM profile",
-      "-clip-mask           clip as defined by an image mask",
+      "-clip-mask filename  associate a clip mask with the image",
       "-clip-path id        clip along a named path from the 8BIM profile",
-      "-clone index         clone an image",
-      "-coalesce            merge a sequence of images",
       "-colorize value      colorize the image with the fill color",
-      "-colors value        preferred number of colors in the image",
-      "-colorspace type     alternate image colorspace",
-      "-combine             combine a sequence of images",
-      "-comment string      annotate image with comment",
-      "-compose operator    set image composite operator",
-      "-composite           composite image",
-      "-compress type       type of pixel compression when writing the image",
       "-contrast            enhance or reduce the image contrast",
       "-contrast-stretch geometry",
       "                     improve contrast by `stretching' the intensity range",
       "-convolve coefficients",
       "                     apply a convolution kernel to the image",
-      "-crop geometry       cut out a rectangular region of the image",
       "-cycle amount        cycle the image colormap",
-      "-debug events        display copious debugging information",
-      "-define format:option",
-      "                     define one or more image format options",
-      "-deconstruct         break down an image sequence into constituent parts",
-      "-delay value         display the next image after pausing",
-      "-delete index        delete the image from the image sequence",
-      "-density geometry    horizontal and vertical density of the image",
-      "-depth value         image depth",
       "-despeckle           reduce the speckles within an image",
-      "-display server      get image or font from this X server",
-      "-dispose method      GIF disposal method",
-      "-dither              apply Floyd/Steinberg error diffusion to image",
       "-draw string         annotate the image with a graphic primitive",
       "-edge radius         apply a filter to detect edges in the image",
       "-emboss radius       emboss an image",
-      "-encoding type       text encoding type",
-      "-endian type         endianness (MSB or LSB) of the image",
       "-enhance             apply a digital filter to enhance a noisy image",
       "-equalize            perform histogram equalization to an image",
       "-evaluate operator value",
       "                     evaluate an arithmetic, relational, or logical expression",
       "-extent geometry     set the image size",
       "-extract geometry    extract area from image",
-      "-family name         render text with this font family",
-      "-fill color          color to use when filling a graphic primitive",
-      "-filter type         use this filter when resizing an image",
-      "-flatten             flatten a sequence of images",
       "-flip                flip image vertically",
       "-floodfill geometry color",
       "                     floodfill the image with color",
       "-flop                flop image horizontally",
-      "-font name           render text with this font",
-      "-format \"string\"     output formatted image characteristics",
       "-frame geometry      surround image with an ornamental border",
-      "-fuzz distance       colors within this distance are considered equal",
-      "-fx expression       apply mathematical expression to an image channel(s)",
       "-gamma value         level of gamma correction",
-      "-gaussian geometry   gaussian blur an image",
+      "-gaussian-blur geometry",
+      "                     reduce image noise and reduce detail levels",
       "-geometry geometry   perferred size or location of the image",
-      "-green-primary point chromaticity green primary point",
-      "-gravity type        horizontal and vertical text placement",
       "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-implode amount      implode image pixels about the center",
-      "-insert index        insert last image into the image sequence",
-      "-intent type         type of rendering intent when managing the image color",
-      "-interlace type      type of image interlacing scheme",
-      "-interpolate method  pixel color interpolation method",
-      "-label name          assign a label to an image",
       "-lat geometry        local adaptive thresholding",
       "-layers method       optimize or compare image layers",
       "-level value         adjust the level of image contrast",
-      "-limit type value    pixel cache resource limit",
-      "-log format          format of debugging information",
-      "-loop iterations     add Netscape loop extension to your GIF animation",
-      "-map filename        transform image colors to match this set of colors",
-      "-mask filename       set the image clip mask",
-      "-matte               store matte channel if the image has one",
-      "-mattecolor color    frame color",
+      "-linear-stretch geometry",
+      "                     improve contrast by `stretching with saturation' the intensity range",
       "-median radius       apply a median filter to the image",
       "-modulate value      vary the brightness, saturation, and hue",
-      "-monitor             monitor progress",
       "-monochrome          transform image to black and white",
-      "-morph value         morph an image sequence",
-      "-mosaic              create a mosaic from an image sequence",
       "-motion-blur geometry",
       "                     simulate motion blur",
       "-negate              replace every pixel with its complementary color ",
@@ -261,26 +203,18 @@ static void ConvertUsage(void)
       "-normalize           transform image to span the full range of colors",
       "-opaque color        change this color to the fill color",
       "-ordered-dither NxN",
-      "                     ordered dither the image",
-      "-orient type         image orientation",
-      "-page geometry       size and location of an image canvas (setting)",
+      "                     add a noise pattern to the image with specific amplitudes",
       "-paint radius        simulate an oil painting",
-      "-ping                efficiently determine image attributes",
-      "-pointsize value     font point size",
+      "-polaroid angle      simulate a Polaroid picture",
       "-posterize levels    reduce the image to a limited number of color levels",
-      "-preview type        image preview type",
       "-print string        interpret string and print to console",
-      "-process arguments   process the image with a custom image filter",
       "-profile filename    add, delete, or apply an image profile",
-      "-quality value       JPEG/MIFF/PNG compression level",
       "-quantize colorspace reduce colors in this colorspace",
-      "-quiet               suppress all error or warning messages",
       "-radial-blur angle   radial blur the image",
       "-raise value         lighten/darken image edges to create a 3-D effect",
       "-random-threshold low,high",
       "                     random threshold the image",
-      "-red-primary point   chromaticity red primary point",
-      "-regard-warnings     pay attention to warning messages",
+      "-recolor matrix      translate, scale, shear, or rotate image colors",
       "-region geometry     apply options to a portion of the image",
       "-render              render vector graphics",
       "-repage geometry     size and location of an image canvas",
@@ -289,16 +223,11 @@ static void ConvertUsage(void)
       "-roll geometry       roll an image vertically or horizontally",
       "-rotate degrees      apply Paeth rotation to the image",
       "-sample geometry     scale image with pixel sampling",
-      "-sampling-factor geometry",
-      "                     horizontal and vertical sampling factor",
       "-scale geometry      scale the image",
-      "-scene value         image scene number",
-      "-seed value          pseudo-random number generator seed value",
       "-segment values      segment an image",
-      "-separate            separate an image channel into a grayscale image",
       "-sepia-tone threshold",
       "                     simulate a sepia-toned photo",
-      "-set attribute value set an image attribute",
+      "-set property value  set an image property",
       "-shade degrees       shade the image using a distant light source",
       "-shadow geometry     simulate an image shadow",
       "-sharpen geometry    sharpen the image",
@@ -306,50 +235,140 @@ static void ConvertUsage(void)
       "-shear geometry      slide one edge of the image along the X or Y axis",
       "-sigmoidal-contrast geometry",
       "                     lightness rescaling using sigmoidal contrast enhancement",
-      "-size geometry       width and height of image",
       "-sketch geometry     simulate a pencil sketch",
       "-solarize threshold  negate all pixels above the threshold level",
       "-splice geometry     splice the background color into the image",
       "-spread amount       displace image pixels by a random amount",
       "-strip               strip image of all profiles and comments",
-      "-stroke color        graphic primitive stroke color",
-      "-strokewidth value   graphic primitive stroke width",
-      "-stretch type        render text with this font stretch",
-      "-style type          render text with this font style",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
-      "-swap indexes        swap two images in the image sequence",
       "-swirl degrees       swirl image pixels about the center",
-      "-texture filename    name of texture to tile onto the image background",
       "-threshold value     threshold the image",
       "-thumbnail geometry  create a thumbnail of the image",
       "-tile filename       tile image when filling a graphic primitive",
       "-tint value          tint the image with the fill color",
       "-transform           affine transform image",
       "-transparent color   make this color transparent within the image",
-      "-transparent-color color",
-      "                     transparent color",
       "-transpose           flip image vertically and rotate 90 degrees",
       "-transverse          flop image horizontally and rotate 270 degrees",
-      "-treedepth value     color tree depth",
       "-trim                trim image edges",
       "-type type           image type",
-      "-undercolor color    annotation bounding box color",
       "-unique-colors       discard all but one of any pixel color",
-      "-units type          the units of image resolution",
       "-unsharp geometry    sharpen the image",
-      "-verbose             print detailed information about the image",
       "-version             print version information",
-      "-view                FlashPix viewing transforms",
       "-vignette geometry   soften the edges of the image in vignette style",
-      "-virtual-pixel method",
-      "                     virtual pixel access method",
       "-wave geometry       alter an image along a sine wave",
-      "-weight type         render text with this font weight",
-      "-white-point point   chromaticity white point",
       "-white-threshold value",
       "                     force all pixels above the threshold into white",
+      (char *) NULL
+    },
+    *sequence_operators[]=
+    {
+      "-append              append an image sequence",
+      "-average             average an image sequence",
+      "-coalesce            merge a sequence of images",
+      "-combine             combine a sequence of images",
+      "-composite           composite image",
+      "-crop geometry       cut out a rectangular region of the image",
+      "-deconstruct         break down an image sequence into constituent parts",
+      "-flatten             flatten a sequence of images",
+      "-fx expression       apply mathematical expression to an image channel(s)",
+      "-map filename        transform image colors to match this set of colors",
+      "-morph value         morph an image sequence",
+      "-mosaic              create a mosaic from an image sequence",
+      "-process arguments   process the image with a custom image filter",
+      "-separate            separate an image channel into a grayscale image",
       "-write filename      write images to this file",
       (char *) NULL
+    },
+    *settings[]=
+    {
+      "-adjoin              join images into a single multi-image file",
+      "-affine matrix       affine transform matrix",
+      "-antialias           remove pixel-aliasing",
+      "-authenticate value  decrypt image with this password",
+      "-background color    background color",
+      "-bias value          add bias when convolving an image",
+      "-black-point-compensation",
+      "                     use black point compensation",
+      "-blue-primary point  chromaticity blue primary point",
+      "-bordercolor color   border color",
+      "-caption string      assign a caption to an image",
+      "-channel type        apply option to select image channels",
+      "-colors value        preferred number of colors in the image",
+      "-colorspace type     alternate image colorspace",
+      "-comment string      annotate image with comment",
+      "-compose operator    set image composite operator",
+      "-compress type       type of pixel compression when writing the image",
+      "-debug events        display copious debugging information",
+      "-define format:option",
+      "                     define one or more image format options",
+      "-delay value         display the next image after pausing",
+      "-density geometry    horizontal and vertical density of the image",
+      "-depth value         image depth",
+      "-display server      get image or font from this X server",
+      "-dispose method      GIF disposal method",
+      "-dither              apply Floyd/Steinberg error diffusion to image",
+      "-encoding type       text encoding type",
+      "-endian type         endianness (MSB or LSB) of the image",
+      "-family name         render text with this font family",
+      "-fill color          color to use when filling a graphic primitive",
+      "-filter type         use this filter when resizing an image",
+      "-font name           render text with this font",
+      "-format \"string\"     output formatted image characteristics",
+      "-fuzz distance       colors within this distance are considered equal",
+      "-gravity type        horizontal and vertical text placement",
+      "-green-primary point chromaticity green primary point",
+      "-intent type         type of rendering intent when managing the image color",
+      "-interlace type      type of image interlacing scheme",
+      "-interpolate method  pixel color interpolation method",
+      "-label string        assign a label to an image",
+      "-limit type value    pixel cache resource limit",
+      "-log format          format of debugging information",
+      "-loop iterations     add Netscape loop extension to your GIF animation",
+      "-mask filename       associate a mask with the image",
+      "-matte               store matte channel if the image has one",
+      "-mattecolor color    frame color",
+      "-monitor             monitor progress",
+      "-orient type         image orientation",
+      "-origin geometry     image origin",
+      "-page geometry       size and location of an image canvas (setting)",
+      "-ping                efficiently determine image attributes",
+      "-pointsize value     font point size",
+      "-preview type        image preview type",
+      "-quality value       JPEG/MIFF/PNG compression level",
+      "-quiet               suppress all error or warning messages",
+      "-red-primary point   chromaticity red primary point",
+      "-regard-warnings     pay attention to warning messages",
+      "-sampling-factor geometry",
+      "                     horizontal and vertical sampling factor",
+      "-scene value         image scene number",
+      "-seed value          pseudo-random number generator seed value",
+      "-size geometry       width and height of image",
+      "-stretch type        render text with this font stretch",
+      "-stroke color        graphic primitive stroke color",
+      "-strokewidth value   graphic primitive stroke width",
+      "-style type          render text with this font style",
+      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
+      "-texture filename    name of texture to tile onto the image background",
+      "-treedepth value     color tree depth",
+      "-transparent-color color",
+      "                     transparent color",
+      "-undercolor color    annotation bounding box color",
+      "-units type          the units of image resolution",
+      "-verbose             print detailed information about the image",
+      "-view                FlashPix viewing transforms",
+      "-virtual-pixel method",
+      "                     virtual pixel access method",
+      "-weight type         render text with this font weight",
+      "-white-point point   chromaticity white point",
+      (char *) NULL
+    },
+    *stack_operators[]=
+    {
+      "-clone index         clone an image",
+      "-delete index        delete the image from the image sequence",
+      "-insert index        insert last image into the image sequence",
+      "-swap indexes        swap two images in the image sequence",
+      (char *) NULL
     };
 
   const char
@@ -359,8 +378,17 @@ static void ConvertUsage(void)
   (void) printf("Copyright: %s\n\n",GetMagickCopyright());
   (void) printf("Usage: %s [options ...] file [ [options ...] "
     "file ...] [options ...] file\n",GetClientName());
-  (void) printf("\nWhere options include:\n");
-  for (p=options; *p != (char *) NULL; p++)
+  (void) printf("\nImage Settings:\n");
+  for (p=settings; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Operators:\n");
+  for (p=operators; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Sequence Operators:\n");
+  for (p=sequence_operators; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Stack Operators:\n");
+  for (p=stack_operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
   (void) printf(
     "\nBy default, the image format of `file' is determined by its magic\n");
@@ -688,6 +716,15 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("caption",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("channel",option+1) == 0)
           {
             long
@@ -729,7 +766,14 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         if (LocaleCompare("clip",option+1) == 0)
           break;
         if (LocaleCompare("clip-mask",option+1) == 0)
-          break;
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("clip-path",option+1) == 0)
           {
             i++;
@@ -1239,7 +1283,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
-        if (LocaleCompare("gaussian",option+1) == 0)
+        if ((LocaleCompare("gaussian-blur",option+1) == 0) ||
+            (LocaleCompare("gaussian",option+1) == 0))
           {
             i++;
             if (i == (long) (argc-1))
@@ -1456,6 +1501,15 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("linear-stretch",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("list",option+1) == 0)
           {
             long
@@ -1647,6 +1701,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 argv[i]);
             break;
           }
+        if (LocaleCompare("origin",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         ThrowConvertException(OptionError,"UnrecognizedOption",argv[i])
       }
       case 'p':
@@ -1684,6 +1749,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("polaroid",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("posterize",option+1) == 0)
           {
             if (*option == '+')
@@ -1804,6 +1880,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("recolor",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("red-primary",option+1) == 0)
           {
             if (*option == '+')
@@ -2458,7 +2545,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
       char
         *text;
 
-      text=InterpretImageAttributes(image_info,image_stack[k],format);
+      text=InterpretImageProperties(image_info,image_stack[k],format);
       if (text == (char *) NULL)
         {
           char
