@@ -101,88 +101,90 @@ static void DisplayUsage(void)
       "3    press to load an image from a visual image directory",
       (char *) NULL
     },
-    *options[]=
+    *operators[]=
+    {
+      "-auto-orient         automatically orient image",
+      "-border geometry     surround image with a border of color",
+      "-clip                clip along the first path from the 8BIM profile",
+      "-clip-path id        clip along a named path from the 8BIM profile",
+      "-colors value        preferred number of colors in the image",
+      "-contrast            enhance or reduce the image contrast",
+      "-crop geometry       preferred size and location of the cropped image",
+      "-despeckle           reduce the speckles within an image",
+      "-edge factor         apply a filter to detect edges in the image",
+      "-enhance             apply a digital filter to enhance a noisy image",
+      "-extract geometry    extract area from image",
+      "-flip                flip image in the vertical direction",
+      "-flop                flop image in the horizontal direction",
+      "-frame geometry      surround image with an ornamental border",
+      "-gamma value         level of gamma correction",
+      "-monochrome          transform image to black and white",
+      "-negate              replace every pixel with its complementary color",
+      "-raise value         lighten/darken image edges to create a 3-D effect",
+      "-resample geometry   change the resolution of an image",
+      "-resize geometry     resize the image",
+      "-roll geometry       roll an image vertically or horizontally",
+      "-rotate degrees      apply Paeth rotation to the image",
+      "-sample geometry     scale image with pixel sampling",
+      "-segment value       segment an image",
+      "-sharpen geometry    sharpen the image",
+      "-strip               strip image of all profiles and comments",
+      "-trim                trim image edges",
+      (char *) NULL
+    },
+    *settings[]=
     {
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
-      "-auto-orient         automatically orient image",
       "-backdrop            display image centered on a backdrop",
-      "-border geometry     surround image with a border of color",
       "-channel type        apply option to select image channels",
-      "-clip                clip along the first path from the 8BIM profile",
-      "-clip-path id        clip along a named path from the 8BIM profile",
-      "-coalesce            merge a sequence of images",
       "-colormap type       Shared or Private",
-      "-colors value        preferred number of colors in the image",
       "-colorspace type     alternate image colorspace",
       "-comment string      annotate image with comment",
       "-compress type       type of pixel compression when writing the image",
-      "-contrast            enhance or reduce the image contrast",
-      "-crop geometry       preferred size and location of the cropped image",
       "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
       "-delay value         display the next image after pausing",
       "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
-      "-despeckle           reduce the speckles within an image",
       "-display server      display image to this X server",
       "-dispose method      GIF disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
-      "-edge factor         apply a filter to detect edges in the image",
       "-endian type         endianness (MSB or LSB) of the image",
-      "-enhance             apply a digital filter to enhance a noisy image",
-      "-extract geometry    extract area from image",
       "-filter type         use this filter when resizing an image",
-      "-flatten             flatten a sequence of images",
-      "-flip                flip image in the vertical direction",
-      "-flop                flop image in the horizontal direction",
       "-format \"string\"     output formatted image characteristics",
-      "-frame geometry      surround image with an ornamental border",
-      "-gamma value         level of gamma correction",
       "-geometry geometry   preferred size and location of the Image window",
       "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-immutable           displayed image cannot be modified",
       "-interlace type      type of image interlacing scheme",
       "-interpolate method  pixel color interpolation method",
-      "-label name          assign a label to an image",
+      "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
       "-log format          format of debugging information",
       "-loop iterations     loop images then exit",
       "-map type            display image using this Standard Colormap",
       "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
-      "-monochrome          transform image to black and white",
-      "-negate              replace every pixel with its complementary color",
       "-page geometry       size and location of an image canvas",
       "-profile filename    add, delete, or apply an image profile",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
-      "-raise value         lighten/darken image edges to create a 3-D effect",
       "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
       "-repage geometry     size and location of an image canvas (operator)",
-      "-resample geometry   change the resolution of an image",
-      "-resize geometry     resize the image",
-      "-roll geometry       roll an image vertically or horizontally",
-      "-rotate degrees      apply Paeth rotation to the image",
-      "-sample geometry     scale image with pixel sampling",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
-      "-segment value       segment an image",
-      "-set attribute value set an image attribute",
-      "-sharpen geometry    sharpen the image",
+      "-set property value  set an image property",
       "-size geometry       width and height of image",
-      "-strip               strip image of all profiles and comments",
       "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-texture filename    name of texture to tile onto the image background",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
-      "-trim                trim image edges",
       "-update seconds      detect when image file is modified and redisplay",
       "-verbose             print detailed information about the image",
       "-version             print version information",
@@ -193,14 +195,26 @@ static void DisplayUsage(void)
       "-window-group id     exit program when this window id is destroyed",
       "-write filename      write image to a file",
       (char *) NULL
+    },
+    *sequence_operators[]=
+    {
+      "-coalesce            merge a sequence of images",
+      "-flatten             flatten a sequence of images",
+      (char *) NULL
     };
 
   (void) printf("Version: %s\n",GetMagickVersion((unsigned long *) NULL));
   (void) printf("Copyright: %s\n\n",GetMagickCopyright());
   (void) printf("Usage: %s [options ...] file [ [options ...] file ...]\n",
     GetClientName());
-  (void) printf("\nWhere options include: \n");
-  for (p=options; *p != (char *) NULL; p++)
+  (void) printf("\nImage Settings:\n");
+  for (p=settings; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Operators:\n");
+  for (p=operators; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Sequence Operators:\n");
+  for (p=sequence_operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
   (void) printf(
     "\nIn addition to those listed above, you can specify these standard X\n");
