@@ -410,15 +410,15 @@ int main ( int argc, char **argv )
   rows=842;
   image_info=CloneImageInfo((ImageInfo*)NULL);
   GetExceptionInfo( &exception );
-  FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
+  (void) FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
   (void) CloneString(&image_info->size,size);
   (void) CopyMagickString(image_info->filename,"xc:white",MaxTextExtent);
-  canvas = ReadImage ( image_info, &exception );
+  canvas=ReadImage ( image_info, &exception );
   if (exception.severity >= ErrorException)
     CatchException(&exception);
   if ( canvas == (Image *)NULL )
     {
-      (void) printf ( "Failed to read canvas image %s\n", image_info->filename );
+      (void) printf ( "Failed to read canvas image %s\n",image_info->filename);
       exit(1);
     }
 
