@@ -91,7 +91,7 @@ static void IdentifyUsage(void)
     **p;
 
   static const char
-    *options[]=
+    *settings[]=
     {
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
@@ -134,9 +134,18 @@ static void IdentifyUsage(void)
   (void) printf("Copyright: %s\n\n",GetMagickCopyright());
   (void) printf("Usage: %s [options ...] file [ [options ...] "
     "file ... ]\n",GetClientName());
-  (void) printf("\nWhere options include:\n");
-  for (p=options; *p != (char *) NULL; p++)
+  (void) printf("\nImage Settings:\n");
+  for (p=settings; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf(
+    "\nBy default, the image format of `file' is determined by its magic\n");
+  (void) printf(
+    "number.  To specify a particular image format, precede the filename\n");
+  (void) printf(
+    "with an image format name and a colon (i.e. ps:image) or specify the\n");
+  (void) printf(
+    "image type as the filename suffix (i.e. image.ps).  Specify 'file' as\n");
+  (void) printf("'-' for standard input or output.\n");
   exit(0);
 }
 
@@ -297,7 +306,7 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
               char
                 *text;
 
-              text=InterpretImageAttributes(image_info,image,format);
+              text=InterpretImageProperties(image_info,image,format);
               if (text == (char *) NULL)
                 {
                   char
