@@ -102,72 +102,76 @@ static void ImportUsage(void)
     **p;
 
   static const char
-    *options[]=
+    *operators[]=
     {
-      "-adjoin              join images into a single multi-image file",
       "-annotate geometry text",
       "                     annotate the image with text",
       "-border              include image borders in the output image",
-      "-channel type        apply option to select image channels",
       "-colors value        preferred number of colors in the image",
+      "-crop geometry       preferred size and location of the cropped image",
+      "-geometry geometry   perferred size or location of the image",
+      "-help                print program options",
+      "-monochrome          transform image to black and white",
+      "-negate              replace every pixel with its complementary color ",
+      "-repage geometry     size and location of an image canvas",
+      "-quantize colorspace reduce colors in this colorspace",
+      "-resize geometry     resize the image",
+      "-rotate degrees      apply Paeth rotation to the image",
+      "-strip               strip image of all profiles and comments",
+      "-thumbnail geometry  create a thumbnail of the image",
+      "-transparent color   make this color transparent within the image",
+      "-trim                trim image edges",
+      "-type type           image type",
+      "-version             print version information",
+      (char *) NULL
+    },
+    *settings[]=
+    {
+      "-adjoin              join images into a single multi-image file",
+      "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
       "-comment string      annotate image with comment",
       "-compress type       type of pixel compression when writing the image",
-      "-crop geometry       preferred size and location of the cropped image",
       "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
-      "-delay value         display the next image after pausing",
       "-density geometry    horizontal and vertical density of the image",
       "-depth value         image depth",
       "-descend             obtain image by descending window hierarchy",
       "-display server      X server to contact",
       "-dispose method      GIF disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
-      "-encoding type       text encoding type",
+      "-delay value         display the next image after pausing",
       "-endian type         endianness (MSB or LSB) of the image",
+      "-encoding type       text encoding type",
       "-format \"string\"     output formatted image characteristics",
       "-frame               include window manager frame",
-      "-geometry geometry   perferred size or location of the image",
       "-gravity direction   which direction to gravitate towards",
-      "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-interlace type      None, Line, Plane, or Partition",
       "-interpolate method  pixel color interpolation method",
-      "-label name          assign a label to an image",
+      "-label string        assign a label to an image",
       "-limit type value    Area, Disk, Map, or Memory resource limit",
       "-log format          format of debugging information",
       "-monitor             monitor progress",
-      "-monochrome          transform image to black and white",
-      "-negate              replace every pixel with its complementary color ",
       "-page geometry       size and location of an image canvas",
       "-pause value         seconds delay between snapshots",
       "-pointsize value     font point size",
       "-quality value       JPEG/MIFF/PNG compression level",
-      "-quantize colorspace reduce colors in this colorspace",
       "-quiet               suppress all error or warning messages",
       "-regard-warnings     pay attention to warning messages",
-      "-repage geometry     size and location of an image canvas",
-      "-resize geometry     resize the image",
-      "-rotate degrees      apply Paeth rotation to the image",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
       "-screen              select image from root window",
-      "-set attribute value set an image attribute",
+      "-set property value  set an image property",
       "-silent              operate silently, i.e. don't ring any bells ",
       "-snaps value         number of screen snapshots",
-      "-strip               strip image of all profiles and comments",
       "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
-      "-thumbnail geometry  create a thumbnail of the image",
-      "-transparent color   make this color transparent within the image",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
-      "-trim                trim image edges",
-      "-type type           image type",
       "-verbose             print detailed information about the image",
-      "-version             print version information",
       "-virtual-pixel method",
       "                     Constant, Edge, Mirror, or Tile",
       "-window id           select window with this id or name",
@@ -178,8 +182,11 @@ static void ImportUsage(void)
   (void) printf("Copyright: %s\n\n",GetMagickCopyright());
   (void) printf("Usage: %s [options ...] [ file ]\n",
     GetClientName());
-  (void) printf("\nWhere options include:\n");
-  for (p=options; *p != (char *) NULL; p++)
+  (void) printf("\nImage Settings:\n");
+  for (p=settings; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nImage Operators:\n");
+  for (p=operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
   (void) printf(
   "\nBy default, 'file' is written in the MIFF image format.  To\n");
